@@ -11,7 +11,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.boaddressbook.inc.php,v 1.46.2.1 2004/10/06 09:11:40 wolffc Exp $ */
+  /* $Id: class.boaddressbook.inc.php 21829 2006-06-14 14:57:22Z ralfbecker $ */
 
 	class boaddressbook
 	{
@@ -23,7 +23,7 @@
 			'add_vcard'       => True,
 			'add_email'       => True,
 			'update_entry'    => True,
-			'delete_entry'    => True,
+			'delete_entry'    => True
 		);
 
 		var $xml_functions  = array();
@@ -56,7 +56,7 @@
 			'customfields' => array(
 				'in' => array('array'),
 				'out'=> array('struct')
-			),
+			)
 		);
 
 		var $debug = False;
@@ -194,13 +194,13 @@
 			if($this->use_session)
 			{
 				if($this->debug) { echo '<br>Save:'; _debug_array($data); }
-				$GLOBALS['phpgw']->session->appsession('session_data','addressbook',$data);
+				$GLOBALS['egw']->session->appsession('session_data','addressbook',$data);
 			}
 		}
 
 		function read_sessiondata()
 		{
-			$data = $GLOBALS['phpgw']->session->appsession('session_data','addressbook');
+			$data = $GLOBALS['egw']->session->appsession('session_data','addressbook');
 			if($this->debug) { echo '<br>Read:'; _debug_array($data); }
 
 			$this->start  = $data['start'];
@@ -227,12 +227,12 @@
 				{
 					foreach($dirty[$i] as $name => $value)
 					{
-						$cleaned[$i][$name] = $GLOBALS['phpgw']->strip_html($dirty[$i][$name]);
+						$cleaned[$i][$name] = $GLOBALS['egw']->strip_html($dirty[$i][$name]);
 					}
 				}
 				else
 				{
-					$cleaned[$i] == $GLOBALS['phpgw']->strip_html($dirty[$i]);
+					$cleaned[$i] == $GLOBALS['egw']->strip_html($dirty[$i]);
 				}
 			}
 			return $cleaned;
@@ -247,27 +247,27 @@
 		// return array with all addressbook customfields (for xmlrpc)
 		function customfields($new_fields=False)
 		{
-			$fields = CreateObject('addressbook.uifields',True);	// no extra bo-class
+			$fields = CreateObject('addressbook.bofields');
 
-			if (is_array($new_fields) && count($new_fields))
+			if(is_array($new_fields) && count($new_fields))
 			{
-				if (!$GLOBALS['phpgw_info']['user']['apps']['admin'])
+				if(!$GLOBALS['egw_info']['user']['apps']['admin'])
 				{
 					$GLOBALS['server']->xmlrpc_error($GLOBALS['xmlrpcerr']['no_access'],$GLOBALS['xmlrpcstr']['no_access']);
 				}
 				foreach($new_fields as $new)
 				{
-					$fields->save_custom_field('',$new);
+					$fields->_save('',$new);
 				}
 			}
 			$customfields = array();
-			foreach($fields->read_custom_fields() as $data)
+			foreach($fields->_read() as $data)
 			{
 				$customfields[$data['name']] = $data['title'];
 			}
-			if ($this->xmlrpc && !isset($customfields['freebusy_url']))
+			if($this->xmlrpc && !isset($customfields['freebusy_url']))
 			{
-				$fields->save_custom_field('','freebusy URL');
+				$fields->_save('','freebusy URL');
 				$customfields['freebusy_url'] = 'freebusy URL';
 			}
 			return $customfields;
@@ -276,14 +276,14 @@
 		// translate array of internal datas to xmlrpc, eg. format bday as iso8601
 		function data2xmlrpc($datas)
 		{
-			if (is_array($datas))
+			if(is_array($datas))
 			{
 				foreach($datas as $n => $data)
 				{
 					// translate birthday to a iso8601 date
-					if (isset($data['bday']))
+					if(isset($data['bday']))
 					{
-						if (strlen($data['bday']) > 2)
+						if(strlen($data['bday']) > 2)
 						{
 							list($m,$d,$y) = explode('/',$data['bday']);
 						}
@@ -294,12 +294,12 @@
 						$datas[$n]['bday'] = $GLOBALS['server']->date2iso8601(array('year'=>$y,'month'=>$m,'mday'=>$d));
 					}
 					// translate modification time
-					if (isset($data['last_mod']))
+					if(isset($data['last_mod']))
 					{
 						$datas[$n]['last_mod'] = $GLOBALS['server']->date2iso8601($data['last_mod']);
 					}
 					// translate categories-id-list to array with id-name pairs
-					if (isset($data['cat_id']))
+					if(isset($data['cat_id']))
 					{
 						$datas[$n]['cat_id'] = $GLOBALS['server']->cats2xmlrpc(explode(',',$data['cat_id']));
 					}
@@ -311,16 +311,16 @@
 		// retranslate from xmlrpc / iso8601 to internal format
 		function xmlrpc2data($data)
 		{
-			if (isset($data['bday']))
+			if(isset($data['bday']))
 			{
 				$arr = $GLOBALS['server']->iso86012date($data['bday']);
 				$data['bday'] = $arr['year'] && $arr['month'] && $arr['mday'] ? sprintf('%d/%02d/%04d',$arr['month'],$arr['mday'],$arr['year']) : '';
 			}
-			if (isset($data['last_mod']))
+			if(isset($data['last_mod']))
 			{
 				$data['last_mod']  = $GLOBALS['server']->iso86012date($data['last_mod'],True);
 			}
-			if (isset($data['cat_id']))
+			if(isset($data['cat_id']))
 			{
 				$cats = $GLOBALS['server']->xmlrpc2cats($data['cat_id']);
 				$data['cat_id'] = count($cats) > 1 ? ','.implode(',',$cats).',' : (int)$cats[0];
@@ -332,19 +332,19 @@
 		function user_pseudo_entry($account)
 		{
 			static $prefs=False;
-			if (!is_object($prefs))
+			if(!is_object($prefs))
 			{
 				$prefs = CreateObject('phpgwapi.preferences');	// wie need a new copy, as wie change the user
 			}
-			if (!is_array($account))
+			if(!is_array($account))
 			{
-				$GLOBALS['phpgw']->accounts->account_id = $account;
-				$account = $GLOBALS['phpgw']->accounts->read_repository();
+				$GLOBALS['egw']->accounts->account_id = $account;
+				$account = $GLOBALS['egw']->accounts->read_repository();
 			}
 			$prefs->account_id = $account['account_id'];
 			$prefs->read_repository();
-			$freebusy_url = $GLOBALS['phpgw_info']['server']['webserver_url'].'/calendar/freebusy.php?user='.$account['account_lid'];
-			if ($freebusy_url[0] == '/')
+			$freebusy_url = $GLOBALS['egw_info']['server']['webserver_url'].'/calendar/freebusy.php?user='.$account['account_lid'];
+			if($freebusy_url[0] == '/')
 			{
 				$freebusy_url = ($_SERVER['HTTPS'] ? 'https://' : 'http://').$_SERVER['HTTP_HOST'].$freebusy_url;
 			}
@@ -353,7 +353,7 @@
 			$ret = array(
 				'n_family' => $lastname,
 				'n_given'  => $firstname,
-				'fn'       => $GLOBALS['phpgw']->common->display_fullname($account['account_lid'],$firstname,$lastname),
+				'fn'       => $GLOBALS['egw']->common->display_fullname($account['account_lid'],$firstname,$lastname),
 				'email'    => $prefs->email_address($account['account_id']),
 				'freebusy_url' => $freebusy_url,
 				'rights'   => PHPGW_ACL_READ,	// readonly access
@@ -367,17 +367,17 @@
 		function get_users($type='all')
 		{
 			$users = array();
-			switch ($type)
+			switch($type)
 			{
 				case 'all':			// all
-					$accounts = $GLOBALS['phpgw']->accounts->get_list('accounts');
+					$accounts = $GLOBALS['egw']->accounts->get_list('accounts');
 					break;
 				case 'calendar':	// Calendar users
-					$accounts = $GLOBALS['phpgw']->acl->get_ids_for_location('run',1,'calendar');
+					$accounts = $GLOBALS['egw']->acl->get_ids_for_location('run',1,'calendar');
 					break;
 				case 'groupmates':	// Groupmates
 					$accounts = array();
-					foreach($GLOBALS['phpgw']->accounts->membership() as $group)
+					foreach($GLOBALS['egw']->accounts->membership() as $group)
 					{
 						$accounts[] = $group['account_id'];
 					}
@@ -385,12 +385,12 @@
 			}
 			foreach($accounts as $key => $account)
 			{
-				if ($type == 'calendar' && $GLOBALS['phpgw']->accounts->get_type($account) == 'g' || $type == 'groupmates')
+				if($type == 'calendar' && $GLOBALS['egw']->accounts->get_type($account) == 'g' || $type == 'groupmates')
 				{
 					// $account is a group
 					unset($accounts[$key]);
-					$members = $GLOBALS['phpgw']->accounts->member($account);
-					if (is_array($members))
+					$members = $GLOBALS['egw']->accounts->member($account);
+					if(is_array($members))
 					{
 						foreach($members as $member)
 						{
@@ -399,7 +399,7 @@
 					}
 				}
 			}
-			if ($type != 'all')
+			if($type != 'all')
 			{
 				$accounts = array_unique($accounts);	// remove doubles
 			}
@@ -413,24 +413,26 @@
 
 		function read_entries($data)
 		{
-			if ($this->xmlrpc && !isset($data['fields']))
+			if($this->xmlrpc && !isset($data['fields']))
 			{
 				$data['fields'] = array_keys(array_merge($this->so->contacts->non_contact_fields,$this->so->contacts->stock_contact_fields,$this->customfields()));
 			}
 			$entries = $this->so->read_entries($data);
 			$this->total = $this->so->contacts->total_records;
-			if (!is_array($entries))
+			if(!is_array($entries))
 			{
 				$entries = array();
 			}
-			$entries = $this->strip_html($entries);
-
+			else
+			{
+				$entries = $this->strip_html($entries);
+			}
 			// evtl. get uses as read-only addressbook entries, just with Name, Firstname, Email
-			if (@$data['include_users'])
+			if(@$data['include_users'])
 			{
 				$entries = array_merge($entries,$this->get_users($data['include_users']));
 			}
-			if ($this->xmlrpc)
+			if($this->xmlrpc)
 			{
 				$entries = $this->data2xmlrpc($entries);
 			}
@@ -440,14 +442,14 @@
 
 		function read_entry($data)
 		{
-			if ($this->xmlrpc && !isset($data['fields']))
+			if($this->xmlrpc && !isset($data['fields']))
 			{
 				$data['fields'] = array_keys(array_merge($this->so->contacts->non_contact_fields,$this->so->contacts->stock_contact_fields,$this->customfields()));
 			}
-			if ($data['id'] < 0)
+			if($data['id'] < 0)
 			{
 				$entry = array($this->user_pseudo_entry(-$data['id']));
-				if ($this->xmlrpc)
+				if($this->xmlrpc)
 				{
 					$entry = $this->data2xmlrpc($entry);
 				}
@@ -457,13 +459,13 @@
 			{
 				$entry = $this->so->read_entry($data['id'],$data['fields']);
 				$entry = $this->strip_html($entry);
-				if ($this->xmlrpc)
+				if($this->xmlrpc)
 				{
 					$entry = $this->data2xmlrpc($entry);
 				}
 				return $entry;
 			}
-			if ($this->xmlrpc)
+			if($this->xmlrpc)
 			{
 				$GLOBALS['server']->xmlrpc_error($GLOBALS['xmlrpcerr']['no_access'],$GLOBALS['xmlrpcstr']['no_access']);
 			}
@@ -476,13 +478,13 @@
 			{
 				$entry = $this->so->read_last_entry($fields);
 				$entry = $this->strip_html($entry);
-				if ($this->xmlrpc)
+				if($this->xmlrpc)
 				{
 					$entry = $this->data2xmlrpc($entry);
 				}
 				return $entry;
 			}
-			if ($this->xmlrpc)
+			if($this->xmlrpc)
 			{
 				$GLOBALS['server']->xmlrpc_error($GLOBALS['xmlrpcerr']['no_access'],$GLOBALS['xmlrpcstr']['no_access']);
 			}
@@ -502,7 +504,7 @@
 				$vcard = CreateObject('phpgwapi.vcard');
 				$entry = $vcard->in_file($filename);
 				/* _debug_array($entry);exit; */
-				$entry['owner'] = (int)$GLOBALS['phpgw_info']['user']['account_id'];
+				$entry['owner'] = (int)$GLOBALS['egw_info']['user']['account_id'];
 				$entry['access'] = 'private';
 				$entry['tid'] = 'n';
 				/* _debug_array($entry);exit; */
@@ -534,11 +536,11 @@
 			$fields['email']    = $add_email;
 			$referer = urlencode($referer);
 
-			$this->so->add_entry($GLOBALS['phpgw_info']['user']['account_id'],$fields,'private','','n');
+			$this->so->add_entry($GLOBALS['egw_info']['user']['account_id'],$fields,'private','','n');
 			$ab_id = $this->get_lastid();
 
 			Header('Location: '
-				. $GLOBALS['phpgw']->link('/index.php',"menuaction=addressbook.uiaddressbook.view&ab_id=$ab_id&referer=$referer"));
+				. $GLOBALS['egw']->link('/index.php',"menuaction=addressbook.uiaddressbook.view&ab_id=$ab_id&referer=$referer"));
 		}
 
 		function add_entry($fields)
@@ -551,19 +553,24 @@
 			}
 			if(!@$fields['owner'])
 			{
-				$fields['owner'] = (int)$GLOBALS['phpgw_info']['user']['account_id'];
+				$fields['owner'] = (int)$GLOBALS['egw_info']['user']['account_id'];
 			}
 			if(empty($fields['access']))
 			{
 				$fields['access'] = 'public';
 			}
-			if ($this->xmlrpc)
+			if($this->xmlrpc)
 			{
 				$fields = $this->xmlrpc2data($fields);
 			}
 			$id = $this->so->add_entry($fields);
+			
+			if($id)
+			{
+				$GLOBALS['egw']->contenthistory->updateTimeStamp('contacts', $id, 'add', time());
+			}
 
-			if ($this->xmlrpc && !$id)
+			if($this->xmlrpc && !$id)
 			{
 				$GLOBALS['server']->xmlrpc_error($GLOBALS['xmlrpcerr']['no_access'],$GLOBALS['xmlrpcstr']['no_access']);
 			}
@@ -577,20 +584,24 @@
 
 		function update_entry($fields)
 		{
-			if (!$fields['id'] && !$fields['ab_id'])
+			if(!$fields['id'] && !$fields['ab_id'])
 			{
 				return $this->add_entry($fields);
 			}
 			$ok = False;
 			if($this->check_perms($fields,PHPGW_ACL_EDIT))
 			{
-				if ($this->xmlrpc)
+				if($this->xmlrpc)
 				{
 					$fields = $this->xmlrpc2data($fields);
 				}
 				$ok = $this->so->update_entry($fields);
+				if($ok)
+				{
+					$GLOBALS['egw']->contenthistory->updateTimeStamp('contacts', $fields['ab_id'], 'modify', time());
+				}
 			}
-			if ($this->xmlrpc && !$ok)
+			if($this->xmlrpc && !$ok)
 			{
 				$GLOBALS['server']->xmlrpc_error($GLOBALS['xmlrpcerr']['no_access'],$GLOBALS['xmlrpcstr']['no_access']);
 			}
@@ -617,8 +628,9 @@
 			if($this->check_perms($id,PHPGW_ACL_DELETE))
 			{
 				$this->so->delete_entry($id);
+				$GLOBALS['egw']->contenthistory->updateTimeStamp('contacts', $id, 'delete', time());
 			}
-			elseif ($this->xmlrpc)
+			elseif($this->xmlrpc)
 			{
 				$GLOBALS['server']->xmlrpc_error($GLOBALS['xmlrpcerr']['no_access'],$GLOBALS['xmlrpcstr']['no_access']);
 			}
@@ -636,14 +648,14 @@
 		{
 			$id = (int) (!is_array($addr) ? $addr : (isset($addr['id']) ? $addr['id'] : $addr['ab_id']));
 
-			if ($id < 0)
+			if($id < 0)
 			{
 				return $rights == PHPGW_ACL_READ;
 			}
-			if (!is_array($addr) || !isset($addr['rights']) && !isset($addr['owner']))
+			if(!is_array($addr) || !isset($addr['rights']) && !isset($addr['owner']))
 			{
 				$addr = $this->so->read_entry($id,array('owner'));
-				if (!$addr && $this->xmlrpc)
+				if(!$addr && $this->xmlrpc)
 				{
 					$GLOBALS['server']->xmlrpc_error($GLOBALS['xmlrpcerr']['not_exist'],$GLOBALS['xmlrpcstr']['not_exist']);
 				}
@@ -656,7 +668,7 @@
 
 		function save_preferences($prefs,$other,$qfields,$fcat_id)
 		{
-			$GLOBALS['phpgw']->preferences->read_repository();
+			$GLOBALS['egw']->preferences->read_repository();
 			if(is_array($prefs))
 			{
 				/* _debug_array($prefs);exit; */
@@ -665,39 +677,39 @@
 					/* echo '<br>checking: ' . $pref . '=' . $prefs[$pref]; */
 					if($prefs[$pref] == 'on')
 					{
-						$GLOBALS['phpgw']->preferences->add('addressbook',$pref,'addressbook_on');
+						$GLOBALS['egw']->preferences->add('addressbook',$pref,'addressbook_on');
 					}
 					else
 					{
-						$GLOBALS['phpgw']->preferences->delete('addressbook',$pref);
+						$GLOBALS['egw']->preferences->delete('addressbook',$pref);
 					}
 				}
 			}
 			if(is_array($other))
 			{
-				$GLOBALS['phpgw']->preferences->delete('addressbook','mainscreen_showbirthdays');
+				$GLOBALS['egw']->preferences->delete('addressbook','mainscreen_showbirthdays');
 				if($other['mainscreen_showbirthdays'])
 				{
-					$GLOBALS['phpgw']->preferences->add('addressbook','mainscreen_showbirthdays',True);
+					$GLOBALS['egw']->preferences->add('addressbook','mainscreen_showbirthdays',True);
 				}
 
-				$GLOBALS['phpgw']->preferences->delete('addressbook','default_filter');
+				$GLOBALS['egw']->preferences->delete('addressbook','default_filter');
 				if($other['default_filter'])
 				{
-					$GLOBALS['phpgw']->preferences->add('addressbook','default_filter',$other['default_filter']);
+					$GLOBALS['egw']->preferences->add('addressbook','default_filter',$other['default_filter']);
 				}
 
-				$GLOBALS['phpgw']->preferences->delete('addressbook','autosave_category');
+				$GLOBALS['egw']->preferences->delete('addressbook','autosave_category');
 				if($other['autosave_category'])
 				{
-					$GLOBALS['phpgw']->preferences->add('addressbook','autosave_category',True);
+					$GLOBALS['egw']->preferences->add('addressbook','autosave_category',True);
 				}
 			}
 
-			$GLOBALS['phpgw']->preferences->delete('addressbook','default_category');
-			$GLOBALS['phpgw']->preferences->add('addressbook','default_category',$fcat_id);
+			$GLOBALS['egw']->preferences->delete('addressbook','default_category');
+			$GLOBALS['egw']->preferences->add('addressbook','default_category',$fcat_id);
 
-			$GLOBALS['phpgw']->preferences->save_repository(True);
+			$GLOBALS['egw']->preferences->save_repository(True);
 		}
 
 		function list_methods($_type='xmlrpc')
@@ -776,6 +788,5 @@
 					break;
 			}
 		}
-
 	}
 ?>
