@@ -9,11 +9,10 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: index.php,v 1.125 2004/01/25 21:49:43 reinerj Exp $ */
+	/* $Id: index.php 20295 2006-02-15 12:31:25Z  $ */
 
-	$GLOBALS['phpgw_info'] = array();
-
-	$GLOBALS['phpgw_info']['flags'] = array(
+	$GLOBALS['egw_info'] = array();
+	$GLOBALS['egw_info']['flags'] = array(
 		'currentapp' => 'addressbook',
 		'noheader'   => True,
 		'nonavbar'   => True
