@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.boaclmanager.inc.php,v 1.3 2004/01/26 23:22:17 reinerj Exp $ */
+	/* $Id: class.boaclmanager.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	class boaclmanager
 	{
@@ -21,8 +21,8 @@
 
 		function boaclmanager()
 		{
-			//$this->so = createobject('admin.soaclmanager');
-			$this->ui = createobject('admin.uiaclmanager');
+			//$this->so =& CreateObject('admin.soaclmanager');
+			$this->ui =& CreateObject('admin.uiaclmanager');
 		}
 
 		function submit()
@@ -41,7 +41,7 @@
 				$total_rights += $rights;
 			}
 
-			$GLOBALS['phpgw']->acl->add_repository($GLOBALS['acl_app'], $location, $GLOBALS['account_id'], $total_rights);
+			$GLOBALS['egw']->acl->add_repository($GLOBALS['acl_app'], $location, $GLOBALS['account_id'], $total_rights);
 
 			$this->ui->list_apps();
 		}
