@@ -10,12 +10,12 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: hook_admin.inc.php,v 1.11 2004/01/25 21:31:48 reinerj Exp $ */
+	/* $Id: hook_admin.inc.php 19419 2005-10-14 16:24:39Z ralfbecker $ */
 
 	$title = $appname;
 	$file = Array(
-		'Site Configuration' => $GLOBALS['phpgw']->link('/index.php','menuaction=admin.uiconfig.index&appname=' . $appname),
-		'Global Categories' => $GLOBALS['phpgw']->link('/index.php','menuaction=admin.uicategories.index&appname=bookmarks')
+		'Site Configuration' => $GLOBALS['egw']->link('/index.php','menuaction=admin.uiconfig.index&appname=' . $appname),
+		'Global Categories' => $GLOBALS['egw']->link('/index.php','menuaction=admin.uicategories.index&appname=bookmarks')
 	);
 
 	display_section($appname,$title,$file);
