@@ -1,7 +1,7 @@
 <?php
 	/**************************************************************************\
-	* eGroupWare - Bookmarks                                                 *
-	* http://www.egroupware.org                                              *
+	* eGroupWare - Bookmarks                                                   *
+	* http://www.egroupware.org                                                *
 	* Based on Bookmarker Copyright (C) 1998  Padraic Renaghan                 *
 	*                     http://www.renaghan.com/bookmarker                   *
 	* --------------------------------------------                             *
@@ -11,17 +11,17 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: index.php,v 1.19 2004/01/25 21:32:43 reinerj Exp $ */
+	/* $Id: index.php 20295 2006-02-15 12:31:25Z  $ */
 
-	$GLOBALS['phpgw_info']['flags'] = array(
-		'currentapp' => 'bookmarks',
-		'nonavbar'   => True,
-		'noheader' => True
+	$GLOBALS['egw_info'] = array(
+		'flags' => array(
+			'currentapp' => 'bookmarks',
+			'nonavbar'   => True,
+			'noheader'   => True
+		)
 	);
 	include('../header.inc.php');
 
-	$obj = createobject('bookmarks.ui');
+	$obj =& CreateObject('bookmarks.ui');
 	$obj->init();
-	$GLOBALS['phpgw']->common->phpgw_footer();
-
-?>
+	$GLOBALS['egw']->common->egw_footer();
