@@ -1,60 +1,58 @@
 <?php
-  /**************************************************************************\
-  * eGroupWare - Calendar: CSV - Import                                      *
-  * http://www.egroupware.org                                                *
-  * Written by Ralf Becker <RalfBecker@outdoor-training.de>                  *
-  * --------------------------------------------                             *
-  *  This program is free software; you can redistribute it and/or modify it *
-  *  under the terms of the GNU General Public License as published by the   *
-  *  Free Software Foundation; either version 2 of the License, or (at your  *
-  *  option) any later version.                                              *
-  \**************************************************************************/
+	/**************************************************************************\
+	* eGroupWare - Calendar: CSV - Import                                      *
+	* http://www.egroupware.org                                                *
+	* Written by Ralf Becker <RalfBecker@outdoor-training.de>                  *
+	* --------------------------------------------                             *
+	*  This program is free software; you can redistribute it and/or modify it *
+	*  under the terms of the GNU General Public License as published by the   *
+	*  Free Software Foundation; either version 2 of the License, or (at your  *
+	*  option) any later version.                                              *
+	\**************************************************************************/
 
-  /* $Id: csv_import.php,v 1.8.2.2 2005/03/10 06:53:38 ralfbecker Exp $ */
+	/* $Id: csv_import.php 20604 2006-03-17 21:11:44Z ralfbecker $ */
 
-	$GLOBALS['phpgw_info']['flags'] = array(
+	$GLOBALS['egw_info']['flags'] = array(
 		'currentapp' => 'calendar',
 		'noheader'   => True
 	);
 	include('../header.inc.php');
 
-	if (!isset($GLOBALS['phpgw_info']['user']['apps']['admin']) ||
-	    !$GLOBALS['phpgw_info']['user']['apps']['admin'])		// no admin
-	{
-		$GLOBALS['phpgw']->redirect_link('/home.php');
-	}
+	$is_admin = isset($GLOBALS['egw_info']['user']['apps']['admin']) && $GLOBALS['egw_info']['user']['apps']['admin'];
+
 	if (isset($_FILES['csvfile']['tmp_name']))
 	{
-		$csvfile = tempnam($GLOBALS['phpgw_info']['server']['temp_dir'],$GLOBALS['phpgw_info']['flags']['currentapp']."_");
-		$GLOBALS['phpgw']->session->appsession('csvfile','',$csvfile);
+		$csvfile = tempnam($GLOBALS['egw_info']['server']['temp_dir'],$GLOBALS['egw_info']['flags']['currentapp']."_");
+		$GLOBALS['egw']->session->appsession('csvfile','',$csvfile);
 		$_POST['action'] = move_uploaded_file($_FILES['csvfile']['tmp_name'],$csvfile) ?
 			'download' : '';
 	}
 	else
 	{
-		$csvfile = $GLOBALS['phpgw']->session->appsession('csvfile');
+		$csvfile = $GLOBALS['egw']->session->appsession('csvfile');
 	}
 	if ($_POST['cancel'])
 	{
 		@unlink($csvfile);
-		$GLOBALS['phpgw']->redirect_link('/admin/index.php');
+		$GLOBALS['egw']->redirect_link('/admin/index.php');
 	}
-	$GLOBALS['phpgw_info']['flags']['app_header'] = $GLOBALS['phpgw_info']['apps']['calendar']['title'].' - '.lang('Import CSV-File');
-	$GLOBALS['phpgw']->common->phpgw_header();
+	$GLOBALS['egw_info']['flags']['app_header'] = $GLOBALS['egw_info']['apps']['calendar']['title'].' - '.lang('Import CSV-File');
+	$cal =& CreateObject('calendar.uical',true);
+	$GLOBALS['egw']->common->egw_header();
 
-	$GLOBALS['phpgw']->template->set_file(array('import_t' => 'csv_import.tpl'));
-	$GLOBALS['phpgw']->template->set_block('import_t','filename','filenamehandle');
-	$GLOBALS['phpgw']->template->set_block('import_t','fheader','fheaderhandle');
-	$GLOBALS['phpgw']->template->set_block('import_t','fields','fieldshandle');
-	$GLOBALS['phpgw']->template->set_block('import_t','ffooter','ffooterhandle');
-	$GLOBALS['phpgw']->template->set_block('import_t','imported','importedhandle');
-	$GLOBALS['phpgw']->template->set_block('import_t','import','importhandle');
+	$GLOBALS['egw']->template->set_file(array('import_t' => 'csv_import.tpl'));
+	$GLOBALS['egw']->template->set_block('import_t','filename','filenamehandle');
+	$GLOBALS['egw']->template->set_block('import_t','fheader','fheaderhandle');
+	$GLOBALS['egw']->template->set_block('import_t','fields','fieldshandle');
+	$GLOBALS['egw']->template->set_block('import_t','ffooter','ffooterhandle');
+	$GLOBALS['egw']->template->set_block('import_t','imported','importedhandle');
+	$GLOBALS['egw']->template->set_block('import_t','import','importhandle');
 
 	if(($_POST['action'] == 'download' || $_POST['action'] == 'continue') && (!$_POST['fieldsep'] || !$csvfile || !($fp=fopen($csvfile,'rb'))))
 	{
 		$_POST['action'] = '';
 	}
-	$GLOBALS['phpgw']->template->set_var("action_url",$GLOBALS['phpgw']->link("/calendar/csv_import.php"));
+	$GLOBALS['egw']->template->set_var("action_url",$GLOBALS['egw']->link("/calendar/csv_import.php"));
 
 	$PSep = '||'; // Pattern-Separator, separats the pattern-replacement-pairs in trans
 	$ASep = '|>'; // Assignment-Separator, separats pattern and replacesment
@@ -64,7 +62,7 @@
 
 	function addr_id( $n_family,$n_given,$org_name )
 	{		// find in Addressbook, at least n_family AND (n_given OR org_name) have to match
-		$contacts = createobject('phpgwapi.contacts');
+		$contacts =& CreateObject('phpgwapi.contacts');
 
 		$addrs = $contacts->read(0,0,array('id'),'',"n_family=$n_family,n_given=$n_given,org_name=$org_name");
 		if(!count($addrs))
@@ -101,73 +99,68 @@
 			}
 			else
 			{
-				if (!is_object($GLOBALS['phpgw']->categories))
+				if (!is_object($GLOBALS['egw']->categories))
 				{
-					$GLOBALS['phpgw']->categories = createobject('phpgwapi.categories');
+					$GLOBALS['egw']->categories =& CreateObject('phpgwapi.categories','','calendar');
 				}
-				if (is_numeric($cat) && $GLOBALS['phpgw']->categories->id2name($cat) != '--')
+				if (is_numeric($cat) && $GLOBALS['egw']->categories->id2name($cat) != '--')
 				{
 					$cat2id[$cat] = $ids[$cat] = $cat;
 				}	
-				elseif ($id = $GLOBALS['phpgw']->categories->name2id( addslashes($cat) ))
+				elseif ($id = $GLOBALS['egw']->categories->name2id( addslashes($cat) ))
 				{	// cat exists
 					$cat2id[$cat] = $ids[$cat] = $id;
 				}
 				else
 				{	// create new cat
-					$GLOBALS['phpgw']->categories->add( array('name' => $cat,'descr' => $cat ));
-					$cat2id[$cat] = $ids[$cat] = $GLOBALS['phpgw']->categories->name2id( addslashes($cat) );
+					$GLOBALS['egw']->categories->add( array('name' => $cat,'descr' => $cat ));
+					$cat2id[$cat] = $ids[$cat] = $GLOBALS['egw']->categories->name2id( addslashes($cat) );
 				}
 			}
 		}
-		$id_str = implode( ',',$ids );
-
-		if (count($ids) > 1)		// multiple cats need to be in ','
-		{
-			$id_str = ",$id_str,";
-		}
-		return  $id_str;
+		return implode( ',',$ids );
 	}
 
-	if (!is_object($GLOBALS['phpgw']->html))
+	if (!is_object($GLOBALS['egw']->html))
 	{
-		$GLOBALS['phpgw']->html = CreateObject('phpgwapi.html');
+		$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
 	}
 
 	if ($_POST['next']) $_POST['action'] = 'next';
 	switch ($_POST['action'])
 	{
 	case '':	// Start, ask Filename
-		$GLOBALS['phpgw']->template->set_var('lang_csvfile',lang('CSV-Filename'));
-		$GLOBALS['phpgw']->template->set_var('lang_fieldsep',lang('Fieldseparator'));
-		$GLOBALS['phpgw']->template->set_var('lang_charset',lang('Charset of file'));
-		$GLOBALS['phpgw']->template->set_var('select_charset',
-			$GLOBALS['phpgw']->html->select('charset','',
-			$GLOBALS['phpgw']->translation->get_installed_charsets()+
+		$GLOBALS['egw']->template->set_var('lang_csvfile',lang('CSV-Filename'));
+		$GLOBALS['egw']->template->set_var('lang_fieldsep',lang('Fieldseparator'));
+		$GLOBALS['egw']->template->set_var('lang_charset',lang('Charset of file'));
+		$GLOBALS['egw']->template->set_var('lang_help',lang('Please note: You can configure the field assignments AFTER you uploaded the file.'));
+		$GLOBALS['egw']->template->set_var('select_charset',
+			$GLOBALS['egw']->html->select('charset','',
+			$GLOBALS['egw']->translation->get_installed_charsets()+
 			array('utf-8' => 'utf-8 (Unicode)'),True));
-		$GLOBALS['phpgw']->template->set_var('fieldsep',$_POST['fieldsep'] ? $_POST['fieldsep'] : ',');
-		$GLOBALS['phpgw']->template->set_var('submit',lang('Import'));
-		$GLOBALS['phpgw']->template->set_var('enctype','ENCTYPE="multipart/form-data"');
+		$GLOBALS['egw']->template->set_var('fieldsep',$_POST['fieldsep'] ? $_POST['fieldsep'] : ';');
+		$GLOBALS['egw']->template->set_var('submit',lang('Import'));
+		$GLOBALS['egw']->template->set_var('enctype','ENCTYPE="multipart/form-data"');
 
-		$GLOBALS['phpgw']->template->parse('rows','filename');
+		$GLOBALS['egw']->template->parse('rows','filename');
 		break;
 
 	case 'continue':
 	case 'download':
-		$GLOBALS['phpgw']->preferences->read_repository();
-		$defaults = $GLOBALS['phpgw_info']['user']['preferences']['calendar']['cvs_import'];
+		$GLOBALS['egw']->preferences->read_repository();
+		$defaults = $GLOBALS['egw_info']['user']['preferences']['calendar']['cvs_import'];
 		if (!is_array($defaults))
 		{
 			$defaults = array();
 		}
-		$GLOBALS['phpgw']->template->set_var('lang_csv_fieldname',lang('CSV-Fieldname'));
-		$GLOBALS['phpgw']->template->set_var('lang_info_fieldname',lang('calendar-Fieldname'));
-		$GLOBALS['phpgw']->template->set_var('lang_translation',lang("Translation").' <a href="#help">'.lang('help').'</a>');
-		$GLOBALS['phpgw']->template->set_var('submit',
-			$GLOBALS['phpgw']->html->submit_button('convert','Import') . '&nbsp;'.
-			$GLOBALS['phpgw']->html->submit_button('cancel','Cancel'));
-		$GLOBALS['phpgw']->template->set_var('lang_debug',lang('Test Import (show importable records <u>only</u> in browser)'));
-		$GLOBALS['phpgw']->template->parse('rows','fheader');
+		$GLOBALS['egw']->template->set_var('lang_csv_fieldname',lang('CSV-Fieldname'));
+		$GLOBALS['egw']->template->set_var('lang_info_fieldname',lang('calendar-Fieldname'));
+		$GLOBALS['egw']->template->set_var('lang_translation',lang("Translation").' <a href="#help">'.lang('help').'</a>');
+		$GLOBALS['egw']->template->set_var('submit',
+			$GLOBALS['egw']->html->submit_button('convert','Import') . '&nbsp;'.
+			$GLOBALS['egw']->html->submit_button('cancel','Cancel'));
+		$GLOBALS['egw']->template->set_var('lang_debug',lang('Test Import (show importable records <u>only</u> in browser)'));
+		$GLOBALS['egw']->template->parse('rows','fheader');
 
 		$cal_names = array(
 			'title'		=> 'Title varchar(80)',
@@ -180,18 +173,18 @@
 			'priority'  => 'Priority: 1=Low, 2=Normal, 3=High',
 			'public'	=> 'Access: 1=public, 0=private',
 			'owner'		=> 'Owner: int(11) user-id/-name',
-			'modtime'	=> 'Modification date',
-//			'groups'	=> 'Groups (dont know what this field is for)',
-//			'cal_type'	=> 'cal_type: single_event=E (default) else M',
+			'modified'	=> 'Modification date',
+			'non_blocking' => '0=Event blocks time, 1=Event creates no conflicts',
+			'uid'       => 'Unique Id, allows multiple import to update identical entries',
+//			'recur_type'=> 'Type of recuring event',
 		);
-		$custom_fields = CreateObject('calendar.bocustom_fields');
+		$config =& CreateObject('phpgwapi.config','calendar');
+		$custom_fields = $config->read_repository();
+		unset($config);
 		//echo "custom-fields=<pre>".print_r($custom_fields,True)."</pre>";
-		foreach ($custom_fields->fields as $name => $data)
+		foreach ($custom_fields as $name => $data)
 		{
-			if ($name[0] == '#')	// a custom field ?
-			{
-				$cal_names[$name] = $data['name'].': Custom field, varchar('.$data['length'].')';
-			}
+			$cal_names['#'.$name] = $data['label'].': Custom field ('.$data['type'].')';
 		}
 
 		// the next line is used in the help-text too
@@ -200,41 +193,41 @@
 		$cal_name_options = "<option value=\"\">none\n";
 		foreach($cal_names as $field => $name)
 		{
-			$cal_name_options .= "<option value=\"$field\">".$GLOBALS['phpgw']->strip_html($name)."\n";
+			$cal_name_options .= "<option value=\"$field\">".$GLOBALS['egw']->strip_html($name)."\n";
 		}
 		$csv_fields = fgetcsv($fp,8000,$_POST['fieldsep']);
-		$csv_fields = $GLOBALS['phpgw']->translation->convert($csv_fields,$_POST['charset']);
+		$csv_fields = $GLOBALS['egw']->translation->convert($csv_fields,$_POST['charset']);
 		$csv_fields[] = 'no CSV 1';					// eg. for static assignments
 		$csv_fields[] = 'no CSV 2';
 		$csv_fields[] = 'no CSV 3';
 		foreach($csv_fields as $csv_idx => $csv_field)
 		{
-			$GLOBALS['phpgw']->template->set_var('csv_field',$csv_field);
-			$GLOBALS['phpgw']->template->set_var('csv_idx',$csv_idx);
+			$GLOBALS['egw']->template->set_var('csv_field',$csv_field);
+			$GLOBALS['egw']->template->set_var('csv_idx',$csv_idx);
 			if ($def = $defaults[$csv_field])
 			{
 				list( $info,$trans ) = explode($PSep,$def,2);
-				$GLOBALS['phpgw']->template->set_var('trans',$trans);
-				$GLOBALS['phpgw']->template->set_var('cal_fields',str_replace('="'.$info.'">','="'.$info.'" selected>',$cal_name_options));
+				$GLOBALS['egw']->template->set_var('trans',$trans);
+				$GLOBALS['egw']->template->set_var('cal_fields',str_replace('="'.$info.'">','="'.$info.'" selected>',$cal_name_options));
 			}
 			else
 			{
-				$GLOBALS['phpgw']->template->set_var('trans','');
-				$GLOBALS['phpgw']->template->set_var('cal_fields',$cal_name_options);
+				$GLOBALS['egw']->template->set_var('trans','');
+				$GLOBALS['egw']->template->set_var('cal_fields',$cal_name_options);
 			}
-			$GLOBALS['phpgw']->template->parse('rows','fields',True);
+			$GLOBALS['egw']->template->parse('rows','fields',True);
 		}
-		$GLOBALS['phpgw']->template->set_var('lang_start',lang('Startrecord'));
-		$GLOBALS['phpgw']->template->set_var('start',get_var('start',array('POST'),1));
+		$GLOBALS['egw']->template->set_var('lang_start',lang('Startrecord'));
+		$GLOBALS['egw']->template->set_var('start',get_var('start',array('POST'),1));
 		$msg = ($safe_mode = ini_get('safe_mode') == 'On') ? lang('to many might exceed your execution-time-limit'):
 			lang('empty for all');
-		$GLOBALS['phpgw']->template->set_var('lang_max',lang('Number of records to read (%1)',$msg));
-		$GLOBALS['phpgw']->template->set_var('max',get_var('max',array('POST'),$safe_mode ? 200 : ''));
-		$GLOBALS['phpgw']->template->set_var('debug',get_var('debug',array('POST'),True)?' checked':'');
-		$GLOBALS['phpgw']->template->parse('rows','ffooter',True);
+		$GLOBALS['egw']->template->set_var('lang_max',lang('Number of records to read (%1)',$msg));
+		$GLOBALS['egw']->template->set_var('max',get_var('max',array('POST'),$safe_mode ? 200 : ''));
+		$GLOBALS['egw']->template->set_var('debug',get_var('debug',array('POST'),True)?' checked':'');
+		$GLOBALS['egw']->template->parse('rows','ffooter',True);
 		fclose($fp);
 
-		$hiddenvars = $GLOBALS['phpgw']->html->input_hidden(array(
+		$hiddenvars = $GLOBALS['egw']->html->input_hidden(array(
 			'action'  => 'import',
 			'fieldsep'=> $_POST['fieldsep'],
 			'charset' => $_POST['charset']
@@ -247,8 +240,8 @@
 			"First example: <b>1${ASep}private${PSep}public</b><br>".
 			"This will translate a '1' in the CVS field to 'privat' and everything else to 'public'.<p>".
 			"Patterns as well as the replacement can be regular expressions (the replacement is done via ereg_replace). ".
-			"If, after all replacements, the value starts with an '@' the whole value is eval()'ed, so you ".
-			"may use all php, phpgw plus your own functions. This is quiet powerfull, but <u>circumvents all ACL</u>.<p>".
+			"If, after all replacements, the value starts with an '@' AND you have admin rights the whole value is eval()'ed, so you ".
+			"may use php, eGroupWare or your own functions. This is quiet powerfull, but <u>circumvents all ACL</u>.<p>".
 			"Example using regular expressions and '@'-eval(): <br><b>$mktime_lotus</b><br>".
 			"It will read a date of the form '2001-05-20 08:00:00.00000000000000000' (and many more, see the regular expr.). ".
 			"The&nbsp;[&nbsp;.:-]-separated fields are read and assigned in different order to @mktime(). Please note to use ".
@@ -269,9 +262,9 @@
 			"with the addressbook.<br>".
 			"<b>@cat_id(Cat1,...,CatN)</b> returns a (','-separated) list with the cat_id's. If a category isn't found, it ".
 			"will be automaticaly added. This function is automaticaly called if the category is not numerical!<p>".
-			"I hope that helped to understand the features, if not <a href='mailto:RalfBecker@outdoor-training.de'>ask</a>.";
+			"I hope that helped to understand the features, if not <a href='mailto:egroupware-users@lists.sf.net'>ask</a>.";
 
-		$GLOBALS['phpgw']->template->set_var('help_on_trans',lang($help_on_trans));	// I don't think anyone will translate this
+		$GLOBALS['egw']->template->set_var('help_on_trans',lang($help_on_trans));	// I don't think anyone will translate this
 		break;
 
 	case 'next':
@@ -279,7 +272,7 @@
 		$_POST['trans']       = unserialize(stripslashes($_POST['trans']));
 		// fall-through
 	case 'import':
-		$hiddenvars = $GLOBALS['phpgw']->html->input_hidden(array(
+		$hiddenvars = $GLOBALS['egw']->html->input_hidden(array(
 			'action'  => 'continue',
 			'fieldsep'=> $_POST['fieldsep'],
 			'charset' => $_POST['charset'],
@@ -292,7 +285,7 @@
 		@set_time_limit(0);
 		$fp=fopen($csvfile,'r');
 		$csv_fields = fgetcsv($fp,8000,$_POST['fieldsep']);
-		$csv_fields = $GLOBALS['phpgw']->translation->convert($csv_fields,$_POST['charset']);
+		$csv_fields = $GLOBALS['egw']->translation->convert($csv_fields,$_POST['charset']);
 		$csv_fields[] = 'no CSV 1';						// eg. for static assignments
 		$csv_fields[] = 'no CSV 2';
 		$csv_fields[] = 'no CSV 3';
@@ -309,11 +302,11 @@
 			}
 		}
 
-		$GLOBALS['phpgw']->preferences->read_repository();
-		$GLOBALS['phpgw']->preferences->add('calendar','cvs_import',$defaults);
-		$GLOBALS['phpgw']->preferences->save_repository(True);
+		$GLOBALS['egw']->preferences->read_repository();
+		$GLOBALS['egw']->preferences->add('calendar','cvs_import',$defaults);
+		$GLOBALS['egw']->preferences->save_repository(True);
 
-		$log = "<table border=1>\n\t<tr><td>#</td>\n";
+		$log = '<table border="1" style="border: 1px dotted black; border-collapse: collapse;">'."\n\t<tr><td>#</td>\n";
 
 		foreach($cal_fields as $csv_idx => $info)
 		{	// convert $trans[$csv_idx] into array of pattern => value
@@ -342,12 +335,12 @@
 		{
 			$log .= "\t\t<td><b>isPublic</b></td>\n";
 		}
-/* maybe later ;-)
-		if (!in_array('cal_type',$cal_fields))	// autocreate single event if not set by user
+/*		if (!in_array('recur_type',$cal_fields))	// autocreate single event if not set by user
 		{
 			$log .= "\t\t<td><b>recureing</b></td>\n";
-		}
-*/
+		}*/
+		$log .= "\t\t<td><b>Imported</b></td>\n\t</tr>\n";
+
 		$start = $_POST['start'] < 1 ? 1 : $_POST['start'];
 
 		// ignore empty lines, is_null($fields[0]) is returned on empty lines !!!
@@ -362,9 +355,9 @@
 			{
 				break;	// EOF
 			}
-			$fields = $GLOBALS['phpgw']->translation->convert($fields,$_POST['charset']);
+			$fields = $GLOBALS['egw']->translation->convert($fields,$_POST['charset']);
 
-			$log .= "\t</tr><tr><td>".($start+$anz)."</td>\n";
+			$log .= "\t<tr>\n\t\t<td>".($start+$anz)."</td>\n";
 
 			$values = array();
 			foreach($cal_fields as $csv_idx => $info)
@@ -377,16 +370,17 @@
 					{
 						if (ereg((string) $pattern,$val))
 						{
-							// echo "<p>csv_idx='$csv_idx',info='$info',trans_csv=".print_r($trans_csv).",ereg_replace('$pattern','$replace','$val') = ";
+							//echo "<p>csv_idx='$csv_idx',info='$info',trans_csv=".print_r($trans_csv).",ereg_replace('$pattern','$replace','$val') = ";
 							$val = ereg_replace((string) $pattern,str_replace($VPre,'\\',$replace),(string) $val);
-							// echo "'$val'</p>";
+							//echo "'$val'";
 
-							$reg = $CPreReg.'([a-zA-Z_0-9]+)'.$CPosReg;
+							$reg = $CPreReg.'([a-zA-Z_0-9 ]+)'.$CPosReg;
 							while (ereg($reg,$val,$vars))
 							{	// expand all CSV fields
 								$val = str_replace($CPre.$vars[1].$CPos,$val[0] == '@' ? "'".addslashes($fields[array_search($vars[1],$csv_fields)])."'" : $fields[array_search($vars[1],$csv_fields)],$val);
 							}
-							if ($val[0] == '@')
+							//echo "='$val'</p>";
+							if ($val[0] == '@' && is_admin)
 							{
 								// removing the $ to close security hole of showing vars, which contain eg. passwords
 								$val = 'return '.substr(str_replace('$','',$val),1).';';
@@ -408,37 +402,23 @@
 				$values['public'] = 1;	// public access if not set by user
 				$log .= "\t\t<td>".$values['public']."</td>\n";
 			}
-/* maybe later ;-)
-			if (!in_array('cal_type',$cal_fields))
+			if (!in_array('recur_type',$cal_fields))
 			{
-				$values['cal_type'] = 'E';	// single event if not set by user
-				$log .= "\t\t<td>".$values['cal_type']."</td>\n";
+				$values['recur_type'] = MCAL_RECUR_NONE;	// single event if not set by user
+//				$log .= "\t\t<td>".$values['recure_type']."</td>\n";
 			}
-*/
+
 			if(!$_POST['debug'] && count($values))	// dont import empty contacts
 			{
 				//echo "values=<pre>".print_r($values,True)."</pre>\n";
 				if (!is_numeric($values['owner']))
 				{
-					$values['owner'] = $GLOBALS['phpgw']->accounts->name2id($values['owner']);
+					$values['owner'] = $GLOBALS['egw']->accounts->name2id($values['owner']);
 				}
-				if (!$values['owner'] || !$GLOBALS['phpgw']->accounts->exists($values['owner']))
+				if (!$values['owner'] || !$GLOBALS['egw']->accounts->exists($values['owner']))
 				{
-					$values['owner'] = $GLOBALS['phpgw_info']['user']['account_id'];
+					$values['owner'] = $GLOBALS['egw_info']['user']['account_id'];
 				}
-				if (!is_object($calendar))
-				{
-					$calendar = createobject('calendar.socalendar',array());
-					$cal_owner = False;
-				}
-				if ($cal_owner != $values['owner'])
-				{
-					$calendar->open_box($cal_owner = $values['owner']);
-				}
-				// echo "<p>adding: ".dump_array($values)."</p>\n";
-				$calendar->event_init();		// set some reasonable defaults
-				$calendar->set_recur_none();
-
 				if ($values['priority'] < 1 || $values['priority'] > 3)
 				{
 					$values['priority'] = 2;
@@ -452,14 +432,9 @@
 				{
 					$values['title'] = '('.lang('none').')';
 				}
-				foreach(array('owner','title','description','location','category','priority','public') as $name)
-				{
-					$calendar->add_attribute($name,$values[$name]);
-				}
 
-				if (!isset($values['modtime'])) $values['modtime'] = $values['start'];
 				// convert dates to timestamps
-				foreach(array('start','end','modtime') as $date)
+				foreach(array('start','end','modified') as $date)
 				{
 					if (isset($values[$date]) && !is_numeric($date))
 					{
@@ -469,58 +444,64 @@
 						if (ereg('(.*)\.[0-9]+',$values[$date],$parts)) $values[$date] = $parts[1];
 						$values[$date] = strtotime($values[$date]);
 					}
-					$datearr = $GLOBALS['phpgw']->datetime->localdates($values[$date]);
-					$calendar->set_date($date,$datearr['year'],$datearr['month'],$datearr['day'],
-						$datearr['hour'],$datearr['minute'],$datearr['second']);
 				}
 				// convert participants-names to user-id's
-				$participants = 0;
-				foreach(split('[,;]',$values['participants']) as $part_status)
+				$parts = $values['participants'] ? split('[,;]',$values['participants']) : array();
+				$values['participants'] = array();
+				foreach($parts as $part_status)
 				{
 					list($part,$status) = explode('=',$part_status);
 					$valid_status = array('U'=>'U','u'=>'U','A'=>'A','a'=>'A','R'=>'R','r'=>'R','T'=>'T','t'=>'T');
 					$status = isset($valid_status[$status]) ? $valid_status[$status] : 'U';
-					if ($GLOBALS['phpgw']->accounts->exists($part))
+					if ($GLOBALS['egw']->accounts->exists($part))
 					{
-						$part = $GLOBALS['phpgw']->accounts->name2id($part);
+						$part = $GLOBALS['egw']->accounts->name2id($part);
 					}
 					if ($part && is_numeric($part))
 					{
-						$calendar->add_attribute('participants',$status,$part);
-						$participants++;
+						$values['participants'][$part] = $status;
 					}
 				}
-				if (!$participants)		// no valid participants so far --> add the importing user/owner
+				if (!count($values['participants']))		// no valid participants so far --> add the importing user/owner
 				{
-					$calendar->add_attribute('participants','A',$values['owner']);
+					$values['participants'][$values['owner']] = 'A';
 				}
-				// add custom-fields
-				foreach($values as $name => $val)
+				if ($values['uid'])
 				{
-					if ($name[0] == '#')
+					if (is_numeric($values['uid']))		// to not conflict with our own id's
 					{
-						$calendar->add_attribute($name,$values[$name]);
+						$values['uid'] = 'cal-csv-import-'.$values['uid'].'-'.$GLOBALS['egw_info']['server']['install_id'];
+					}
+					if (($event = $cal->bo->read($values['uid'],null,$is_admin)))	// no ACL check for admins
+					{
+						//echo "updating existing event"; _debug_array($event);
+						$values['id'] = $event['id'];
 					}
 				}
-				//echo "add_entry(<pre>".print_r($calendar->cal->event,True).")</pre>\n";
-				$calendar->add_entry( $calendar->cal->event );
+				$action = $values['id'] ? 'updating' : 'adding';
+				//echo $action.'<pre>'.print_r($values,True)."</pre>\n";
+				$cal_id = $cal->bo->update($values,true,!$values['modified'],$is_admin);	// ignoring conflicts and ACL (for admins) on import
+				
+				$log .= "\t\t".'<td align="center">'.($cal_id ? $action." cal_id=$cal_id" : 'Error '.$action)."</td>\n\t</tr>\n";
+			}
+			else
+			{
+				$log .= "\t\t".'<td align="center">only test</td>'."\n\t</tr>\n";
 			}
 		}
-		$log .= "\t</tr>\n</table>\n";
+		$log .= "</table>\n";
 
-		$GLOBALS['phpgw']->template->set_var('anz_imported',($_POST['debug'] ?
+		$GLOBALS['egw']->template->set_var('anz_imported',($_POST['debug'] ?
 			lang('%1 records read (not yet imported, you may go back and uncheck Test Import)',
 			$anz,'','') :
 			lang('%1 records imported',$anz)). '&nbsp;'.
-			(!$_POST['debug'] && $fields ? $GLOBALS['phpgw']->html->submit_button('next','Import next set') . '&nbsp;':'').
-			$GLOBALS['phpgw']->html->submit_button('continue','Back') . '&nbsp;'.
-			$GLOBALS['phpgw']->html->submit_button('cancel','Cancel'));
-		$GLOBALS['phpgw']->template->set_var('log',$log);
-		$GLOBALS['phpgw']->template->parse('rows','imported');
+			(!$_POST['debug'] && $fields ? $GLOBALS['egw']->html->submit_button('next','Import next set') . '&nbsp;':'').
+			$GLOBALS['egw']->html->submit_button('continue','Back') . '&nbsp;'.
+			$GLOBALS['egw']->html->submit_button('cancel','Cancel'));
+		$GLOBALS['egw']->template->set_var('log',$log);
+		$GLOBALS['egw']->template->parse('rows','imported');
 		break;
 	}
-	$GLOBALS['phpgw']->template->set_var('hiddenvars',str_replace('{','&#x7B;',$hiddenvars));
-	$GLOBALS['phpgw']->template->pfp('phpgw_body','import');
-	$GLOBALS['phpgw']->common->phpgw_footer();
-
-?>
+	$GLOBALS['egw']->template->set_var('hiddenvars',str_replace('{','&#x7B;',$hiddenvars));
+	$GLOBALS['egw']->template->pfp('phpgw_body','import');
+	$GLOBALS['egw']->common->egw_footer();
