@@ -1,15 +1,15 @@
 <?php
-  /**************************************************************************\
-  * eGroupWare - Translation Editor                                          *
-  * http://www.egroupware.org                                                *
-  * --------------------------------------------                             *
-  *  This program is free software; you can redistribute it and/or modify it *
-  *  under the terms of the GNU General Public License as published by the   *
-  *  Free Software Foundation; either version 2 of the License, or (at your  *
-  *  option) any later version.                                              *
-  \**************************************************************************/
+	/**************************************************************************\
+	* eGroupWare - Translation Editor                                          *
+	* http://www.egroupware.org                                                *
+	* --------------------------------------------                             *
+	*  This program is free software; you can redistribute it and/or modify it *
+	*  under the terms of the GNU General Public License as published by the   *
+	*  Free Software Foundation; either version 2 of the License, or (at your  *
+	*  option) any later version.                                              *
+	\**************************************************************************/
 
-  /* $Id: class.uilangfile.inc.php,v 1.28.2.1 2004/09/08 13:04:25 ralfbecker Exp $ */
+	/* $Id: class.uilangfile.inc.php 19608 2005-11-05 08:51:35Z ralfbecker $ */
 
 	class uilangfile
 	{
@@ -29,17 +29,17 @@
 
 		function uilangfile()
 		{
-			$this->template = $GLOBALS['phpgw']->template;
+			$this->template = $GLOBALS['egw']->template;
 			$this->template->egroupware_hack = False;	// else the phrases got translated
-			$this->bo = CreateObject('developer_tools.bolangfile');
-			$this->nextmatchs = CreateObject('phpgwapi.nextmatchs');
-			$GLOBALS['phpgw']->translation->add_app('developer_tools');
-			$GLOBALS['phpgw']->translation->add_app('common');
-			if (!is_object($GLOBALS['phpgw']->html))
+			$this->bo =& CreateObject('developer_tools.bolangfile');
+			$this->nextmatchs =& CreateObject('phpgwapi.nextmatchs');
+			$GLOBALS['egw']->translation->add_app('developer_tools');
+			$GLOBALS['egw']->translation->add_app('common');
+			if (!is_object($GLOBALS['egw']->html))
 			{
-				$GLOBALS['phpgw']->html = CreateObject('phpgwapi.html');
+				$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
 			}
-			$this->html = $GLOBALS['phpgw']->html;
+			$this->html = $GLOBALS['egw']->html;
 		}
 
 		function addphrase()
@@ -70,7 +70,7 @@
 				}
 				if (!$_POST['more'])
 				{
-					$GLOBALS['phpgw']->redirect_link('/index.php',array(
+					$GLOBALS['egw']->redirect_link('/index.php',array(
 						'menuaction' => 'developer_tools.uilangfile.edit',
 						'app_name'   => $app_name,
 						'sourcelang' => $sourcelang,
@@ -78,24 +78,26 @@
 					));
 				}
 			}
-			$GLOBALS['phpgw_info']['flags']['app_header'] = $GLOBALS['phpgw_info']['apps'][$GLOBALS['phpgw_info']['flags']['currentapp']]['title'].
+			$GLOBALS['egw_info']['flags']['app_header'] = $GLOBALS['egw_info']['apps'][$GLOBALS['egw_info']['flags']['currentapp']]['title'].
 				' - '.lang('Add new phrase');
 
-			$GLOBALS['phpgw']->common->phpgw_header();
+			$GLOBALS['egw']->common->egw_header();
 			echo parse_navbar();
 
-			$this->template->set_file(array('form' => 'addphrase.tpl'));
-			$this->template->set_var('message_id_field','<input size ="40" name="entry[message_id]">');
-			$this->template->set_var('translation_field','<input size ="40" name="entry[content]">');
-			$this->template->set_var('target_field','<input size ="40" name="entry[target]">');
-			$this->template->set_var('app_name','<input type="hidden" name="entry[app_name]" value="'.$app_name.'">');
-
-			$this->template->set_var('form_action',$GLOBALS['phpgw']->link('/index.php','menuaction=developer_tools.uilangfile.addphrase'));
+			$this->template->set_var('form_action',$GLOBALS['egw']->link('/index.php','menuaction=developer_tools.uilangfile.addphrase'));
 			$this->template->set_var('sourcelang',$sourcelang);
 			$this->template->set_var('targetlang',$targetlang);
 			$this->template->set_var('app_name',$app_name);
 
+			$this->template->set_file(array('form' => 'addphrase.tpl'));
+			$this->template->set_var('message_id_field','<input size ="40" name="entry[message_id]">');
+			if ($app_name == 'phpgwapi') $app_name = 'common';
+			$this->template->set_var('app_field',$this->lang_option($app_name,$app_name,'entry[app_name]'));
+			$this->template->set_var('translation_field','<input size ="40" name="entry[content]">');
+			$this->template->set_var('target_field','<input size ="40" name="entry[target]">');
+
 			$this->template->set_var('lang_message_id',lang('message_id in English'));
+			$this->template->set_var('lang_app',lang('Application'));
 			$this->template->set_var('lang_translation',lang('Phrase in English (or empty if identical)'));
 			$this->template->set_var('lang_target',lang('Translation of phrase'));
 			$this->template->set_var('lang_add',lang('Add'));
@@ -117,7 +119,7 @@
 
 			// we have to redirect here, as solangfile defines function sidebox_menu, which clashes with the iDots func.
 			//
-			$GLOBALS['phpgw']->redirect_link('/index.php',array(
+			$GLOBALS['egw']->redirect_link('/index.php',array(
 				'menuaction' => 'developer_tools.uilangfile.missingphrase2',
 				'app_name'   => $app_name,
 				'sourcelang' => $sourcelang,
@@ -175,14 +177,14 @@
 				unset($deleteme);
 
 				$this->bo->save_sessiondata();
-				$GLOBALS['phpgw']->redirect_link('/index.php',array(
+				$GLOBALS['egw']->redirect_link('/index.php',array(
 					'menuaction' => 'developer_tools.uilangfile.edit',
 					'app_name'   => $app_name,
 					'sourcelang' => $sourcelang,
 					'targetlang' => $targetlang
 				));
 			}
-			$GLOBALS['phpgw']->common->phpgw_header();
+			$GLOBALS['egw']->common->egw_header();
 			echo parse_navbar();
 
 			$this->template->set_var('lang_remove',lang('Add phrase'));
@@ -190,20 +192,20 @@
 			$this->template->set_var('lang_update',lang('Add'));
 			$this->template->set_var('lang_view',lang('Cancel'));
 			
-			$this->template->set_var('action_url',$GLOBALS['phpgw']->link('/index.php','menuaction=developer_tools.uilangfile.missingphrase2'));
+			$this->template->set_var('action_url',$GLOBALS['egw']->link('/index.php','menuaction=developer_tools.uilangfile.missingphrase2'));
 			$this->template->set_var('sourcelang',$sourcelang);
 			$this->template->set_var('targetlang',$targetlang);
 			$this->template->set_var('app_name',$app_name);
-			$this->template->set_var('app_title',$GLOBALS['phpgw_info']['apps'][$app_name]['title']);
+			$this->template->set_var('app_title',$GLOBALS['egw_info']['apps'][$app_name]['title']);
 			$this->template->pfp('out','header');
 			if($sourcelang && $targetlang)
 			{
 				$this->template->set_var('lang_appname',lang('Application'));
 				$this->template->set_var('lang_message',lang('Message'));
 				$this->template->set_var('lang_original',lang('Original'));
-				$this->template->set_var('th_bg',$GLOBALS['phpgw_info']['theme']['th_bg']);
+				$this->template->set_var('th_bg',$GLOBALS['egw_info']['theme']['th_bg']);
 				$this->template->set_var('view_link',
-					$GLOBALS['phpgw']->link(
+					$GLOBALS['egw']->link(
 						'/index.php',
 						'menuaction=developer_tools.uilangfile.edit&app_name='.$app_name.'&sourcelang=' . $sourcelang . '&targetlang=' . $targetlang
 					)
@@ -214,7 +216,7 @@
 					$mess_id  = $this->encode_id($key);
 					$this->template->set_var('mess_id',$mess_id);
 					$this->template->set_var('source_content',$this->html->htmlspecialchars($data['content']));
-					$this->template->set_var('transapp',$this->lang_option($app_name,$data['app_name'],$mess_id));
+					$this->template->set_var('transapp',$this->lang_option($app_name,$data['app_name'],"transapp[$mess_id]"));
 					$this->template->set_var('tr_color',$this->nextmatchs->alternate_row_color());
 					$this->template->pfp('out','detail');
 				}
@@ -229,9 +231,8 @@
 		{
 			if ($_POST['cancel'])
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php','menuaction=developer_tools.uilangfile.index');
+				$GLOBALS['egw']->redirect_link('/index.php','menuaction=developer_tools.uilangfile.index');
 			}
-
 			$app_name   = get_var('app_name',array('POST','GET'));
 			$sourcelang = get_var('sourcelang',array('POST','GET'));
 			$targetlang = get_var('targetlang',array('POST','GET'));
@@ -239,7 +240,7 @@
 
 			if($_POST['addphrase'] || $_POST['missingphrase'])
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array(
+				$GLOBALS['egw']->redirect_link('/index.php',array(
 					'menuaction' => 'developer_tools.uilangfile.'.($_POST['addphrase']?'addphrase':'missingphrase'),
 					'app_name'   => $app_name,
 					'sourcelang' => $sourcelang,
@@ -261,7 +262,7 @@
 				$this->download('target',$targetlang);
 			}
 
-			$GLOBALS['phpgw']->common->phpgw_header();
+			$GLOBALS['egw']->common->egw_header();
 			echo parse_navbar();
 
 			$this->template->set_file(array('langfile' => 'langfile.tpl'));
@@ -271,7 +272,7 @@
 			$this->template->set_block('langfile','detail_long','detail_long');
 			$this->template->set_block('langfile','footer','footer');
 
-			$this->template->set_var('action_url',$GLOBALS['phpgw']->link('/index.php','menuaction=developer_tools.uilangfile.edit'));
+			$this->template->set_var('action_url',$GLOBALS['egw']->link('/index.php','menuaction=developer_tools.uilangfile.edit'));
 			$this->template->set_var('lang_remove',lang('Remove'));
 			$this->template->set_var('lang_loaddb',lang('Update Database'));
 			$this->template->set_var('lang_application',lang('Application'));
@@ -293,75 +294,45 @@
 			$this->template->set_var('write_help',sprintf($help,str_replace("'","\\'",lang('Write the lang-file to the apps setup-dir'))));
 			$this->template->set_var('loaddb_help',sprintf($help,str_replace("'","\\'",lang('Updates the translations of both lang-files in your database, so you can verify your work immediately'))));
 
-			$languages = $this->bo->list_langs();
-
 			if(!$sourcelang)
 			{
 				$sourcelang = 'en';
 			}
 			if(!$targetlang)
 			{
-				$targetlang = $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'];
+				$targetlang = $GLOBALS['egw_info']['user']['preferences']['common']['lang'];
 			}
 
-			while (list($x,$_lang) = @each($languages))
+			foreach($GLOBALS['egw']->translation->list_langs() as $lang_id => $lang_name)
 			{
-				$sourcelangs .= '      <option value="' . $_lang['lang_id'] . '"';
-				if ($sourcelang)
+				$sourcelangs .= '      <option value="' . $lang_id . '"';
+				if ($lang_id == $sourcelang || !$sourcelang && $lang_id == 'en')
 				{
-					if ($_lang['lang_id'] == $sourcelang)
-					{
-						$sourcelangs .= ' selected';
-					}
+					$sourcelangs .= ' selected="selected"';
 				}
-				elseif ($_lang['lang_id'] == 'EN')
-				{
-					$sourcelangs .= ' selected';
-				}
-				$sourcelangs .= '>' . $_lang['lang_name'] . '</option>' . "\n";
-			}
-			@reset($languages);
+				$sourcelangs .= '>' . $lang_name . '</option>' . "\n";
 
-			while (list($x,$_lang) = @each($languages))
-			{
-				$targetlangs .= '      <option value="' . $_lang['lang_id'] . '"';
-				if ($targetlang)
+				$targetlangs .= '      <option value="' . $lang_id . '"';
+				if ($lang_id == $targetlang || !$targetlang && $lang_id == 'en')
 				{
-					if ($_lang['lang_id'] == $targetlang)
-					{
-						$targetlangs .= ' selected';
-					}
+					$targetlangs .= ' selected="selected"';
 				}
-				elseif ($_lang['lang_id'] == 'EN')
-				{
-					$targetlangs .= ' selected';
-				}
-				$targetlangs .= '>' . $_lang['lang_name'] . '</option>' . "\n";
+				$targetlangs .= '>' . $lang_name . '</option>' . "\n";
 			}
 			$this->template->set_var('sourcelangs',$sourcelangs);
 			$this->template->set_var('targetlangs',$targetlangs);
 			$this->template->set_var('app_name',$app_name);
-			$this->template->set_var('app_title',$GLOBALS['phpgw_info']['apps'][$app_name]['title']);
+			$this->template->set_var('app_title',$GLOBALS['egw_info']['apps'][$app_name]['title']);
 			$this->template->pfp('out','header');
 
-			$db_perms = $GLOBALS['phpgw']->acl->get_user_applications($GLOBALS['phpgw_info']['user']['account_id']);
-			@ksort($db_perms);
-			@reset($db_perms);
-			while (list($userapp) = each($db_perms))
+			foreach($GLOBALS['egw_info']['apps']+array('setup' => array('title' => lang('Setup'))) as $app => $data)
 			{
-				if ($GLOBALS['phpgw_info']['apps'][$userapp]['enabled'] || $userapp == 'setup')
+				$userapps .= '<option value="' . $userapp . '"';
+				if ($application_name == $userapp)
 				{
-					$userapps .= '<option value="' . $userapp . '"';
-					if ($application_name == $userapp)
-					{
-						$userapps .= ' selected';
-					}
-					elseif ($GLOBALS['phpgw_info']['user']['preferences']['default_app'] == $userapp)
-					{
-						$userapps .= ' selected';
-					}
-					$userapps .= '>' . (isset($GLOBALS['phpgw_info']['apps'][$userapp]['title']) ? $GLOBALS['phpgw_info']['apps'][$userapp]['title'] : lang($userapp)) . '</option>' . "\n";
+					$userapps .= ' selected="selected"';
 				}
+				$userapps .= '>' . $data['title'] . '</option>' . "\n";
 			}
 			$this->template->set_var('userapps',$userapps);
 
@@ -370,7 +341,7 @@
 				$transapp     = $_POST['transapp'];
 				$translations = $_POST['translations'];
 				$deleteme     = $_POST['delete'];
-				while (list($_mess,$_app) = each($transapp))
+				foreach($transapp as $_mess => $_app)
 				{
 					if($_mess)
 					{
@@ -383,7 +354,7 @@
 				{
 					$this->bo->target_langarray = array();
 				}
-				while (list($_mess,$_cont) = each($translations))
+				foreach($translations as $_mess => $_cont)
 				{
 					if($_mess && $_cont)
 					{
@@ -401,7 +372,8 @@
 						}
 					}
 				}
-				while (list($_mess,$_checked) = @each($deleteme))
+				if ($deleteme)
+				foreach($deleteme as $_mess => $_checked)
 				{
 					if($_checked == 'on')
 					{
@@ -451,7 +423,7 @@
 				$this->template->set_var('lang_translation',lang('Translation'));
 				$this->template->set_var('lang_missingphrase',lang('Search new phrases'));
 				$this->template->set_var('lang_addphrase',lang('Add new phrase'));
-				$this->template->set_var('th_bg',$GLOBALS['phpgw_info']['theme']['th_bg']);
+				$this->template->set_var('th_bg',$GLOBALS['egw_info']['theme']['th_bg']);
 				$this->template->set_var('sourcelang',$sourcelang);
 				$this->template->set_var('targetlang',$targetlang);
 				$this->template->pfp('out','postheader');
@@ -467,8 +439,8 @@
 					$this->template->set_var('mess_id',$mess_id);
 					$this->template->set_var('source_content',$content);
 					$this->template->set_var('content',$transy);
-					$this->template->set_var('transapp',$this->lang_option($app_name,$data['app_name'],$mess_id));
-					$this->template->set_var('tr_color',empty($transy) ? $GLOBALS['phpgw_info']['theme']['bg06'] : $this->nextmatchs->alternate_row_color());
+					$this->template->set_var('transapp',$this->lang_option($app_name,$data['app_name'],"transapp[$mess_id]"));
+					$this->template->set_var('tr_color',empty($transy) ? $GLOBALS['egw_info']['theme']['bg06'] : $this->nextmatchs->alternate_row_color());
 					if (($len = max(strlen($key),strlen($content))) > 50)
 					{
 						$this->template->set_var('rows',min(intval($len/80+0.5),10));
@@ -511,7 +483,9 @@
 
 		function recode_id($id)
 		{
-			if (get_magic_quotes_gpc())
+			// PHP4 only quotes array-keys (NOT values) if magic_quotes_gpc is on, PHP5 does it always
+			// maybe anyone knows why ;-)
+			if (get_magic_quotes_gpc() || (int) PHP_VERSION >= 5)
 			{
 				$id = stripslashes($id);
 			}
@@ -526,24 +500,25 @@
 					$langarray = $this->bo->source_langarray;
 					break;
 				case 'target':
-					$langarray = $this->bo->target_langarray;
+					// removing phrases not in the source language
+					$langarray = $this->bo->target_langarray = array_intersect_assoc($this->bo->target_langarray,$this->bo->source_langarray);
 					break;
 				default:
 					break;
 			}
-			$browser = CreateObject('phpgwapi.browser');
+			$browser =& CreateObject('phpgwapi.browser');
 			$browser->content_header('phpgw_' . $userlang . '.lang');
-			$to = $GLOBALS['phpgw']->translation->charset($userlang);
-			$from = $GLOBALS['phpgw']->translation->charset();
+			$to = $GLOBALS['egw']->translation->charset($userlang);
+			$from = $GLOBALS['egw']->translation->charset();
 			while(list($mess_id,$data) = @each($langarray))
 			{
-				$content = $GLOBALS['phpgw']->translation->convert(trim($data['content']),$from,$to);
+				$content = $GLOBALS['egw']->translation->convert(trim($data['content']),$from,$to);
 				if (!empty($content))
 				{
 					echo $mess_id . "\t" . $data['app_name'] . "\t" . $userlang . "\t" . $content . "\n";
 				}
 			}
-			$GLOBALS['phpgw']->common->phpgw_exit();
+			$GLOBALS['egw']->common->egw_exit();
 		}
 
 		function index()
@@ -554,16 +529,16 @@
 			$query = $_POST['query'];
 
 			$this->bo->save_sessiondata('','');
-			$GLOBALS['phpgw_info']['flags']['app_header'] = $GLOBALS['phpgw_info']['apps'][$GLOBALS['phpgw_info']['flags']['currentapp']]['title'].
+			$GLOBALS['egw_info']['flags']['app_header'] = $GLOBALS['egw_info']['apps'][$GLOBALS['egw_info']['flags']['currentapp']]['title'].
 				' - '.lang('Installed applications');
-			$GLOBALS['phpgw']->common->phpgw_header();
+			$GLOBALS['egw']->common->egw_header();
 			echo parse_navbar();
 
 			$this->template->set_file(array('applications' => 'applications.tpl'));
 			$this->template->set_block('applications','list','list');
 			$this->template->set_block('applications','row','row');
 
-			$offset = $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
+			$offset = $GLOBALS['egw_info']['user']['preferences']['common']['maxmatchs'];
 
 			$apps = array(
 				strtolower(lang('Setup')) => array(
@@ -571,7 +546,7 @@
 					'title' => lang('Setup')
 				)
 			);
-			foreach($GLOBALS['phpgw_info']['apps'] as $app => $data)
+			foreach($GLOBALS['egw_info']['apps'] as $app => $data)
 			{
 				$apps[strtolower($data['title'])] = $data;
 			}
@@ -614,8 +589,8 @@
 				$limit = $total;
 			}
 
-			$this->template->set_var('bg_color',$GLOBALS['phpgw_info']['theme']['bg_color']);
-			$this->template->set_var('th_bg',$GLOBALS['phpgw_info']['theme']['th_bg']);
+			$this->template->set_var('bg_color',$GLOBALS['egw_info']['theme']['bg_color']);
+			$this->template->set_var('th_bg',$GLOBALS['egw_info']['theme']['th_bg']);
 
 			$this->template->set_var('sort_title',$this->nextmatchs->show_sort_order($sort,'title','title','/index.php',lang('Title'),'&menuaction=developer_tools.uilangfile.index'));
 			$this->template->set_var('lang_showing',$this->nextmatchs->show_hits($total,$start));
@@ -624,7 +599,7 @@
 
 			$this->template->set_var('lang_edit',lang('Edit'));
 			//$this->template->set_var('lang_translate',lang('Translate'));
-			$this->template->set_var('new_action',$GLOBALS['phpgw']->link('/index.php','menuaction=developer_tools.uilangfile.create'));
+			$this->template->set_var('new_action',$GLOBALS['egw']->link('/index.php','menuaction=developer_tools.uilangfile.create'));
 			$this->template->set_var('create_new',lang('Create New Language File'));
 
 			$i = 0;
@@ -637,8 +612,8 @@
 					$this->template->set_var('tr_color',$tr_color);
 					$this->template->set_var('name',$data['title']);
 
-					$this->template->set_var('edit','<a href="' . $GLOBALS['phpgw']->link('/index.php','menuaction=developer_tools.uilangfile.edit&app_name=' . urlencode($data['name'])) . '"> ' . lang('Edit') . ' </a>');
-				//	$this->template->set_var('translate','<a href="' . $GLOBALS['phpgw']->link('/index.php','menuaction=developer_tools.uilangfile.translate&app_name=' . urlencode($app['name'])) . '"> ' . lang('Translate') . ' </a>');
+					$this->template->set_var('edit','<a href="' . $GLOBALS['egw']->link('/index.php','menuaction=developer_tools.uilangfile.edit&app_name=' . urlencode($data['name'])) . '"> ' . lang('Edit') . ' </a>');
+				//	$this->template->set_var('translate','<a href="' . $GLOBALS['egw']->link('/index.php','menuaction=developer_tools.uilangfile.translate&app_name=' . urlencode($app['name'])) . '"> ' . lang('Translate') . ' </a>');
 
 					$this->template->set_var('status',$status);
 
@@ -660,13 +635,13 @@
 				'preferences' => 'preferences'
 			);
 
-			$select  = "\n" .'<select name="transapp[' . $name . ']">' . "\n";
-			while (list($key,$val) = each($list))
+			$select  = "\n" .'<select name="' . $name . '">' . "\n";
+			foreach($list as $key => $val)
 			{
 				$select .= '<option value="' . $key . '"';
 				if ($key == $current && $current != '')
 				{
-					$select .= ' selected';
+					$select .= ' selected="selected"';
 				}
 				$select .= '>' . $val . '</option>'."\n";
 			}
