@@ -9,7 +9,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.ui.inc.php,v 1.8.2.1 2004/08/25 10:42:04 ralfbecker Exp $ */
+	/* $Id: class.ui.inc.php 20261 2006-01-22 17:59:06Z lkneschke $ */
 
 	class ui
 	{
@@ -31,16 +31,33 @@
 
 		function ui()
 		{
-			$this->cats			= CreateObject('phpgwapi.categories');
-			$this->nextmatchs		= CreateObject('phpgwapi.nextmatchs');
-			$this->t			= CreateObject('phpgwapi.Template',PHPGW_APP_TPL);
-			#$this->grants			= $phpgw->acl->get_grants('notes');
-			#$this->grants[$this->account]	= PHPGW_ACL_READ + PHPGW_ACL_ADD + PHPGW_ACL_EDIT + PHPGW_ACL_DELETE;
-			$this->boemailadmin		= CreateObject('emailadmin.bo');
+			$this->nextmatchs   =& CreateObject('phpgwapi.nextmatchs');
+			$this->t            =& CreateObject('phpgwapi.Template',EGW_APP_TPL);
+			$this->boemailadmin =& CreateObject('emailadmin.bo');
 		}
 		
 		function addProfile()
 		{
+			$allGroups = $GLOBALS['egw']->accounts->get_list('groups');
+			foreach($allGroups as $groupInfo)
+			{
+				$groups[$groupInfo['account_id']] = $groupInfo['account_lid'];
+			}
+			asort($groups);
+
+			$allGroups = array('' => lang('any group'));
+			foreach($groups as $groupID => $groupName)
+			{
+				$allGroups[$groupID] = $groupName;
+			}
+			
+			$applications = array(
+				'calendar'	=> $GLOBALS['egw_info']['apps']['calendar']['title'],
+				'felamimail' 	=> $GLOBALS['egw_info']['apps']['felamimail']['title'],
+			);
+			asort($applications);
+			$applications = array_merge(array('' => lang('any application')),$applications);
+			
 			$this->display_app_header();
 			
 			$this->t->set_file(array("body" => "editprofile.tpl"));
@@ -51,18 +68,20 @@
 			#$this->t->set_var('profile_name',$profileList[0]['description']);
 			$this->t->set_var('smtpActiveTab','1');
 			$this->t->set_var('imapActiveTab','1');
+			$this->t->set_var('application_select_box', $GLOBALS['egw']->html->select('globalsettings[ea_appname]','',$applications, true, "style='width: 250px;'"));
+			$this->t->set_var('group_select_box', $GLOBALS['egw']->html->select('globalsettings[ea_group]','',$allGroups, true, "style='width: 250px;'"));
 			
 			$linkData = array
 			(
 				'menuaction'	=> 'emailadmin.ui.saveProfile'
 			);
-			$this->t->set_var('action_url',$GLOBALS['phpgw']->link('/index.php',$linkData));
+			$this->t->set_var('action_url',$GLOBALS['egw']->link('/index.php',$linkData));
 			
 			$linkData = array
 			(
 				'menuaction'	=> 'emailadmin.ui.listProfiles'
 			);
-			$this->t->set_var('back_url',$GLOBALS['phpgw']->link('/index.php',$linkData));
+			$this->t->set_var('back_url',$GLOBALS['egw']->link('/index.php',$linkData));
 
 			foreach($this->boemailadmin->getSMTPServerTypes() as $key => $value)
 			{
@@ -122,27 +141,56 @@
 		
 		function display_app_header()
 		{
-			if(!@is_object($GLOBALS['phpgw']->js))
+			if(!@is_object($GLOBALS['egw']->js))
 			{
-				$GLOBALS['phpgw']->js = CreateObject('phpgwapi.javascript');
+				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
 			}
-			$GLOBALS['phpgw']->js->validate_file('tabs','tabs');
+			$GLOBALS['egw']->js->validate_file('tabs','tabs');
+			$GLOBALS['egw_info']['flags']['include_xajax'] = True;
+
 			switch($_GET['menuaction'])
 			{
 				case 'emailadmin.ui.addProfile':
 				case 'emailadmin.ui.editProfile':
-					$GLOBALS['phpgw']->js->validate_file('jscode','editProfile','emailadmin');
-					$GLOBALS['phpgw']->js->set_onload('javascript:initAll();');
-					#$GLOBALS['phpgw']->js->set_onload('smtp.init();');
+					$GLOBALS['egw_info']['nofooter'] = true;
+					$GLOBALS['egw']->js->validate_file('jscode','editProfile','emailadmin');
+					$GLOBALS['egw']->js->set_onload('javascript:initAll();');
+					#$GLOBALS['egw']->js->set_onload('smtp.init();');
+
+					break;
+
+				case 'emailadmin.ui.listProfiles':
+					$GLOBALS['egw']->js->validate_file('jscode','listProfile','emailadmin');
 
 					break;
 			}
-			$GLOBALS['phpgw']->common->phpgw_header();
-			echo parse_navbar();
+			$GLOBALS['egw']->common->egw_header();
+			
+			if($_GET['menuaction'] == 'emailadmin.ui.listProfiles' || $_GET['menuaction'] == 'emailadmin.ui.deleteProfile')
+				echo parse_navbar();
 		}
 
 		function editProfile($_profileID='')
 		{
+			$allGroups = $GLOBALS['egw']->accounts->get_list('groups');
+			foreach($allGroups as $groupInfo)
+			{
+				$groups[$groupInfo['account_id']] = $groupInfo['account_lid'];
+			}
+			asort($groups);
+
+			$allGroups = array('' => lang('any group'));
+			foreach($groups as $groupID => $groupName)
+			{
+				$allGroups[$groupID] = $groupName;
+			}
+			
+			$applications = array(
+				'calendar'	=> $GLOBALS['egw_info']['apps']['calendar']['title'],
+				'felamimail' 	=> $GLOBALS['egw_info']['apps']['felamimail']['title'],
+			);
+			asort($applications);
+			$applications = array_merge(array('' => lang('any application')),$applications);
 			
 			if($_profileID != '')
 			{
@@ -166,9 +214,9 @@
 			
 			$this->translate();
 			
-			foreach($profileData as $key => $value)
+			foreach((array)$profileData as $key => $value)
 			{
-				#print "$key $value<br>";
+				//print "$key $value<br>";
 				switch($key)
 				{
 					case 'imapEnableCyrusAdmin':
@@ -179,6 +227,7 @@
 					case 'smtpLDAPUseDefault':
 					case 'userDefinedAccounts':
 					case 'imapoldcclient':
+					case 'editforwardingaddress':
 						if($value == 'yes')
 							$this->t->set_var('selected_'.$key,'checked="1"');
 						break;
@@ -187,6 +236,12 @@
 					case 'imapLoginType':
 						$this->t->set_var('selected_'.$key.'_'.$value,'selected="1"');
 						break;
+					case 'ea_appname':
+						$this->t->set_var('application_select_box', $GLOBALS['egw']->html->select('globalsettings[ea_appname]',$value,$applications, true, "style='width: 250px;'"));
+						break;
+					case 'ea_group':
+						$this->t->set_var('group_select_box', $GLOBALS['egw']->html->select('globalsettings[ea_group]',$value,$allGroups, true, "style='width: 250px;'"));
+						break;
 					default:
 						$this->t->set_var('value_'.$key,$value);
 						break;
@@ -198,19 +253,19 @@
 				'menuaction'	=> 'emailadmin.ui.saveProfile',
 				'profileID'	=> $profileID
 			);
-			$this->t->set_var('action_url',$GLOBALS['phpgw']->link('/index.php',$linkData));
+			$this->t->set_var('action_url',$GLOBALS['egw']->link('/index.php',$linkData));
 			
 			$linkData = array
 			(
 				'menuaction'	=> 'emailadmin.ui.listProfiles'
 			);
-			$this->t->set_var('back_url',$GLOBALS['phpgw']->link('/index.php',$linkData));
+			$this->t->set_var('back_url',$GLOBALS['egw']->link('/index.php',$linkData));
 
 			foreach($this->boemailadmin->getSMTPServerTypes() as $key => $value)
 			{
 				$this->t->set_var("lang_smtp_option_$key",$value);
 			};
-						
+
 			foreach($this->boemailadmin->getIMAPServerTypes() as $key => $value)
 			{
 				$this->t->set_var("lang_imap_option_$key",$value['description']);
@@ -243,7 +298,7 @@
 						'tabpage'	=> '3',
 						'profileid'	=> $profileList[$i]['profileID']
 					);
-					$imapServerLink = '<a href="'.$GLOBALS['phpgw']->link('/index.php',$linkData).'">'.$profileList[$i]['imapServer'].'</a>';
+					$imapServerLink = '<a href="#" onclick="egw_openWindowCentered2(\''.$GLOBALS['egw']->link('/index.php',$linkData).'\',\'ea_editProfile\',700,600); return false;">'.$profileList[$i]['imapServer'].'</a>';
 					
 					$linkData = array
 					(
@@ -252,7 +307,7 @@
 						'tabpage'	=> '1',
 						'profileid'	=> $profileList[$i]['profileID']
 					);
-					$descriptionLink = '<a href="'.$GLOBALS['phpgw']->link('/index.php',$linkData).'">'.$profileList[$i]['description'].'</a>';
+					$descriptionLink = '<a href="#" onclick="egw_openWindowCentered2(\''.$GLOBALS['egw']->link('/index.php',$linkData).'\',\'ea_editProfile\',700,600); return false;">'.$profileList[$i]['description'].'</a>';
 					
 					$linkData = array
 					(
@@ -261,22 +316,48 @@
 						'tabpage'	=> '2',
 						'profileid'	=> $profileList[$i]['profileID']
 					);
-					$smtpServerLink = '<a href="'.$GLOBALS['phpgw']->link('/index.php',$linkData).'">'.$profileList[$i]['smtpServer'].'</a>';
+					$smtpServerLink = '<a href="#" onclick="egw_openWindowCentered2(\''.$GLOBALS['egw']->link('/index.php',$linkData).'\',\'ea_editProfile\',700,600); return false;">'.$profileList[$i]['smtpServer'].'</a>';
 					
 					$linkData = array
 					(
 						'menuaction'	=> 'emailadmin.ui.deleteProfile',
 						'profileid'	=> $profileList[$i]['profileID']
 					);
-					$deleteLink = '<a href="'.$GLOBALS['phpgw']->link('/index.php',$linkData).
-						      '" onClick="return confirm(\''.lang('Do you really want to delete this Profile').'?\')">'.
-						      lang('delete').'</a>';
+					$deleteLink = '<a href="'.$GLOBALS['egw']->link('/index.php',$linkData).
+									'" onClick="return confirm(\''.lang('Do you really want to delete this Profile').'?\')">'.
+									lang('delete').'</a>';
+
+					$application = (empty($profileList[$i]['ea_appname']) ? lang('any application') : $GLOBALS['egw_info']['apps'][$profileList[$i]['ea_appname']]['title']);
+					$linkData = array
+					(
+						'menuaction'	=> 'emailadmin.ui.editProfile',
+						'nocache'	=> '1',
+						'tabpage'	=> '1',
+						'profileid'	=> $profileList[$i]['profileID']
+					);
+					$applicationLink = '<a href="#" onclick="egw_openWindowCentered2(\''.$GLOBALS['egw']->link('/index.php',$linkData).'\',\'ea_editProfile\',700,600); return false;">'.$application.'</a>';					
+
+					$group = (empty($profileList[$i]['ea_group']) ? lang('any group') : $GLOBALS['egw']->accounts->id2name($profileList[$i]['ea_group']));
+					$linkData = array
+					(
+						'menuaction'	=> 'emailadmin.ui.editProfile',
+						'nocache'	=> '1',
+						'tabpage'	=> '1',
+						'profileid'	=> $profileList[$i]['profileID']
+					);
+					$groupLink = '<a href="#" onclick="egw_openWindowCentered2(\''.$GLOBALS['egw']->link('/index.php',$linkData).'\',\'ea_editProfile\',700,600); return false;">'.$group.'</a>';
+
+					$moveButtons = '<img src="'. $GLOBALS['egw']->common->image('phpgwapi', 'up') .'" onclick="moveUp(this)">&nbsp;'.
+						       '<img src="'. $GLOBALS['egw']->common->image('phpgwapi', 'down') .'" onclick="moveDown(this)">';
 					
-					$data[] = array(
+					$data['profile_'.$profileList[$i]['profileID']] = array(
 						$descriptionLink,
 						$smtpServerLink,
 						$imapServerLink,
-						$deleteLink
+						$applicationLink,
+						$groupLink,
+						$deleteLink,
+						$moveButtons,
 						
 					);
 				}
@@ -287,7 +368,10 @@
 				lang('description'),
 				lang('smtp server name'),
 				lang('imap/pop3 server name'),
-				lang('delete')
+				lang('application'),
+				lang('group'),
+				lang('delete'),
+				lang('order'),
 			);
 				
 			// create the table html code
@@ -304,7 +388,7 @@
 			(
 				'menuaction'	=> 'emailadmin.ui.addProfile'
 			);
-			$this->t->set_var('add_link',$GLOBALS['phpgw']->link('/index.php',$linkData));
+			$this->t->set_var('add_link',$GLOBALS['egw']->link('/index.php',$linkData));
 
 			$this->t->parse("out","main");
 			
@@ -314,13 +398,13 @@
 
 		function nextMatchTable($_rows, $_data, $_description, $_start, $_total, $_menuAction)
 		{
-			$template = CreateObject('phpgwapi.Template',PHPGW_APP_TPL);
+			$template =& CreateObject('phpgwapi.Template',EGW_APP_TPL);
 			$template->set_file(array("body" => "nextMatch.tpl"));
 			$template->set_block('body','row_list','rowList');
 			$template->set_block('body','header_row','headerRow');
 		
 			$var = Array(
-				'th_bg'			=> $GLOBALS['phpgw_info']['theme']['th_bg'],
+				'th_bg'			=> $GLOBALS['egw_info']['theme']['th_bg'],
 				'left_next_matchs'	=> $this->nextmatchs->left('/index.php',$start,$total,'menuaction=emailadmin.ui.listServers'),
 				'right_next_matchs'	=> $this->nextmatchs->right('/admin/groups.php',$start,$total,'menuaction=emailadmin.ui.listServers'),
 				'lang_groups'		=> lang('user groups'),
@@ -345,7 +429,7 @@
 
 			if(is_array($_data))
 			{
-				foreach($_data as $value)
+				foreach($_data as $rowID => $value)
 				{
 					$data = '';
 					foreach($value as $rowData)
@@ -353,6 +437,7 @@
 						$data .= "<td align='center'>$rowData</td>";
 					}
 					$template->set_var('row_data', $data);
+					$template->set_var('row_id', $rowID);
 					$template->fp('rowList','row_list',True);
 				}
 			}
@@ -376,6 +461,8 @@
 			$globalSettings['defaultDomain'] = $_POST['globalsettings']['defaultDomain'];
 			$globalSettings['organisationName'] = $_POST['globalsettings']['organisationName'];
 			$globalSettings['userDefinedAccounts'] = $_POST['globalsettings']['userDefinedAccounts'];
+			$globalSettings['ea_appname'] = ($_POST['globalsettings']['ea_appname'] == 'any' ? '' : $_POST['globalsettings']['ea_appname']);
+			$globalSettings['ea_group'] = ($_POST['globalsettings']['ea_group'] == 'any' ? '' : (int)$_POST['globalsettings']['ea_group']);
 			
 			
 			// get the settings for the smtp server
@@ -399,14 +486,17 @@
 			#_debug_array($imapSettings);
 			
 			$this->boemailadmin->saveProfile($globalSettings, $smtpSettings, $imapSettings);
-			#if ($HTTP_POST_VARS['bo_action'] == 'save_ldap' || $HTTP_GET_VARS['bo_action'] == 'save_ldap')
+			#if ($_POST['bo_action'] == 'save_ldap' || $_GET['bo_action'] == 'save_ldap')
 			#{
-				$this->listProfiles();
+			#	$this->listProfiles();
 			#}
 			#else
 			#{
-			#	$this->editServer($HTTP_GET_VARS["serverid"],$HTTP_GET_VARS["pagenumber"]);
+			#	$this->editServer($_GET["serverid"],$_GET["pagenumber"]);
 			#}
+			print "<script type=\"text/javascript\">opener.location.reload(); window.close();</script>";
+			$GLOBALS['egw']->common->egw_exit();
+			exit;
 		}
 		
 		function translate()
@@ -457,9 +547,27 @@
 			$this->t->set_var('lang_admin_username',lang('admin username'));
 			$this->t->set_var('lang_admin_password',lang('admin passwort'));
 			$this->t->set_var('lang_imap_server_logintyp',lang('imap server logintyp'));
-			$this->t->set_var('lang_standard',lang('standard'));
-			$this->t->set_var('lang_vmailmgr',lang('Virtual MAIL ManaGeR'));
+			$this->t->set_var('lang_standard',lang('username (standard)'));
+			$this->t->set_var('lang_vmailmgr',lang('username@domainname (Virtual MAIL ManaGeR)'));
 			$this->t->set_var('lang_pre_2001_c_client',lang('IMAP C-Client Version < 2001'));
+			$this->t->set_var('lang_user_can_edit_forwarding_address',lang('user can edit forwarding address'));
+			$this->t->set_var('lang_can_be_used_by_application',lang('can be used by application'));
+			$this->t->set_var('lang_can_be_used_by_group',lang('can be used by group'));
+			$this->t->set_var('lang_smtp_auth',lang('smtp authentication'));
+			$this->t->set_var('lang_username',lang('username'));
+			$this->t->set_var('lang_password',lang('password'));
+			$this->t->set_var('lang_smtp_settings',lang('smtp settings'));
+			$this->t->set_var('lang_smtp_options',lang('smtp options'));
+			$this->t->set_var('lang_profile_access_rights',lang('profile access rights'));
+			$this->t->set_var('lang_global_settings',lang(''));
+			$this->t->set_var('lang_organisation',lang('organisation'));
+			$this->t->set_var('lang_global_options',lang('global options'));
+			$this->t->set_var('lang_server_settings',lang('server settings'));
+			$this->t->set_var('lang_encryption_settings',lang('encryption settings'));
+			$this->t->set_var('',lang(''));
+			$this->t->set_var('',lang(''));
+			$this->t->set_var('',lang(''));
+			$this->t->set_var('',lang(''));
 			# $this->t->set_var('',lang(''));
 			
 		}
