@@ -10,15 +10,15 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: index.php,v 1.4 2004/01/27 16:58:15 reinerj Exp $ */
+	/* $Id: index.php 20295 2006-02-15 12:31:25Z  $ */
 
-	$GLOBALS['phpgw_info']['flags'] = array(
-		'currentapp'	=> 'et_media',
-		'noheader'	=> True,
-		'nonavbar'	=> True
+	$GLOBALS['egw_info'] = array(
+		'flags' => array(
+			'currentapp'	=> 'et_media',
+			'noheader'	=> True,
+			'nonavbar'	=> True,
+		),
 	);
 	include('../header.inc.php');
 
-	header('Location: '.$GLOBALS['phpgw']->link('/index.php','menuaction=et_media.et_media.edit'));
-	$GLOBALS['phpgw_info']['flags']['nodisplay'] = True;
-	exit;
+	$GLOBALS['egw']->redirect_link('/index.php','menuaction=et_media.et_media.edit');
