@@ -10,35 +10,53 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.select_widget.inc.php,v 1.15 2004/07/09 18:21:01 ralfbecker Exp $ */
+	/* $Id: class.select_widget.inc.php 22216 2006-08-12 06:15:32Z ralfbecker $ */
 
-	/*!
-	@class select_widget
-	@author ralfbecker
-	@abstract Several select-boxes with predefined phpgw specific content.
-	@discussion This widget replaces the old sbox class
-	@discussion This widget is independent of the UI as it only uses etemplate-widgets and has therefor no render-function
-	*/
+	/**
+	 * eTemplate Extension: several select-boxes with predefined eGW specific content
+	 *
+	 * This widgets replaces the old phpgwapi.sbox class. The widgets are independent of the UI,
+	 * as they only uses etemplate-widgets and therefor have no render-function.
+	 *
+	 * @package etemplate
+	 * @subpackage extensions
+	 * @author RalfBecker-AT-outdoor-training.de
+	 * @license GPL
+	 */
 	class select_widget
 	{
+		/** 
+		 * exported methods of this class
+		 * @var array
+		 */
 		var $public_functions = array(
-			'pre_process' => True
+			'pre_process' => True,
+			'post_process' => True,
 		);
-		var $human_name = array(	// this are the names for the editor
+		/**
+		 * availible extensions and there names for the editor
+		 * @var array
+		 */
+		var $human_name = array(
 			'select-percent'  => 'Select Percentage',
 			'select-priority' => 'Select Priority',
 			'select-access'   => 'Select Access',
 			'select-country'  => 'Select Country',
 			'select-state'    => 'Select State',	// US-states
-			'select-cat'      => 'Select Category',// Category-Selection, size: -1=Single+All, 0=Single, >0=Multiple with size lines
+			'select-cat'      => 'Select Category',	// Category-Selection, size: -1=Single+All, 0=Single, >0=Multiple with size lines
 			'select-account'  => 'Select Account',	// label=accounts(default),groups,both
-																// size: -1=Single+not assigned, 0=Single, >0=Multiple
+													// size: -1=Single+not assigned, 0=Single, >0=Multiple
 			'select-year'     => 'Select Year',
 			'select-month'    => 'Select Month',
 			'select-day'      => 'Select Day',
+			'select-dow'      => 'Select Day of week',
+			'select-hour'     => 'Select Hour',		// either 0-23 or 12am,1am-11am,12pm,1pm-11pm
 			'select-number'   => 'Select Number',
 			'select-app'      => 'Select Application'
 		);
+		/**
+		 * @var array
+		 */
 		var $monthnames = array(
 			0  => '',
 			1  => 'January',
@@ -54,7 +72,9 @@
 			11 => 'November',
 			12 => 'December'
 		);
-
+		/**
+		 * @var array
+		 */
 		var $states = array(
 			''		=> '',
 			'--'	=> 'non US',
@@ -111,6 +131,11 @@
 			'WY'	=>	'Wyoming'
 		);
 
+		/**
+		 * Constructor of the extension
+		 *
+		 * @param string $ui '' for html
+		 */
 		function select_widget($ui)
 		{
 			foreach($this->monthnames as $k => $name)
@@ -123,10 +148,25 @@
 			$this->ui = $ui;
 		}
 
+		/**
+		 * pre-processing of the extension
+		 *
+		 * This function is called before the extension gets rendered
+		 *
+		 * @param string $name form-name of the control
+		 * @param mixed &$value value / existing content, can be modified
+		 * @param array &$cell array with the widget, can be modified for ui-independent widgets 
+		 * @param array &$readonlys names of widgets as key, to be made readonly
+		 * @param mixed &$extension_data data the extension can store persisten between pre- and post-process
+		 * @param object &$tmpl reference to the template we belong too
+		 * @return boolean true if extra label is allowed, false otherwise
+		 */
 		function pre_process($name,&$value,&$cell,&$readonlys,&$extension_data,&$tmpl)
 		{
 			list($rows,$type,$type2,$type3) = explode(',',$cell['size']);
 
+			$extension_data['type'] = $cell['type'];
+
 			switch ($cell['type'])
 			{
 				case 'select-percent':	// options: #row,decrement(default=10)
@@ -136,7 +176,10 @@
 						$cell['sel_options'][intval($i)] = intval($i).'%';
 					}
 					$cell['sel_options'][100] = '100%';
-					$value = intval(($value+($decr/2)) / $decr) * $decr;
+					if (!$rows || !empty($value))
+					{
+						$value = intval(($value+($decr/2)) / $decr) * $decr;
+					}
 					$cell['no_lang'] = True;
 					break;
 
@@ -155,7 +198,7 @@
 				case 'select-country':
 					if (!$this->countrys)
 					{
-						$country = CreateObject('phpgwapi.country');
+						$country =& CreateObject('phpgwapi.country');
 						$this->countrys = &$country->country_array;
 						unset($country);
 						unset($this->countrys['  ']);
@@ -179,29 +222,20 @@
 					$cell['no_lang'] = True;
 					break;
 
-				case 'select-cat':	// !$type == globals cats too
-					if (!is_object($GLOBALS['phpgw']->categories))
+				case 'select-cat':	// !$type == globals cats too, $type2: extraStyleMultiselect
+					if (!is_object($GLOBALS['egw']->categories))
 					{
-						$GLOBALS['phpgw']->categories = CreateObject('phpgwapi.categories');
+						$GLOBALS['egw']->categories =& CreateObject('phpgwapi.categories');
 					}
-					$cats = $GLOBALS['phpgw']->categories->return_sorted_array(0,False,'','','',!$type);
-
-					while (list(,$cat) = @each($cats))
+					foreach((array)$GLOBALS['egw']->categories->return_sorted_array(0,False,'','','',!$type) as $cat)
 					{
-						for ($j=0,$s=''; $j < $cat['level']; $j++)
+						$s = str_repeat('&nbsp;',$cat['level']) . $GLOBALS['egw']->strip_html($cat['name']);
+
+						if ($cat['app_name'] == 'phpgw' || $cat['owner'] == '-1')
 						{
-							$s .= '&nbsp;';
+							$s .= ' &#9830;';
 						}
-						$s .= $GLOBALS['phpgw']->strip_html($cat['name']);
-						if ($cat['app_name'] == 'phpgw')
-						{
-							$s .= '&nbsp;&lt;' . lang('Global') . '&gt;';
-						}
-						if ($cat['owner'] == '-1')
-						{
-							$s .= '&nbsp;&lt;' . lang('Global') . '&nbsp;' . lang($cat['app_name']) . '&gt;';
-						}
-						if ($tmpl->stable)
+						if (!$tmpl->xslt)
 						{
 							$cell['sel_options'][$cat['id']] = $s;	// 0.9.14 only
 						}
@@ -210,15 +244,23 @@
 							$cell['sel_options'][$cat['cat_id']] = $s;
 						}
 					}
+					$cell['size'] = $rows.($type2 ? ','.$type2 : '');
 					$cell['no_lang'] = True;
 					break;
 
-				case 'select-account':	// options: #rows,{accounts(default)|both|groups},{0(=lid)|1(default=name)|2(=lid+name))}
+				case 'select-account':	// options: #rows,{accounts(default)|both|groups|owngroups},{0(=lid)|1(default=name)|2(=lid+name))}
+					//echo "<p>select-account widget: name=$cell[name], type='$type', rows=$rows, readonly=".(int)($cell['readonly'] || $readonlys)."</p>\n";
+					if($type == 'owngroups') 
+					{
+						$type = 'groups';
+						$owngroups = true;
+						foreach($GLOBALS['egw']->accounts->membership() as $group) $mygroups[] = $group['account_id'];
+					}
 					// in case of readonly, we read/create only the needed entries, as reading accounts is expensive
 					if ($cell['readonly'] || $readonlys)
 					{
 						$cell['no_lang'] = True;
-						foreach(is_array($value) ? $value : array($value) as $id)
+						foreach(is_array($value) ? $value : (strpos($value,',') !== false ? explode(',',$value) : array($value)) as $id)
 						{
 							$cell['sel_options'][$id] = $this->accountInfo($id,$acc,$type2,$type=='both');
 						}
@@ -226,24 +268,37 @@
 					}
 					if ($this->ui == 'html' && $type != 'groups')	// use eGW's new account-selection (html only)
 					{
-						if (!is_object($GLOBALS['phpgw']->uiaccountsel))
+						if (!is_object($GLOBALS['egw']->uiaccountsel))
 						{
-							$GLOBALS['phpgw']->uiaccountsel = CreateObject('phpgwapi.uiaccountsel');
+							$GLOBALS['egw']->uiaccountsel =& CreateObject('phpgwapi.uiaccountsel');
 						}
 						$help = (int)$cell['no_lang'] < 2 ? lang($cell['help']) : $cell['help'];
 						$onFocus = "self.status='".addslashes(htmlspecialchars($help))."'; return true;";
 						$onBlur  = "self.status=''; return true;";
-						$value = $GLOBALS['phpgw']->uiaccountsel->selection($name,'eT_accountsel_'.str_replace(array('[','][',']'),array('_','_',''),$name),
-							$value,$type,$rows > 0 ? $rows : 0,False,' onfocus="'.$onFocus.'" onblur="'.$onBlur.'"',
+						if ($cell['noprint'])
+						{
+							foreach(is_array($value) ? $value : (strpos($value,',') !== false ? explode(',',$value) : array($value)) as $id)
+							{
+								if ($id) $onlyPrint[] = $this->accountInfo($id,$acc,$type2,$type=='both');
+							}
+							$onlyPrint = $onlyPrint ? implode('<br />',$onlyPrint) : lang((int)$rows < 0 ? 'all' : $rows);
+							$noPrint_class = ' class="noPrint"';
+						}
+						$value = $GLOBALS['egw']->uiaccountsel->selection($name,'eT_accountsel_'.str_replace(array('[','][',']'),array('_','_',''),$name),
+							$value,$type,$rows > 0 ? $rows : 0,False,' onfocus="'.$onFocus.'" onblur="'.$onBlur.'"'.$noPrint_class,
 							$cell['onchange'] == '1' ? 'this.form.submit();' : $cell['onchange'],
 							!empty($rows) && 0+$rows <= 0 ? lang($rows < 0 ? 'all' : $rows) : False);
+						if ($cell['noprint'])
+						{
+							$value = '<span class="onlyPrint">'.$onlyPrint.'</span>'.$value;
+						}
 						$cell['type'] = 'html';
 						$cell['size'] = '';	// is interpreted as link otherwise
-						$GLOBALS['phpgw_info']['etemplate']['to_process'][$name] = 'select';
+						$GLOBALS['egw_info']['etemplate']['to_process'][$name] = 'select';
 						break;
 					}
 					$cell['no_lang'] = True;
-					$accs = $GLOBALS['phpgw']->accounts->get_list(empty($type) ? 'accounts' : $type); // default is accounts
+					$accs = $GLOBALS['egw']->accounts->get_list(empty($type) ? 'accounts' : $type); // default is accounts
 					foreach($accs as $acc)
 					{
 						if ($acc['account_type'] == 'u')
@@ -253,7 +308,7 @@
 					}
 					foreach($accs as $acc)
 					{
-						if ($acc['account_type'] == 'g')
+						if ($acc['account_type'] == 'g' && (!$owngroups || ($owngroups && in_array($acc['account_id'],(array)$mygroups))))
 						{
 							$cell['sel_options'][$acc['account_id']] = $this->accountInfo($acc['account_id'],$acc,$type2,$type=='both');
 						}
@@ -280,6 +335,74 @@
 					$cell['sel_options'] = $this->monthnames;
 					$value = intval($value);
 					break;
+					
+				case 'select-dow':	// options: rows[,0=summaries befor days, 1=summaries after days, 2=no summaries[,extraStyleMultiselect]]
+					if (!defined('MCAL_M_SUNDAY'))
+					{
+						define('MCAL_M_SUNDAY',1);
+						define('MCAL_M_MONDAY',2);
+						define('MCAL_M_TUESDAY',4);
+						define('MCAL_M_WEDNESDAY',8);
+						define('MCAL_M_THURSDAY',16);
+						define('MCAL_M_FRIDAY',32);
+						define('MCAL_M_SATURDAY',64);
+						
+						define('MCAL_M_WEEKDAYS',62);
+						define('MCAL_M_WEEKEND',65);
+						define('MCAL_M_ALLDAYS',127);
+					}
+					$weekstart = $GLOBALS['egw_info']['user']['preferences']['calendar']['weekdaystarts'];
+					$cell['sel_options'] = array();
+					if ($rows >= 2 && !$type) 
+					{
+						$cell['sel_options'] = array(
+							MCAL_M_ALLDAYS	=> 'all days',
+							MCAL_M_WEEKDAYS	=> 'working days',
+							MCAL_M_WEEKEND	=> 'weekend',
+						);
+					}
+					if ($weekstart == 'Saturday') $cell['sel_options'][MCAL_M_SATURDAY] = 'saturday';
+					if ($weekstart != 'Monday') $cell['sel_options'][MCAL_M_SUNDAY] = 'sunday';
+					$cell['sel_options'] += array(
+						MCAL_M_MONDAY	=> 'monday',
+						MCAL_M_TUESDAY	=> 'tuesday',
+						MCAL_M_WEDNESDAY=> 'wednesday',
+						MCAL_M_THURSDAY	=> 'thursday',
+						MCAL_M_FRIDAY	=> 'friday',
+					);
+					if ($weekstart != 'Saturday') $cell['sel_options'][MCAL_M_SATURDAY] = 'saturday';
+					if ($weekstart == 'Monday') $cell['sel_options'][MCAL_M_SUNDAY] = 'sunday';
+					if ($rows >= 2 && $type == 1) 
+					{
+						$cell['sel_options'] += array(
+							MCAL_M_ALLDAYS	=> 'all days',
+							MCAL_M_WEEKDAYS	=> 'working days',
+							MCAL_M_WEEKEND	=> 'weekend',
+						);
+					}
+					$value_in = $value;
+					$value = array();
+					$readonly = $cell['readonly'] || $readonlys;
+					foreach($cell['sel_options'] as $val => $lable)
+					{
+						if (($value_in & $val) == $val)
+						{
+							$value[] = $val;
+							
+							if ($val == MCAL_M_ALLDAYS || 
+								$val == MCAL_M_WEEKDAYS && $value_in == MCAL_M_WEEKDAYS ||
+								$val == MCAL_M_WEEKEND && $value_in == MCAL_M_WEEKEND)
+							{
+								break;	// dont set the others
+							}			
+						}
+					}
+					if (!$readonly)
+					{
+						$GLOBALS['egw_info']['etemplate']['to_process'][$name] = 'ext-select-dow';
+					}
+					$cell['size'] = $rows.($type2 ? ','.$type2 : '');
+					break;
 
 				case 'select-day':
 					$type = 1;
@@ -307,22 +430,32 @@
 					$cell['no_lang'] = True;
 					break;
 					
+				case 'select-hour':
+					for ($h = 0; $h <= 23; ++$h)
+					{
+						$cell['sel_options'][$h] = $GLOBALS['egw_info']['user']['preferences']['common']['timeformat'] == 12 ?
+							(($h % 12 ? $h % 12 : 12).' '.($h < 12 ? lang('am') : lang('pm'))) : 
+							sprintf('%02d',$h);
+					}
+					$cell['no_lang'] = True;
+					break;
+					
 				case 'select-app':	// type2: ''=users enabled apps, 'installed', 'all' = not installed ones too
 					$apps = array();
-					foreach ($GLOBALS['phpgw_info']['apps'] as $app => $data)
+					foreach ($GLOBALS['egw_info']['apps'] as $app => $data)
 					{
-						if (!$type2 || $GLOBALS['phpgw_info']['user']['apps'][$app])
+						if (!$type2 || $GLOBALS['egw_info']['user']['apps'][$app])
 						{
 							$apps[$app] = $data['title'] ? $data['title'] : lang($app);
 						}
 					}
 					if ($type2 == 'all')
 					{
-						$dir = opendir(PHPGW_SERVER_ROOT);
+						$dir = opendir(EGW_SERVER_ROOT);
 						while ($file = readdir($dir))
 						{
-							if (@is_dir(PHPGW_SERVER_ROOT."/$file/setup") && $file[0] != '.' &&
-							    !isset($apps[$app = basename($file)]))
+							if (@is_dir(EGW_SERVER_ROOT."/$file/setup") && $file[0] != '.' &&
+									!isset($apps[$app = basename($file)]))
 							{
 								$apps[$app] = $app . ' (*)';
 							}
@@ -348,6 +481,9 @@
 			return True;	// extra Label Ok
 		}
 
+		/**
+		 * internal function to format account-data
+		 */
 		function accountInfo($id,$acc=0,$longnames=0,$show_type=0)
 		{
 			if (!$id)
@@ -357,14 +493,18 @@
 
 			if (!is_array($acc))
 			{
-				$data = $GLOBALS['phpgw']->accounts->get_account_data($id);
+				$data = $GLOBALS['egw']->accounts->get_account_data($id);
 				foreach(array('type','lid','firstname','lastname') as $name)
 				{
 					$acc['account_'.$name] = $data[$id][$name];
 				}
 			}
 			$info = $show_type ? '('.$acc['account_type'].') ' : '';
-
+			
+			if ($acc['account_type'] == 'g')
+			{
+				$longnames = 1;
+			}
 			switch ($longnames)
 			{
 				case 2:
@@ -378,10 +518,48 @@
 					$info .= $acc['account_lid'];
 					break;
 				default:			// use the phpgw default
-					$info = $GLOBALS['phpgw']->common->display_fullname($acc['account_lid'],
+					$info = $GLOBALS['egw']->common->display_fullname($acc['account_lid'],
 						$acc['account_firstname'],$acc['account_lastname']);
 					break;
 			}
 			return $info;
 		}
+		
+		/**
+		 * postprocessing method, called after the submission of the form
+		 *
+		 * It has to copy the allowed/valid data from $value_in to $value, otherwise the widget
+		 * will return no data (if it has a preprocessing method). The framework insures that
+		 * the post-processing of all contained widget has been done before.
+		 *
+		 * Only used by select-dow so far
+		 *
+		 * @param string $name form-name of the widget
+		 * @param mixed &$value the extension returns here it's input, if there's any
+		 * @param mixed &$extension_data persistent storage between calls or pre- and post-process
+		 * @param boolean &$loop can be set to true to request a re-submision of the form/dialog
+		 * @param object &$tmpl the eTemplate the widget belongs too
+		 * @param mixed &value_in the posted values (already striped of magic-quotes)
+		 * @return boolean true if $value has valid content, on false no content will be returned!
+		 */
+		function post_process($name,&$value,&$extension_data,&$loop,&$tmpl,$value_in)
+		{
+			switch ($extension_data['type'])
+			{
+				case 'select-dow':
+					$value = 0;
+					if (!is_array($value_in)) $value_in = explode(',',$value_in);
+					foreach($value_in as $val)
+					{
+						$value |= $val;
+					}
+					//echo "<p>select_widget::post_process('$name',...,'$value_in'): value='$value'</p>\n";
+					break;
+				default:
+					$value = $value_in;
+					break;
+			}
+			//echo "<p>select_widget::post_process('$name',,'$extension_data',,,'$value_in'): value='$value', is_null(value)=".(int)is_null($value)."</p>\n";
+			return true;
+		}
 	}
