@@ -1,9 +1,9 @@
 <?php
 	/***************************************************************************\
-	* phpGroupWare - FeLaMiMail                                                 *
+	* eGroupWare - FeLaMiMail                                                   *
 	* http://www.linux-at-work.de                                               *
 	* http://www.phpgw.de                                                       *
-	* http://www.phpgroupware.org                                               *
+	* http://www.egroupware.org                                                 *
 	* Written by : Lars Kneschke [lkneschke@linux-at-work.de]                   *
 	* -------------------------------------------------                         *
 	* This program is free software; you can redistribute it and/or modify it   *
@@ -11,7 +11,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.bocompose.inc.php,v 1.17 2004/04/04 20:59:43 lkneschke Exp $ */
+	/* $Id: class.bocompose.inc.php 19571 2005-11-03 09:17:37Z lkneschke $ */
 
 	class bocompose
 	{
@@ -27,10 +27,10 @@
 		function bocompose($_composeID = '', $_charSet = 'iso-8859-1')
 		{
 			$this->displayCharset	= strtolower($_charSet);
-			$this->bopreferences	= CreateObject('felamimail.bopreferences');
-			$this->bofelamimail	= CreateObject('felamimail.bofelamimail',$_charSet);
+			$this->bopreferences	=& CreateObject('felamimail.bopreferences');
+			$this->bofelamimail	=& CreateObject('felamimail.bofelamimail',$_charSet);
 			$this->preferences	= $this->bopreferences->getPreferences();
-			$this->botranslation	= CreateObject('phpgwapi.translation');
+			$this->botranslation	=& CreateObject('phpgwapi.translation');
 
 			if (!empty($_composeID))
 			{
@@ -39,6 +39,13 @@
 			}
 		}
 		
+		/**
+		 * adds uploaded files or files in eGW's temp directory as attachments
+		 *
+		 * It also stores the given data in the session
+		 *
+		 * @param array $_formData fields of the compose form (to,cc,bcc,reply_to,subject,body,priority,signature), plus data of the file (name,file,size,type)
+		 */
 		function addAttachment($_formData)
 		{
 			$this->sessionData['to']	= $_formData['to'];
@@ -50,27 +57,29 @@
 			$this->sessionData['priority']	= $_formData['priority'];
 			$this->sessionData['signature'] = $_formData['signature'];
 			
-			#while(list($key,$value) = each($GLOBALS['phpgw_info']['user']))
+			#while(list($key,$value) = each($GLOBALS['egw_info']['user']))
 			#{
 			#	print "$key: $value<br>";
 			#}
 			
-			if ($_formData['size'] != 0)
+			// to gard against exploidts the file must be either uploaded or be in the temp_dir
+			if ($_formData['size'] != 0 && (is_uploaded_file($_formData['file']) || 
+				realpath(dirname($_formData['file'])) == realpath($GLOBALS['egw_info']['server']['temp_dir'])))
 			{
-				// ensure existance of PHPGROUPWARE temp dir
+				// ensure existance of eGW temp dir
 				// note: this is different from apache temp dir, 
 				// and different from any other temp file location set in php.ini
-				if (!file_exists($GLOBALS['phpgw_info']['server']['temp_dir']))
+				if (!file_exists($GLOBALS['egw_info']['server']['temp_dir']))
 				{
-					@mkdir($GLOBALS['phpgw_info']['server']['temp_dir'],0700);
+					@mkdir($GLOBALS['egw_info']['server']['temp_dir'],0700);
 				}
 				
 				// if we were NOT able to create this temp directory, then make an ERROR report
-				if (!file_exists($GLOBALS['phpgw_info']['server']['temp_dir']))
+				if (!file_exists($GLOBALS['egw_info']['server']['temp_dir']))
 				{
 					$alert_msg .= 'Error:'.'<br>'
 						.'Server is unable to access phpgw tmp directory'.'<br>'
-						.$GLOBALS['phpgw_info']['server']['temp_dir'].'<br>'
+						.$GLOBALS['egw_info']['server']['temp_dir'].'<br>'
 						.'Please check your configuration'.'<br>'
 						.'<br>';
 				}
@@ -84,14 +93,20 @@
 					$_formData['type'] = $mime_type_default;
 				}
 				
-				$tmpFileName = $GLOBALS['phpgw_info']['server']['temp_dir'].
+				$tmpFileName = $GLOBALS['egw_info']['server']['temp_dir'].
 					SEP.
-					$GLOBALS['phpgw_info']['user']['account_id'].
+					$GLOBALS['egw_info']['user']['account_id'].
 					$this->composeID.
 					basename($_formData['file']);
 				
-				copy($_formData['file'],$tmpFileName);
-				
+				if (is_uploaded_file($_formData['file']))
+				{
+					move_uploaded_file($_formData['file'],$tmpFileName);	// requirement for safe_mode!
+				}
+				else
+				{
+					rename($_formData['file'],$tmpFileName);
+				}
 				$this->sessionData['attachments'][]=array
 				(
 					'name'	=> $_formData['name'],
@@ -150,7 +165,7 @@
 		
 		function getForwardData($_uid, $_partID, $_folder)
 		{
-			$bofelamimail    = CreateObject('felamimail.bofelamimail',$this->displayCharset);
+			$bofelamimail    =& CreateObject('felamimail.bofelamimail',$this->displayCharset);
 			$bofelamimail->openConnection();
 
 			// get message headers for specified message
@@ -177,7 +192,7 @@
 		// all: for a reply to all
 		function getReplyData($_mode, $_uid, $_partID)
 		{
-			$bofelamimail    = CreateObject('felamimail.bofelamimail',$this->displayCharset);
+			$bofelamimail    =& CreateObject('felamimail.bofelamimail',$this->displayCharset);
 			$bofelamimail->openConnection();
 			
 			// get message headers for specified message
@@ -344,19 +359,19 @@
 		
 		function restoreSessionData()
 		{
-			$this->sessionData = $GLOBALS['phpgw']->session->appsession('compose_session_data_'.$this->composeID);
+			$this->sessionData = $GLOBALS['egw']->session->appsession('compose_session_data_'.$this->composeID);
 			#print "bocompose after restore<pre>";print_r($this->sessionData);print"</pre>";
 		}
 		
 		function saveSessionData()
 		{
-			$GLOBALS['phpgw']->session->appsession('compose_session_data_'.$this->composeID,'',$this->sessionData);
+			$GLOBALS['egw']->session->appsession('compose_session_data_'.$this->composeID,'',$this->sessionData);
 		}
 
 		function send($_formData)
 		{
-			$bofelamimail	= CreateObject('felamimail.bofelamimail',$this->displayCharset);
-			$mail 		= CreateObject('phpgwapi.phpmailer');
+			$bofelamimail	=& CreateObject('felamimail.bofelamimail',$this->displayCharset);
+			$mail 		=& CreateObject('phpgwapi.phpmailer');
 			
 			$this->sessionData['to']	= trim($_formData['to']);
 			$this->sessionData['cc']	= trim($_formData['cc']);
@@ -368,17 +383,17 @@
 			$this->sessionData['signature']	= $_formData['signature'];
 
 
-			$userLang = $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'];
-			$langFile = PHPGW_SERVER_ROOT."/phpgwapi/setup/phpmailer.lang-$userLang.php";
+			$userLang = $GLOBALS['egw_info']['user']['preferences']['common']['lang'];
+			$langFile = EGW_SERVER_ROOT."/phpgwapi/setup/phpmailer.lang-$userLang.php";
 			if(file_exists($langFile))
 			{
-				$mail->SetLanguage($userLang, PHPGW_SERVER_ROOT."/phpgwapi/setup/");
+				$mail->SetLanguage($userLang, EGW_SERVER_ROOT."/phpgwapi/setup/");
 			}
 			else
 			{
-				$mail->SetLanguage("en", PHPGW_SERVER_ROOT."/phpgwapi/setup/");
+				$mail->SetLanguage("en", EGW_SERVER_ROOT."/phpgwapi/setup/");
 			}
-			$mail->PluginDir = PHPGW_SERVER_ROOT."/phpgwapi/inc/";
+			$mail->PluginDir = EGW_SERVER_ROOT."/phpgwapi/inc/";
 			
 			#print $this->sessionData['uid']."<bR>";
 			#print $this->sessionData['folder']."<bR>";
@@ -386,7 +401,7 @@
 			#_debug_array($_formData);
 			#exit;
 			
-			#include(PHPGW_APP_ROOT . "/config/config.php");
+			#include(EGW_APP_ROOT . "/config/config.php");
 				
 			$mail->IsSMTP();
 			$mail->From 	= $this->preferences['emailAddress'][0]['address'];
@@ -459,7 +474,7 @@
 			$mail->Body    = $this->sessionData['body'];
 			if (!empty($this->sessionData['signature']))
 			{
-				$mail->Body	.= "\r\n--\r\n";
+				$mail->Body	.= "\r\n-- \r\n";
 				$mail->Body	.= $this->sessionData['signature'];
 			}
 
@@ -514,7 +529,7 @@
 			if (isset($this->preferences['sentFolder']))
 			{
 				// mark message as answered
-				$bofelamimail = CreateObject('felamimail.bofelamimail');
+				$bofelamimail =& CreateObject('felamimail.bofelamimail');
 				$bofelamimail->openConnection($this->preferences['sentFolder']);
 				$bofelamimail->appendMessage($this->preferences['sentFolder'],
 								$mail->sentHeader,
@@ -526,7 +541,7 @@
 			if(isset($this->sessionData['uid']))
 			{
 				// mark message as answered
-				$bofelamimail = CreateObject('felamimail.bofelamimail',$this->sessionData['folder']);
+				$bofelamimail =& CreateObject('felamimail.bofelamimail',$this->sessionData['folder']);
 				$bofelamimail->openConnection();
 				$bofelamimail->flagMessages("answered",array('0' => $this->sessionData['uid']));
 				$bofelamimail->closeConnection();
@@ -553,7 +568,7 @@
 		
 		function setDefaults()
 		{
-			$this->sessionData['signature']	= $this->preferences['signature'];
+			$this->sessionData['signature']	= $GLOBALS['egw']->preferences->parse_notify($this->preferences['signature']);
 			
 			$this->saveSessionData();
 		}
@@ -569,6 +584,6 @@
 				return $_string;
 			}
 		}
-                              
+															
 
 }
