@@ -26,7 +26,7 @@
 	*
 	*/
 	
-	/* $Id: class.uidisplay.inc.php,v 1.31.2.4 2004/08/27 05:08:50 alpeb Exp $ */
+	/* $Id: class.uidisplay.inc.php 22128 2006-07-20 07:13:35Z lkneschke $ */
 
 	class uidisplay
 	{
@@ -40,13 +40,13 @@
 
 		function uidisplay()
 		{
-			$this->t 		= CreateObject('phpgwapi.Template',PHPGW_APP_TPL);
-			$this->displayCharset   = $GLOBALS['phpgw']->translation->charset();
-			$this->bofelamimail	= CreateObject('felamimail.bofelamimail',$this->displayCharset);
-			$this->bofilter 	= CreateObject('felamimail.bofilter');
-			$this->bopreferences	= CreateObject('felamimail.bopreferences');
-			$this->kses		= CreateObject('phpgwapi.kses');
-			$this->botranslation	= CreateObject('phpgwapi.translation');
+			$this->t 		=& CreateObject('phpgwapi.Template',EGW_APP_TPL);
+			$this->displayCharset   = $GLOBALS['egw']->translation->charset();
+			$this->bofelamimail	=& CreateObject('felamimail.bofelamimail',$this->displayCharset);
+			$this->bofilter 	=& CreateObject('felamimail.bofilter');
+			$this->bopreferences	=& CreateObject('felamimail.bopreferences');
+			$this->kses		=& CreateObject('phpgwapi.kses');
+			$this->botranslation	=& CreateObject('phpgwapi.translation');
 			
 			$this->mailPreferences	= $this->bopreferences->getPreferences();
 			
@@ -54,28 +54,29 @@
 			
 			$this->mailbox		= $this->bofelamimail->sessionData['mailbox'];
 			$this->sort		= $this->bofelamimail->sessionData['sort'];
+			$this->activeFilter	= $activeFilter = (isset($this->bofelamimail->sessionData['activeFilter'])?$this->bofelamimail->sessionData['activeFilter']:-1);
 			
-			$this->uid		= $GLOBALS['HTTP_GET_VARS']['uid'];
+			$this->uid		= $_GET['uid'];
 			
-			if(isset($GLOBALS['HTTP_GET_VARS']['part']) &&
-				is_numeric($GLOBALS['HTTP_GET_VARS']['part']))
+			if(isset($_GET['partID']) &&
+				is_numeric($_GET['partID']))
 			{
-				$this->partID = $GLOBALS['HTTP_GET_VARS']['part'];
+				$this->partID = $_GET['partID'];
 			}
 			else
 			{
 				$this->partID = 0;
 			}
 
-			$this->bocaching	= CreateObject('felamimail.bocaching',
+			$this->bocaching	=& CreateObject('felamimail.bocaching',
 							$this->mailPreferences['imapServerAddress'],
 							$this->mailPreferences['username'],
 							$this->mailbox);
 
-			$this->rowColor[0] = $GLOBALS['phpgw_info']["theme"]["bg01"];
-			$this->rowColor[1] = $GLOBALS['phpgw_info']["theme"]["bg02"];
+			$this->rowColor[0] = $GLOBALS['egw_info']["theme"]["bg01"];
+			$this->rowColor[1] = $GLOBALS['egw_info']["theme"]["bg02"];
 
-			if($GLOBALS['HTTP_GET_VARS']['showHeader'] == "false")
+			if($_GET['showHeader'] == "false")
 			{
 				$this->bofelamimail->sessionData['showHeader'] = 'False';
 				$this->bofelamimail->saveSessionData();
@@ -130,20 +131,25 @@
 		
 		function display()
 		{
-			$partID		= $_GET['part'];
-			$transformdate	= CreateObject('felamimail.transformdate');
-			$htmlFilter	= CreateObject('felamimail.htmlfilter');
-
+			$partID		= $_GET['partID'];
+			$transformdate	=& CreateObject('felamimail.transformdate');
+			$htmlFilter	=& CreateObject('felamimail.htmlfilter');
+			$uiWidgets	=& CreateObject('felamimail.uiwidgets');
+			// (regis) seems to be necessary to reopen...
+			$this->bofelamimail->reopen($this->mailbox);
 			$headers	= $this->bofelamimail->getMessageHeader($this->uid, $partID);
 			$rawheaders	= $this->bofelamimail->getMessageRawHeader($this->uid, $partID);
 			$bodyParts	= $this->bofelamimail->getMessageBody($this->uid,'',$partID);
 			$attachments	= $this->bofelamimail->getMessageAttachments($this->uid,$partID);
 			$filterList 	= $this->bofilter->getFilterList();
-			$activeFilter 	= $this->bofilter->getActiveFilter();
-			$filter 	= $filterList[$activeFilter];
+			$filter 	= $filterList[$this->activeFilter];
 			$nextMessage	= $this->bocaching->getNextMessage($this->uid, $this->sort, $filter);
 
-			$webserverURL	= $GLOBALS['phpgw_info']['server']['webserver_url'];
+			$webserverURL	= $GLOBALS['egw_info']['server']['webserver_url'];
+
+			$nonDisplayAbleCharacters = array('[\016]','[\017]',
+					'[\020]','[\021]','[\022]','[\023]','[\024]','[\025]','[\026]','[\027]',
+					'[\030]','[\031]','[\032]','[\033]','[\034]','[\035]','[\036]','[\037]');
 
 			#print "<pre>";print_r($rawheaders);print"</pre>";exit;
 
@@ -183,15 +189,15 @@
 			
 			$this->bofelamimail->closeConnection();
 			
+			$this->display_app_header();
 			if(!isset($_GET['printable']))
 			{
-				$this->display_app_header();
 				$this->t->set_file(array("displayMsg" => "view_message.tpl"));
 			}
 			else
 			{
 				$this->t->set_file(array("displayMsg" => "view_message_printable.tpl"));
-				$this->t->set_var('charset',$GLOBALS['phpgw']->translation->charset());
+				$this->t->set_var('charset',$GLOBALS['egw']->translation->charset());
 			}
 
 			$this->t->set_block('displayMsg','message_main');
@@ -209,45 +215,10 @@
 			
 			$this->translate();
 			
-//			if(!isset($GLOBALS['HTTP_GET_VARS']['printable']))
+//			if(!isset($_GET['printable']))
 //			{
-				// navbar
-				$linkData = array
-				(
-					'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen'
-				);
-				if($this->mailPreferences['messageNewWindow'])
-				{
-					$this->t->set_var("link_message_list","javascript:window.close();");
-				}
-				else
-				{
-					$this->t->set_var("link_message_list",$GLOBALS['phpgw']->link('/felamimail/index.php',$linkData));
-				}
-	
-				$linkData = array
-				(
-					'menuaction'	=> 'felamimail.uicompose.compose'
-				);
-				$this->t->set_var("link_compose",$GLOBALS['phpgw']->link('/index.php',$linkData));
-				$this->t->set_var('folder_name',$this->bofelamimail->sessionData['mailbox']);
-				
-				// return link to main message
-				if($partID != '')
-				{
-					$linkData = array
-					(
-						'menuaction'	=> 'felamimail.uidisplay.display',
-						'showHeader'	=> 'false',
-						'uid'		=> $this->uid
-					);
-					$this->t->set_var('link_mainmessage','<a href="'.$GLOBALS['phpgw']->link('/index.php',$linkData).'">'.lang('mainmessage').'</a>');
-				}
-				else
-				{
-					$this->t->set_var('link_mainmessage','');
-				}
-
+			// navbar start
+				// reply url
 				$linkData = array
 				(
 					'menuaction'	=> 'felamimail.uicompose.reply',
@@ -255,8 +226,9 @@
 				);
 				if($partID != '')
 					$linkData['part_id'] = $partID;
-				$this->t->set_var("link_reply",$GLOBALS['phpgw']->link('/index.php',$linkData));
+				$replyURL = $GLOBALS['egw']->link('/index.php',$linkData);
 
+				// reply all url
 				$linkData = array
 				(
 					'menuaction'	=> 'felamimail.uicompose.replyAll',
@@ -264,8 +236,9 @@
 				);
 				if($partID != '')
 					$linkData['part_id'] = $partID;
-				$this->t->set_var("link_reply_all",$GLOBALS['phpgw']->link('/index.php',$linkData));
+				$replyAllURL = $GLOBALS['egw']->link('/index.php',$linkData);
 
+				// forward url
 				$linkData = array
 				(
 					'menuaction'	=> 'felamimail.uicompose.forward',
@@ -273,22 +246,41 @@
 				);
 				if($partID != '')
 					$linkData['part_id'] = $partID;
-				$this->t->set_var("link_forward",$GLOBALS['phpgw']->link('/index.php',$linkData));	
+				$forwardURL = $GLOBALS['egw']->link('/index.php',$linkData);	
 
+				//delete url
 				$linkData = array
 				(
 					'menuaction'	=> 'felamimail.uifelamimail.deleteMessage',
 					'message'	=> $this->uid
 				);
-				$this->t->set_var("link_delete",$GLOBALS['phpgw']->link('/index.php',$linkData));
+				$deleteURL = $GLOBALS['egw']->link('/index.php',$linkData);
 
-				$linkData = array
-				(
-					'menuaction'	=> 'felamimail.uidisplay.showHeader',
-					'uid'		=> $this->uid
+				$navbarImages = array(
+					'mail_reply'	=> array(
+						'action'	=> "window.location.href = '$replyURL'",
+						'tooltip'	=> lang('reply'),
+					),
+					'mail_replyall'	=> array(
+						'action'	=> "window.location.href = '$replyAllURL'",
+						'tooltip'	=> lang('reply all'),
+					),
+					'mail_forward'	=> array(
+						'action'	=> "window.location.href = '$forwardURL'",
+						'tooltip'	=> lang('forward'),
+					),
+					'delete'	=> array(
+						'action'	=> "window.location.href = '$deleteURL'",
+						'tooltip'	=> lang('delete'),
+					),
 				);
-				$this->t->set_var("link_header",$GLOBALS['phpgw']->link('/index.php',$linkData));
+				foreach($navbarImages as $buttonName => $buttonInfo)
+				{
+					$navbarButtons .= $uiWidgets->navbarButton($buttonName, $buttonInfo['action'], $buttonInfo['tooltip']);
+				}
+				$navbarButtons .= $uiWidgets->navbarSeparator();
 
+				// print url
 				$linkData = array
 				(
 					'menuaction'	=> 'felamimail.uidisplay.display',
@@ -296,9 +288,24 @@
 					'uid'		=> $this->uid
 				);
 				if($partID != '')
-					$linkData['part'] = $partID;
-				$this->t->set_var("link_printable",$GLOBALS['phpgw']->link('/index.php',$linkData));
+					$linkData['partID'] = $partID;
+				$printURL = $GLOBALS['egw']->link('/index.php',$linkData);
+
+				$navbarImages = array(
+					'fileprint' => array(
+						'action'	=> "window.location.href = '$printURL'",
+						'tooltip'	=> lang('print it'),
+					),
+				);
 				
+				foreach($navbarImages as $buttonName => $buttonData)
+				{
+					$navbarButtons .= $uiWidgets->navbarButton($buttonName, $buttonData['action'], $buttonData['tooltip']);
+				}
+				$this->t->set_var('navbarButtonsLeft',$navbarButtons);
+				
+				$navbarButtons = '';
+
 				if($nextMessage['previous'])
 				{
 					$linkData = array
@@ -307,12 +314,12 @@
 						'showHeader'	=> 'false',
 						'uid'		=> $nextMessage['previous']
 					);
-					$this->t->set_var('previous_url',$GLOBALS['phpgw']->link('/index.php',$linkData));
-					$this->t->parse('previous_message','previous_message_block',True);
+					$previousURL = $GLOBALS['egw']->link('/index.php',$linkData);
+					$previousURL = "window.location.href = '$previousURL'";
 				}
 				else
 				{
-					$this->t->set_var('previous_message',lang('previous message'));
+					$previousURL = '';
 				}
 	
 				if($nextMessage['next'])
@@ -323,28 +330,36 @@
 						'showHeader'	=> 'false',
 						'uid'		=> $nextMessage['next']
 					);
-					$this->t->set_var('next_url',$GLOBALS['phpgw']->link('/index.php',$linkData));
-					$this->t->parse('next_message','next_message_block',True);
+					$nextURL = $GLOBALS['egw']->link('/index.php',$linkData);
+					$nextURL = "window.location.href = '$nextURL'";
 				}
 				else
 				{
-					$this->t->set_var('next_message',lang('next message'));
+					$nextURL = '';
 				}
-	
-				$langArray = array
-				(
-					'lang_messagelist'      => lang('Message List'),
-					'lang_compose'          => lang('Compose'),
-					'lang_delete'           => lang('Delete'),
-					'lang_forward'          => lang('Forward'),
-					'lang_reply'            => lang('Reply'),
-					'lang_reply_all'        => lang('Reply All'),
-					'lang_back_to_folder'   => lang('back to folder'),
-					'print_navbar'		=> '',
-					'app_image_path'        => PHPGW_IMAGES
+
+				$navbarImages = array(
+					'down.button'	=> array(
+						'action'	=> $nextURL,
+						'tooltip'	=> lang('next message'),
+					),
+					'up.button'	=> array(
+						'action'	=> $previousURL,
+						'tooltip'	=> lang('previous message'),
+					),
 				);
-				$this->t->set_var($langArray);
+				
+				foreach($navbarImages as $buttonName => $buttonData)
+				{
+					$navbarButtons .= $uiWidgets->navbarButton($buttonName, $buttonData['action'], $buttonData['tooltip'], 'right');
+				}
+
+				$this->t->set_var('navbarButtonsRight',$navbarButtons);
+				
 				$this->t->parse('navbar','message_navbar',True);
+
+			// navbar end
+			
 /*			}
 			else
 			{	
@@ -357,7 +372,7 @@
 					'lang_reply_all'        => lang('Reply All'),
 					'lang_back_to_folder'   => lang('back to folder'),
 					'navbar'		=> '',
-					'app_image_path'        => PHPGW_IMAGES
+					'app_image_path'        => EGW_IMAGES
 				);
 				$this->t->set_var($langArray);
 				$this->t->parse('print_navbar','message_navbar_print',True);
@@ -419,17 +434,17 @@
 			{
 				$tmpdate = $date = array("","","","","","");
 			}
-                                                                                                                                                                                                                                                                                                                
+																																																																																																																																																								
 			$this->t->set_var("date_data",
-				@htmlspecialchars($GLOBALS['phpgw']->common->show_date($transformdate->getTimeStamp($tmpdate)),
+				@htmlspecialchars($GLOBALS['egw']->common->show_date($transformdate->getTimeStamp($tmpdate)),
 				ENT_QUOTES,$this->displayCharset));
 			$this->t->set_var("subject_data",
-				@htmlspecialchars($this->bofelamimail->decode_header($headers->subject),
+				@htmlspecialchars($this->bofelamimail->decode_header(preg_replace($nonDisplayAbleCharacters,'',$headers->subject)),
 				ENT_QUOTES,$this->displayCharset));
 			//if(isset($organization)) exit;
 			$this->t->parse("header","message_header",True);
 
-			$this->t->set_var("rawheader",@htmlentities($rawheaders,ENT_QUOTES,$this->displayCharset));
+			$this->t->set_var("rawheader",@htmlentities(preg_replace($nonDisplayAbleCharacters,'',$rawheaders),ENT_QUOTES,$this->displayCharset));
 
 			#$this->kses->AddProtocol("http");
 			$this->kses->AddHTML(
@@ -571,11 +586,15 @@
 			{
 				$bodyParts[$i]['body']= 
 					$this->botranslation->convert($bodyParts[$i]['body'],
-								      strtolower($bodyParts[$i]['charSet']));
+											strtolower($bodyParts[$i]['charSet']));
 
 				if($bodyParts[$i]['mimeType'] == 'text/plain')
 				{
 					$newBody	= $bodyParts[$i]['body'];
+					// MS-Outlookbug workaround (don't break links)
+					$newBody	= preg_replace("!((http(s?)://)|((www|ftp)\.))(([^\n\t\r]+)([=](\r)?\n))+!i", 
+							"$1$7", 
+							$newBody);
 
 					$newBody	= @htmlentities($bodyParts[$i]['body'],ENT_QUOTES,$this->displayCharset);
 					$newBody	= $this->bofelamimail->wordwrap($newBody,90,"\n");
@@ -597,7 +616,7 @@
 					(
 						'menuaction'    => 'felamimail.uicompose.compose'
 					);
-					$link = $GLOBALS['phpgw']->link('/index.php',$linkData);
+					$link = $GLOBALS['egw']->link('/index.php',$linkData);
 					$newBody = preg_replace("/(?<=\s{1}|&lt;)(([\w\.,-.,_.,0-9.]+)(@)([\w\.,-.,_.,0-9.]+))/ie", 
 						"'<a href=\"$link&send_to='.base64_encode('$0').'\"><font color=\"blue\">$0</font></a>'", $newBody);
 
@@ -629,12 +648,12 @@
 					(
 						'menuaction'    => 'felamimail.uicompose.compose'
 					);
-					$link = $GLOBALS['phpgw']->link('/index.php',$linkData);
+					$link = $GLOBALS['egw']->link('/index.php',$linkData);
 					$newBody = preg_replace("/href=(\"|\')mailto:([\w,\-,\/,\?,\=,\.,&amp;,!\n,\%,@,\*,#,:,~,\+]+)(\"|\')/ie", 
 						"'href=\"$link&send_to='.base64_encode('$2').'\"'", $newBody);
 					#print "<pre>".htmlentities($newBody)."</pre><hr>";
 
-					$link = $GLOBALS['phpgw']->link('/index.php',$linkData);
+					$link = $GLOBALS['egw']->link('/index.php',$linkData);
 					#$newBody = preg_replace("/(?<!:)(?<=\s{1}|&lt;)(([\w\.,-.,_.,0-9.]+)(@)([\w\.,-.,_.,0-9.]+))/ie", 
 					$newBody = preg_replace("/(?<!:)(([\w\.,-.,_.,0-9.]+)(@)([\w\.,-.,_.,0-9.]+))/ie", 
 						"'<a href=\"$link&send_to='.base64_encode('$0').'\"><font color=\"blue\">$0</font></a>'", $newBody);
@@ -648,6 +667,8 @@
 			$body = preg_replace("/(\\\\\\\\)([\w,\\\\,-]+)/i", 
 				"<a href=\"file:$1$2\" target=\"_blank\"><font color=\"blue\">$1$2</font></a>", $body);
 			
+			$body = preg_replace($nonDisplayAbleCharacters,'',$body);
+                                                                                                                                			
 				
 			$this->t->set_var("body",$body);
 			$this->t->set_var("signature",$sessionData['signature']);
@@ -660,10 +681,12 @@
 
 			if (is_array($attachments) && count($attachments) > 0)
 			{
+				#_debug_array($attachments);
 				$this->t->set_var('row_color',$this->rowColor[0]);
 				$this->t->set_var('name',lang('name'));
 				$this->t->set_var('type',lang('type'));
 				$this->t->set_var('size',lang('size'));
+				$this->t->set_var('url_img_save',$GLOBALS['egw']->common->image('felamimail','fileexport'));
 				#$this->t->parse('attachment_rows','attachment_row_bold',True);
 				foreach ($attachments as $key => $value)
 				{
@@ -676,37 +699,40 @@
 					switch($value['mimeType'])
 					{
 						case 'message/rfc822':
+						case 'message/delivery-status':
 							$linkData = array
 							(
 								'menuaction'	=> 'felamimail.uidisplay.display',
 								'uid'		=> $this->uid,
-								'part'		=> $value['partID']
+								'partID'	=> $value['partID']
 							);
-							$target = '';
+							$windowName = 'displayMessage_'.$this->uid.'_'.$value['partID'];
+							$linkView = "egw_openWindowCentered('".$GLOBALS['egw']->link('/index.php',$linkData)."','$windowName',700,egw_getWindowOuterHeight());";
 							break;
 						case 'image/jpeg':
 						case 'image/png':
 						case 'image/gif':
-						case 'application/pdf':
+						#case 'application/pdf':
 							$linkData = array
 							(
 								'menuaction'	=> 'felamimail.uidisplay.getAttachment',
 								'uid'		=> $this->uid,
-								'part'		=> $value['partID']
+								'partID'	=> $value['partID']
 							);
-							$target = '_blank';
+							$windowName = 'displayAttachment_'.$this->uid;
+							$linkView = "egw_openWindowCentered('".$GLOBALS['egw']->link('/index.php',$linkData)."','$windowName',800,600);";
 							break;
 						default:
 							$linkData = array
 							(
 								'menuaction'	=> 'felamimail.uidisplay.getAttachment',
 								'uid'		=> $this->uid,
-								'part'		=> $value['partID']
+								'partID'	=> $value['partID']
 							);
-							$target = '';
+							$linkView = "window.location.href = '".$GLOBALS['egw']->link('/index.php',$linkData)."';";
 							break;
 					}
-					$this->t->set_var("link_view",$GLOBALS['phpgw']->link('/index.php',$linkData));
+					$this->t->set_var("link_view",$linkView);
 					$this->t->set_var("target",$target);
 
 					$linkData = array
@@ -714,9 +740,9 @@
 						'menuaction'	=> 'felamimail.uidisplay.getAttachment',
 						'mode'		=> 'save',
 						'uid'		=> $this->uid,
-						'part'		=> $value['partID']
+						'partID'	=> $value['partID']
 					);
-					$this->t->set_var("link_save",$GLOBALS['phpgw']->link('/index.php',$linkData));
+					$this->t->set_var("link_save",$GLOBALS['egw']->link('/index.php',$linkData));
 					
 					$this->t->parse('attachment_rows','message_attachement_row',True);
 				}
@@ -735,19 +761,22 @@
 
 		function display_app_header()
 		{
-			if(!@is_object($GLOBALS['phpgw']->js))
+			if(!@is_object($GLOBALS['egw']->js))
 			{
-				$GLOBALS['phpgw']->js = CreateObject('phpgwapi.javascript');
+				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
+			}
+			if(!isset($_GET['printable']))
+			{
+				$GLOBALS['egw']->js->validate_file('tabs','tabs');
+				$GLOBALS['egw']->js->validate_file('jscode','view_message','felamimail');
+				$GLOBALS['egw']->js->set_onload('javascript:initAll();');
+			}
+			else
+			{
+				$GLOBALS['egw']->js->set_onload('javascript:window.print()');
 			}
-			$GLOBALS['phpgw']->js->validate_file('tabs','tabs');
-			$GLOBALS['phpgw']->js->validate_file('jscode','view_message','felamimail');
-			$GLOBALS['phpgw']->js->set_onload('javascript:initAll();');
 			
-			$GLOBALS['phpgw']->common->phpgw_header();
-			if(!$this->mailPreferences['messageNewWindow'])
-			{
-				echo parse_navbar();
-			}
+			$GLOBALS['egw']->common->egw_header();
 		}
 
 		function emailAddressToHTML($_emailAddress)
@@ -775,11 +804,13 @@
 							'menuaction'	=> 'felamimail.uicompose.compose',
 							'send_to'	=> base64_encode($newSenderAddress)
 						);
-						$link = $GLOBALS['phpgw']->link('/index.php',$linkData);
+						$link = $GLOBALS['egw']->link('/index.php',$linkData);
 						$senderAddress .= sprintf('<a href="%s" title="%s">%s</a>',
 									$link,
 									@htmlentities($newSenderAddress,ENT_QUOTES,$this->displayCharset),
 									@htmlentities($val->personal,ENT_QUOTES,$this->displayCharset));
+						//TODO: This uses old addressbook code, which should be removed in Version 1.4
+						//Please use addressbook.uicontacts.edit with proper paramenters
 						$linkData = array
 						(
 							'menuaction'	=> 'addressbook.uiaddressbook.add_email',
@@ -787,13 +818,15 @@
 							'name'		=> $val->personal,
 							'referer'	=> $_SERVER['PHP_SELF'].'?'.$_SERVER['QUERY_STRING']
 						);
-						$urlAddToAddressbook = $GLOBALS['phpgw']->link('/index.php',$linkData);
-						$image = $GLOBALS['phpgw']->common->image('felamimail','sm_envelope');
-						$senderAddress .= sprintf('<a href="%s">
+						$urlAddToAddressbook = $GLOBALS['egw']->link('/index.php',$linkData);
+						$onClick = "window.open(this,this.target,'dependent=yes,width=850,height=440,location=no,menubar=no,toolbar=no,scrollbars=yes,status=yes'); return false;";
+						$image = $GLOBALS['egw']->common->image('felamimail','sm_envelope');
+						$senderAddress .= sprintf('<a href="%s" onClick="%s">
 							<img src="%s" width="10" height="8" border="0" 
 							align="absmiddle" alt="%s" 
 							title="%s"></a>',
 							$urlAddToAddressbook,
+							$onClick,
 							$image,
 							lang('add to addressbook'),
 							lang('add to addressbook'));
@@ -806,22 +839,26 @@
 							'menuaction'	=> 'felamimail.uicompose.compose',
 							'send_to'	=> base64_encode($tempSenderAddress)
 						);
-						$link = $GLOBALS['phpgw']->link('/index.php',$linkData);
+						$link = $GLOBALS['egw']->link('/index.php',$linkData);
 						$senderAddress .= sprintf('<a href="%s">%s</a>',
 									$link,@htmlentities($tempSenderAddress,ENT_QUOTES,$this->displayCharset));
+						//TODO: This uses old addressbook code, which should be removed in Version 1.4
+						//Please use addressbook.uicontacts.edit with proper paramenters
 						$linkData = array
 						(
 							'menuaction'	=> 'addressbook.uiaddressbook.add_email',
 							'add_email'	=> $tempSenderAddress,
 							'referer'	=> $_SERVER['PHP_SELF'].'?'.$_SERVER['QUERY_STRING']
 						);
-						$urlAddToAddressbook = $GLOBALS['phpgw']->link('/index.php',$linkData);
-						$image = $GLOBALS['phpgw']->common->image('felamimail','sm_envelope');
-						$senderAddress .= sprintf('<a href="%s">
+						$urlAddToAddressbook = $GLOBALS['egw']->link('/index.php',$linkData);
+						$onClick = "window.open(this,this.target,'dependent=yes,width=850,height=440,location=no,menubar=no,toolbar=no,scrollbars=yes,status=yes'); return false;";
+						$image = $GLOBALS['egw']->common->image('felamimail','sm_envelope');
+						$senderAddress .= sprintf('<a href="%s" onClick="%s">
 							<img src="%s" width="10" height="8" border="0" 
 							align="absmiddle" alt="%s" 
 							title="%s"></a>',
 							$urlAddToAddressbook,
+							$onClick,
 							$image,
 							lang('add to addressbook'),
 							lang('add to addressbook'));
@@ -837,22 +874,22 @@
 		function getAttachment()
 		{
 			
-			$part		= $GLOBALS['HTTP_GET_VARS']['part'];
+			$part		= $_GET['partID'];
 			
 			$attachment 	= $this->bofelamimail->getAttachment($this->uid,$part);
 			
 			$this->bofelamimail->closeConnection();
 			
-			header ("Content-Type: ".$attachment['type']."; name=\"".$attachment['filename']."\"");
-			if($GLOBALS['HTTP_GET_VARS']['mode'] == "save")
+			header ("Content-Type: ".$attachment['type']."; name=\"". $this->bofelamimail->decode_header($attachment['filename']) ."\"");
+			if($_GET['mode'] == "save")
 			{
 				// ask for download
-				header ("Content-Disposition: attachment; filename=\"".$attachment['filename']."\"");
+				header ("Content-Disposition: attachment; filename=\"". $this->bofelamimail->decode_header($attachment['filename']) ."\"");
 			}
 			else
 			{
 				// display it
-				header ("Content-Disposition: inline; filename=\"".$attachment['filename']."\"");
+				header ("Content-Disposition: inline; filename=\"". $this->bofelamimail->decode_header($attachment['filename']) ."\"");
 			}
 			header("Expires: 0");
 			// the next headers are for IE and SSL
@@ -861,9 +898,9 @@
 
 			echo $attachment['attachment'];
 			
-			$GLOBALS['phpgw']->common->phpgw_exit();
+			$GLOBALS['egw']->common->egw_exit();
 			exit;
-			                                
+																			
 		}
 		
 		function showHeader()
@@ -919,11 +956,11 @@
 			$this->t->set_var("lang_Message", lang('Message'));
 			$this->t->set_var("lang_Attachment", lang('attachments'));
 			$this->t->set_var("lang_Header_Lines", lang('Header Lines'));
-			
-			$this->t->set_var("th_bg",$GLOBALS['phpgw_info']["theme"]["th_bg"]);
-			$this->t->set_var("bg01",$GLOBALS['phpgw_info']["theme"]["bg01"]);
-			$this->t->set_var("bg02",$GLOBALS['phpgw_info']["theme"]["bg02"]);
-			$this->t->set_var("bg03",$GLOBALS['phpgw_info']["theme"]["bg03"]);
+
+			$this->t->set_var("th_bg",$GLOBALS['egw_info']["theme"]["th_bg"]);
+			$this->t->set_var("bg01",$GLOBALS['egw_info']["theme"]["bg01"]);
+			$this->t->set_var("bg02",$GLOBALS['egw_info']["theme"]["bg02"]);
+			$this->t->set_var("bg03",$GLOBALS['egw_info']["theme"]["bg03"]);
 		}
 }
 
