@@ -1,7 +1,7 @@
 <?php
 	/**************************************************************************\
-	* phpGroupWare - FeLaMiMail                                              *
-	* http://www.phpgroupware.org                                              *
+	* eGroupWare - FeLaMiMail                                                  *
+	* http://www.egroupware.org                                                *
 	* http://www.phpgw.de                                                      *
 	* http://www.linux-at-work.de                                              *
 	* Written by Lars Kneschke [lkneschke@linux-at-work.de]                    *
@@ -11,19 +11,20 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: index.php,v 1.9 2003/09/14 09:10:11 lkneschke Exp $ */
+	/* $Id: index.php 20295 2006-02-15 12:31:25Z  $ */
 
 	// this is to get css inclusion working
 	$_GET['menuaction']	= 'felamimail.uifelamimail.viewMainScreen';
 	
-	$phpgw_info = array();
-	$phpgw_info['flags'] = array
+	$egw_info = array();
+	$egw_info['flags'] = array
 	(
 		'currentapp' => 'felamimail',
 		'noheader'   => True,
-		'nonavbar'   => True
+		'nonavbar'   => True,
+		'include_xajax' => True,
 	);
-                
+								
 	include('../header.inc.php');
 
 	execmethod('felamimail.uifelamimail.viewMainScreen');
