@@ -9,30 +9,25 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: setup.inc.php,v 1.26 2004/07/02 22:31:52 ralfbecker Exp $ */
+	/* $Id: setup.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	$setup_info['filemanager']['name']    = 'filemanager';
 	$setup_info['filemanager']['title']   = 'Filemanager';
-	$setup_info['filemanager']['version'] = '1.0.0';
+	$setup_info['filemanager']['version'] = '1.2';
 	$setup_info['filemanager']['app_order'] = 6;
 	$setup_info['filemanager']['enable']  = 1;
 
 	/* The hooks this app includes, needed for hooks registration */
-	$setup_info['filemanager']['hooks'] = array
-	(
-		'add_def_pref',
-		'admin',
+	$setup_info['filemanager']['hooks'] = array(
 		'deleteaccount',
 		'settings',
 		'sidebox_menu',
-		'personalizer',
-		'preferences',
+		'preferences'
 	);
 
 	/* Dependencies for this app to work */
-	$setup_info['filemanager']['depends'][] = array
-	(
-		 'appname' => 'phpgwapi',
-		 'versions' => array('0.9.14','0.9.16','1.0.0')
+	$setup_info['filemanager']['depends'][] = array(
+		'appname' => 'phpgwapi',
+		'versions' => array('1.0.0','1.0.1','1.2')
 	);
 ?>
