@@ -10,55 +10,55 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: csv_import.php,v 1.20.2.1 2004/09/02 10:30:48 ralfbecker Exp $ */
+  /* $Id: csv_import.php 22223 2006-08-13 05:46:38Z ralfbecker $ */
 
-	$GLOBALS['phpgw_info']['flags'] = array(
+	$GLOBALS['egw_info']['flags'] = array(
 		'currentapp' => 'infolog',
 		'noheader'   => True,
 		'enable_contacts_class' => True,
 	);
 	include('../header.inc.php');
 
-	if (!isset($GLOBALS['phpgw_info']['user']['apps']['admin']) ||
-	    !$GLOBALS['phpgw_info']['user']['apps']['admin'])		// no admin
+	if (!isset($GLOBALS['egw_info']['user']['apps']['admin']) ||
+	    !$GLOBALS['egw_info']['user']['apps']['admin'])		// no admin
 	{
-		$GLOBALS['phpgw']->redirect_link('/home.php');
+		$GLOBALS['egw']->redirect_link('/home.php');
 	}
 	if (isset($_FILES['csvfile']['tmp_name']))
 	{
-		$csvfile = tempnam($GLOBALS['phpgw_info']['server']['temp_dir'],$GLOBALS['phpgw_info']['flags']['currentapp']."_");
-		$GLOBALS['phpgw']->session->appsession('csvfile','',$csvfile);
+		$csvfile = tempnam($GLOBALS['egw_info']['server']['temp_dir'],$GLOBALS['egw_info']['flags']['currentapp']."_");
+		$GLOBALS['egw']->session->appsession('csvfile','',$csvfile);
 		$_POST['action'] = move_uploaded_file($_FILES['csvfile']['tmp_name'],$csvfile) ?
 			'download' : '';
 	}
 	else
 	{
-		$csvfile = $GLOBALS['phpgw']->session->appsession('csvfile');
+		$csvfile = $GLOBALS['egw']->session->appsession('csvfile');
 	}
 	if ($_POST['cancel'])
 	{
 		@unlink($csvfile);
-		$GLOBALS['phpgw']->redirect_link('/admin/index.php');
+		$GLOBALS['egw']->redirect_link('/admin/index.php');
 	}
-	$GLOBALS['phpgw_info']['flags']['app_header'] = lang('InfoLog - Import CSV-File');
-	$GLOBALS['phpgw']->common->phpgw_header();
+	$GLOBALS['egw_info']['flags']['app_header'] = lang('InfoLog - Import CSV-File');
+	$GLOBALS['egw']->common->egw_header();
 
 	$boinfolog = createobject('infolog.boinfolog');
 
-	$GLOBALS['phpgw']->template->set_file(array('import_t' => 'csv_import.tpl'));
-	$GLOBALS['phpgw']->template->set_block('import_t','filename','filenamehandle');
-	$GLOBALS['phpgw']->template->set_block('import_t','fheader','fheaderhandle');
-	$GLOBALS['phpgw']->template->set_block('import_t','fields','fieldshandle');
-	$GLOBALS['phpgw']->template->set_block('import_t','ffooter','ffooterhandle');
-	$GLOBALS['phpgw']->template->set_block('import_t','imported','importedhandle');
-	$GLOBALS['phpgw']->template->set_block('import_t','import','importhandle');
+	$GLOBALS['egw']->template->set_file(array('import_t' => 'csv_import.tpl'));
+	$GLOBALS['egw']->template->set_block('import_t','filename','filenamehandle');
+	$GLOBALS['egw']->template->set_block('import_t','fheader','fheaderhandle');
+	$GLOBALS['egw']->template->set_block('import_t','fields','fieldshandle');
+	$GLOBALS['egw']->template->set_block('import_t','ffooter','ffooterhandle');
+	$GLOBALS['egw']->template->set_block('import_t','imported','importedhandle');
+	$GLOBALS['egw']->template->set_block('import_t','import','importhandle');
 
 
 	if(($_POST['action'] == 'download' || $_POST['action'] == 'continue') && (!$_POST['fieldsep'] || !$csvfile || !($fp=fopen($csvfile,'rb'))))
 	{
 		$_POST['action'] = '';
 	}
-	$GLOBALS['phpgw']->template->set_var("action_url",$GLOBALS['phpgw']->link("/infolog/csv_import.php"));
+	$GLOBALS['egw']->template->set_var("action_url",$GLOBALS['egw']->link("/infolog/csv_import.php"));
 
 	$PSep = '||'; // Pattern-Separator, separats the pattern-replacement-pairs in trans
 	$ASep = '|>'; // Assignment-Separator, separats pattern and replacesment
@@ -66,25 +66,28 @@
 	$CPre = '|['; $CPreReg = '\|\['; // |{csv-fieldname} is expanded to the value of the csv-field
 	$CPos = ']';  $CPosReg = '\]';	// if used together with @ (replacement is eval-ed) value gets autom. quoted
 
-function addr_id( $n_family,$n_given=False,$org_name=False )
+function addr_id( $n_family,$n_given=null,$org_name=null )
 {		// find in Addressbook, at least n_family AND (n_given OR org_name) have to match
-	$contacts = createobject('phpgwapi.contacts');
-
-	if ($org_name !== False)	// org_name given?
+	static $contacts;
+	if (!is_object($contacts))
+	{
+		$contacts =& CreateObject('phpgwapi.contacts');
+	}
+	if (!is_null($org_name))	// org_name given?
 	{
 		$addrs = $contacts->read( 0,0,array('id'),'',"n_family=$n_family,n_given=$n_given,org_name=$org_name" );
 		if (!count($addrs))
 		{
-			$addrs = $contacts->read( 0,0,array('id'),'',"n_family=$n_family,org_name=$org_name" );
+			$addrs = $contacts->read( 0,0,array('id'),'',"n_family=$n_family,org_name=$org_name",'','n_family,org_name');
 		}
 	}
-	if ($n_given !== False && ($org_name === False || !count($addrs)))	// first name given and no result so far
+	if (!is_null($n_given) && (is_null($org_name) || !count($addrs)))	// first name given and no result so far
 	{
-		$addrs = $contacts->read( 0,0,array('id'),'',"n_family=$n_family,n_given=$n_given" );
+		$addrs = $contacts->read( 0,0,array('id'),'',"n_family=$n_family,n_given=$n_given",'','n_family,n_given' );
 	}
-	if ($n_given === False && $org_name === False)	// just one name given, check against fn (= full name)
+	if (is_null($n_given) && is_null($org_name))	// just one name given, check against fn (= full name)
 	{
-		$addrs = $contacts->read( 0,0,array('id'),'',"fn=$n_family" );
+		$addrs = $contacts->read( 0,0,array('id'),'',"fn=$n_family",'','fn' );
 	}
 	if (count($addrs))
 	{
@@ -93,6 +96,24 @@ function addr_id( $n_family,$n_given=False,$org_name=False )
 	return False;
 }
 
+function project_id($num_or_title)
+{
+	static $boprojects;
+
+	if (!$num_or_title) return false;
+
+	if (!is_object($boprojects))
+	{
+		$boprojects =& CreateObject('projectmanager.boprojectmanager');
+	}
+	if (($projects = $boprojects->search(array('pm_number' => $num_or_title))) ||
+		($projects = $boprojects->search(array('pm_title'  => $num_or_title))))
+	{
+		return $projects[0]['pm_id'];
+	}
+	return false;
+}
+
 $cat2id = array( );
 
 function cat_id($cats)
@@ -111,22 +132,22 @@ function cat_id($cats)
 		}
 		else
 		{
-			if (!is_object($GLOBALS['phpgw']->categories))
+			if (!is_object($GLOBALS['egw']->categories))
 			{
-				$GLOBALS['phpgw']->categories = createobject('phpgwapi.categories');
+				$GLOBALS['egw']->categories = createobject('phpgwapi.categories');
 			}
-			if (is_numeric($cat) && $GLOBALS['phpgw']->categories->id2name($cat) != '--')
+			if (is_numeric($cat) && $GLOBALS['egw']->categories->id2name($cat) != '--')
 			{
 				$cat2id[$cat] = $ids[$cat] = $cat;
 			}	
-			elseif ($id = $GLOBALS['phpgw']->categories->name2id( addslashes($cat) ))
+			elseif (($id = $GLOBALS['egw']->categories->name2id( addslashes($cat) )))
 			{	// cat exists
 				$cat2id[$cat] = $ids[$cat] = $id;
 			}
 			else
 			{	// create new cat
-				$GLOBALS['phpgw']->categories->add( array('name' => $cat,'descr' => $cat ));
-				$cat2id[$cat] = $ids[$cat] = $GLOBALS['phpgw']->categories->name2id( addslashes($cat) );
+				$GLOBALS['egw']->categories->add( array('name' => $cat,'descr' => $cat ));
+				$cat2id[$cat] = $ids[$cat] = $GLOBALS['egw']->categories->name2id( addslashes($cat) );
 			}
 		}
 	}
@@ -139,67 +160,73 @@ function cat_id($cats)
 	return  $id_str;
 }
 
-	if (!is_object($GLOBALS['phpgw']->html))
+	if (!is_object($GLOBALS['egw']->html))
 	{
-		$GLOBALS['phpgw']->html = CreateObject('phpgwapi.html');
+		$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
 	}
 
 	if ($_POST['next']) $_POST['action'] = 'next';
 	switch ($_POST['action'])
 	{
 	case '':	// Start, ask Filename
-		$GLOBALS['phpgw']->template->set_var('lang_csvfile',lang('CSV-Filename'));
-		$GLOBALS['phpgw']->template->set_var('lang_fieldsep',lang('Fieldseparator'));
-		$GLOBALS['phpgw']->template->set_var('lang_charset',lang('Charset of file'));
-		$GLOBALS['phpgw']->template->set_var('select_charset',
-			$GLOBALS['phpgw']->html->select('charset','',
-			$GLOBALS['phpgw']->translation->get_installed_charsets()+
+		$GLOBALS['egw']->template->set_var('lang_csvfile',lang('CSV-Filename'));
+		$GLOBALS['egw']->template->set_var('lang_fieldsep',lang('Fieldseparator'));
+		$GLOBALS['egw']->template->set_var('lang_charset',lang('Charset of file'));
+		$GLOBALS['egw']->template->set_var('select_charset',
+			$GLOBALS['egw']->html->select('charset','',
+			$GLOBALS['egw']->translation->get_installed_charsets()+
 			array('utf-8' => 'utf-8 (Unicode)'),True));
-		$GLOBALS['phpgw']->template->set_var('fieldsep',$_POST['fieldsep'] ? $_POST['fieldsep'] : ',');
-		$GLOBALS['phpgw']->template->set_var('submit',lang('Import'));
-		$GLOBALS['phpgw']->template->set_var('enctype','ENCTYPE="multipart/form-data"');
+		$GLOBALS['egw']->template->set_var('fieldsep',$_POST['fieldsep'] ? $_POST['fieldsep'] : ';');
+		$GLOBALS['egw']->template->set_var('submit',lang('Import'));
+		$GLOBALS['egw']->template->set_var('enctype','ENCTYPE="multipart/form-data"');
 
-		$GLOBALS['phpgw']->template->parse('rows','filename');
+		$GLOBALS['egw']->template->parse('rows','filename');
 		break;
 
 	case 'continue':
 	case 'download':
-		$GLOBALS['phpgw']->preferences->read_repository();
-		$defaults = $GLOBALS['phpgw_info']['user']['preferences']['infolog']['cvs_import'];
+		$GLOBALS['egw']->preferences->read_repository();
+		$defaults = $GLOBALS['egw_info']['user']['preferences']['infolog']['cvs_import'];
 		if (!is_array($defaults))
 		{
 			$defaults = array();
 		}
-		$GLOBALS['phpgw']->template->set_var('lang_csv_fieldname',lang('CSV-Fieldname'));
-		$GLOBALS['phpgw']->template->set_var('lang_info_fieldname',lang('InfoLog-Fieldname'));
-		$GLOBALS['phpgw']->template->set_var('lang_translation',lang("Translation").' <a href="#help">'.lang('help').'</a>');
-		$GLOBALS['phpgw']->template->set_var('submit',
-			$GLOBALS['phpgw']->html->submit_button('convert','Import') . '&nbsp;'.
-			$GLOBALS['phpgw']->html->submit_button('cancel','Cancel'));
-		$GLOBALS['phpgw']->template->set_var('lang_debug',lang('Test Import (show importable records <u>only</u> in browser)'));
-		$GLOBALS['phpgw']->template->parse('rows','fheader');
+		$GLOBALS['egw']->template->set_var('lang_csv_fieldname',lang('CSV-Fieldname'));
+		$GLOBALS['egw']->template->set_var('lang_info_fieldname',lang('InfoLog-Fieldname'));
+		$GLOBALS['egw']->template->set_var('lang_translation',lang("Translation").' <a href="#help">'.lang('help').'</a>');
+		$GLOBALS['egw']->template->set_var('submit',
+			$GLOBALS['egw']->html->submit_button('convert','Import') . '&nbsp;'.
+			$GLOBALS['egw']->html->submit_button('cancel','Cancel'));
+		$GLOBALS['egw']->template->set_var('lang_debug',lang('Test Import (show importable records <u>only</u> in browser)'));
+		$GLOBALS['egw']->template->parse('rows','fheader');
 
 		$info_names = array(	
-			'type'        => 'Type: char(10) task,phone,note,confirm,reject,email,fax',
-			'from'        => 'From: text(64) free text if no Addressbook-entry assigned',
-			'addr'        => 'Addr: text(64) phone-nr/email-address',
-			'subject'     => 'Subject: text(64)',
+			'type'        => 'Type: char(10) task,phone,note',
+			'from'        => 'From: text(255) free text if no Addressbook-entry assigned',
+			'addr'        => 'Addr: text(255) phone-nr/email-address',
+			'subject'     => 'Subject: text(255)',
 			'des'         => 'Description: text long free text',
+			'location'    => 'Location: text(255)',
 			'responsible' => 'Responsible: int(11) user-id or user-name',
 			'owner'       => 'Owner: int(11) user-id/-name of owner, if empty current user',
 			'access'      => 'Access: public,private',
 			'cat'         => 'Category: int(11) category-id or -name (new ones got created)',
 			'startdate'   => 'Start Date: DateTime: Timestamp or eg. YYYY-MM-DD hh:mm',
 			'enddate'     => 'End Date: DateTime',
-			'datecreated' => 'Date Created: DateTime, if empty = Start Date or now',
+			'datecompleted'=> 'Date completed: DateTime',
 			'datemodified'=> 'Date Last Modified: DateTime, if empty = Date Created',
 			'modifier'    => 'Modifier: int(11) user-id, if empty current user',
-			'pri'         => 'Priority: urgent,high,normal,low',
-			'time'        => 'Time: int(11) time used in min',
-			//'bill_cat'    => 'Billing Cathegory: int(11)',
-			'status'      => 'Status: char(10) offer,ongoing,call,will-call,done,billed,xx%',
-			'confirm'     => 'Confirmation: char(10) not,accept,finish,both when to confirm',
-			'addr_id'     => 'Addressbook id, to set use @addr_id(nlast,nfirst,org)'
+			'priority'    => 'Priority: 3=urgent, 2=high, 1=normal, 0=low',
+			'planned_time'=> 'planned Time: int(11) time used in min',
+			'used_time'   => 'used Time: int(11) time used in min',
+			'status'      => 'Status: char(10) offer,not-started,ongoing,call,will-call,done,billed,cancelled',
+			'percent'     => 'Percent completed: int',
+//			'confirm'     => 'Confirmation: char(10) not,accept,finish,both when to confirm',
+			'project_id'  => 'Link to Projectmanager, use Project-ID, Title or @project_id(id_or_title)',
+			'addr_id'     => 'Link to Addressbook, use nlast,nfirst[,org] or @addr_id(nlast,nfirst,org)',
+			'link_1'      => '1. link: appname:appid the entry should be linked to, eg.: addressbook:123',
+			'link_2'      => '2. link: appname:appid the entry should be linked to, eg.: addressbook:123',
+			'link_3'      => '3. link: appname:appid the entry should be linked to, eg.: addressbook:123',
 		);
 
 		// the next line is used in the help-text too
@@ -221,41 +248,42 @@ function cat_id($cats)
 		$info_name_options = "<option value=\"\">none\n";
 		foreach($info_names as $field => $name) 
 		{
-			$info_name_options .= "<option value=\"$field\">".$GLOBALS['phpgw']->strip_html($name)."\n";
+			$info_name_options .= "<option value=\"$field\">".$GLOBALS['egw']->strip_html($name)."\n";
 		}
 		$csv_fields = fgetcsv($fp,8000,$_POST['fieldsep']);
-		$csv_fields = $GLOBALS['phpgw']->translation->convert($csv_fields,$_POST['charset']);
+		$csv_fields = $GLOBALS['egw']->translation->convert($csv_fields,$_POST['charset']);
 		$csv_fields[] = 'no CSV 1'; 						// eg. for static assignments
 		$csv_fields[] = 'no CSV 2';
 		$csv_fields[] = 'no CSV 3';
 		foreach($csv_fields as $csv_idx => $csv_field) 
 		{
-			$GLOBALS['phpgw']->template->set_var('csv_field',$csv_field);
-			$GLOBALS['phpgw']->template->set_var('csv_idx',$csv_idx);
-			if ($def = $defaults[$csv_field]) 
+			$GLOBALS['egw']->template->set_var('csv_field',$csv_field);
+			$GLOBALS['egw']->template->set_var('csv_idx',$csv_idx);
+			
+			if (($def = $defaults[$csv_field]))
 			{
 				list( $info,$trans ) = explode($PSep,$def,2);
-				$GLOBALS['phpgw']->template->set_var('trans',$trans);
-				$GLOBALS['phpgw']->template->set_var('info_fields',str_replace('="'.$info.'">','="'.$info.'" selected>',$info_name_options));
+				$GLOBALS['egw']->template->set_var('trans',$trans);
+				$GLOBALS['egw']->template->set_var('info_fields',str_replace('="'.$info.'">','="'.$info.'" selected>',$info_name_options));
 			} 
 			else 
 			{
-				$GLOBALS['phpgw']->template->set_var('trans','');
-				$GLOBALS['phpgw']->template->set_var('info_fields',$info_name_options);
+				$GLOBALS['egw']->template->set_var('trans','');
+				$GLOBALS['egw']->template->set_var('info_fields',$info_name_options);
 			}
-			$GLOBALS['phpgw']->template->parse('rows','fields',True);
+			$GLOBALS['egw']->template->parse('rows','fields',True);
 		}
-		$GLOBALS['phpgw']->template->set_var('lang_start',lang('Startrecord'));
-		$GLOBALS['phpgw']->template->set_var('start',get_var('start',array('POST'),1));
+		$GLOBALS['egw']->template->set_var('lang_start',lang('Startrecord'));
+		$GLOBALS['egw']->template->set_var('start',get_var('start',array('POST'),1));
 		$msg = ($safe_mode = ini_get('safe_mode') == 'On') ? lang('to many might exceed your execution-time-limit'):
 			lang('empty for all');
-		$GLOBALS['phpgw']->template->set_var('lang_max',lang('Number of records to read (%1)',$msg));
-		$GLOBALS['phpgw']->template->set_var('max',get_var('max',array('POST'),$safe_mode ? 200 : ''));
-		$GLOBALS['phpgw']->template->set_var('debug',get_var('debug',array('POST'),True)?' checked':'');
-		$GLOBALS['phpgw']->template->parse('rows','ffooter',True);
+		$GLOBALS['egw']->template->set_var('lang_max',lang('Number of records to read (%1)',$msg));
+		$GLOBALS['egw']->template->set_var('max',get_var('max',array('POST'),$safe_mode ? 200 : ''));
+		$GLOBALS['egw']->template->set_var('debug',get_var('debug',array('POST'),True)?' checked':'');
+		$GLOBALS['egw']->template->parse('rows','ffooter',True);
 		fclose($fp);
 
-		$hiddenvars = $GLOBALS['phpgw']->html->input_hidden(array(
+		$hiddenvars = $GLOBALS['egw']->html->input_hidden(array(
 			'action'  => 'import',
 			'fieldsep'=> $_POST['fieldsep'],
 			'charset' => $_POST['charset']
@@ -290,9 +318,9 @@ function cat_id($cats)
 			"with the addressbook.<br>".
 			"<b>@cat_id(Cat-name)</b> returns a numerical cat_id. If a category isn't found, it ".
 			"will be automaticaly added.<p>".
-			"I hope that helped to understand the features, if not <a href='mailto:RalfBecker@outdoor-training.de'>ask</a>.";
+			"I hope that helped to understand the features, if not <a href='mailto:egroupware-users@lists.sf.net'>ask</a>.";
 
-		$GLOBALS['phpgw']->template->set_var('help_on_trans',lang($help_on_trans));	// I don't think anyone will translate this
+		$GLOBALS['egw']->template->set_var('help_on_trans',lang($help_on_trans));	// I don't think anyone will translate this
 		break;
 
 	case 'next':
@@ -300,7 +328,7 @@ function cat_id($cats)
 		$_POST['trans']       = unserialize(stripslashes($_POST['trans']));
 		// fall-through
 	case 'import':
-		$hiddenvars = $GLOBALS['phpgw']->html->input_hidden(array(
+		$hiddenvars = $GLOBALS['egw']->html->input_hidden(array(
 			'action'  => 'continue',
 			'fieldsep'=> $_POST['fieldsep'],
 			'charset' => $_POST['charset'],
@@ -313,7 +341,7 @@ function cat_id($cats)
 		@set_time_limit(0);
 		$fp=fopen($csvfile,'r');
 		$csv_fields = fgetcsv($fp,8000,$_POST['fieldsep']);
-		$csv_fields = $GLOBALS['phpgw']->translation->convert($csv_fields,$_POST['charset']);
+		$csv_fields = $GLOBALS['egw']->translation->convert($csv_fields,$_POST['charset']);
 		$csv_fields[] = 'no CSV 1'; 						// eg. for static assignments
 		$csv_fields[] = 'no CSV 2';
 		$csv_fields[] = 'no CSV 3';
@@ -330,9 +358,9 @@ function cat_id($cats)
 			}
 		}
 
-		$GLOBALS['phpgw']->preferences->read_repository();
-		$GLOBALS['phpgw']->preferences->add('infolog','cvs_import',$defaults);
-		$GLOBALS['phpgw']->preferences->save_repository(True);
+		$GLOBALS['egw']->preferences->read_repository();
+		$GLOBALS['egw']->preferences->add('infolog','cvs_import',$defaults);
+		$GLOBALS['egw']->preferences->save_repository(True);
 
 		$log = "<table border=1>\n\t<tr><td>#</td>\n";
 
@@ -377,7 +405,7 @@ function cat_id($cats)
 			{
 				break;	// EOF
 			}
-			$fields = $GLOBALS['phpgw']->translation->convert($fields,$_POST['charset']);
+			$fields = $GLOBALS['egw']->translation->convert($fields,$_POST['charset']);
 
 			$log .= "\t</tr><tr><td>".($start+$anz)."</td>\n";
 
@@ -428,7 +456,7 @@ function cat_id($cats)
 			}
 
 			// convert dates to timestamps
-			foreach(array('datecreated','startdate','enddate','datemodified') as $date)
+			foreach(array('startdate','enddate','datemodified','datecompleted') as $date)
 			{
 				if (isset($values[$date]) && !is_numeric($date))
 				{
@@ -436,16 +464,21 @@ function cat_id($cats)
 					$values[$date] = strtotime($values[$date]);
 				}
 			}
-			if (!isset($values['datecreated'])) $values['datecreated'] = $values['startdate'];
-
-			if (!isset($values['datemodified'])) $values['datemodified'] = $values['datecreated'];
+			if (!isset($values['datemodified'])) $values['datemodified'] = $values['startdate'];
 
 			// convert user-names to user-id's
-			foreach(array('owner','responsible') as $user)
+			if (isset($values['owner']) && !is_numeric($values['owner']))
 			{
-				if (isset($values[$user]) && !is_numeric($user))
+				$values['owner'] = $GLOBALS['egw']->accounts->name2id($values['owner']);
+			}
+			if (isset($values['responsible']))
+			{
+				$responsible = $values['responsible'];
+				$values['responsible'] = array();
+				foreach(split('[,;]',$responsible) as $user)
 				{
-					$values[$user] = $GLOBALS['phpgw']->accounts->name2id($values[$user]);
+					if ($user && !is_numeric($user)) $user = $GLOBALS['egw']->accounts->name2id($user);
+					if ($user) $values['responsible'][] = $user;
 				}
 			}
 			if (!in_array('access',$info_fields))
@@ -455,32 +488,62 @@ function cat_id($cats)
 			}
 			if(!$_POST['debug'] && !$empty)	// dont import empty contacts
 			{
-				$id = $boinfolog->write($values,True,False);
-
-				if ($id && $values['addr_id'])
+				// create new names with info_ prefix
+				$to_write = array();
+				foreach($values as $name => $value)
 				{
-					$boinfolog->write(array(
-						'info_id'      => $id,
-						'info_link_id' => $boinfolog->link->link('infolog',$id,'addressbook',$values['addr_id'])
-					));
+					$to_write[substr($name,0,5) != 'info_' ? 'info_'.$name : $name] = $value;
+				}
+				if ($values['addr_id'] && !is_numeric($values['addr_id']))
+				{
+					list($lastname,$firstname,$org_name) = explode(',',$values['addr_id']);
+					$values['addr_id'] = addr_id($lastname,$firstname,$org_name);
+				}
+				if ($values['project_id'] && !is_numeric($values['project_id']))
+				{
+					$values['project_id'] = project_id($values['project_id']);
+				}
+				if (($id = $boinfolog->write($to_write,True,False)))
+				{
+					$info_link_id = false;
+					foreach(array(
+						'projectmanager:'.$values['project_id'],
+						'addressbook:'.$values['addr_id'],
+						$values['link_1'],$values['link_2'],$values['link_3'],
+					) as $value)
+					{
+						list($app,$app_id) = explode(':',$value);
+						if ($app && $app_id)
+						{
+							//echo "<p>linking infolog:$id with $app:$app_id</p>\n";
+							$link_id = $boinfolog->link->link('infolog',$id,$app,$app_id);
+							if ($link_id && !$info_link_id)
+							{
+								$to_write = array(
+									'info_id'      => $id,
+									'info_link_id' => $link_id,
+								);
+								$boinfolog->write($to_write);
+								$info_link_id = true;
+							}
+						}
+					}
 				}
 			}
 		}
 		$log .= "\t</tr>\n</table>\n";
 
-		$GLOBALS['phpgw']->template->set_var('anz_imported',($_POST['debug'] ?
+		$GLOBALS['egw']->template->set_var('anz_imported',($_POST['debug'] ?
 			lang('%1 records read (not yet imported, you may go %2back%3 and uncheck Test Import)',
 			$anz,'','') :
 			lang('%1 records imported',$anz)). '&nbsp;'.
-			(!$_POST['debug'] && $fields ? $GLOBALS['phpgw']->html->submit_button('next','Import next set') . '&nbsp;':'').
-			$GLOBALS['phpgw']->html->submit_button('continue','Back') . '&nbsp;'.
-			$GLOBALS['phpgw']->html->submit_button('cancel','Cancel'));
-		$GLOBALS['phpgw']->template->set_var('log',$log);
-		$GLOBALS['phpgw']->template->parse('rows','imported');
+			(!$_POST['debug'] && $fields ? $GLOBALS['egw']->html->submit_button('next','Import next set') . '&nbsp;':'').
+			$GLOBALS['egw']->html->submit_button('continue','Back') . '&nbsp;'.
+			$GLOBALS['egw']->html->submit_button('cancel','Cancel'));
+		$GLOBALS['egw']->template->set_var('log',$log);
+		$GLOBALS['egw']->template->parse('rows','imported');
 		break;
 	}
-	$GLOBALS['phpgw']->template->set_var('hiddenvars',str_replace('{','&#x7B;',$hiddenvars));
-	$GLOBALS['phpgw']->template->pfp('phpgw_body','import');
-	$GLOBALS['phpgw']->common->phpgw_footer();
-
-?>
+	$GLOBALS['egw']->template->set_var('hiddenvars',str_replace('{','&#x7B;',$hiddenvars));
+	$GLOBALS['egw']->template->pfp('phpgw_body','import');
+	$GLOBALS['egw']->common->egw_footer();
