@@ -1,20 +1,22 @@
 <?php
 	/**************************************************************************\
-	* phpGroupWare                                                             *
-	* http://www.phpgroupware.org                                              *
+	* eGroupWare                                                               *
+	* http://www.egroupware.org                                                *
 	* --------------------------------------------                             *
 	*  This program is free software; you can redistribute it and/or modify it *
 	*  under the terms of the GNU General Public License as published by the   *
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: hook_deleteaccount.inc.php,v 1.2 2002/11/20 19:57:53 ralfbecker Exp $ */
+	/* $Id: hook_deleteaccount.inc.php 19386 2005-10-13 14:20:40Z ralfbecker $ */
 
 	// Delete all records for a user
-	$info = CreateObject('infolog.soinfolog');
+	if((int)$GLOBALS['hook_values']['account_id'] > 0)
+	{
+		$info =& CreateObject('infolog.soinfolog');
 
-	$info->change_delete_owner(intval($GLOBALS['HTTP_POST_VARS']['account_id']),
-		intval($GLOBALS['HTTP_POST_VARS']['new_owner']));
+		$info->change_delete_owner((int)$GLOBALS['hook_values']['account_id'],(int)$_POST['new_owner']);
 
-	unset($info);
+		unset($info);
+	}
 ?>
