@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: tables_update.inc.php,v 1.10.2.1 2004/08/28 14:36:27 ralfbecker Exp $ */
+  /* $Id: tables_update.inc.php 20719 2006-03-20 19:49:55Z ralfbecker $ */
 
 	$test[] = '0.9.11';
 	function infolog_upgrade0_9_11()
@@ -370,4 +370,180 @@
 		$GLOBALS['setup_info']['infolog']['currentver'] = '1.0.0.001';
 		return $GLOBALS['setup_info']['infolog']['currentver'];
 	}
+
+
+	$test[] = '1.0.0.001';
+	function infolog_upgrade1_0_0_001()
+	{
+		$GLOBALS['phpgw_setup']->oProc->RenameColumn('phpgw_infolog','info_time','info_planned_time');
+		$GLOBALS['phpgw_setup']->oProc->RenameColumn('phpgw_infolog','info_bill_cat','info_used_time');
+		// timestamps have to be 8byte ints
+		$GLOBALS['phpgw_setup']->oProc->AlterColumn('phpgw_infolog','info_datemodified',array(
+			'type' => 'int',
+			'precision' => '8',
+			'nullable' => False
+		));
+		$GLOBALS['phpgw_setup']->oProc->AlterColumn('phpgw_infolog','info_startdate',array(
+			'type' => 'int',
+			'precision' => '8',
+			'nullable' => False,
+			'default' => '0'
+		));
+		$GLOBALS['phpgw_setup']->oProc->AlterColumn('phpgw_infolog','info_enddate',array(
+			'type' => 'int',
+			'precision' => '8',
+			'nullable' => False,
+			'default' => '0'
+		));
+		
+		// setting numerical priority 3=urgent, 2=high, 1=normal, 0=
+		$GLOBALS['phpgw_setup']->oProc->AddColumn('phpgw_infolog','info_priority',array(
+			'type' => 'int',
+			'precision' => '2',
+			'default' => '1'
+		));
+		$GLOBALS['phpgw_setup']->oProc->query("UPDATE phpgw_infolog SET info_priority=(CASE WHEN info_pri='urgent' THEN 3 WHEN info_pri='high' THEN 2 WHEN info_pri='low' THEN 0 ELSE 1 END)",__LINE__,__FILE__);
+
+		$GLOBALS['phpgw_setup']->oProc->DropColumn('phpgw_infolog',array(
+			'fd' => array(
+				'info_id' => array('type' => 'auto','nullable' => False),
+				'info_type' => array('type' => 'varchar','precision' => '40','nullable' => False,'default' => 'task'),
+				'info_from' => array('type' => 'varchar','precision' => '255'),
+				'info_addr' => array('type' => 'varchar','precision' => '255'),
+				'info_subject' => array('type' => 'varchar','precision' => '255'),
+				'info_des' => array('type' => 'text'),
+				'info_owner' => array('type' => 'int','precision' => '4','nullable' => False),
+				'info_responsible' => array('type' => 'int','precision' => '4','nullable' => False,'default' => '0'),
+				'info_access' => array('type' => 'varchar','precision' => '10','default' => 'public'),
+				'info_cat' => array('type' => 'int','precision' => '4','nullable' => False,'default' => '0'),
+				'info_datemodified' => array('type' => 'int','precision' => '8','nullable' => False),
+				'info_startdate' => array('type' => 'int','precision' => '8','nullable' => False,'default' => '0'),
+				'info_enddate' => array('type' => 'int','precision' => '8','nullable' => False,'default' => '0'),
+				'info_id_parent' => array('type' => 'int','precision' => '4','nullable' => False,'default' => '0'),
+				'info_planned_time' => array('type' => 'int','precision' => '4','nullable' => False,'default' => '0'),
+				'info_used_time' => array('type' => 'int','precision' => '4','nullable' => False,'default' => '0'),
+				'info_status' => array('type' => 'varchar','precision' => '40','default' => 'done'),
+				'info_confirm' => array('type' => 'varchar','precision' => '10','default' => 'not'),
+				'info_modifier' => array('type' => 'int','precision' => '4','nullable' => False,'default' => '0'),
+				'info_link_id' => array('type' => 'int','precision' => '4','nullable' => False,'default' => '0'),
+				'info_priority' => array('type' => 'int','precision' => '2','default' => '1')
+			),
+			'pk' => array('info_id'),
+			'fk' => array(),
+			'ix' => array(array('info_owner','info_responsible','info_status','info_startdate'),array('info_id_parent','info_owner','info_responsible','info_status','info_startdate')),
+			'uc' => array()
+		),'info_pri');
+		
+		$GLOBALS['phpgw_setup']->oProc->RenameTable('phpgw_infolog','egw_infolog');
+		$GLOBALS['phpgw_setup']->oProc->RenameTable('phpgw_infolog_extra','egw_infolog_extra');
+		// only rename links table, if it has not been moved into the API and therefor been already renamed by the API update
+		if ($GLOBALS['phpgw_setup']->oProc->GetTableDefinition('phpgw_links'))
+		{
+			$GLOBALS['phpgw_setup']->oProc->RenameTable('phpgw_links','egw_links');
+		}
+		$GLOBALS['setup_info']['infolog']['currentver'] = '1.0.1.001';
+		return $GLOBALS['setup_info']['infolog']['currentver'];
+	}
+
+
+	$test[] = '1.0.1.001';
+	function infolog_upgrade1_0_1_001()
+	{
+		$GLOBALS['phpgw_setup']->oProc->AlterColumn('egw_infolog','info_responsible',array(
+			'type' => 'varchar',
+			'precision' => '255',
+			'nullable' => False,
+			'default' => '0'
+		));
+
+		$GLOBALS['setup_info']['infolog']['currentver'] = '1.0.1.002';
+		return $GLOBALS['setup_info']['infolog']['currentver'];
+	}
+
+
+	$test[] = '1.0.1.002';
+	function infolog_upgrade1_0_1_002()
+	{
+		$GLOBALS['setup_info']['infolog']['currentver'] = '1.2';
+		return $GLOBALS['setup_info']['infolog']['currentver'];
+	}
+
+
+	$test[] = '1.2';
+	function infolog_upgrade1_2()
+	{
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_infolog','pl_id',array(
+			'type' => 'int',
+			'precision' => '4'
+		));
+
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_infolog','info_price',array(
+			'type' => 'float',
+			'precision' => '8'
+		));
+
+		return $GLOBALS['setup_info']['infolog']['currentver'] = '1.2.001';
+	}
+
+
+	$test[] = '1.2.001';
+	function infolog_upgrade1_2_001()
+	{
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_infolog','info_percent',array(
+			'type' => 'int',
+			'precision' => '2',
+			'default' => '0'
+		));
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_infolog','info_datecompleted',array(
+			'type' => 'int',
+			'precision' => '8'
+		));
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_infolog','info_location',array(
+			'type' => 'varchar',
+			'precision' => '255'
+		));
+		
+		// all not explicit named stati have the default percent 0
+		$GLOBALS['egw_setup']->oProc->query("UPDATE egw_infolog SET info_percent=10 WHERE info_status='ongoing'",__LINE__,__FILE__);
+		$GLOBALS['egw_setup']->oProc->query("UPDATE egw_infolog SET info_percent=50 WHERE info_status='will-call'",__LINE__,__FILE__);
+
+		for($p = 0; $p <= 90; $p += 10)
+		{
+			$GLOBALS['egw_setup']->oProc->query("UPDATE egw_infolog SET info_percent=$p,info_status='".(!$p ? 'not-started' : 'ongoing').
+				"' WHERE info_status = '$p%'",__LINE__,__FILE__);
+		}
+		$GLOBALS['egw_setup']->oProc->query("UPDATE egw_infolog SET info_datecompleted=info_datemodified,info_percent=100 WHERE info_status IN ('done','billed','100%')",__LINE__,__FILE__);
+		
+		// remove the percentages from the custom stati, if they exist
+		$config =& CreateObject('phpgwapi.config','infolog');
+		$config->read_repository();
+		if (is_array($config->config_data['status']['task']))
+		{
+			$config->config_data['status']['task'] = array_diff($config->config_data['status']['task'],
+				array('0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'));
+			$config->save_repository();
+		}
+		return $GLOBALS['setup_info']['infolog']['currentver'] = '1.2.002';
+	}
+
+
+	$test[] = '1.2.002';
+	function infolog_upgrade1_2_002()
+	{
+		// change the phone-status: call --> not-started, will-call --> ongoing to be able to sync them 
+		$GLOBALS['egw_setup']->oProc->query("UPDATE egw_infolog SET info_status='not-started' WHERE info_status='call'",__LINE__,__FILE__);
+		$GLOBALS['egw_setup']->oProc->query("UPDATE egw_infolog SET info_status='ongoing' WHERE info_status='will-call'",__LINE__,__FILE__);
+		
+		// remove the call and will-call from the custom stati, if they exist
+		$config =& CreateObject('phpgwapi.config','infolog');
+		$config->read_repository();
+		if (is_array($config->config_data['status']['phone']))
+		{
+			unset($config->config_data['status']['phone']['call']);
+			unset($config->config_data['status']['phone']['will-call']);
+
+			$config->save_repository();
+		}
+		return $GLOBALS['setup_info']['infolog']['currentver'] = '1.2.003';
+	}
 ?>
