@@ -13,15 +13,15 @@
 *  option) any later version.                                              *
 \**************************************************************************/
 
-	/* $Id: class.uikb.inc.php,v 1.33.2.16 2005/02/14 17:33:51 alpeb Exp $ */
+	/* $Id: class.uikb.inc.php 20295 2006-02-15 12:31:25Z  $ */
 	
 	/**
 	* Presentation layer of the Knowledge Base
 	*
-	* Last Editor:	$Author: alpeb $
+	* Last Editor:	$Author: $
 	* @author		Alejandro Pedraza
 	* @package		phpbrain
-	* @version		$Revision: 1.33.2.16 $
+	* @version		$Revision: 20295 $
 	* @license		GPL
 	*/
 	class uikb
@@ -190,7 +190,7 @@
 		*/
 		function index()
 		{
-			$category_passed	= (int)get_var('cat', 'GET', 0);
+			$category_passed	= (int) $_REQUEST['cat'];
 
 			$this->t->set_file('main', 'main.tpl');
 			$this->t->set_block('main', 'articles_block', 'articles');
@@ -199,6 +199,7 @@
 			$this->t->set_block('main', 'articles_mostviewed_block', 'articles_mostviewed');
 			$this->t->set_block('main', 'unanswered_questions_block', 'unanswered_questions');
 			$this->t->set_var(array(
+				'lang_last_modified'			=> lang('Last Modified'),
 				'message'				=> $this->message,
 				'search_tpl'			=> $this->show_basic_search(),
 				'tr_class'				=> 'th',
@@ -317,8 +318,8 @@
 			{
 				if ($this->sitemgr) $this->nextmatchs->template->set_var('action_sitemgr', $this->link('menuaction=phpbrain.uikb.index'));
 				$this->t->set_var(array(
-					'left'		=> $this->nextmatchs->left($this->link, $this->bo->start, $this->bo->num_rows, 'menuaction=phpbrain.uikb.index'),
-					'right'		=> $this->nextmatchs->right($this->link, $this->bo->start, $this->bo->num_rows, 'menuaction=phpbrain.uikb.index'),
+					'left'		=> $this->nextmatchs->left($this->link, $this->bo->start, $this->bo->num_rows, 'menuaction=phpbrain.uikb.index&cat='.$category_passed),
+					'right'		=> $this->nextmatchs->right($this->link, $this->bo->start, $this->bo->num_rows, 'menuaction=phpbrain.uikb.index&cat='.$category_passed),
 					'num_regs'	=> $this->nextmatchs->show_hits($this->bo->num_rows, $this->bo->start)
 				));
 				$this->t->parse('articles_navigation', 'articles_navigation_block');
@@ -349,7 +350,7 @@
 						'art_num'		=> $article_preview['art_id'],
 						'art_href'		=> $this->link('menuaction=phpbrain.uikb.view_article&art_id=' . $article_preview['art_id'] . $query),
 						'art_title'		=> $article_preview['title'],
-						'art_date'		=> date('F j, Y, g:i a', $article_preview['modified']),
+						'art_date'		=> $GLOBALS['egw']->common->show_date($article_preview['modified'], $GLOBALS['egw_info']['user']['preferences']['common']['dateformat'] . ' H:i'),
 						'img_stars'		=> $img_stars,
 						'attachment'	=> $attachment,
 						'art_category'	=> $category_path? lang('in %1', $category_path) : '',
@@ -615,7 +616,7 @@
 			}
 
 			// Process related articles added
-			if ($_POST['update_related'])
+			if ($_POST['update_related'] && !empty($_POST['related_articles']))
 			{
 				$message = $this->bo->add_related();
 				$this->reload_page($article_id, $message);
@@ -647,6 +648,10 @@
 			// *** SHOW ARTICLE ***
 			if ($print_view)
 			{
+				// add a content-type header to overwrite an existing default charset in apache (AddDefaultCharset directiv)
+				header('Content-type: text/html; charset='.$GLOBALS['egw']->translation->charset());
+				ob_end_flush();
+
 				$this->t->set_file('view_article', 'print_article.tpl');
 				$this->t->set_block('view_article', 'file_item_block', 'file_item');
 				$this->t->set_block('view_article', 'file_block', 'file');
@@ -1196,18 +1201,7 @@
 			$this->t->set_file('edit_article', 'edit_article.tpl');
 			$this->t->set_block('edit_article', 'answer_question_block', 'answer_question');
 			$this->t->set_block('edit_article', 'article_id_block', 'article_id');
-			$checking_spell = False;
 			
-			// show check spell button only if pspell functions and dictionnary in current language are available, and not comming from doing just that
-			if (function_exists(pspell_new) && @$pspell_link = pspell_new($GLOBALS['phpgw_info']['user']['preferences']['common']['lang']) && !$_POST['check_spell'])
-			{
-				$btn_spell = "<input type='submit' name='check_spell' value='". lang('Check spelling') ."'>&nbsp;";
-			}
-			else
-			{
-				$btn_spell = '';
-			}
-
 			$this->t->set_var(array(
 				'lang_articleID'		=> lang('Article ID'),
 				'lang_category'			=> lang('Category'),
@@ -1215,7 +1209,6 @@
 				'lang_title'			=> lang('Title'),
 				'lang_topic'			=> lang('Topic'),
 				'lang_keywords'			=> lang('Keywords'),
-				'btn_spell'				=> $btn_spell
 			));
 
 			// These are the default values, that apply for entering a new article
@@ -1234,40 +1227,11 @@
 				'article_id'		=> '',
 				));
 
-			// check spelling
-			if ($_POST['check_spell'])
-			{
-				if (!$content = $this->check_spell())
-				{
-					$temp		= get_var('exec', 'POST', '');
-					$content	= $temp['text'];
-					$this->message = lang("The article doesn't have spell errors");
-				}
-				else
-				{
-					$checking_spell =True;
-					$btn_save		= "<input type='submit' name='confirm_spell' value='". lang('Confirm') . "'>&nbsp;";
-					$btn_cancel		= '';
-					$this->message		= lang('Correct the errors and press confirm');
-				}
-				$GLOBALS['phpgw']->session->appsession('tagged_text', 'phpbrain', $content);
-			}
-
-			// correct spelling
-			if ($_POST['confirm_spell'])
-			{
-				$category_selected	= (int)get_var('cat_id', 'POST', 0);
-				$title				= get_var('title', 'POST', '');
-				$topic				= get_var('topic', 'POST', '');
-				$keywords			= get_var('keywords', 'POST', '');
-				$content			= $this->correct_spell();
-			}
-
 			// saving either an edited or a new article (answering a question or just a new article)
 			if ($_POST['save'])
 			{
 				$article_id = (int)get_var('editing_article_id', 'POST', 0);
-				$article	= $this->bo->get_article($article_id);
+				$article	= ($article_id)? $this->bo->get_article($article_id) : false;
 
 				//data validation
 				if (!$_POST['title'])
@@ -1308,10 +1272,8 @@
 				$title				= get_var('title', 'POST', '');
 				$topic				= get_var('topic', 'POST', '');
 				$keywords			= get_var('keywords', 'POST', '');
-				if (!$checking_spell) {
-					$temp = get_var('exec', 'POST', '');
-					$content = $temp['text'];
-				}
+				$temp = get_var('exec', 'POST', '');
+				$content = $temp['text'];
 			}
 
 			// Edit existant article
@@ -1324,7 +1286,7 @@
 					die();
 				}
 
-				if (!$this->message && !$_POST['confirm_spell'])
+				if (!$this->message)
 				{
 					$article	= $this->bo->get_article($article_id);
 
@@ -1370,12 +1332,8 @@
 				$category_selected = $question['cat_id'];
 			}
 			
-			// don't use htmlarea if checking spelling
-			if (!$checking_spell)
-			{
-				$html = CreateObject('phpgwapi.html');
-				$content = $html->htmlarea('exec[text]', $content);
-			}
+			$html = CreateObject('phpgwapi.html');
+			$content = $html->htmlarea('exec[text]', $content);
 	
 			// Finally, fill the input fields
 			if (!$this->sitemgr)
@@ -2039,68 +1997,6 @@
 
 		}
 
-		/**
-		* Places spelling suggestions in original text
-		*
-		* @author	Alejandro Pedraza
-		* @access	private
-		* @return	mixed	Corrected text or 0
-		*/
-		function check_spell()
-		{
-			$temp		= get_var('exec', 'POST', '');
-			$text_orig	= $temp['text'];
-			//echo "<br><br><br>text_orig: <pre>";print_r($text_orig);echo "</pre>";
-			$text_noHTML = preg_replace('/<.*?>/', ' ', $text_orig);
-			$words = preg_split('/[\W]+?/', $text_noHTML);
-			//echo "words: <pre>";print_r($words);echo "</pre>";
-			$pspell_link = pspell_new($GLOBALS['phpgw_info']['user']['preferences']['common']['lang']);
-			$i = 0;
-			foreach ($words as $word)
-			{
-				if (!pspell_check($pspell_link, $word))
-				{
-					$i++;
-					$suggestions = array($word);
-					$suggestions = array_merge($suggestions, pspell_suggest($pspell_link, $word));
-					//echo "<br><br><br>word: $word -- suggestions: <pre>";print_r($suggestions);echo "</pre>";
-					$replacement = "<span name='nn' style='color:red; font-weight: bold'>$word&nbsp;</span><select name='correction[$i]'>";
-					foreach ($suggestions as $suggestion)
-					{
-						$replacement .= "<option value='$suggestion'>". $suggestion ."</option>";
-					}
-					$replacement .= "</select>";
-					$text_orig = preg_replace('/\b'.$word.'\b/', $replacement, $text_orig);
-					//echo "<br><br><br>original changed to: $text_orig <br><br>";
-				}
-			}
-			if (!$i) return 0;
-			return $text_orig;
-		}
-
-		/**
-		* Corrects text spelling
-		*
-		* @author	Alejandro Pedraza
-		* @access	private
-		* @return	string	Corrected text
-		*/
-		function correct_spell()
-		{
-			$corrections = get_var('correction', 'post');
-			//echo "corrections: <pre>";print_r($corrections);echo "</pre>\n";
-			$tagged_text = $GLOBALS['phpgw']->session->appsession('tagged_text', 'phpbrain');
-			//echo "tagged_text in session: ";print_r($tagged_text);echo "</pre>\n";
-			$corrected_text = preg_replace("/<span name='nn' style='color:red; font-weight: bold'>[\w]+?&nbsp;<\/span>/", '', $tagged_text);
-			//echo "tagged_text sin span rojos: ";print_r($corrected_text);echo "</pre>\n";
-			foreach ($corrections as $index=>$correction)
-			{
-				$corrected_text = preg_replace("/<select name='correction.".$index."]'.*?<\/select>/", $correction, $corrected_text);
-			}
-			//echo "corrected_text: ";print_r($corrected_text);die();
-			return $corrected_text;
-		}
-
 		/**
 		* Shows link string. Necessary because might be different depending if entered through sitemgr or not
 		*
