@@ -9,12 +9,11 @@
     *  option) any later version.                                              *
     \**************************************************************************/
 
-	/* $Id: hook_preferences.inc.php,v 1.1 2004/05/26 07:32:30 ralfbecker Exp $ */
+	/* $Id: hook_preferences.inc.php 20295 2006-02-15 12:31:25Z  $ */
 {
-
 	$file = Array(
-		'Preferences'		=> $GLOBALS['phpgw']->link('/preferences/preferences.php','appname=phpbrain'),
-		'Edit Categories'	=> $GLOBALS['phpgw']->link('/index.php','menuaction=preferences.uicategories.index&cats_app='.$appname.'&cats_level=True&global_cats=True')
+		'Preferences'     => $GLOBALS['egw']->link('/index.php','menuaction=preferences.uisettings.index&appname=' . $appname),
+		'Edit Categories' => $GLOBALS['egw']->link('/index.php','menuaction=preferences.uicategories.index&cats_app='.$appname.'&cats_level=True&global_cats=True')
 	);
 	display_section($appname,$file);
 }
