@@ -21,53 +21,70 @@
   * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
   \**************************************************************************/
 
-  /* $Id: class.acl.inc.php,v 1.72.4.6 2005/04/13 08:58:03 ralfbecker Exp $ */
+  /* $Id: class.acl.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
-	/*!
-		@class acl
-		@abstract Access Control List Security System
-		@discussion This class provides an ACL security scheme.
-		This can manage rights to 'run' applications, and limit certain features within an application.
-		It is also used for granting a user "membership" to a group, or making a user have the security equivilance of another user.
-		It is also used for granting a user or group rights to various records, such as todo or calendar items of another user.
-		@syntax CreateObject('phpgwapi.acl',int account_id);
-		@example $acl = CreateObject('phpgwapi.acl',5);  // 5 is the user id
-		@example $acl = CreateObject('phpgwapi.acl',10);  // 10 is the user id
-		@author Seek3r
-		@copyright LGPL
-		@package phpgwapi
-		@access public
-	*/
+	/**
+	 * Access Control List System
+	 *
+	 * This class provides an ACL security scheme.
+	 * This can manage rights to 'run' applications, and limit certain features within an application.
+	 * It is also used for granting a user "membership" to a group, or making a user have the security equivilance of another user.
+	 * It is also used for granting a user or group rights to various records, such as todo or calendar items of another user.
+	 * $acl =& CreateObject('phpgwapi.acl',5);  // 5 is the user id
+	 *
+	 * @author Seek3r and others
+	 * @copyright LGPL
+	 * @package api
+	 * @subpackage accounts
+	 * @access public
+	 */
 	class acl
 	{
-		/*! @var $account_id */
-		var $account_id;
-		/*! @var $account_type */
+		/**
+		 * @var int $account_id the account-id this class is instanciated for
+		 */
+		var $account_id = 0;
+		/**
+		 * @var $account_type 
+		 */
 		var $account_type;
-		/*! @var $data  */
+		/**
+		 * @var array $data internal repository with acl rows for the given app and account-id (incl. memberships)
+		 */
 		var $data = Array();
-		/*! @var $db */
+		/**
+		 * @var object/db $db internal copy of the db-object
+		 */
 		var $db;
-		var $table_name = 'phpgw_acl';
+		/**
+		 * @var string $table_name name of the acl_table
+		 */
+		var $table_name = 'egw_acl';
 
-		/*!
-		@function acl
-		@abstract ACL constructor for setting account id
-		@discussion Author: Seek3r <br>
-		Sets the ID for $acl->account_id. Can be used to change a current instances id as well. <br>
-		Some functions are specific to this account, and others are generic. <br>
-		@syntax int acl(int account_id) <br>
-		@example1 acl->acl(5); // 5 is the user id  <br>
-		@param account_id int-the user id
-		*/
+		/**
+		 * ACL constructor for setting account id
+		 *
+		 * Sets the ID for $acl->account_id. Can be used to change a current instances id as well.
+		 * Some functions are specific to this account, and others are generic. 
+		 *
+		 * @example acl->acl(5); // 5 is the user id
+		 * @param int $account_id int-the user id
+		 */
 		function acl($account_id = '')
 		{
-			$this->db = clone($GLOBALS['phpgw']->db);
+			if (is_object($GLOBALS['egw_setup']->db))
+			{
+				$this->db = clone($GLOBALS['egw_setup']->db);
+			}
+			else
+			{
+				$this->db = clone($GLOBALS['egw']->db);
+			}
 			$this->db->set_app('phpgwapi');
 
 			if ((int)$this->account_id != (int)$account_id)
 			{
-				$this->account_id = get_account_id((int)$account_id,@$GLOBALS['phpgw_info']['user']['account_id']);
+				$this->account_id = get_account_id((int)$account_id,@$GLOBALS['egw_info']['user']['account_id']);
 			}
 		}
 
@@ -120,15 +137,12 @@
 		* These are the standard $this->account_id specific functions              *
 		\**************************************************************************/
 
-		/*!
-		@function read_repository
-		@abstract Read acl records from reposity
-		@discussion Author: Seek3r <br>
-		Reads ACL records for $acl->account_id and returns array along with storing it in $acl->data.  <br>
-		Syntax: array read_repository() <br>
-		Example1: acl->read_repository(); <br>
-		Should only be called within this class
-		*/
+		/**
+		 * Read acl records for $acl->account_id from reposity
+		 *
+		 * @internal 
+		 * @return array along with storing it in $acl->data.  <br>
+		 */
 		function read_repository()
 		{
 			// For some reason, calling this via XML-RPC doesn't call the constructor.
@@ -140,28 +154,25 @@
  			$acl_acc_list = array_values((array)$this->get_location_list_for_id('phpgw_group', 1, $this->account_id)); 
  			array_unshift($acl_acc_list,$this->account_id,0); 
 			$this->db->select($this->table_name,'*',array('acl_account' => $acl_acc_list ),__LINE__,__FILE__); 
-			
+ 
 			$this->data = Array();
-			while($this->db->next_record())
+			while(($row = $this->db->row(true)))
 			{
 				$this->data[] = array(
-					'appname'  => $this->db->f('acl_appname'),
-					'location' => $this->db->f('acl_location'), 
-					'account'  => $this->db->f('acl_account'), 
-					'rights'   => $this->db->f('acl_rights')
+					'appname'  => $row['acl_appname'],
+					'location' => $row['acl_location'], 
+					'account'  => $row['acl_account'], 
+					'rights'   => $row['acl_rights'],
 				);
 			}
 			return $this->data;
 		}
 
-		/*!
-		@function read
-		@abstract Read acl records from $acl->data
-		@discussion Author: Seek3r <br>
-		Returns ACL records from $acl->data. <br>
-		Syntax: array read() <br>
-		Example1: acl->read(); <br>
-		*/
+		/**
+		 * Read acl records from $acl->data
+		 *
+		 * @return array all ACL records from $this->data.
+		 */
 		function read()
 		{
 			if (!count($this->data))
@@ -171,19 +182,19 @@
 			return $this->data;
 		}
 
-		/*!
-		@function add
-		@abstract Adds ACL record to $acl->data
-		@discussion Adds ACL record to $acl->data. <br>
-		Syntax: array add() <br>
-		Example1: acl->add();
-		@param $appname default False derives value from $phpgw_info['flags']['currentapp']
-		@param $location location
-		@param $rights rights
-		*/
+		/**
+		 * Adds ACL record to  the repository of the class
+		 *
+		 * Adds ACL record to $this->data. 
+		 *
+		 * @param string $appname default False derives value from $GLOBALS['egw_info']['flags']['currentapp']
+		 * @param string $location location
+		 * @param int $rights rights
+		 * @return array all ACL records from $this->data.
+		 */
 		function add($appname,$location,$rights)
 		{
-			if (!$appname) $appname = $GLOBALS['phpgw_info']['flags']['currentapp'];
+			if (!$appname) $appname = $GLOBALS['egw_info']['flags']['currentapp'];
 
 			$this->data[] = array(
 				'appname'  => $appname, 
@@ -195,18 +206,16 @@
 			return $this->data;
 		}
 
-		/*!
-		@function delete
-		@abstract Delete ACL record
-		@discussion 
-		Syntax <br>
-		Example: <br>
-		@param $appname optional defaults to $phpgw_info['flags']['currentapp']
-		@param $location app location
-		*/
-		function delete($appname, $location)
+		/**
+		 * Delete ACL record in the repository of the class
+		 *
+		 * @param string $appname appname or '' for $GLOBALS['egw_info']['flags']['currentapp']
+		 * @param string $location location
+		 * @return array all ACL records from $this->data.
+		 */
+		function delete($appname,$location)
 		{
-			if (!$appname) $appname = $GLOBALS['phpgw_info']['flags']['currentapp'];
+			if (!$appname) $appname = $GLOBALS['egw_info']['flags']['currentapp'];
 
 			foreach($this->data as $idx => $value)
 			{
@@ -218,14 +227,11 @@
 			return $this->data;
 		}
 
-		/*!
-		@function save_repostiory
-		@abstract save repository
-		@discussion save the repository <br>
-		Syntax: save_repository() <br>
-		example: acl->save_repository()
-		*/
-		
+		/**
+		 * save the internal repository or the class
+		 *
+		 * @return array all ACL records from $this->data.
+		 */
 		function save_repository()
 		{
 			$this->db->delete($this->table_name,array(
@@ -244,6 +250,11 @@
 					),false,__LINE__,__FILE__);
 				}
 			}
+			if ($this->account_id == $GLOBALS['egw_info']['user']['account_id'] && 
+				method_exists($GLOBALS['egw'],'invalidate_session_cache'))	// egw object in setup is limited
+			{
+				$GLOBALS['egw']->invalidate_session_cache();
+			}
 			return $this->data;
 		}
 
@@ -251,14 +262,14 @@
 		* These are the non-standard $this->account_id specific functions          *
 		\**************************************************************************/
 
-		/*!
-		@function get_rights
-		@abstract get rights from the repository not specific to this->account_id (?)
-		@discussion 
-		@param $location app location to get rights from
-		@param $appname optional defaults to $phpgw_info['flags']['currentapp'];
-		*/
-		function get_rights($location,$appname = False)
+		/**
+		 * get rights from the class repository (included rights of $this->account_id and all it's memberships)
+		 *
+		 * @param string $location app location to get rights from
+		 * @param string $appname optional defaults to $GLOBALS['egw_info']['flags']['currentapp'];
+		 * @return int all rights or'ed together
+		 */
+		function get_rights($location,$appname = '')
 		{
 			// For XML-RPC, change this once its working correctly for passing parameters (jengo)
 			if (is_array($location))
@@ -271,9 +282,9 @@
 			{
 				$this->read_repository();
 			}
-			if (!$appname) $appname = $GLOBALS['phpgw_info']['flags']['currentapp'];
+			if (!$appname) $appname = $GLOBALS['egw_info']['flags']['currentapp'];
 
-			if (!count($this->data) && $GLOBALS['phpgw_info']['server']['acl_default'] != 'deny')
+			if (!count($this->data) && $GLOBALS['egw_info']['server']['acl_default'] != 'deny')
 			{
 				return True;
 			}
@@ -294,31 +305,35 @@
 			}
 			return $rights;
 		}
-		/*!
-		@function check
-		@abstract check required rights (not specific to this->account_id?)
-		@param $location app location
-		@param $required required right to check against
-		@param $appname optional defaults to currentapp
-		*/
+
+		/**
+		 * check required rights agains the internal repository (included rights of $this->account_id and all it's memberships)
+		 *
+		 * @param $location app location
+		 * @param $required required right to check against
+		 * @param $appname optional defaults to currentapp
+		 * @return boolean
+		 */
 		function check($location, $required, $appname = False)
 		{
 			$rights = $this->get_rights($location,$appname);
 
 			return !!($rights & $required);
 		}
-		/*!
-		@function get_specific_rights
-		@abstract get specific rights for this->account_id for an app location
-		@param $location app location
-		@param $appname optional defaults to currentapp
-		@result $rights ?
-		*/
-		function get_specific_rights($location, $appname = False)
-		{
-			if (!$appname) $appname = $GLOBALS['phpgw_info']['flags']['currentapp'];
 
-			if (!count($this->data) && $GLOBALS['phpgw_info']['server']['acl_default'] != 'deny')
+		/**
+		 * get specific rights for this->account_id for an app location
+		 *
+		 * @param string $location app location
+		 * @param string $appname='' optional defaults to currentapp
+		 * @param int $account_id=0 optional defaults to $this->account_id
+		 * @return int $rights
+		 */
+		function get_specific_rights($location, $appname = '')
+		{
+			if (!$appname) $appname = $GLOBALS['egw_info']['flags']['currentapp'];
+
+			if (!count($this->data) && $GLOBALS['egw_info']['server']['acl_default'] != 'deny')
 			{
 				return True;
 			}
@@ -339,15 +354,16 @@
 			}
 			return $rights;
 		}
-		/*!
-		@function check_specific
-		@abstract check specific
-		@param $location app location
-		@param $required required rights
-		@param $appname optional defaults to currentapp
-		@result boolean
-		*/
-		function check_specific($location, $required, $appname = False)
+
+		/**
+		 * check specific rights
+		 *
+		 * @param string $location app location
+		 * @param int $required required rights
+		 * @param string $appname optional defaults to currentapp
+		 * @return boolean
+		 */
+		function check_specific($location, $required, $appname = '')
 		{
 			$rights = $this->get_specific_rights($location,$appname);
 
@@ -359,12 +375,13 @@
 		\**************************************************************************/
 
 		/**
-		 * add repository information / rights for app/location/account_id
+		 * add repository information / rights for app/location/account_id to the database 
 		 *
-		 * @param $app appname
-		 * @param $location location
-		 * @param $account_id account id
-		 * @param $rights rights
+		 * @param string $app appname
+		 * @param string $location location
+		 * @param int $account_id account id
+		 * @param int $rights rights
+		 * @return boolean allways true
 		 */
 		function add_repository($app, $location, $account_id, $rights)
 		{
@@ -377,11 +394,17 @@
 				'acl_account'  => $account_id,
 			),__LINE__,__FILE__);
 
+			if ($account_id == $GLOBALS['egw_info']['user']['account_id'] &&
+				method_exists($GLOBALS['egw'],'invalidate_session_cache'))	// egw object in setup is limited
+			{
+				$GLOBALS['egw']->invalidate_session_cache();
+			}
 			return True;
 		}
 
 		/**
-		 * delete repository information / rights for app/location[/account_id]
+		 * delete repository information / rights for app/location[/account_id] from the DB
+		 *
 		 * @param string $app appname
 		 * @param string $location location
 		 * @param int/boolean $account_id account id, default 0=$this->account_id, or false to delete all entries for $app/$location
@@ -406,20 +429,103 @@
 					$where['acl_account'] = $cache_accountid[$accountid] = get_account_id($accountid,$this->account_id);
 				}
 			}
+			if (method_exists($GLOBALS['egw'],'invalidate_session_cache'))	// egw object in setup is limited
+			{
+				$GLOBALS['egw']->invalidate_session_cache();
+			}
 			if ($app == '%' || $app == '%%') unset($where['acl_appname']);
 
 			$this->db->delete($this->table_name,$where,__LINE__,__FILE__);
 
 			return $this->db->affected_rows();
 		}
+		
+		/**
+		 * Get rights for a given account, location and application
+		 *
+		 * @param int $account_id
+		 * @param string $location
+		 * @param string $appname='' defaults to current app
+		 * @return int/boolean rights or false if none exist
+		 */
+		function get_specific_rights_for_account($account_id,$location,$appname='')
+		{
+			if (!$appname) $appname = $GLOBALS['egw_info']['flags']['currentapp'];
 
-		/*!
-		@function get_app_list_for_id
-		@abstract get application list for an account id
-		@param $location location
-		@param $required ?
-		@param $account_id account id defaults to $phpgw_info['user']['account_id'];
-		*/
+			$this->db->select($this->table_name,'acl_rights',array(
+				'acl_location' => $location,
+				'acl_account'  => $account_id,
+				'acl_appname'  => $appname,
+			),__LINE__,__FILE__);
+	
+			return $this->db->next_record() ? $this->db->f('acl_rights') : false;
+		}
+		
+		/**
+		 * Get all rights for a given location and application
+		 *
+		 * @param string $location
+		 * @param string $appname='' defaults to current app
+		 * @return array with account => rights pairs
+		 */
+		function get_all_rights($location,$appname='')
+		{
+			if (!$appname) $appname = $GLOBALS['egw_info']['flags']['currentapp'];
+
+			$this->db->select($this->table_name,'acl_account,acl_rights',array(
+				'acl_location' => $location,
+				'acl_appname'  => $appname,
+			),__LINE__,__FILE__);
+	
+			$rights = array();
+			while($this->db->next_record())
+			{
+				$rights[$this->db->f('acl_account')] = $this->db->f('acl_rights');
+			}
+			return $rights;
+		}
+
+		/**
+		 * Get the rights for all locations
+		 *
+		 * @param int $account_id
+		 * @param string $appname='' defaults to current app
+		 * @param boolean $use_memberships=true
+		 * @return array with location => rights pairs
+		 */
+		function get_all_location_rights($account_id,$appname='',$use_memberships=true)
+		{
+			if (!$appname) $appname = $GLOBALS['egw_info']['flags']['currentapp'];
+
+			$accounts = array($account_id);
+			if ($use_memberships)
+			{
+				foreach((array)$GLOBALS['egw']->accounts->membership($account_id) as $group)
+				{
+					$accounts[] = $group['account_id'];
+				}
+			}
+			$this->db->select($this->table_name,'acl_location,acl_rights',array(
+				'acl_account' => $accounts,
+				'acl_appname' => $appname,
+			),__LINE__,__FILE__);
+	
+			$rights = array();
+			while($this->db->next_record())
+			{
+				$rights[$this->db->f('acl_location')] |= $this->db->f('acl_rights');
+			}
+			return $rights;
+		}
+
+		/**
+		 * get application list for an account id
+		 *
+		 * @param string $location location
+		 * @param int $required required rights
+		 * @param int $account_id account id defaults to $GLOBALS['egw_info']['user']['account_id'];
+		 * @return array/boolean false if there are no matching row in the db, else array with app-names
+		 */
 		function get_app_list_for_id($location, $required, $accountid = '')
 		{
 			static $cache_accountid;
@@ -455,18 +561,18 @@
 			return $apps;
 		}
 
-		/*!
-		@function get_location_list_for_id
-		@abstract get location list for id
-		@discussion ?
-		@param $app app
-		@param $required required
-		@param $account_id optional defaults to $phpgw_info['user']['account_id'];
-		*/
+		/**
+		 * get location list for id
+		 *
+		 * @param string $app app
+		 * @param int $required required rights
+		 * @param int $accountid optional defaults to $GLOBALS['egw_info']['user']['account_id'];
+		 * @return array/boolean false if there are no matching rows in the db or array with location-strings
+		 */
 		function get_location_list_for_id($app, $required, $accountid = '')
 		{
 			static $cache_accountid;
-
+			
 			if($cache_accountid[$accountid])
 			{
 				$accountid = $cache_accountid[$accountid];
@@ -490,16 +596,18 @@
 			}
 			return $locations;
 		}
-		/*!
-		@function get_ids_for_location
-		@abstract get ids for location
-		@param $location location
-		@param $required required
-		@param $app app optional defaults to $phpgw_info['flags']['currentapp'];
-		*/
-		function get_ids_for_location($location, $required, $app = False)
+
+		/**
+		 * get ids for location
+		 *
+		 * @param string $location location
+		 * @param int $required required rights
+		 * @param string $app app optional defaults to $GLOBALS['egw_info']['flags']['currentapp'];
+		 * @return boolean/array false if there are no matching rows in the db or array of account-ids
+		 */
+		function get_ids_for_location($location, $required, $app = '')
 		{
-			if (!$app) $app = $GLOBALS['phpgw_info']['flags']['currentapp'];
+			if (!$app) $app = $GLOBALS['egw_info']['flags']['currentapp'];
 
 			$this->db->select($this->table_name,array('acl_account','acl_rights'),array(
 				'acl_appname'  => $app,
@@ -517,12 +625,37 @@
 			return $accounts;
 		}
 
-		/*!
-		@function get_user_applications
-		@abstract get a list of applications a user has rights to
-		@param $account_id optional defaults to $phpgw_info['user']['account_id'];
-		@result $apps array containing list of apps
-		*/
+		/**
+		 * get the locations for an app (excluding the run location !!!)
+		 *
+		 * @param string $app app optional defaults to $GLOBALS['egw_info']['flags']['currentapp'];
+		 * @return boolean/array false if there are no matching location in the db or array of locations
+		 */
+		function get_locations_for_app($app='')
+		{
+			if (!$app) $app = $GLOBALS['egw_info']['flags']['currentapp'];
+
+			$this->db->select($this->table_name,'DISTINCT '.'acl_location',array(
+				'acl_appname'  => $app,
+			),__LINE__,__FILE__);
+
+			$locations = false;
+			while ($this->db->next_record())
+			{
+				if (($location = $this->db->f(0)) != 'run')
+				{
+					$locations[] = $location;
+				}
+			}
+			return $locations;
+		}
+
+		/**
+		 * get a list of applications a user has rights to
+		 *
+		 * @param int $account_id optional defaults to $GLOBALS['egw_info']['user']['account_id'];
+		 * @return boolean/array containing list of apps or false if there are none
+		 */
 		function get_user_applications($accountid = '')
 		{
 			static $cache_accountid;
@@ -537,7 +670,7 @@
 				$cache_accountid[$accountid] = $account_id;
 			}
 			$memberships = array($account_id);
-			foreach((array)$GLOBALS['phpgw']->accounts->membership($account_id) as $group)
+			foreach((array)$GLOBALS['egw']->accounts->membership($account_id) as $group)
 			{
 				$memberships[] = $group['account_id'];
 			}
@@ -559,17 +692,19 @@
 			}
 			return $apps;
 		}
-		/*!
-		@function get_grants
-		@abstract ?
-		@param $app optional defaults to $phpgw_info['flags']['currentapp'];
-		*/
+
+		/**
+		 * Read the grants other users gave $this->account_id for $app, group ACL is taken into account
+		 *
+		 * @param string $app optional defaults to $GLOBALS['egw_info']['flags']['currentapp'];
+		 * @return array with account-ids (of owners) and granted rights as values
+		 */
 		function get_grants($app='')
 		{
-			if (!$app) $app = $GLOBALS['phpgw_info']['flags']['currentapp'];
+			if (!$app) $app = $GLOBALS['egw_info']['flags']['currentapp'];
 
 			$memberships = array($this->account_id);
-			foreach((array)$GLOBALS['phpgw']->accounts->membership($this->account_id) as $group)
+			foreach((array)$GLOBALS['egw']->accounts->membership($this->account_id) as $group)
 			{
 				$memberships[] = $group['account_id'];
 			}
@@ -604,15 +739,15 @@
 				if(@$is_group[$grantor])
 				{
 					// Don't allow to override private!
-					$rights &= (~ PHPGW_ACL_PRIVATE);
+					$rights &= (~ EGW_ACL_PRIVATE);
 					if(!isset($grants[$grantor]))
 					{
 						$grants[$grantor] = 0;
 					}
 					$grants[$grantor] |= $rights;
-					if(!!($rights & PHPGW_ACL_READ))
+					if(!!($rights & EGW_ACL_READ))
 					{
-						$grants[$grantor] |= PHPGW_ACL_READ;
+						$grants[$grantor] |= EGW_ACL_READ;
 					}
 				}
 				foreach($accounts[$grantor] as $grantors)
@@ -624,7 +759,7 @@
 					$grants[$grantors] |= $rights;
 				}
 			}
-			$grants[$GLOBALS['phpgw_info']['user']['account_id']] = ~0;
+			$grants[$GLOBALS['egw_info']['user']['account_id']] = ~0;
 
 			return $grants;
 		}
