@@ -1,6 +1,7 @@
 <?php
 	/**************************************************************************\
 	* eGroupWare API - Contacts manager for SQL                                *
+	* Reworked with new DB-functions by RalfBecker-AT-outdoor-training.de      *
 	* This file written by Joseph Engo <jengo@phpgroupware.org>                *
 	*   and Miles Lott <milosch@groupwhere.org>                                *
 	* View and manipulate contact records using SQL                            *
@@ -21,30 +22,39 @@
 	* along with this library; if not, write to the Free Software Foundation,  *
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
-	
+
 	/**
-	* This class provides a contact database scheme. 
-	* It attempts to be based on the vcard 2.1 standard, with mods as needed 
+	* This class provides a contact database scheme.
+	* It attempts to be based on the vcard 2.1 standard, with mods as needed
 	* to make for more reasonable sql storage.
 	* Note that changes here must also work in the LDAP version.
 	* Syntax: CreateObject('phpgwapi.contacts');
 	* Example1: $contacts = CreateObject('phpgwapi.contacts');
 	*
+	* The contacts class now uses user-time in all param- and return-values.
+	* The time stored in the DB is in server-time, as in all other eGW apps.
+	*
 	* Last Editor: $Author: ralfbecker $
 	* @class contacts_
 	* @abstract Contact Management System
 	* @author jengo/Milosch
-	* @version $Revision: 1.50.4.1 $    
+	* @version $Revision: 21368 $
 	* @license LGPL
 	*/
-	
-	/* $Id: class.contacts_sql.inc.php,v 1.50.4.1 2004/09/19 12:35:44 ralfbecker Exp $ */
+
+	/* $Id: class.contacts_sql.inc.php 21368 2006-04-14 09:53:05Z ralfbecker $ */
 
 	class contacts_
 	{
 		var $db = '';
-		var $std_table='phpgw_addressbook';
-		var $ext_table='phpgw_addressbook_extra';
+		var $std_table='egw_addressbook';
+		var $ext_table='egw_addressbook_extra';
+
+		/**
+		 * @var int $tz_offset_s offset in secconds between user and server-time,
+		 *	it need to be add to a server-time to get the user-time or substracted from a user-time to get the server-time
+		 */
+		var $tz_offset_s;
 
 		var $account_id = 0;
 		var $total_records = 0;
@@ -146,13 +156,14 @@
 
 		function contacts_($useacl=True)
 		{
-//			$this->db = $GLOBALS['phpgw']->db;
-			copyobj($GLOBALS['phpgw']->db,$this->db);
+			$this->db = clone($GLOBALS['egw']->db);
+			$this->db->set_app('phpgwapi');
+
 			if($useacl)
 			{
-				$this->grants = $GLOBALS['phpgw']->acl->get_grants('addressbook');
+				$this->grants = $GLOBALS['egw']->acl->get_grants('addressbook');
 			}
-			$this->account_id = $GLOBALS['phpgw_info']['user']['account_id'];
+			$this->account_id = $GLOBALS['egw_info']['user']['account_id'];
 
 			/* Used to flag an address as being:
 			   domestic AND/OR international(default)
@@ -165,6 +176,11 @@
 				'parcel' => lang('Parcel'),
 				'postal' => lang('Postal')
 			);
+			if (!is_object($GLOBALS['egw']->datetime))
+			{
+				$GLOBALS['egw']->datetime =& CreateObject('phpgwapi.datetime');
+			}
+			$this->tz_offset_s = $GLOBALS['egw']->datetime->tz_offset;
 		}
 
 		/* send this the id and whatever fields you want to see */
@@ -185,7 +201,7 @@
 				}
 			}
 
-			$this->db->query("SELECT id,lid,tid,owner,access,cat_id $t_fields FROM $this->std_table WHERE id=" . (int)$id);
+			$this->db->select($this->std_table,'id,lid,tid,owner,access,cat_id'.$t_fields,array('id' => $id),__LINE__,__FILE__);
 			$this->db->next_record();
 
 			$return_fields[0]['id']     = $this->db->f('id');
@@ -210,7 +226,10 @@
 				$one_type = $this->db->f('adr_one_type');
 				foreach($this->adr_types as $name => $val)
 				{
-					eval("if (strstr(\$one_type,\$name)) { \$return_fields[0][\"one_\$name\"] = \"on\"; }");
+					if (strstr($one_type,$name))
+					{
+						$return_fields[0]['one_'.$name] = 'on';
+					}
 				}
 			}
 			if ($this->db->f('adr_two_type'))
@@ -218,11 +237,14 @@
 				$two_type = $this->db->f('adr_two_type');
 				foreach($this->adr_types as $name => $val)
 				{
-					eval("if (strstr(\$two_type,\$name)) { \$return_fields[0][\"two_\$name\"] = \"on\"; }");
+					if (strstr($two_type,$name))
+					{
+						$return_fields[0]['two_'.$name] = 'on';
+					}
 				}
 			}
 
-			$this->db->query("SELECT contact_name,contact_value FROM $this->ext_table WHERE contact_id=" . (int)$this->db->f('id'),__LINE__,__FILE__);
+			$this->db->select($this->ext_table,'contact_name,contact_value',array('contact_id'=>$id),__LINE__,__FILE__);
 			while ($this->db->next_record())
 			{
 				if ($extra_fields[$this->db->f('contact_name')])
@@ -233,79 +255,39 @@
 			return $return_fields;
 		}
 
+		// better use get_last_insert_id !!!
 		function read_last_entry($fields='')
 		{
-			if (!$fields || empty($fields)) { $fields = $this->stock_contact_fields; }
-			list($stock_fields,$stock_fieldnames,$extra_fields) =
-				$this->split_stock_and_extras($fields);
-
-			if (count($stock_fieldnames))
-			{
-				$t_fields = ',' . implode(',',$stock_fieldnames);
-				if ($t_fields == ',')
-				{
-					unset($t_fields);
-				}
-			}
-
-			$this->db->query('SELECT max(id) FROM '.$this->std_table,__LINE__,__FILE__);
+			$this->db->select($this->std_table,'max(id)',False,__LINE__,__FILE__);
 			$this->db->next_record();
 
-			$id = $this->db->f(0);
-
-			$this->db->query("SELECT id,lid,tid,owner,access,cat_id $t_fields FROM $this->std_table WHERE id=" . (int)$id,__LINE__,__FILE__);
-			$this->db->next_record();
-
-			$return_fields[0]['id']     = $this->db->f('id');
-			$return_fields[0]['lid']    = $this->db->f('lid');
-			$return_fields[0]['tid']    = $this->db->f('tid');
-			$return_fields[0]['owner']  = $this->db->f('owner');
-			$return_fields[0]['access'] = $this->db->f('access');
-			$return_fields[0]['cat_id'] = $this->db->f('cat_id');
-			$return_fields[0]['rights'] = (int)$this->grants[$this->db->f('owner')];
-
-			if (@is_array($stock_fieldnames))
-			{
-				foreach($stock_fieldnames as $f_name)
-				{
-					$return_fields[0][$f_name] = $this->db->f($f_name);
-				}
-			}
-
-			/* Setup address type fields for ui forms display */
-			if($this->db->f('adr_one_type'))
-			{
-				$one_type = $this->db->f('adr_one_type');
-				foreach($this->adr_types as $name => $val)
-				{
-					eval("if (strstr(\$one_type,\$name)) { \$return_fields[0][\"one_\$name\"] = \"on\"; }");
-				}
-			}
-			if($this->db->f('adr_two_type'))
-			{
-				$two_type = $this->db->f('adr_two_type');
-				foreach($this->adr_types as $name => $val)
-				{
-					eval("if (strstr(\$two_type,\$name)) { \$return_fields[0][\"two_\$name\"] = \"on\"; }");
-				}
-			}
-
-			$this->db->query("SELECT contact_name,contact_value FROM $this->ext_table WHERE contact_id=" . (int)$this->db->f('id'),__LINE__,__FILE__);
-			while ($this->db->next_record())
-			{
-				if ($extra_fields[$this->db->f('contact_name')])
-				{
-					$return_fields[0][$this->db->f('contact_name')] = $this->db->f('contact_value');
-				}
-			}
-			return $return_fields;
+			return $this->read_single_entry($this->db->f(0),$fields);
 		}
 
-		/* send this the range, query, sort, order and whatever fields you want to see */
-		function read($start=0,$limit=0,$fields='',$query='',$filter='',$sort='',$order='', $lastmod=-1,$cquery='')
+		/**
+		 * Searches for contacts meating certain criteria and evtl. return only a range of them
+		 *
+		 * @param int $start=0 starting number of the range, if $limit != 0
+		 * @param int $limit=0 max. number of entries to return, 0=all
+		 * @param array $fields=null fields to return or null for all stock fields
+		 * @param string $query='' search pattern or '' for none
+		 * @param string $filter='' filters with syntax like <name>=<value>,<name2>=<value2> OR <name3>=<value3>,<name4>=!'' for not empty
+		 * @param string $sort='' sorting: ASC or DESC
+		 * @param string $order='' column to order, default ('') n_family,n_given,email ASC
+		 * @param int $lastmod=-1 return only values modified after given timestamp, default (-1) return all
+		 * @param string $cquery='' return only entries starting with given character, default ('') all
+		 * @return array of contacts
+		 */
+		function read($start=0,$limit=0,$fields=null,$query='',$filter='',$sort='',$order='', $lastmod=-1,$cquery='')
 		{
-			if(!$start)  { $start  = 0; }
-			if(!$limit)  { $limit  = 0; }
+			if (!$limit)
+			{
+				$limit = -1;	// db::query uses -1 for all
+			}
+			elseif (!$start)
+			{
+				$start  = 0;
+			}
 			if(!$filter) { $filter = 'tid=n'; }
 
 			if (!$fields || empty($fields)) { $fields = $this->stock_contact_fields; }
@@ -351,18 +333,16 @@
 							if (!(int)$value) continue;	// nothing to filter
 
 							//$filterlist[] = "(" . $name . " LIKE '%," . (int)$value . ",%' OR " . $name."='".(int)$value."')";
-							if (!is_object($GLOBALS['phpgw']->categories))
+							if (!is_object($GLOBALS['egw']->categories))
 							{
-								$GLOBALS['phpgw']->categories = CreateObject('phpgwapi.categories');
+								$GLOBALS['egw']->categories = CreateObject('phpgwapi.categories');
 							}
-							$cats = $GLOBALS['phpgw']->categories->return_all_children((int)$value);
-							$cat_filter = '(cat_id IN ('.implode(',',$cats).')';
+							$cats = $GLOBALS['egw']->categories->return_all_children((int)$value);
 							foreach($cats as $cat)
 							{
-								$cat_filter .= " OR cat_id LIKE '%,$cat,%'";
+								$cat_filter[] = $this->db->concat("','",cat_id,"','")." LIKE '%,$cat,%'";
 							}
-							$cat_filter .= ')';
-							$filterlist[] = $cat_filter;
+							$filterlist[] = '('.implode(' OR ',$cat_filter).')';
 						}
 						elseif(@is_int($value))
 						{
@@ -455,18 +435,15 @@
 				echo "<br>DEBUG - $ordermethod";
 			}
 
-			if($lastmod >= 0 && $fwhere)
+			if($lastmod >= 0)
 			{
-				$fwhere .= " AND last_mod > ".(int)$lastmod.' ';
-			}
-			elseif($lastmod >= 0)
-			{
-				$fwhere = " WHERE last_mod > ".(int)$lastmod.' ';
-			}
+				if (!$fwhere) $fwhere = ' WHERE ';
+				$fwhere .= " AND last_mod > ".(int)($lastmod - $this->tz_offset_s).' ';
 
-			if ($DEBUG && $last_mod_filter && $fwhere)
-			{
-				echo "<br>DEBUG - last_mod_filter added to fwhere: $fwhere";
+				if ($DEBUG)
+				{
+					echo "<br>DEBUG - last_mod_filter added to fwhere: $fwhere";
+				}
 			}
 
 			$filtermethod = '';
@@ -478,6 +455,7 @@
 				foreach(array(
 					'fn'       => 'cn',
 					'n_family' => 'sn',
+					'n_given'  => 'givenname',
 					'org_name' => 'o'
 				) as $f => $x)
 				{
@@ -506,14 +484,23 @@
 						{
 							switch($this->db->Type)
 							{
+								case 'sapdb': case 'maxdb':
+									$queryKey = false;	// sapdb cant use LIKE on text/LONG columns
+									break;
 								case 'mssql':
 									$queryKey = "CAST($queryKey AS varchar)";	// mssql cant use UPPER on text columns
 									break;
 							}
+							if (!$queryKey) continue;
 						}
 						$queryValue  = strtoupper($this->db->db_addslashes($queryValue));
-						$sql .= " UPPER($queryKey) LIKE '$queryValue' AND ";
-						$sqlcount .= " UPPER($queryKey) LIKE '$queryValue' AND ";
+						if(empty($queryValue)) {
+							$sql .= " ($queryKey IS NULL OR $queryKey = '') AND ";
+							$sqlcount .= " ($queryKey IS NULL OR $queryKey = '') AND ";
+						} else {
+							$sql .= " UPPER($queryKey) LIKE '$queryValue' AND ";
+							$sqlcount .= " UPPER($queryKey) LIKE '$queryValue' AND ";
+						}
 					}
 					$sql = substr($sql,0,-5) . ') ' . $fand . $filtermethod . $ordermethod;
 					$sqlcount = substr($sqlcount,0,-5) . ') ' . $fand . $filtermethod;
@@ -524,7 +511,7 @@
 					$query = strtoupper($this->db->db_addslashes($query));
 
 					$sql = "SELECT * FROM $this->std_table WHERE (";
-					$sqlcount = "SELECT COUNT(id) FROM $this->std_table WHERE (";
+					$sqlcount = "SELECT COUNT(*) FROM $this->std_table WHERE (";
 					foreach($this->stock_contact_fields as $f => $x)
 					{
 						// special handling of text columns for certain db's;
@@ -532,10 +519,14 @@
 						{
 							switch($this->db->Type)
 							{
+								case 'sapdb': case 'maxdb':
+									$f = false;	// sapdb cant use LIKE on text/LONG columns
+									break;
 								case 'mssql':
 									$f = "CAST($f AS varchar)";	// mssql cant use UPPER on text columns
 									break;
 							}
+							if (!$f) continue;
 						}
 						$sql .= " UPPER($f) LIKE '%$query%' OR ";
 						$sqlcount .= " UPPER($f) LIKE '%$query%' OR ";
@@ -549,8 +540,7 @@
 			{
 				$sql = "SELECT id,lid,tid,owner,access,cat_id,last_mod $t_fields FROM $this->std_table " . $fwhere
 					. $filtermethod . ' ' . $ordermethod;
-				$sqlcount = "SELECT COUNT(id) FROM $this->std_table " . $fwhere
-					. $filtermethod;
+				$sqlcount = "SELECT COUNT(*) FROM $this->std_table " . $fwhere . $filtermethod;
 			}
 			if($DEBUG)
 			{
@@ -567,25 +557,10 @@
 			unset($sqlcount);
 			$this->total_records = $this->db->f(0);
 
-			if($start && $limit)
-			{
-				if($this->total_records <= $limit)
-				{
-					$this->db->query($sql,__LINE__,__FILE__);
-				}
-				else
-				{
-					$this->db->limit_query($sql,$start,__LINE__,__FILE__,$limit);
-				}
-			}
-			elseif(!$limit)
-			{
-				$this->db->query($sql,__LINE__,__FILE__);
-			}
-			else
-			{
-				$this->db->limit_query($sql,$start,__LINE__,__FILE__);
-			}
+			//echo "<p align=right>search() start=$start, limit=$limit, total=$this->total_records</p>\n";
+			if ($this->total_records < $start) $start = 0;
+
+			$this->db->query($sql,__LINE__,__FILE__,$start,$limit);
 
 			$i = 0;
 			while($this->db->next_record())
@@ -596,7 +571,7 @@
 				$return_fields[$i]['owner']    = $this->db->f('owner');
 				$return_fields[$i]['access']   = $this->db->f('access');
 				$return_fields[$i]['cat_id']   = $this->db->f('cat_id');
-				$return_fields[$i]['last_mod'] = $this->db->f('last_mod');
+				$return_fields[$i]['last_mod'] = $this->db->f('last_mod')+$this->tz_offset_s;
 				$return_fields[$i]['rights']   = (int)$this->grants[$this->db->f('owner')];
 
 				if(@is_array($stock_fieldnames))
@@ -607,8 +582,7 @@
 					}
 					reset($stock_fieldnames);
 				}
-				$db2->query("SELECT contact_name,contact_value FROM $this->ext_table WHERE contact_id="
-					. (int)$this->db->f('id') . $filterextra,__LINE__,__FILE__);
+				$db2->select($this->ext_table,'contact_name,contact_value',array('contact_id'=>$this->db->f('id')),__LINE__,__FILE__);
 				while($db2->next_record())
 				{
 					if($extra_fields[$db2->f('contact_name')])
@@ -624,7 +598,6 @@
 		function add($owner,$fields,$access=NULL,$cat_id=NULL,$tid=NULL)
 		{
 			$owner = (int)$owner;
-			$lid   = array();
 			// access, cat_id and tid can be in $fields now or as extra params
 			foreach(array('access','cat_id','tid') as $extra)
 			{
@@ -637,33 +610,41 @@
 			{
 				$fields['tid'] = 'n';
 			}
-			if(isset($fields['lid']))
+			// setting the telephone numbers to empty if unset, as otherwise the db-default adds '+1 (000) 000-0000' 
+			// I dont want to change the default in the stable release
+			foreach($this->stock_contact_fields as $name)
 			{
-				//fix by pim
-				//$lid = array('lid,' => $fields['lid']."','");
-				$lid = array('lid,', $fields['lid'] . "','");
+				if (substr($name,0,4) == 'tel_' && !isset($fields[$name])) $fields[$name] = '';
 			}
 			list($stock_fields,$stock_fieldnames,$extra_fields) = $this->split_stock_and_extras($fields);
 
 			//this is added here so it is never tainted
 			$this->stock_contact_fields['last_mod'] = 'last_mod';
-			$stock_fields['last_mod'] = $GLOBALS['phpgw']->datetime->gmtnow;
+			$stock_fields['last_mod'] = time();
 
-			$sql = 'INSERT INTO ' . $this->std_table . " (owner,access,cat_id,tid," . $lid[0]
-				. implode(',',$this->stock_contact_fields)
-				. ') VALUES (' . $owner . ",'" . $fields['access'] . "','" . $fields['cat_id']
-				. "','" . $fields['tid'] . "','" . $lid[1]
-				. implode("','",$this->loop_addslashes($stock_fields)) . "')";
-			$this->db->query($sql,__LINE__,__FILE__);
+			$data = array(
+				'owner'		=> $owner,
+				'access'	=> $fields['access'],
+				'cat_id'	=> $fields['cat_id'],
+				'tid'		=> $fields['tid'],
+			);
+			if (isset($fields['lid'])) $data['lid'] = $fields['lid'];
+			
+
+			$this->db->insert($this->std_table,array_merge($data,$stock_fields),False,__LINE__,__FILE__);
 
 			$id = $this->db->get_last_insert_id($this->std_table, 'id');
 
-			if(count($extra_fields))
+			if($id && count($extra_fields))
 			{
 				foreach($extra_fields as $name => $value)
 				{
-					$this->db->query("INSERT INTO $this->ext_table VALUES (" . (int)$id . ",'" . $owner . "','"
-						. $this->db->db_addslashes($name) . "','" . $this->db->db_addslashes($value) . "')",__LINE__,__FILE__);
+					$this->db->insert($this->ext_table,array(
+							'contact_id'	=> $id,
+							'contact_owner'	=> $owner,
+							'contact_name'	=> $name,
+							'contact_value'	=> $value,
+						),False,__LINE__,__FILE__);
 				}
 			}
 			return ($id ? $id : False);
@@ -671,30 +652,36 @@
 
 		function field_exists($id,$field_name)
 		{
-			$this->db->query("SELECT COUNT(*) FROM $this->ext_table WHERE contact_id=" . (int)$id . " AND contact_name='"
-				. $this->db->db_addslashes($field_name) . "'",__LINE__,__FILE__);
+			$this->db->select($this->ext_table,'COUNT(*)',array(
+					'contact_id'	=> $id,
+					'contact_name'	=> $field_name,
+				),__LINE__,__FILE__);
 			$this->db->next_record();
 			return $this->db->f(0);
 		}
 
 		function add_single_extra_field($id,$owner,$field_name,$field_value)
 		{
-			$this->db->query("INSERT INTO $this->ext_table VALUES (" . (int)$id . ",'".(int)$owner."','" . $this->db->db_addslashes($field_name)
-				. "','" . $this->db->db_addslashes($field_value) . "')",__LINE__,__FILE__);
+			$this->db->insert($this->ext_table,array(
+					'contact_id'	=> $id,
+					'contact_owner'	=> $owner,
+					'contact_name'	=> $field_name,
+					'contact_value'	=> $field_value,
+				),False,__LINE__,__FILE__);
 		}
 
 		function delete_single_extra_field($id,$field_name)
 		{
-			$this->db->query("DELETE FROM $this->ext_table WHERE contact_id=" . (int)$id . " AND contact_name='"
-				. $this->db->db_addslashes($field_name) . "'",__LINE__,__FILE__);
+			$this->db->delete($this->ext_table,array(
+					'contact_id'	=> $id,
+					'contact_name'	=> $field_name,
+				),__LINE__,__FILE__);
 		}
 
 		function update($id,$owner,$fields,$access=NULL,$cat_id=NULL,$tid=NULL)
 		{
-			$owner = (int)$owner;
-			$id    = (int)$id;
 			/* First make sure that id number exists */
-			$this->db->query("SELECT COUNT(*) FROM $this->std_table WHERE id=$id",__LINE__,__FILE__);
+			$this->db->select($this->std_table,'COUNT(*)',array('id'=>$id),__LINE__,__FILE__);
 			$this->db->next_record();
 			if (!$this->db->f(0))
 			{
@@ -703,7 +690,7 @@
 
 			list($stock_fields,,$extra_fields) = $this->split_stock_and_extras($fields);
 			// access, cat_id and tid can be in $fields now or as extra params
-			foreach(array('access','cat_id','tid') as $extra)
+			foreach(array('access','cat_id','tid','owner') as $extra)
 			{
 				if (!is_null($$extra))
 				{
@@ -717,18 +704,8 @@
 
 			if (count($stock_fields))
 			{
-				foreach($stock_fields as $name => $value)
-				{
-					$ta[] = $name . "='" . $this->db->db_addslashes($value) . "'";
-				}
-				$ta[] = 'last_mod=' . $GLOBALS['phpgw']->datetime->gmtnow;
-				$fields_s = implode(',',$ta);
-				if ($field_s == ',')
-				{
-					unset($field_s);
-				}
-				$this->db->query($sql="UPDATE $this->std_table SET $fields_s WHERE "
-					. "id=$id",__LINE__,__FILE__);
+				$stock_fields['last_mod'] = time();
+				$this->db->update($this->std_table,$stock_fields,array('id'=>$id),__LINE__,__FILE__);
 			}
 			if (is_array($extra_fields))
 			{
@@ -742,9 +719,13 @@
 						}
 						else
 						{
-							$this->db->query("UPDATE $this->ext_table SET contact_value='" . $this->db->db_addslashes($x_value)
-								. "',contact_owner=$owner WHERE contact_name='" . $this->db->db_addslashes($x_name)
-								. "' AND contact_id=$id",__LINE__,__FILE__);
+							$this->db->update($this->ext_table,array(
+									'contact_value'	=> $x_value,
+									'contact_owner'	=> $owner,
+								),array(
+									'contact_name'	=> $x_name,
+									'contact_id'	=> $id,
+								),__LINE__,__FILE__);
 						}
 					}
 					elseif($x_value)	// dont write emtpy extra-fields
@@ -759,31 +740,28 @@
 		/* Used by admin to change ownership on account delete */
 		function change_owner($old_owner,$new_owner)
 		{
-			$old_owner = (int) $old_owner;
-			$new_owner = (int) $new_owner;
-			if (!$new_owner || !$old_owner)
+			if (!(int)$new_owner || !(int)$old_owner)
 			{
 				return False;
 			}
-			$this->db->query("UPDATE $this->std_table SET owner='$new_owner' WHERE owner=$old_owner",__LINE__,__FILE__);
-			$this->db->query("UPDATE $this->ext_table SET contact_owner='$new_owner' WHERE contact_owner=$old_owner",__LINE__,__FILE__);
+			$this->db->update($this->std_table,array('owner'=>$new_owner),array('owner'=>$old_owner),__LINE__,__FILE__);
+			$this->db->update($this->ext_table,array('contact_owner'=>$new_owner),array('contact_owner'=>$old_owner),__LINE__,__FILE__);
 		}
 
 		/* This is where the real work of delete() is done, shared class file contains calling function */
 		function delete_($id)
 		{
-			$this->db->query("DELETE FROM $this->std_table WHERE id=" . (int)$id,__LINE__,__FILE__);
-			$this->db->query("DELETE FROM $this->ext_table WHERE contact_id=" . (int)$id,__LINE__,__FILE__);
+			$this->db->delete($this->std_table,array('id'=>$id),__LINE__,__FILE__);
+			$this->db->delete($this->ext_table,array('contact_id'=>$id),__LINE__,__FILE__);
 		}
 
 		/* This is for the admin script deleteaccount.php */
 		function delete_all($owner=0)
 		{
-			$owner = (int) $owner;
 			if ($owner)
 			{
-				$this->db->query("DELETE FROM $this->std_table WHERE owner=$owner",__LINE__,__FILE__);
-				$this->db->query("DELETE FROM $this->ext_table WHERE contact_owner=$owner",__LINE__,__FILE__);
+				$this->db->delete($this->std_table,array('owner'=>$owner),__LINE__,__FILE__);
+				$this->db->delete($this->ext_table,array('contact_owner'=>$owner),__LINE__,__FILE__);
 			}
 		}
 	}
