@@ -21,13 +21,13 @@
   * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
   \**************************************************************************/
 
-  /* $Id: class.interserver.inc.php,v 1.29 2004/05/05 12:03:19 reinerj Exp $ */
+  /* $Id: class.interserver.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	class interserver
 	{
 		var $db;
 		var $accounts;
-		var $table = 'phpgw_interserv';
+		var $table = 'egw_interserv';
 		var $total = 0;
 		var $result = '';
 
@@ -81,13 +81,13 @@
 
 		function interserver($serverid='')
 		{
-			$url = eregi_replace('https*://[^/]*/','',$GLOBALS['phpgw_info']['server']['webserver_url']);
+			$url = eregi_replace('https*://[^/]*/','',$GLOBALS['egw_info']['server']['webserver_url']);
 			$this->urlparts = array(
 				'xmlrpc' => $url.'/xmlrpc.php',
 				'soap'   => $url.'/soap.php'
 			);
 
-			$this->db = $GLOBALS['phpgw']->db;
+			$this->db = clone($GLOBALS['egw']->db);
 			if($serverid)
 			{
 				$this->serverid = (int)$serverid;
@@ -117,7 +117,7 @@
 			$this->read_repository();
 			if($this->server['trust_level'])
 			{
-				$this->accounts = CreateObject('phpgwapi.accounts');
+				$this->accounts =& CreateObject('phpgwapi.accounts');
 				$this->accounts->server = $this->serverid;
 			}
 			$this->security = $this->server['server_security'];
@@ -125,7 +125,7 @@
 		}
 
 		/* send command to remote server */
-		function send($method_name, $args, $url, $debug=True)
+		function send($method_name, $args, $url, $debug=False)
 		{
 			$cmd = '_send_' . ($this->mode ? $this->mode : 'xmlrpc') . '_' . $this->security;
 			$this->$cmd($method_name, $args, $url, $debug);
@@ -169,11 +169,11 @@
 			}
 			else
 			{
-				while(list($key,$val) = @each($args))
+				foreach($args as $key => $val)
 				{
 					if(@is_array($val))
 					{
-						while(list($x,$y) = each($val))
+						foreach($val as $x => $y)
 						{
 							$tmp[$x] = CreateObject('phpgwapi.xmlrpcval',$y, 'string');
 						}
@@ -188,10 +188,10 @@
 				$f = CreateObject('phpgwapi.xmlrpcmsg', $method_name, $arr,'struct');
 			}
 
-			$this->debug("<pre>" . htmlentities($f->serialize()) . "</pre>\n",$debug);
+			$this->debug('<pre>' . htmlentities($f->serialize()) . "</pre>\n",$debug);
 			$c = CreateObject('phpgwapi.xmlrpc_client',$uri, $hostpart, 443);
 			$c->setCredentials($this->sessionid,$this->kp3);
-			$c->setDebug(0);
+			$c->setDebug($debug);
 			$r = $c->send($f,0,'https');
 			if (!$r)
 			{
@@ -221,11 +221,11 @@
 			}
 			else
 			{
-				while(list($key,$val) = @each($args))
+				foreach($args as $key => $val)
 				{
 					if(@is_array($val))
 					{
-						while(list($x,$y) = each($val))
+						foreach($val as $x => $y)
 						{
 							$tmp[$x] = CreateObject('phpgwapi.xmlrpcval',$y, 'string');
 						}
@@ -244,7 +244,7 @@
 			$c = CreateObject('phpgwapi.xmlrpc_client',$uri, $hostpart, 80);
 			$c->setCredentials($this->sessionid,$this->kp3);
 //			_debug_array($c);
-			$c->setDebug(0);
+			$c->setDebug($debug);
 			$r = $c->send($f);
 			if (!$r)
 			{
@@ -274,11 +274,11 @@
 			}
 			else
 			{
-				while(list($key,$val) = @each($args))
+				foreach($args as $key => $val)
 				{
 					if(@is_array($val))
 					{
-						while(list($x,$y) = each($val))
+						foreach($val as $x => $y)
 						{
 							$tmp[] = CreateObject('phpgwapi.soapval',$x,'string',$y);
 						}
@@ -320,11 +320,11 @@
 			}
 			elseif(@is_array($args))
 			{
-				while(list($key,$val) = @each($args))
+				foreach($args as $key => $val)
 				{
 					if(@is_array($val))
 					{
-						while(list($x,$y) = each($val))
+						foreach($val as $x => $y)
 						{
 							$tmp[] = CreateObject('phpgwapi.soapval',$x,'string',$y);
 						}
@@ -368,8 +368,7 @@
 			if(@is_array($_req))
 			{
 				$ele = array();
-				@reset($_req);
-				while(list($key,$val) = @each($_req))
+				foreach($_req as $key => $val)
 				{
 					$ele[$key] = $this->build_request($val,True,$key);
 				}
@@ -543,7 +542,7 @@
 
 			$x = '';
 			$slist = $this->get_list('','','','','',$x);
-			while (list($key,$val) = each($slist))
+			foreach($slist as $key => $val)
 			{
 				$foundservers = True;
 				$select .= '<option value="' . $val['server_id'] . '"';
@@ -642,8 +641,8 @@
 			$this->db->query($sql,__LINE__,__FILE__);
 			if($this->db->next_record())
 			{
-				if ($username == $GLOBALS['phpgw_info']['server']['site_username'] &&
-					$password == $GLOBALS['phpgw_info']['server']['site_password'] &&
+				if ($username == $GLOBALS['egw_info']['server']['site_username'] &&
+					$password == $GLOBALS['egw_info']['server']['site_password'] &&
 					$this->db->f('trust_rel') >= 1)
 				{
 					$this->authed = True;
