@@ -10,7 +10,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.jscalendar.inc.php,v 1.10.4.2 2005/02/09 10:34:03 ralfbecker Exp $ */
+  /* $Id: class.jscalendar.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	/*!
 	@class jscalendar
@@ -29,15 +29,15 @@
 		*/
 		function jscalendar($do_header=True,$path='jscalendar')
 		{
-			$this->jscalendar_url = $GLOBALS['phpgw_info']['server']['webserver_url'].'/phpgwapi/js/'.$path;
-			$this->dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
+			$this->jscalendar_url = $GLOBALS['egw_info']['server']['webserver_url'].'/phpgwapi/js/'.$path;
+			$this->dateformat = $GLOBALS['egw_info']['user']['preferences']['common']['dateformat'];
 
-			if ($do_header && !strstr($GLOBALS['phpgw_info']['flags']['java_script'],'jscalendar'))
+			if ($do_header && !strstr($GLOBALS['egw_info']['flags']['java_script'],'jscalendar'))
 			{
-				$GLOBALS['phpgw_info']['flags']['java_script'] .=
-'<link rel="stylesheet" type="text/css" media="all" href="'.$this->jscalendar_url.'/calendar-win2k-cold-1.css" title="win2k-cold-1" />
+				$GLOBALS['egw_info']['flags']['java_script'] .=
+'<link rel="stylesheet" type="text/css" media="all" href="'.$this->jscalendar_url.'/calendar-blue.css" title="blue" />
 <script type="text/javascript" src="'.$this->jscalendar_url.'/calendar.js"></script>
-<script type="text/javascript" src="'.ereg_replace('[?&]*click_history=[0-9a-f]*','',$GLOBALS['phpgw']->link('/phpgwapi/inc/jscalendar-setup.php')).'"></script>
+<script type="text/javascript" src="'.ereg_replace('[?&]*click_history=[0-9a-f]*','',$GLOBALS['egw']->link('/phpgwapi/inc/jscalendar-setup.php')).'"></script>
 ';
 			}
 		}
@@ -53,7 +53,7 @@
 		@param $helpmsg a helpmessage for the statusline of the browser
 		@param $options any other options to the inputfield
 		*/
-		function input($name,$date,$year=0,$month=0,$day=0,$helpmsg='',$options='')
+		function input($name,$date,$year=0,$month=0,$day=0,$helpmsg='',$options='',$jsreturn=false)
 		{
 			//echo "<p>jscalendar::input(name='$name', date='$date'='".date('Y-m-d',$date)."', year='$year', month='$month', day='$day')</p>\n";
 
@@ -81,10 +81,20 @@
 				$options .= " onFocus=\"self.status='".addslashes($helpmsg)."'; return true;\"" .
 				" onBlur=\"self.status=''; return true;\"";
 			}
+
+			if ($jsreturn)
+			{
+				$return_array = array(
+					'html' => '<input type="text" id="'.$name.'" name="'.$name.'" size="10" value="'.$date.'"'.$options.'/><img id="'.$name.'-trigger" src="'.$GLOBALS['egw']->common->find_image('phpgwpai','datepopup').'" title="'.lang('Select date').'" style="cursor:pointer; cursor:hand;"/>',
+					'js'   => 'Calendar.setup({inputField : "'.$name.'",button: "'.$name.'-trigger"	});'
+					);
+
+				return $return_array;
+			}
 			return
 '<input type="text" id="'.$name.'" name="'.$name.'" size="10" value="'.$date.'"'.$options.'/>
 <script type="text/javascript">
-	document.writeln(\'<img id="'.$name.'-trigger" src="'.$GLOBALS['phpgw']->common->find_image('phpgwpai','datepopup').'" title="'.lang('Select date').'" style="cursor:pointer; cursor:hand;"/>\');
+	document.writeln(\'<img id="'.$name.'-trigger" src="'.$GLOBALS['egw']->common->find_image('phpgwpai','datepopup').'" title="'.lang('Select date').'" style="cursor:pointer; cursor:hand;"/>\');
 	Calendar.setup(
 	{
 		inputField  : "'.$name.'",
