@@ -19,7 +19,7 @@
   *  the License, or (at your option) any later version.               *
   \********************************************************************/
 
-  /* $Id: class.mime_magic.inc.php,v 1.6 2004/05/05 12:03:19 reinerj Exp $ */
+  /* $Id: class.mime_magic.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	class mime_magic
 	{
@@ -28,12 +28,12 @@
 
 		//map of file contents to mime type
 		var $mime_magic_file;
-		
+
 		/**
-		* Wrapper to PHP5 Compatiable Constructor
+		* Wrapper to PHP5 Compatible Constructor
 		*
 		* @author skwashd
-		
+
 		function mime_magic()
 		{
 			$this->__constructor()
@@ -198,14 +198,14 @@
 		*/
 		function analyze_data($data)
 		{
-			if(!is_writeable(@$GLOBALS['phpgw_info']['server']['temp_dir']))
+			if(!is_writeable(@$GLOBALS['egw_info']['server']['temp_dir']))
 			{
 				//nothing we can do but bail out
 				return false;
 			}
 
 			mt_srand(time());
-			$filename = $GLOBALS['phpgw_info']['server']['temp_dir'] . SEP
+			$filename = $GLOBALS['egw_info']['server']['temp_dir'] . SEP
 				. md5( time() + mt_rand() ) . '.tmp';
 
 			$fp = @fopen($filename, 'ab');
