@@ -18,7 +18,7 @@
   * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
   \**************************************************************************/
 
-  /* $Id: class.xmlrpc_server.inc.php,v 1.34.4.6 2005/08/19 12:33:21 milosch Exp $ */
+  /* $Id: class.xmlrpc_server.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	// contains useful functions for xmlrpc methods
 	class xmlrpc_server_shared
@@ -77,16 +77,16 @@
 		// translate cat-ids to array with id-name pairs
 		function cats2xmlrpc($cats)
 		{
-			if (!is_object($GLOBALS['phpgw']->categories))
+			if (!is_object($GLOBALS['egw']->categories))
 			{
-				$GLOBALS['phpgw']->categories = CreateObject('phpgwapi.categories');
+				$GLOBALS['egw']->categories = CreateObject('phpgwapi.categories');
 			}
 			$xcats = array();
 			foreach($cats as $cat)
 			{
 				if ($cat)
 				{
-					$xcats[$cat] = stripslashes($GLOBALS['phpgw']->categories->id2name($cat));
+					$xcats[$cat] = stripslashes($GLOBALS['egw']->categories->id2name($cat));
 				}
 			}
 			return $xcats;
@@ -99,29 +99,29 @@
 			{
 				$xcats = array();
 			}
-			elseif (!is_object($GLOBALS['phpgw']->categories))
+			elseif (!is_object($GLOBALS['egw']->categories))
 			{
-				$GLOBALS['phpgw']->categories = CreateObject('phpgwapi.categories');
+				$GLOBALS['egw']->categories = CreateObject('phpgwapi.categories');
 			}
 			$cats = array();
 			foreach($xcats as $cat => $name)
 			{
-				if ($id = $GLOBALS['phpgw']->categories->name2id($name))
+				if ($id = $GLOBALS['egw']->categories->name2id($name))
 				{
 					// existing cat-name use the id
 					$cat = $id;
 				}
-				elseif (!($org_name = stripslashes($GLOBALS['phpgw']->categories->id2name($cat))) || $org_name == '--')
+				elseif (!($org_name = stripslashes($GLOBALS['egw']->categories->id2name($cat))) || $org_name == '--')
 				{
 					// new cat
-					$cat = $GLOBALS['phpgw']->categories->add(array('name' => $name,'parent' => 0));
+					$cat = $GLOBALS['egw']->categories->add(array('name' => $name,'parent' => 0));
 				}
 				elseif ($org_name != $name)
 				{
 					// cat-name edited
-					list($cat_vals) =$GLOBALS['phpgw']->categories->return_single($cat);
+					list($cat_vals) =$GLOBALS['egw']->categories->return_single($cat);
 					$cat_vals['name'] = $name;
-					$GLOBALS['phpgw']->categories->edit($cat_vals);
+					$GLOBALS['egw']->categories->edit($cat_vals);
 				}
 				$cats[] = (int)$cat;
 			}
@@ -140,15 +140,15 @@
 				list($app) = explode('.',$this->last_method);
 			}
 
-			if (!is_object($GLOBALS['phpgw']->categories))
+			if (!is_object($GLOBALS['egw']->categories))
 			{
-				$GLOBALS['phpgw']->categories = CreateObject('phpgwapi.categories');
+				$GLOBALS['egw']->categories = CreateObject('phpgwapi.categories');
 			}
-			if ($GLOBALS['phpgw']->categories->app_name != $app)
+			if ($GLOBALS['egw']->categories->app_name != $app)
 			{
-				$GLOBALS['phpgw']->categories->categories('',$app);
+				$GLOBALS['egw']->categories->categories('',$app);
 			}
-			$cats_arr = $GLOBALS['phpgw']->categories->return_sorted_array(0,False,'','','',True);
+			$cats_arr = $GLOBALS['egw']->categories->return_sorted_array(0,False,'','','',True);
 			$cats = array();
 			if (is_array($cats_arr))
 			{
@@ -170,8 +170,8 @@
 		}
 	}
 
-	if(empty($GLOBALS['phpgw_info']['server']['xmlrpc_type']))
+	if(empty($GLOBALS['egw_info']['server']['xmlrpc_type']))
 	{
-		$GLOBALS['phpgw_info']['server']['xmlrpc_type'] = 'php';
+		$GLOBALS['egw_info']['server']['xmlrpc_type'] = 'php';
 	}
-	include_once(PHPGW_API_INC.SEP.'class.xmlrpc_server_' . $GLOBALS['phpgw_info']['server']['xmlrpc_type'] . '.inc.php');
+	include_once(EGW_API_INC.SEP.'class.xmlrpc_server_' . $GLOBALS['egw_info']['server']['xmlrpc_type'] . '.inc.php');
