@@ -17,7 +17,7 @@
   * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
   \**************************************************************************/
 
-  /* $Id: class.xmlrpc_server_epi.inc.php,v 1.4.4.4 2005/08/19 12:33:21 milosch Exp $ */
+  /* $Id: class.xmlrpc_server_epi.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	class xmlrpc_server extends xmlrpc_server_shared
 	{
@@ -69,7 +69,7 @@
 			{
 				$fp = fopen($this->log,'a+');
 				fwrite($fp,"\n\n" . date('Y-m-d H:i:s') . " authorized="
-					. ($this->authed ? $GLOBALS['phpgw_info']['user']['account_lid'] : 'False')
+					. ($this->authed ? $GLOBALS['egw_info']['user']['account_lid'] : 'False')
 					. ", method='$this->last_method'\n");
 				fwrite($fp,"==== GOT ============================\n" . $GLOBALS['HTTP_RAW_POST_DATA']
 					. "\n==== RETURNED =======================\n");
@@ -202,7 +202,7 @@
 						case 'server':
 						case 'phpgwapi':
 							/* Server role functions only - api access */
-							if($GLOBALS['phpgw']->acl->get_role() >= PHPGW_ACL_SERVER)
+							if($GLOBALS['egw']->acl->get_role() >= EGW_ACL_SERVER)
 							{
 								$dmap = ExecMethod(sprintf('%s.%s.%s','phpgwapi',$class,'list_methods'),'xmlrpc');
 							}
@@ -214,7 +214,7 @@
 							break;
 						default:
 							/* User-level application access */
-							if($GLOBALS['phpgw']->acl->check('run',PHPGW_ACL_READ,$app))
+							if($GLOBALS['egw']->acl->check('run',EGW_ACL_READ,$app))
 							{
 								$dmap = ExecMethod(sprintf('',$app,$class,'list_methods'),'xmlrpc');
 							}
