@@ -35,7 +35,7 @@
    * Incorporated for egroupware by Miles Lott <milos@groupwhere.org>         
    */
 
-  /* $Id: class.xmlrpc_server_php.inc.php,v 1.4.4.6 2005/09/20 10:13:09 ralfbecker Exp $ */
+  /* $Id: class.xmlrpc_server_php.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	/* BEGIN server class */
 	class xmlrpc_server extends xmlrpc_server_shared
@@ -93,15 +93,16 @@
 			else
 			{
 				$payload = "<?xml version=\"1.0\"?>\n" . $this->serializeDebug() . $r->serialize();
-				Header("Content-type: text/xml\r\nContent-length: " . strlen($payload));
-				echo $GLOBALS['phpgw']->translation->convert($payload,$GLOBALS['phpgw']->translation->charset(),'utf-8');
+				header("Content-type: text/xml");
+				header("Content-length: " . strlen($payload));
+				echo $GLOBALS['egw']->translation->convert($payload,$GLOBALS['egw']->translation->charset(),'utf-8');
 			}
 
 			if ($this->log)
 			{
 				$fp = fopen($this->log,'a+');
 				fwrite($fp,"\n\n".date('Y-m-d H:i:s') . " authorized="
-					. ($this->authed?$GLOBALS['phpgw_info']['user']['account_lid']:'False')
+					. ($this->authed?$GLOBALS['egw_info']['user']['account_lid']:'False')
 					. ", method='$this->last_method'\n");
 				fwrite($fp,"==== GOT ============================\n" . $GLOBALS['HTTP_RAW_POST_DATA']
 					. "\n==== RETURNED =======================\n");
@@ -349,7 +350,7 @@
 							$t = 'phpgwapi.' . $class . '.exec';
 							$dmap = ExecMethod($t,array($service,'list_methods','xmlrpc'));
 						}
-						elseif($GLOBALS['phpgw']->acl->check('run',1,$class))
+						elseif($GLOBALS['egw']->acl->check('run',1,$class))
 						{
 							/* This only happens if they have app access.  If not, we will
 							 * return a fault below.
@@ -416,7 +417,7 @@
 								// _debug_array($params);
 								$this->reqtoarray($params);
 								// decode from utf-8 to our charset
-								$this->req_array = $GLOBALS['phpgw']->translation->convert($this->req_array,'utf-8');
+								$this->req_array = $GLOBALS['egw']->translation->convert($this->req_array,'utf-8');
 								//_debug_array($this->req_array);
 								if (ereg('^service',$method))
 								{
