@@ -1,13 +1,12 @@
 <?php
 	 /**************************************************************************\
-	 * eGroupWare API - phpgwapi loader                                         *
-	 * This file written by Dan Kuykendall <seek3r@phpgroupware.org>            *
+	 * eGroupWare API - commonly used functions included by eGW AND setup       *
+	 * The file was originaly written by Dan Kuykendall <seek3r@phpgroupware.org> *
 	 * and Joseph Engo <jengo@phpgroupware.org>                                 *
-	 * Has a few functions, but primary role is to load the phpgwapi            *
 	 * Copyright (C) 2000, 2001 Dan Kuykendall                                  *
 	 * -------------------------------------------------------------------------*
 	 * This library is part of the eGroupWare API                               *
-	 * http://www.egroupware.org/api                                            * 
+	 * http://www.egroupware.org                                                *
 	 * ------------------------------------------------------------------------ *
 	 * This library is free software; you can redistribute it and/or modify it  *
 	 * under the terms of the GNU Lesser General Public License as published by *
@@ -22,24 +21,18 @@
 	 * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	 \**************************************************************************/
 
-	/* $Id: common_functions.inc.php,v 1.41.4.8 2005/03/15 15:41:31 ralfbecker Exp $ */
+	/* $Id: common_functions.inc.php 20526 2006-03-09 22:34:42Z ralfbecker $ */
 
 	/****************************************************************************\
 	 * Direct functions which are not part of the API classes                    *
 	 * because they are required to be available at the lowest level.            *
 	 \***************************************************************************/
-	/*!
-	 @collection_start direct functions
-	 @abstract Direct functions which are not part of the API classes because they are required to be available at the lowest level.
-	*/
 
-	/*!
-	 @function print_debug_subarray
-	 @abstract Not to be used directly. Should only be used by print_debug()
-	*/
+	/**
+	 * @internal Not to be used directly. Should only be used by print_debug()
+	 */
 	function print_debug_subarray($array)
 	{
-//		while(list($key, $value) = each($array))
 		foreach($array as $key => $value)
 		{
 			if (is_array($value))
@@ -54,17 +47,15 @@
 		return $vartypes;
 	}
 
-	/*!
-	 @function print_debug
-	 @abstract print debug data only when debugging mode is turned on.
-	 @author seek3r
-	 @discussion This function is used to debugging data. 
-	 @syntax print_debug('message', $somevar);
-	 @example print_debug('this is some debugging data',$somevar);
-	*/
+	/**
+	 * print debug data only when debugging mode is turned on.
+	 *
+	 * @author seek3r
+	 * This function is used to debugging data. 
+	 * print_debug('this is some debugging data',$somevar);
+	 */
 	function print_debug($message,$var = 'messageonly',$part = 'app', $level = 3)
 	{
-//		if (($part == 'app' && EXP_DEBUG_APP == True) || ($part == 'api' && DEBUG_API == True))
 		if (($part == 'app' && DEBUG_APP == True) || ($part == 'api' && DEBUG_API == True))
 		{
 			if (!defined('DEBUG_OUTPUT'))
@@ -107,7 +98,7 @@
 					/*
 					if (!!(DEBUG_OUTPUT & 32))
 					{
-						$obj_debug = new COM('Some_COM_App.Class','localhost');
+						$obj_debug =& new COM('Some_COM_App.Class','localhost');
 						if (is_object($obj_debug))
 						{
 							$DebugMessage_return = $obj_debug->DebugMessage($output);
@@ -157,13 +148,12 @@
 		}
 	}
 
-	/*!
-	 @function safe_args
-	 @abstract Allows for array and direct function params as well as sanatization.
-	 @author seek3r
-	 @discussion This function is used to validate param data as well as offer flexible function usage.
-	 @syntax safe_args($expected_args, $recieved_args,__LINE__,__FILE__);
-	 @example 
+	/**
+	  * Allows for array and direct function params as well as sanatization.
+	  *
+	  * @author seek3r
+	  * This function is used to validate param data as well as offer flexible function usage.
+	  * 
 		function somefunc()
 		{
 			$expected_args[0] = Array('name'=>'fname','default'=>'joe', 'type'=>'string');
@@ -195,7 +185,7 @@
 		This would result in - Full name: jack hick brown<br>
 		Its using the default value for the second param.
 		Of course if you have the second param as a required field it will fail to work.
-	*/
+	 */
 	function safe_args($expected, $recieved, $line='??', $file='??')
 	{
 		/* This array will contain all the required fields */
@@ -277,19 +267,13 @@
 		return $args;
 	}
 
-	/*!
-	 @function sanitize
-	 @abstract Validate data.
-	 @author seek3r
-	 @discussion This function is used to validate input data. 
-	 @syntax sanitize('type', 'match string');
-	 @example sanitize('number',$somestring);
-	*/
-
-	/*
-	$GLOBALS['phpgw_info']['server']['sanitize_types']['number'] = Array('type' => 'preg_match', 'string' => '/^[0-9]+$/i');
-	*/
-
+	/**
+	 * Validate data.
+	 *
+	 * @author seek3r
+	 * This function is used to validate input data. 
+	 * sanitize('number',$somestring);
+	 */
 	function sanitize($string,$type)
 	{
 		switch ($type)
@@ -370,16 +354,16 @@
 				$password_numbers = Array('0','1','2','3','4','5','6','7','8','9');
 				$password_special_chars = Array(' ','~','`','!','@','#','$','%','^','&','*','(',')','_','+','-','=','{','}','|','[',']',"\\",':','"',';',"'",'<','>','?',',','.','/');
 
-				if(@isset($GLOBALS['phpgw_info']['server']['pass_min_length']) && is_int($GLOBALS['phpgw_info']['server']['pass_min_length']) && $GLOBALS['phpgw_info']['server']['pass_min_length'] > 1)
+				if(@isset($GLOBALS['egw_info']['server']['pass_min_length']) && is_int($GLOBALS['egw_info']['server']['pass_min_length']) && $GLOBALS['egw_info']['server']['pass_min_length'] > 1)
 				{
-					$min_length = $GLOBALS['phpgw_info']['server']['pass_min_length'];
+					$min_length = $GLOBALS['egw_info']['server']['pass_min_length'];
 				}
 				else
 				{
 					$min_length = 1;
 				}
 
-				if(@isset($GLOBALS['phpgw_info']['server']['pass_require_non_alpha']) && $GLOBALS['phpgw_info']['server']['pass_require_non_alpha'] == True)
+				if(@isset($GLOBALS['egw_info']['server']['pass_require_non_alpha']) && $GLOBALS['egw_info']['server']['pass_require_non_alpha'] == True)
 				{
 					$pass_verify_non_alpha = False;
 				}
@@ -388,7 +372,7 @@
 					$pass_verify_non_alpha = True;
 				}
 				
-				if(@isset($GLOBALS['phpgw_info']['server']['pass_require_numbers']) && $GLOBALS['phpgw_info']['server']['pass_require_numbers'] == True)
+				if(@isset($GLOBALS['egw_info']['server']['pass_require_numbers']) && $GLOBALS['egw_info']['server']['pass_require_numbers'] == True)
 				{
 					$pass_verify_num = False;
 				}
@@ -397,7 +381,7 @@
 					$pass_verify_num = True;
 				}
 
-				if(@isset($GLOBALS['phpgw_info']['server']['pass_require_special_char']) && $GLOBALS['phpgw_info']['server']['pass_require_special_char'] == True)
+				if(@isset($GLOBALS['egw_info']['server']['pass_require_special_char']) && $GLOBALS['egw_info']['server']['pass_require_special_char'] == True)
 				{
 					$pass_verify_special_char = False;
 				}
@@ -427,17 +411,17 @@
 
 					if ($pass_verify_num == False)
 					{
-						$GLOBALS['phpgw_info']['flags']['msgbox_data']['Password requires at least one non-alpha character']=False;
+						$GLOBALS['egw_info']['flags']['msgbox_data']['Password requires at least one non-alpha character']=False;
 					}
 
 					if ($pass_verify_num == False)
 					{
-						$GLOBALS['phpgw_info']['flags']['msgbox_data']['Password requires at least one numeric character']=False;
+						$GLOBALS['egw_info']['flags']['msgbox_data']['Password requires at least one numeric character']=False;
 					}
 
 					if ($pass_verify_special_char == False)
 					{
-						$GLOBALS['phpgw_info']['flags']['msgbox_data']['Password requires at least one special character (non-letter and non-number)']=False;
+						$GLOBALS['egw_info']['flags']['msgbox_data']['Password requires at least one special character (non-letter and non-number)']=False;
 					}
 					
 					if ($pass_verify_num == True && $pass_verify_special_char == True)
@@ -446,16 +430,16 @@
 					}
 					return False;
 				}
-				$GLOBALS['phpgw_info']['flags']['msgbox_data']['Password must be at least '.$min_length.' characters']=False;
+				$GLOBALS['egw_info']['flags']['msgbox_data']['Password must be at least '.$min_length.' characters']=False;
 				return False;
 				break;
 			case 'any':
 				return True;
 				break;
 			default :
-				if (isset($GLOBALS['phpgw_info']['server']['sanitize_types'][$type]['type']))
+				if (isset($GLOBALS['egw_info']['server']['sanitize_types'][$type]['type']))
 				{
-					if ($GLOBALS['phpgw_info']['server']['sanitize_types'][$type]['type']($GLOBALS['phpgw_info']['server']['sanitize_types'][$type]['string'], $string))
+					if ($GLOBALS['egw_info']['server']['sanitize_types'][$type]['type']($GLOBALS['egw_info']['server']['sanitize_types'][$type]['string'], $string))
 					{
 						return True;
 					}
@@ -640,22 +624,21 @@
 		}
 		if($register)
 		{
-			$GLOBALS['phpgw_info'][$GLOBALS['phpgw_info']['flags']['currentapp']][$varname] = $result;
+			$GLOBALS['egw_info'][$GLOBALS['egw_info']['flags']['currentapp']][$varname] = $result;
 		}
 		return $result;
 	}
 
-	/*!
-	 @function get_var
-	 @abstract retrieve a value from either a POST, GET, COOKIE, SERVER or from a class variable.
-	 @author skeeter
-	 @discussion This function is used to retrieve a value from a user defined order of methods. 
-	 @syntax get_var('id',array('HTTP_POST_VARS'||'POST','HTTP_GET_VARS'||'GET','HTTP_COOKIE_VARS'||'COOKIE','GLOBAL','DEFAULT'));
-	 @example $this->id = get_var('id',array('HTTP_POST_VARS'||'POST','HTTP_GET_VARS'||'GET','HTTP_COOKIE_VARS'||'COOKIE','GLOBAL','DEFAULT'));
-	 @param $variable name
-	 @param $method ordered array of methods to search for supplied variable
-	 @param $default_value (optional)
-	*/
+	/**
+	 * retrieve a value from either a POST, GET, COOKIE, SERVER or from a class variable.
+	 *
+	 * @author skeeter
+	 * This function is used to retrieve a value from a user defined order of methods. 
+	 * $this->id = get_var('id',array('HTTP_POST_VARS'||'POST','HTTP_GET_VARS'||'GET','HTTP_COOKIE_VARS'||'COOKIE','GLOBAL','DEFAULT'));
+	 * @param $variable name
+	 * @param $method ordered array of methods to search for supplied variable
+	 * @param $default_value (optional)
+	 */
 	function get_var($variable,$method='any',$default_value='')
 	{
 		if(!@is_array($method))
@@ -665,117 +648,102 @@
 		return reg_var($variable,$method,'any',$default_value,False);
 	}
 
-	/*!
-	 @function include_class
-	 @abstract This will include the class once and guarantee that it is loaded only once.  Similar to CreateObject, but does not instantiate the class.
-	 @author skeeter
-	 @discussion This will include the API class once and guarantee that it is loaded only once.  Similar to CreateObject, but does not instantiate the class.
-	 @syntax include_class('setup');
-	 @example include_class('setup');
-	 @param $included_class API class to load
-	*/
-	function include_class($included_class)
+	/**
+	 * Load a class and include the class file if not done so already.
+	 *
+	 * This function is used to create an instance of a class, and if the class file has not been included it will do so. 
+	 * $GLOBALS['egw']->acl =& CreateObject('phpgwapi.acl');
+	 *
+	 * @author RalfBecker@outdoor-training.de
+	 * @param $classname name of class
+	 * @param $p1,$p2,... class parameters (all optional)
+	 * @return object reference to an object
+	 */
+	function &CreateObject($class)
 	{
-		if (!isset($GLOBALS['phpgw_info']['flags']['included_classes'][$included_class]) ||
-			!$GLOBALS['phpgw_info']['flags']['included_classes'][$included_class])
+		list($appname,$classname) = explode('.',$class);
+
+		include_once($file=EGW_INCLUDE_ROOT.'/'.$appname.'/inc/class.'.$classname.'.inc.php');
+
+		if (class_exists($classname))
 		{
-			$GLOBALS['phpgw_info']['flags']['included_classes'][$included_class] = True;   
-			include(PHPGW_SERVER_ROOT.'/phpgwapi/inc/class.'.$included_class.'.inc.php');
-		}
-	}
-
-	/*!
-	 @function CreateObject
-	 @abstract Load a class and include the class file if not done so already.
-	 @author mdean
-	 @author milosch
-	 @author (thanks to jengo and ralf)
-	 @discussion This function is used to create an instance of a class, and if the class file has not been included it will do so. 
-	 @syntax CreateObject('app.class', 'constructor_params');
-	 @example $phpgw->acl = CreateObject('phpgwapi.acl');
-	 @param $classname name of class
-	 @param $p1-$p16 class parameters (all optional)
-	*/
-	function CreateObject($class,
-		$p1='_UNDEF_',$p2='_UNDEF_',$p3='_UNDEF_',$p4='_UNDEF_',
-		$p5='_UNDEF_',$p6='_UNDEF_',$p7='_UNDEF_',$p8='_UNDEF_',
-		$p9='_UNDEF_',$p10='_UNDEF_',$p11='_UNDEF_',$p12='_UNDEF_',
-		$p13='_UNDEF_',$p14='_UNDEF_',$p15='_UNDEF_',$p16='_UNDEF_')
-	{
-		global $phpgw_info, $phpgw;
-
-		/*
-		if(is_object(@$GLOBALS['phpgw']->log) && $class != 'phpgwapi.error' && $class != 'phpgwapi.errorlog')
-		{
-			$GLOBALS['phpgw']->log->write(array('text'=>'D-Debug, dbg: %1','p1'=>'This class was run: '.$class,'file'=>__FILE__,'line'=>__LINE__));
-		}
-		*/
-
-		/* error_reporting(0); */
-		list($appname,$classname) = explode('.', $class);
-		$filename = PHPGW_INCLUDE_ROOT.'/'.$appname.'/inc/class.'.$classname.'.inc.php';
-		$included_files = get_included_files();
-
-		if(!isset($included_files[$filename]))
-		{
-			if(@file_exists($filename))
+			$args = func_get_args();
+			if(count($args) == 1)
 			{
-				include_once($filename);
-				$is_included = True;
+				$obj =& new $classname;
 			}
 			else
 			{
-				$is_included = False;
-			}
-		}
-		else
-		{
-			$is_included = True;
-		}
-
-		if($is_included)
-		{
-			if($p1 == '_UNDEF_' && $p1 != 1)
-			{
-				$obj = new $classname;
-			}
-			else
-			{
-				$input = array($p1,$p2,$p3,$p4,$p5,$p6,$p7,$p8,$p9,$p10,$p11,$p12,$p13,$p14,$p15,$p16);
-				$i = 1;
-				$code = '$obj = new ' . $classname . '(';
-				foreach($input as $test)
+				$code = '$obj =& new ' . $classname . '(';
+				foreach($args as $n => $arg)
 				{
-					if(($test == '_UNDEF_' && $test != 1 ) || $i == 17)
+					if ($n)
 					{
-						break;
+						$code .= ($n > 1 ? ',' : '') . '$args[' . $n . ']';
 					}
-					else
-					{
-						$code .= '$p' . $i . ',';
-					}
-					$i++;
 				}
-				$code = substr($code,0,-1) . ');';
+				$code .= ');';
 				eval($code);
 			}
-			/* error_reporting(E_ERROR | E_WARNING | E_PARSE); */
-			return $obj;
 		}
+		if (!is_object($obj))
+		{
+			echo "<p>CreateObject('$class'): Cant instanciate class!!!<br />\n".function_backtrace(1)."</p>\n";
+		}
+		return $obj;
 	}
 
-	/*!
-	 @function ExecMethod
-	 @abstract Execute a function, and load a class and include the class file if not done so already.
-	 @author seek3r
-	 @discussion This function is used to create an instance of a class, and if the class file has not been included it will do so.
-	 @syntax ExecObject('app.class', 'constructor_params');
-	 @param $method to execute
-	 @param $functionparams function param should be an array
-	 @param $loglevel developers choice of logging level
-	 @param $classparams params to be sent to the contructor
-	 @example ExecObject('phpgwapi.acl.read');
-	*/
+	/**
+	 * Execute a function with multiple arguments
+	 * We take object $GLOBALS[classname] from class if exists
+	 *
+	 * @param string app.class.method method to execute
+	 * @example ExecObject('etemplates.so_sql.search',$criteria,$key_only,...);
+	 * @return mixed reference to returnvalue of the method
+	 */
+	function &ExecMethod2($acm)
+	{
+		list($app,$class,$method) = explode('.',$acm);
+		if (!is_object($obj =& $GLOBALS[$class]))
+		{
+			$newobj = 1;
+			$obj =& CreateObject($acm);
+		}
+		
+		if (!method_exists($obj,$method))
+		{
+			echo "<p><b>".function_backtrace()."</b>: no methode '$method' in class '$class'</p>\n";
+			return False;
+		}
+		
+		$args = func_get_args();
+		unset($args[0]);
+		$code = '$return =& $obj->'.$method.'(';
+		foreach	($args as $n => $arg)
+		{
+			if ($n)
+			{
+				$code .= ($n > 1 ? ',' : '') . '$args[' . $n . ']';
+			}
+		}		
+		
+		eval($code.');');
+		if($newobj) unset($obj);
+		return $return;
+	}
+
+	/**
+	 * Execute a function, and load a class and include the class file if not done so already.
+	 *
+	 * This function is used to create an instance of a class, and if the class file has not been included it will do so.
+	 *
+	 * @author seek3r
+	 * @param $method to execute
+	 * @param $functionparams function param should be an array
+	 * @param $loglevel developers choice of logging level
+	 * @param $classparams params to be sent to the contructor
+	 * @return mixed returnvalue of method
+	 */
 	function ExecMethod($method, $functionparams = '_UNDEF_', $loglevel = 3, $classparams = '_UNDEF_')
 	{
 		/* Need to make sure this is working against a single dimensional object */
@@ -785,6 +753,7 @@
 			list($appname,$classname,$functionname) = explode(".", $method);
 			if (!is_object($GLOBALS[$classname]))
 			{
+				// please note: no reference assignment (=&) here, as $GLOBALS is a reference itself!!!
 				if ($classparams != '_UNDEF_' && ($classparams || $classparams != 'True'))
 				{
 					$GLOBALS[$classname] = CreateObject($appname.'.'.$classname, $classparams);
@@ -846,16 +815,16 @@
 				{
 					if (is_string($classparams))
 					{
-						eval($parentobject.'->'.$classname.' = CreateObject("'.$appname.'.'.$classname.'", "'.$classparams.'");');
+						eval($parentobject.'->'.$classname.' =& CreateObject("'.$appname.'.'.$classname.'", "'.$classparams.'");');
 					}
 					else
 					{
-						eval($parentobject.'->'.$classname.' = CreateObject("'.$appname.'.'.$classname.'", '.$classparams.');');
+						eval($parentobject.'->'.$classname.' =& CreateObject("'.$appname.'.'.$classname.'", '.$classparams.');');
 					}
 				}
 				else
 				{
-					eval($parentobject.'->'.$classname.' = CreateObject("'.$appname.'.'.$classname.'");');
+					eval($parentobject.'->'.$classname.' =& CreateObject("'.$appname.'.'.$classname.'");');
 				}
 			}
 
@@ -876,16 +845,16 @@
 		}
 	}
 
-	/*!
-	 @function copyobj
-	 @abstract duplicates the result of copying an object under php3/4 even when using php5
-	 @author milosch
-	 @discussion This is critical when looping on db object output and updating or inserting to the database using a copy of the db object.  This was first added to GroupWhere
-	 @syntax copyobj($source_object,$target_object);
-	 @example copyobj($GLOBALS['phpgw']->db,$mydb);
-	 @param $a   - Source Object
-	 @param $b   - Target Object (copy)
-	*/
+	/**
+	  * duplicates the result of copying an object under php3/4 even when using php5
+	  *
+	  * This is critical when looping on db object output and updating or inserting to the database using a copy of the db object.  This was first added to GroupWhere
+	  * 
+	  * @deprecated use $copy = clone($obj);
+	  * @author milosch
+	  * @param $a   - Source Object
+	  * @param $b   - Target Object (copy)
+	 */
 	function copyobj($a,&$b)
 	{
 		if(floor(phpversion()) > 4)
@@ -899,16 +868,16 @@
 		return;
 	}
 
-	/*!
-	 @function get_account_id
-	 @abstract Return a properly formatted account_id.
-	 @author skeeter
-	 @discussion This function will return a properly formatted account_id. This can take either a name or an account_id as paramters. If a name is provided it will return the associated id.
-	 @syntax get_account_id($accountid);
-	 @example $account_id = get_account_id($accountid);
-	 @param $account_id either a name or an id
-	 @param $default_id either a name or an id
-	*/
+	/**
+	 * Return a properly formatted account_id.
+	 *
+	 * @author skeeter
+	 * This function will return a properly formatted account_id. This can take either a name or an account_id as paramters. If a name is provided it will return the associated id.
+	 * $account_id = get_account_id($accountid);
+	 * @param int/string $account_id either a name or an id
+	 * @param int/string $default_id either a name or an id
+	 * @return int account_id
+	 */
 	function get_account_id($account_id = '',$default_id = '')
 	{
 		if (gettype($account_id) == 'integer')
@@ -919,32 +888,34 @@
 		{
 			if ($default_id == '')
 			{
-				return (isset($GLOBALS['phpgw_info']['user']['account_id'])?$GLOBALS['phpgw_info']['user']['account_id']:0);
+				return (isset($GLOBALS['egw_info']['user']['account_id'])?$GLOBALS['egw_info']['user']['account_id']:0);
 			}
 			elseif (is_string($default_id))
 			{
-				return $GLOBALS['phpgw']->accounts->name2id($default_id);
+				return $GLOBALS['egw']->accounts->name2id($default_id);
 			}
 			return (int)$default_id;
 		}
 		elseif (is_string($account_id))
 		{
-			if($GLOBALS['phpgw']->accounts->exists((int)$account_id) == True)
+			if($GLOBALS['egw']->accounts->exists((int)$account_id) == True)
 			{
 				return (int)$account_id;
 			}
 			else
 			{
-				return $GLOBALS['phpgw']->accounts->name2id($account_id);
+				return $GLOBALS['egw']->accounts->name2id($account_id);
 			}
 		}
 	}
 
-	/*!
-	 @function filesystem_separator
-	 @abstract sets the file system seperator depending on OS
-	 @result file system separator
-	*/
+	/**
+	 * sets the file system seperator depending on OS
+	 *
+	 * This is completely unnecessary, as you can use forward slashes in php under every OS -- RalfBecker 2005/11/09
+	 *
+	 * @return file system separator
+	 */
 	function filesystem_separator()
 	{
 		if(PHP_OS == 'Windows' || PHP_OS == 'OS/2' || PHP_OS == 'WINNT')
@@ -957,6 +928,13 @@
 		}
 	}
 
+	/**
+	 * print an array or object as pre-formatted html
+	 *
+	 * @param mixed $array
+	 * @param boolean $print=true print or return the content
+	 * @return string if !$print
+	 */
 	function _debug_array($array,$print=True)
 	{
 		$four = False;
@@ -986,13 +964,13 @@
 		}
 	}
 
-	/*
-	@function alessthanb
-	@abstract phpgw version checking, is param 1 < param 2 in phpgw versionspeak?
-	@param	$a	phpgw version number to check if less than $b
-	@param	$b	phpgw version number to check $a against
-	#return	True if $a < $b
-	*/
+	/**
+	 * eGW version checking, is eGW version in $a < $b
+	 *
+	 * @param string $a	egw version number to check if less than $b
+	 * @param string $b egw version number to check $a against
+	 * @return boolean True if $a < $b
+	 */
 	function alessthanb($a,$b,$DEBUG=False)
 	{
 		$num = array('1st','2nd','3rd','4th');
@@ -1074,13 +1052,13 @@
 		}
 	}
 
-	/*!
-	@function amorethanb
-	@abstract phpgw version checking, is param 1 > param 2 in phpgw versionspeak?
-	@param	$a	phpgw version number to check if more than $b
-	@param	$b	phpgw version number to check $a against
-	#return	True if $a < $b
-	*/
+	/**
+	 * eGW version checking, is eGW version in $a > $b
+	 *
+	 * @param string $a eGW version number to check if more than $b
+	 * @param string $b eGW version number to check check $a against
+	 * @return boolean True if $a > $b
+	 */
 	function amorethanb($a,$b,$DEBUG=False)
 	{
 		$num = array('1st','2nd','3rd','4th');
@@ -1154,14 +1132,14 @@
 		}
 	}
 	
-	/*!
-	 @function prepend_tables_prefix
-	 @abstract prepend a prefix to an array of table names
-	 @author Adam Hull (aka fixe) - No copyright claim
-	 @param	$prefix	the string to be prepended
-	 @param	$tables	and array of tables to have the prefix prepended to
-	 @return array of table names with the prefix prepended
-	*/
+	/**
+	 * prepend a prefix to an array of table names
+	 *
+	 * @author Adam Hull (aka fixe) - No copyright claim
+	 * @param	$prefix	the string to be prepended
+	 * @param	$tables	and array of tables to have the prefix prepended to
+	 * @return array of table names with the prefix prepended
+	 */
 	function prepend_tables_prefix($prefix,$tables)
 	{
 		foreach($tables as $key => $value)
@@ -1171,30 +1149,42 @@
 		return $tables;
 	}
 
-	/*!
-	 @function function_backtrace
-	 @abstract backtrace of the calling functions for php4.3+ else menuaction/scriptname
-	 @author ralfbecker
-	 @return function-names separated by slashes (beginning with the calling function not this one)
-	*/
+	/**
+	 * backtrace of the calling functions for php4.3+ else menuaction/scriptname
+	 *
+	 * @author RalfBecker-AT-outdoor-training.de
+	 * @param int $remove=0 number of levels to remove
+	 * @return string function-names separated by slashes (beginning with the calling function not this one)
+	 */
 	function function_backtrace($remove=0)
 	{
 		if (function_exists('debug_backtrace'))
 		{
 			$backtrace = debug_backtrace();
-			//echo "<pre>".print_r($backtrace,True)."</pre>\n";
+			//echo "function_backtrace($remove)<pre>".print_r($backtrace,True)."</pre>\n";
 			foreach($backtrace as $level)
 			{
 				if ($remove-- < 0)
 				{
-					$ret[] = (isset($level['class'])?$level['class'].'::':'').$level['function'];
+					$ret[] = (isset($level['class'])?$level['class'].'::':'').$level['function'].
+						(!$level['class'] ? '('.str_replace(EGW_SERVER_ROOT,'',$level['args'][0]).')' : '');
 				}
 			}
-			return implode(' / ',$ret);
+			if (is_array($ret))
+			{
+				return implode(' / ',$ret);
+			}
 		}
-		return $_GET['menuaction'] ? $_GET['menuaction'] : str_replace(PHPGW_SERVER_ROOT,'',$_SERVER['SCRIPT_FILENAME']);
+		return $_GET['menuaction'] ? $_GET['menuaction'] : str_replace(EGW_SERVER_ROOT,'',$_SERVER['SCRIPT_FILENAME']);
 	}
 
+	/**
+	 * check $_REQUEST data for XSS, vars containing script tags are moved to $GLOBALS['egw_unset_vars']
+	 *
+	 * @internal 
+	 * @param array &$var reference of array to check
+	 * @param string $name='' name of the array
+	 */
 	function _check_script_tag(&$var,$name='')
 	{
 		if (is_array($var))
@@ -1209,7 +1199,8 @@
 				{
 					if (preg_match('/<\/?[^>]*(iframe|script|onabort|onblur|onchange|onclick|ondblclick|onerror|onfocus|onkeydown|onkeypress|onkeyup|onload|onmousedown|onmousemove|onmouseout|onmouseover|onmouseup|onreset|onselect|onsubmit|onunload|javascript)+[^>]*>/i',$val))
 					{
-						//echo "<p>*** _check_script_tag($name): unset($name [$key]) ***</p>\n";
+						//echo "<p>*** _check_script_tag($name): unset(${name}[$key]) ***</p>\n";
+						$GLOBALS['egw_unset_vars'][$name.'['.$key.']'] =& $var[$key];
 						unset($var[$key]);
 					}
 				}
@@ -1219,10 +1210,10 @@
 		}
 	}
 		
-	foreach(array('_GET','_POST','_REQUEST','HTTP_GET_VARS','HTTP_POST_VARS','HTTP_REQUEST_VARS') as $where)
+	foreach(array('_GET','_POST','_REQUEST','HTTP_GET_VARS','HTTP_POST_VARS') as $n => $where)
 	{
 		$pregs = array(
-			'order' => '/^[a-zA-Z0-9_]*$/',
+			'order' => '/^[a-zA-Z0-9_,]*$/',
 			'sort'  => '/^(ASC|DESC|asc|desc|0|1|2|3|4|5|6|7){0,1}$/',
 		);
 		foreach(array('order','sort') as $name)
@@ -1232,12 +1223,15 @@
 				$GLOBALS[$where][$name] = '';
 			}
 		}
-		if (is_array($GLOBALS[$where]))
+		// do the check for script-tags only for _GET and _POST or if we found something in _GET and _POST
+		// speeds up the execusion a bit
+		if (is_array($GLOBALS[$where]) && ($n < 2 || is_array($GLOBALS['egw_unset_vars'])))
 		{
 			_check_script_tag($GLOBALS[$where],$where);
 		}
 	}
-	
+	//if (is_array($GLOBALS['egw_unset_vars'])) { echo "egw_unset_vars=<pre>".htmlspecialchars(print_r($GLOBALS['egw_unset_vars'],true))."</pre>"; exit; }
+
 	if(floor(phpversion()) <= 4)
 	{
 		/**
@@ -1250,4 +1244,24 @@
 		}
 		');
 	}
+
+	if (!function_exists('lang'))	// setup declares an own version
+	{
+		/**
+		 * function to handle multilanguage support
+		 *
+		 * @param string $key message in englich with %1, %2, ... placeholders
+		 * @param string $vars=null multiple values to replace the placeholders
+		 * @return string translated message with placeholders replaced
+		 */
+		function lang($key,$vars=null)
+		{
+			if(!is_array($vars))
+			{
+				$vars = func_get_args();
+				array_shift($vars);	// remove $key
+			}
+			return $GLOBALS['egw']->translation->translate($key,$vars);
+		}
+	}
 ?>
