@@ -1,51 +1,51 @@
 <?php
-/**************************************************************************\
-* eGroupWare - API htmlarea translations (according to lang in user prefs) *
-* http://www.eGroupWare.org                                                *
-* Modified by Ralf Becker <RalfBecker@outdoor-training.de>                 *
-* This file is derived from htmlareas's lang/en.js file                    *
-* --------------------------------------------                             *
-*  This program is free software; you can redistribute it and/or modify it *
-*  under the terms of the GNU General Public License as published by the   *
-*  Free Software Foundation; either version 2 of the License, or (at your  *
-*  option) any later version.                                              *
-\**************************************************************************/
+  /**************************************************************************\
+  * eGroupWare - API htmlarea translations (according to lang in user prefs) *
+  * http://www.eGroupWare.org                                                *
+  * Modified by Ralf Becker <RalfBecker@outdoor-training.de>                 *
+  * This file is derived from htmlareas's lang/en.js file                    *
+  * --------------------------------------------                             *
+  *  This program is free software; you can redistribute it and/or modify it *
+  *  under the terms of the GNU General Public License as published by the   *
+  *  Free Software Foundation; either version 2 of the License, or (at your  *
+  *  option) any later version.                                              *
+  \**************************************************************************/
 
-/* $Id: htmlarea-lang.php,v 1.1.4.1 2004/11/15 08:53:12 ralfbecker Exp $ */
+  /* $Id: htmlarea-lang.php 20295 2006-02-15 12:31:25Z  $ */
 
-$GLOBALS['phpgw_info']['flags'] = Array(
-	'currentapp'  => 'home',		// can't be phpgwapi, nor htmlarea (no own directory)
-	'noheader'    => True,
-	'nonavbar'    => True,
-	'noappheader' => True,
-	'noappfooter' => True,
-	'nofooter'    => True,
-	'nocachecontrol' => True			// allow cacheing
-);
+	$GLOBALS['egw_info']['flags'] = Array(
+		'currentapp'  => 'home',		// can't be phpgwapi, nor htmlarea (no own directory)
+		'noheader'    => True,
+		'nonavbar'    => True,
+		'noappheader' => True,
+		'noappfooter' => True,
+		'nofooter'    => True,
+		'nocachecontrol' => True			// allow cacheing
+	);
 
-include('../../header.inc.php');
-header('Content-type: text/javascript; charset='.$GLOBALS['phpgw']->translation->charset());
-$GLOBALS['phpgw']->translation->add_app('htmlarea');
+	include('../../header.inc.php');
+	header('Content-type: text/javascript; charset='.$GLOBALS['egw']->translation->charset());
+	$GLOBALS['egw']->translation->add_app('htmlarea');
 
-// I18N constants
+	// I18N constants
 
-// LANG: "en", ENCODING: UTF-8 | ISO-8859-1
-// Author: Mihai Bazon, <mishoo@infoiasi.ro>
+	// LANG: "en", ENCODING: UTF-8 | ISO-8859-1
+	// Author: Mihai Bazon, <mishoo@infoiasi.ro>
 
-// FOR TRANSLATORS:
-//
-//   1. PLEASE PUT YOUR CONTACT INFO IN THE ABOVE LINE
-//      (at least a valid email address)
-//
-//   2. PLEASE TRY TO USE UTF-8 FOR ENCODING;
-//      (if this is not possible, please include a comment
-//       that states what encoding is necessary.)
+	// FOR TRANSLATORS:
+	//
+	//   1. PLEASE PUT YOUR CONTACT INFO IN THE ABOVE LINE
+	//      (at least a valid email address)
+	//
+	//   2. PLEASE TRY TO USE UTF-8 FOR ENCODING;
+	//      (if this is not possible, please include a comment
+	//       that states what encoding is necessary.)
 ?>
 HTMLArea.I18N = {
 
 	// the following should be the filename without .js extension
 	// it will be used for automatically load plugin language.
-	lang: "<?php echo $GLOBALS['phpgw_info']['user']['preferences']['common']['lang']; ?>",
+	lang: "<?php echo $GLOBALS['egw_info']['user']['preferences']['common']['lang']; ?>",
 
 	tooltips: {
 		bold:           "<?php echo lang('Bold'); ?>",
