@@ -12,23 +12,27 @@
 *  option) any later version.                                              *
 \**************************************************************************/
 
-/* $Id: jscalendar-setup.php,v 1.9.4.1 2004/11/15 08:53:12 ralfbecker Exp $ */
+/* $Id: jscalendar-setup.php 22182 2006-07-31 19:43:46Z ralfbecker $ */
 
-$GLOBALS['phpgw_info']['flags'] = Array(
-	'currentapp'  => 'home',		// can't be phpgwapi, nor jscalendar (no own directory)
-	'noheader'    => True,
-	'nonavbar'    => True,
-	'noappheader' => True,
-	'noappfooter' => True,
-	'nofooter'    => True,
-	'nocachecontrol' => True			// allow cacheing
+$GLOBALS['egw_info'] = array(
+	'flags' => Array(
+		'currentapp'  => 'home',		// can't be phpgwapi, nor jscalendar (no own directory)
+		'noheader'    => True,
+		'nonavbar'    => True,
+		'noappheader' => True,
+		'noappfooter' => True,
+		'nofooter'    => True,
+		'nocachecontrol' => True			// allow cacheing
+	)
 );
 
 include('../../header.inc.php');
-header('Content-type: text/javascript; charset='.$GLOBALS['phpgw']->translation->charset());
-$GLOBALS['phpgw']->translation->add_app('jscalendar');
 
-$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
+header('Content-type: text/javascript; charset='.$GLOBALS['egw']->translation->charset());
+$GLOBALS['egw']->translation->add_app('jscalendar');
+
+$dateformat = $GLOBALS['egw_info']['user']['preferences']['common']['dateformat'];
+if (empty($dateformat)) $dateformat = 'Y-m-d';
 $jsDateFormat = str_replace(array('Y','d','m','M'),array('%Y','%d','%m','%b'),$dateformat);
 $dayFirst = strpos($dateformat,'d') < strpos($dateformat,'m');
 $jsLongDateFormat = '%a, '.($dayFirst ? '%e' : '%b').($dateformat[1] == '.' ? '. ' : ' ').($dayFirst ? '%b' : '%e');
@@ -54,7 +58,7 @@ $jsLongDateFormat = '%a, '.($dayFirst ? '%e' : '%b').($dateformat[1] == '.' ? '.
  * than modifying calendar.js itself).
  */
 
-// $Id: jscalendar-setup.php,v 1.9.4.1 2004/11/15 08:53:12 ralfbecker Exp $
+// $Id: jscalendar-setup.php 22182 2006-07-31 19:43:46Z ralfbecker $
 
 /**
  *  This function "patches" an input field (or other element) to use a calendar
@@ -118,7 +122,7 @@ Calendar.setup = function (params) {
 	param_default("disableFirstDowChange", true);
 	param_default("firstDay",       <?php // was 0 defaults to "Sunday" first
 	$day2int = array('Sunday'=>0,'Monday'=>1,'Tuesday'=>2,'Wednesday'=>3,'Thursday'=>4,'Friday'=>5,'Saturday'=>6);
-	echo (int) @$day2int[$GLOBALS['phpgw_info']['user']['preferences']['calendar']['weekdaystarts']]; ?>); // <?php echo $GLOBALS['phpgw_info']['user']['preferences']['calendar']['weekdaystarts']."\n"; ?>
+	echo (int) @$day2int[$GLOBALS['egw_info']['user']['preferences']['calendar']['weekdaystarts']]; ?>); // <?php echo $GLOBALS['egw_info']['user']['preferences']['calendar']['weekdaystarts']."\n"; ?>
 	param_default("align",          "Bl");
 	param_default("range",          [1900, 2999]);
 	param_default("weekNumbers",    true);
@@ -133,7 +137,7 @@ Calendar.setup = function (params) {
 	param_default("onUpdate",       null);
 	param_default("date",           null);
 	param_default("showsTime",      false);
-	param_default("timeFormat",     "<?php /* was 24 */ echo $GLOBALS['phpgw_info']['user']['preferences']['common']['timeformat']; ?>");
+	param_default("timeFormat",     "<?php /* was 24 */ echo $GLOBALS['egw_info']['user']['preferences']['common']['timeformat'] ? $GLOBALS['egw_info']['user']['preferences']['common']['timeformat'] : 24; ?>");
 	param_default("electric",       true);
 	param_default("step",           2);
 	param_default("position",       null);
@@ -251,12 +255,14 @@ foreach($day2int as $name => $n)
 
 Calendar._SDN = new Array
 (<?php // short day names
+$chars_shortcut = (int) lang('3 number of chars for day-shortcut');		// < 0 to take the chars from the end
 foreach($day2int as $name => $n)
 {
-	echo "\n \"".substr(lang($name),0,(int)lang('3 number of chars for day-shortcut')).'"'.($n < 6 ? ',' : '');
+	echo "\n \"".($chars_shortcut > 0 ? substr(lang($name),0,$chars_shortcut) : 
+		substr(lang($name),$chars_shortcut)).'"'.($n < 6 ? ',' : '');
 }
 ?>);
-Calendar._SDN_len = <?php echo (int) lang('3 number of chars for day-shortcut'); ?>;
+Calendar._SDN_len = <?php echo abs((int) lang('3 number of chars for day-shortcut')); ?>;
 
 Calendar._MN = new Array
 (<?php // full month names
@@ -275,12 +281,13 @@ foreach($monthnames as $n => $name)
 	$short = lang(substr($name,0,3));	// test if our lang-file have a translation for the english short with 3 chars
 	if (substr($short,-1) == '*')		// else create one by truncating the full translation to x chars
 	{
-		$short = substr(lang($name),0,(int)lang('3 number of chars for month-shortcut'));
+        $chars_shortcut = (int)lang('3 number of chars for month-shortcut');	// < 0 to take the chars from the end
+        $short = $chars_shortcut > 0 ? substr(lang($name),0,$chars_shortcut) : substr(lang($name),$chars_shortcut);
 	}
 	echo "\n \"".$short.'"'.($n < 11 ? ',' : '');
 }
 ?>);
-Calendar._SMN_len = <?php echo (int) lang('3 number of chars for month-shortcut'); ?>;
+Calendar._SMN_len = <?php echo abs((int) lang('3 number of chars for month-shortcut')); ?>;
 
 // tooltips
 Calendar._TT = {};
