@@ -12,13 +12,13 @@
 	// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 	// IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 	// INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-	// NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
+	// NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 	// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 	// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 	// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 	// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-	/* $Id: xml_functions.inc.php,v 1.31.4.4 2005/08/19 12:33:21 milosch Exp $ */
+	/* $Id: xml_functions.inc.php 20496 2006-03-08 19:40:11Z ralfbecker $ */
 
 	if (!function_exists('xml_parser_create'))
 	{
@@ -142,7 +142,7 @@
 	$GLOBALS['xmlrpcVersion'] = '2.0';
 
 	// let user errors start at 800
-	$GLOBALS['xmlrpcerruser'] = 800; 
+	$GLOBALS['xmlrpcerruser'] = 800;
 	// let XML parse errors start at 100
 	$GLOBALS['xmlrpcerrxml'] = 100;
 
@@ -169,7 +169,7 @@
 		Header('Content-type: text/xml');
 		Header('Content-length: ' . strlen($payload));
 		print $payload;
-		$GLOBALS['phpgw']->common->phpgw_exit(False);
+		$GLOBALS['egw']->common->phpgw_exit(False);
 	}
 
 	// used to store state during parsing
@@ -243,7 +243,7 @@
 			}
 			else
 			{
-				if ($i == 0) 
+				if ($i == 0)
 				{
 					$op = $top[$i];
 				}
@@ -576,8 +576,8 @@
 		//
 		// "Don't assume a timezone. It should be specified by the server in its
 		// documentation what assumptions it makes about timezones."
-		// 
-		// these routines always assume localtime unless 
+		//
+		// these routines always assume localtime unless
 		// $utc is set to 1, in which case UTC is assumed
 		// and an adjustment for locale is made when encoding
 		if (!$utc)
@@ -586,7 +586,7 @@
 		}
 		else
 		{
-			if(function_exists('gmstrftime')) 
+			if(function_exists('gmstrftime'))
 			{
 				// gmstrftime doesn't exist in some versions
 				// of PHP
@@ -614,7 +614,7 @@
 			{
 				$t=mktime($regs[4], $regs[5], $regs[6], $regs[2], $regs[3], $regs[1]);
 			}
-		} 
+		}
 		return $t;
 	}
 
@@ -641,7 +641,7 @@
 			{
 				$arr[] = phpgw_xmlrpc_decode($xmlrpc_val->arraymem($i));
 			}
-			return $arr; 
+			return $arr;
 		}
 		elseif($kind == 'struct')
 		{
@@ -833,7 +833,7 @@
 
 		if($server_name)
 		{
-			list($sessionid,$kp3) = $GLOBALS['phpgw']->session->create_server($username.'@'.$server_name,$password,"text");
+			list($sessionid,$kp3) = $GLOBALS['egw']->session->create_server($username.'@'.$server_name,$password,"text");
 		}
 		else
 		{
@@ -847,9 +847,9 @@
 			}
 			$GLOBALS['login'] = $user;
 
-			$sessionid = $GLOBALS['phpgw']->session->create($user,$password,"text");
-			$kp3 = $GLOBALS['phpgw']->session->kp3;
-			$domain = $GLOBALS['phpgw']->session->account_domain;
+			$sessionid = $GLOBALS['egw']->session->create($user,$password,"text");
+			$kp3 = $GLOBALS['egw']->session->kp3;
+			$domain = $GLOBALS['egw']->session->account_domain;
 		}
 
 		if($sessionid && $kp3)
@@ -875,7 +875,7 @@
 		$sessionid = $data['sessionid']->scalarval();
 		$kp3       = $data['kp3']->scalarval();
 
-		$later = $GLOBALS['phpgw']->session->destroy($sessionid,$kp3);
+		$later = $GLOBALS['egw']->session->destroy($sessionid,$kp3);
 
 		if ($later)
 		{
@@ -893,7 +893,7 @@
 	$GLOBALS['_xmlrpcs_phpgw_api_version_doc'] = 'Returns the eGroupWare API version';
 	function _xmlrpcs_phpgw_api_version($server,$m)
 	{
-		$version = $GLOBALS['phpgw_info']['server']['versions']['phpgwapi'];
+		$version = $GLOBALS['egw_info']['server']['versions']['phpgwapi'];
 
 		return CreateObject('phpgwapi.xmlrpcresp',CreateObject('phpgwapi.xmlrpcval',$version,'string'));
 	}
@@ -904,15 +904,15 @@
 	function _xmlrpcs_listApps($server,$m)
 	{
 		$m->getParam(0);
-		$GLOBALS['phpgw']->db->query("SELECT * FROM phpgw_applications WHERE app_enabled<3",__LINE__,__FILE__);
-		if($GLOBALS['phpgw']->db->num_rows())
+		$GLOBALS['egw']->db->query("SELECT * FROM egw_applications WHERE app_enabled<3",__LINE__,__FILE__);
+		if($GLOBALS['egw']->db->num_rows())
 		{
-			while($GLOBALS['phpgw']->db->next_record())
+			while($GLOBALS['egw']->db->next_record())
 			{
-				$name   = $GLOBALS['phpgw']->db->f('app_name');
-				$title  = $GLOBALS['phpgw']->db->f('app_title');
-				$status = $GLOBALS['phpgw']->db->f('app_enabled');
-				$version= $GLOBALS['phpgw']->db->f('app_version');
+				$name   = $GLOBALS['egw']->db->f('app_name');
+				$title  = $GLOBALS['egw']->db->f('app_title');
+				$status = $GLOBALS['egw']->db->f('app_enabled');
+				$version= $GLOBALS['egw']->db->f('app_version');
 				$apps[$name] = CreateObject('phpgwapi.xmlrpcval',
 					array(
 						'title'  => CreateObject('phpgwapi.xmlrpcval',$title,'string'),
@@ -928,20 +928,27 @@
 	}
 	*/
 
-	/*
-	$GLOBALS['_xmlrpcs_egw_time_sig'] = array(array(xmlrpcString,xmlrpcString));
-	$GLOBALS['_xmlrpcs_egw_time_doc'] = 'Returns system time based on optional format string';
+	$GLOBALS['_xmlrpcs_egw_time_sig'] = array(array(xmlrpcStruct));
+	$GLOBALS['_xmlrpcs_egw_time_doc'] = 'returns system-time and -timezone and if loged in user-time and timezone';
 	function _xmlrpcs_time($server,$m)
 	{
-		$format = $m->getParam(0);
-		$format = $format ? $format : 'Y/m/d H:i';
-
+		$return = array(
+			'system' => $GLOBALS['server']->date2iso8601(time()),
+			'system_tz_offset' => (int) date('Z'),
+		);
+		if ($GLOBALS['server']->authed)
+		{
+			$tz_offset_s = 3600 * (int) $GLOBALS['egw_info']['user']['preferences']['common']['tz_offset'];
+			$return += array(
+				'user' => $GLOBALS['server']->date2iso8601(time()+$tz_offset_s),
+				'user_tz_offset' => (int) date('Z') + $tz_offset_s,
+			);
+		}
 		return CreateObject(
 			'phpgwapi.xmlrpcresp',
-			CreateObject('phpgwapi.xmlrpcval', date($format,time()), 'string')
+			$GLOBALS['server']->build_resp($return,true)
 		);
 	}
-	*/
 
 	/* Add the system functions to the server map */
 	$GLOBALS['_xmlrpcs_dmap'] = array(
@@ -974,7 +981,7 @@
 			'function'  => '_xmlrpcs_phpgw_api_version',
 			'signature' => $GLOBALS['_xmlrpcs_phpgw_api_version_sig'],
 			'docstring' => $GLOBALS['_xmlrpcs_phpgw_api_version_doc']
-		)
+		),
 		/*
 		'system.listApps' => array(
 			'function'  => '_xmlrpcs_listApps',
@@ -982,13 +989,11 @@
 			'docstring' => $GLOBALS['_xmlrpcs_listApps_doc']
 		),
 		*/
-		/*
 		'system.time'  => array(
 			'function'  => '_xmlrpcs_time',
-			'signature' => $GLOBALS['_xmlrpcs_time_sig'],
-			'docstring' => $GLOBALS['_xmlrpcs_time_doc']
+			'signature' => $GLOBALS['_xmlrpcs_egw_time_sig'],
+			'docstring' => $GLOBALS['_xmlrpcs_egw_time_doc']
 		)
-		*/
 	);
 
 	$GLOBALS['_xmlrpc_debuginfo'] = '';
