@@ -9,7 +9,7 @@
 // Version 3.0 developed by Mihai Bazon.
 //   http://dynarch.com/mishoo
 //
-// $Id: htmlarea.js,v 1.4 2004/04/20 22:16:14 mipmip Exp $
+// $Id: htmlarea.js 20295 2006-02-15 12:31:25Z  $
 
 if (typeof _editor_url == "string") {
 	// Leave exactly one backslash at the end of _editor_url
@@ -1651,7 +1651,7 @@ HTMLArea.prototype.execCommand = function(cmdID, UI, param) {
 
 	    case "cut":
 	    case "copy":
-	    case "paste":
+/*	    case "paste":
 		try {
 			if (this.config.killWordOnPaste)
 				this._wordClean();
@@ -1670,6 +1670,7 @@ HTMLArea.prototype.execCommand = function(cmdID, UI, param) {
 			}
 		}
 		break;
+		*/
 	    case "lefttoright":
 	    case "righttoleft":
 		var dir = (cmdID == "righttoleft") ? "rtl" : "ltr";
