@@ -1,7 +1,7 @@
 <?php
 	/**************************************************************************\
-	* phpGroupWare                                                             *
-	* http://www.phpgroupware.org                                              *
+	* eGroupWare                                                               *
+	* http://www.egroupware.org                                                *
 	* --------------------------------------------                             *
 	*  This program is free software; you can redistribute it and/or modify it *
 	*  under the terms of the GNU General Public License as published by the   *
@@ -9,11 +9,11 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	// $Id: tables_current.inc.php,v 1.60 2004/07/10 10:59:37 ralfbecker Exp $
-	// $Source: /cvsroot/egroupware/phpgwapi/setup/tables_current.inc.php,v $
+	// $Id: tables_current.inc.php 21980 2006-06-28 12:24:53Z nelius_weiss $
+	// $Source$
 
 	$phpgw_baseline = array(
-		'phpgw_config' => array(
+		'egw_config' => array(
 			'fd' => array(
 				'config_app' => array('type' => 'varchar','precision' => '50','nullable' => False),
 				'config_name' => array('type' => 'varchar','precision' => '255','nullable' => False),
@@ -24,7 +24,7 @@
 			'ix' => array(),
 			'uc' => array()
 		),
-		'phpgw_applications' => array(
+		'egw_applications' => array(
 			'fd' => array(
 				'app_id' => array('type' => 'auto','precision' => '4','nullable' => False),
 				'app_name' => array('type' => 'varchar','precision' => '25','nullable' => False),
@@ -38,7 +38,7 @@
 			'ix' => array(array('app_enabled','app_order')),
 			'uc' => array('app_name')
 		),
-		'phpgw_acl' => array(
+		'egw_acl' => array(
 			'fd' => array(
 				'acl_appname' => array('type' => 'varchar','precision' => '50','nullable' => False),
 				'acl_location' => array('type' => 'varchar','precision' => '255','nullable' => False),
@@ -50,10 +50,10 @@
 			'ix' => array('acl_account',array('acl_location','acl_account'),array('acl_appname','acl_account')),
 			'uc' => array()
 		),
-		'phpgw_accounts' => array(
+		'egw_accounts' => array(
 			'fd' => array(
 				'account_id' => array('type' => 'auto','nullable' => False),
-				'account_lid' => array('type' => 'varchar','precision' => '25','nullable' => False),
+				'account_lid' => array('type' => 'varchar','precision' => '64','nullable' => False),
 				'account_pwd' => array('type' => 'varchar','precision' => '100','nullable' => False),
 				'account_firstname' => array('type' => 'varchar','precision' => '50'),
 				'account_lastname' => array('type' => 'varchar','precision' => '50'),
@@ -72,7 +72,7 @@
 			'ix' => array(),
 			'uc' => array('account_lid')
 		),
-		'phpgw_preferences' => array(
+		'egw_preferences' => array(
 			'fd' => array(
 				'preference_owner' => array('type' => 'int','precision' => '4','nullable' => False),
 				'preference_app' => array('type' => 'varchar','precision' => '25','nullable' => False),
@@ -83,42 +83,42 @@
 			'ix' => array(),
 			'uc' => array()
 		),
-		'phpgw_sessions' => array(
+		'egw_sessions' => array(
 			'fd' => array(
 				'session_id' => array('type' => 'varchar','precision' => '128','nullable' => False),
 				'session_lid' => array('type' => 'varchar','precision' => '128'),
-				'session_ip' => array('type' => 'varchar','precision' => '32'),
-				'session_logintime' => array('type' => 'int','precision' => '4'),
-				'session_dla' => array('type' => 'int','precision' => '4'),
+				'session_ip' => array('type' => 'varchar','precision' => '40'),
+				'session_logintime' => array('type' => 'int','precision' => '8'),
+				'session_dla' => array('type' => 'int','precision' => '8'),
 				'session_action' => array('type' => 'varchar','precision' => '255'),
 				'session_flags' => array('type' => 'char','precision' => '2')
 			),
-			'pk' => array(),
+			'pk' => array('session_id'),
 			'fk' => array(),
 			'ix' => array(array('session_flags','session_dla')),
-			'uc' => array('session_id')
+			'uc' => array()
 		),
-		'phpgw_app_sessions' => array(
+		'egw_app_sessions' => array(
 			'fd' => array(
 				'sessionid' => array('type' => 'varchar','precision' => '128','nullable' => False),
 				'loginid' => array('type' => 'int','precision' => '4','nullable' => False),
 				'app' => array('type' => 'varchar','precision' => '25','nullable' => False),
 				'location' => array('type' => 'varchar','precision' => '128','nullable' => False),
 				'content' => array('type' => 'longtext'),
-				'session_dla' => array('type' => 'int','precision' => '4')
+				'session_dla' => array('type' => 'int','precision' => '8')
 			),
 			'pk' => array('sessionid','loginid','app','location'),
 			'fk' => array(),
 			'ix' => array(),
 			'uc' => array()
 		),
-		'phpgw_access_log' => array(
+		'egw_access_log' => array(
 			'fd' => array(
-				'sessionid' => array('type' => 'char','precision' => '32','nullable' => False),
-				'loginid' => array('type' => 'varchar','precision' => '30','nullable' => False),
-				'ip' => array('type' => 'varchar','precision' => '30','nullable' => False),
+				'sessionid' => array('type' => 'char','precision' => '128','nullable' => False),
+				'loginid' => array('type' => 'varchar','precision' => '64','nullable' => False),
+				'ip' => array('type' => 'varchar','precision' => '40','nullable' => False),
 				'li' => array('type' => 'int','precision' => '4','nullable' => False),
-				'lo' => array('type' => 'int','precision' => '4','nullable' => True,'default' => '0'),
+				'lo' => array('type' => 'int','precision' => '4','default' => '0'),
 				'account_id' => array('type' => 'int','precision' => '4','nullable' => False,'default' => '0')
 			),
 			'pk' => array(),
@@ -126,7 +126,7 @@
 			'ix' => array(),
 			'uc' => array()
 		),
-		'phpgw_hooks' => array(
+		'egw_hooks' => array(
 			'fd' => array(
 				'hook_id' => array('type' => 'auto','nullable' => False),
 				'hook_appname' => array('type' => 'varchar','precision' => '255'),
@@ -138,7 +138,7 @@
 			'fk' => array(),
 			'uc' => array()
 		),
-		'phpgw_languages' => array(
+		'egw_languages' => array(
 			'fd' => array(
 				'lang_id' => array('type' => 'varchar','precision' => '5','nullable' => False),
 				'lang_name' => array('type' => 'varchar','precision' => '50','nullable' => False)
@@ -148,11 +148,11 @@
 			'ix' => array(),
 			'uc' => array()
 		),
-		'phpgw_lang' => array(
+		'egw_lang' => array(
 			'fd' => array(
 				'lang' => array('type' => 'varchar','precision' => '5','nullable' => False,'default' => ''),
-				'app_name' => array('type' => 'varchar','precision' => '100','nullable' => False,'default' => 'common'),
-				'message_id' => array('type' => 'varchar','precision' => '255','nullable' => False,'default' => ''),
+				'app_name' => array('type' => 'varchar','precision' => '32','nullable' => False,'default' => 'common'),
+				'message_id' => array('type' => 'varchar','precision' => '128','nullable' => False,'default' => ''),
 				'content' => array('type' => 'text')
 			),
 			'pk' => array('lang','app_name','message_id'),
@@ -160,17 +160,17 @@
 			'ix' => array(),
 			'uc' => array()
 		),
-		'phpgw_nextid' => array(
+		'egw_nextid' => array(
 			'fd' => array(
 				'id' => array('type' => 'int','precision' => '4','nullable' => True),
 				'appname' => array('type' => 'varchar','precision' => '25','nullable' => False)
 			),
-			'pk' => array(),
+			'pk' => array('appname'),
 			'fk' => array(),
 			'ix' => array(),
-			'uc' => array('appname')
+			'uc' => array()
 		),
-		'phpgw_categories' => array(
+		'egw_categories' => array(
 			'fd' => array(
 				'cat_id' => array('type' => 'auto','precision' => '4','nullable' => False),
 				'cat_main' => array('type' => 'int','precision' => '4','nullable' => False,'default' => '0'),
@@ -189,7 +189,7 @@
 			'ix' => array(array('cat_appname','cat_owner','cat_parent','cat_level')),
 			'uc' => array()
 		),
-		'phpgw_addressbook' => array(
+		'egw_addressbook' => array(
 			'fd' => array(
 				'id' => array('type' => 'auto','nullable' => False),
 				'lid' => array('type' => 'varchar','precision' => '32'),
@@ -250,7 +250,7 @@
 			'ix' => array(array('tid','owner','access','n_family','n_given','email'),array('tid','cat_id','owner','access','n_family','n_given','email')),
 			'uc' => array()
 		),
-		'phpgw_addressbook_extra' => array(
+		'egw_addressbook_extra' => array(
 			'fd' => array(
 				'contact_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'contact_owner' => array('type' => 'int','precision' => '8'),
@@ -262,7 +262,7 @@
 			'ix' => array(),
 			'uc' => array()
 		),
-		'phpgw_log' => array(
+		'egw_log' => array(
 			'fd' => array(
 				'log_id' => array('type' => 'auto','precision' => '4','nullable' => False),
 				'log_date' => array('type' => 'timestamp','nullable' => False),
@@ -275,7 +275,7 @@
 			'ix' => array(),
 			'uc' => array()
 		),
-		'phpgw_log_msg' => array(
+		'egw_log_msg' => array(
 			'fd' => array(
 				'log_msg_log_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'log_msg_seq_no' => array('type' => 'int','precision' => '4','nullable' => False),
@@ -294,7 +294,7 @@
 			'ix' => array(),
 			'uc' => array()
 		),
-		'phpgw_interserv' => array(
+		'egw_interserv' => array(
 			'fd' => array(
 				'server_id' => array('type' => 'auto','nullable' => False),
 				'server_name' => array('type' => 'varchar','precision' => '64','nullable' => True),
@@ -314,32 +314,32 @@
 			'ix' => array(),
 			'uc' => array()
 		),
-		'phpgw_vfs' => array(
+		'egw_vfs' => array(
 			'fd' => array(
-				'file_id' => array('type' => 'auto','nullable' => False),
-				'owner_id' => array('type' => 'int','precision' => '4','nullable' => False),
-				'createdby_id' => array('type' => 'int','precision' => '4'),
-				'modifiedby_id' => array('type' => 'int','precision' => '4'),
-				'created' => array('type' => 'date','nullable' => False,'default' => '1970-01-01'),
-				'modified' => array('type' => 'date'),
-				'size' => array('type' => 'int','precision' => '4'),
-				'mime_type' => array('type' => 'varchar','precision' => '64'),
-				'deleteable' => array('type' => 'char','precision' => '1','default' => 'Y'),
-				'comment' => array('type' => 'varchar','precision' => '255'),
-				'app' => array('type' => 'varchar','precision' => '25'),
-				'directory' => array('type' => 'varchar','precision' => '255'),
-				'name' => array('type' => 'varchar','precision' => '128','nullable' => False),
-				'link_directory' => array('type' => 'varchar','precision' => '255'),
-				'link_name' => array('type' => 'varchar','precision' => '128'),
-				'version' => array('type' => 'varchar','precision' => '30','nullable' => False,'default' => '0.0.0.0'),
-				'content' => array('type' => 'longtext')
+				'vfs_file_id' => array('type' => 'auto','nullable' => False),
+				'vfs_owner_id' => array('type' => 'int','precision' => '4','nullable' => False),
+				'vfs_createdby_id' => array('type' => 'int','precision' => '4'),
+				'vfs_modifiedby_id' => array('type' => 'int','precision' => '4'),
+				'vfs_created' => array('type' => 'date','nullable' => False,'default' => '1970-01-01'),
+				'vfs_modified' => array('type' => 'date'),
+				'vfs_size' => array('type' => 'int','precision' => '4'),
+				'vfs_mime_type' => array('type' => 'varchar','precision' => '64'),
+				'vfs_deleteable' => array('type' => 'char','precision' => '1','default' => 'Y'),
+				'vfs_comment' => array('type' => 'varchar','precision' => '255'),
+				'vfs_app' => array('type' => 'varchar','precision' => '25'),
+				'vfs_directory' => array('type' => 'varchar','precision' => '233'),
+				'vfs_name' => array('type' => 'varchar','precision' => '100','nullable' => False),
+				'vfs_link_directory' => array('type' => 'varchar','precision' => '255'),
+				'vfs_link_name' => array('type' => 'varchar','precision' => '128'),
+				'vfs_version' => array('type' => 'varchar','precision' => '30','nullable' => False,'default' => '0.0.0.0'),
+				'vfs_content' => array('type' => 'text')
 			),
-			'pk' => array('file_id'),
+			'pk' => array('vfs_file_id'),
 			'fk' => array(),
-			'ix' => array(array('directory','name','mime_type')),
+			'ix' => array(array('vfs_directory','vfs_name')),
 			'uc' => array()
 		),
-		'phpgw_history_log' => array(
+		'egw_history_log' => array(
 			'fd' => array(
 				'history_id' => array('type' => 'auto','precision' => '4','nullable' => False),
 				'history_record_id' => array('type' => 'int','precision' => '4','nullable' => False),
@@ -355,19 +355,215 @@
 			'ix' => array(array('history_appname','history_record_id','history_status','history_timestamp')),
 			'uc' => array()
 		),
-		'phpgw_async' => array(
+		'egw_async' => array(
 			'fd' => array(
-				'id' => array('type' => 'varchar','precision' => '255','nullable' => False),
-				'next' => array('type' => 'int','precision' => '4','nullable' => False),
-				'times' => array('type' => 'varchar','precision' => '255','nullable' => False),
-				'method' => array('type' => 'varchar','precision' => '80','nullable' => False),
-				'data' => array('type' => 'text','nullable' => False),
-				'account_id' => array('type' => 'int','precision' => '4','nullable' => False,'default' => '0')
+				'async_id' => array('type' => 'varchar','precision' => '255','nullable' => False),
+				'async_next' => array('type' => 'int','precision' => '4','nullable' => False),
+				'async_times' => array('type' => 'varchar','precision' => '255','nullable' => False),
+				'async_method' => array('type' => 'varchar','precision' => '80','nullable' => False),
+				'async_data' => array('type' => 'text','nullable' => False),
+				'async_account_id' => array('type' => 'int','precision' => '4','nullable' => False,'default' => '0')
 			),
-			'pk' => array('id'),
+			'pk' => array('async_id'),
 			'fk' => array(),
 			'ix' => array(),
 			'uc' => array()
+		),
+		'egw_api_content_history' => array(
+			'fd' => array(
+				'sync_appname' => array('type' => 'varchar','precision' => '60','nullable' => False),
+				'sync_contentid' => array('type' => 'varchar','precision' => '60','nullable' => False),
+				'sync_added' => array('type' => 'timestamp'),
+				'sync_modified' => array('type' => 'timestamp'),
+				'sync_deleted' => array('type' => 'timestamp'),
+				'sync_id' => array('type' => 'auto','nullable' => False),
+				'sync_guid' => array('type' => 'varchar','precision' => '120','nullable' => False),
+				'sync_changedby' => array('type' => 'int','precision' => '4','nullable' => False)
+			),
+			'pk' => array('sync_id'),
+			'fk' => array(),
+			'ix' => array('sync_added','sync_modified','sync_deleted','sync_guid','sync_changedby',array('sync_appname','sync_contentid')),
+			'uc' => array()
+		),
+		'phpgw_vfs2_mimetypes' => array(
+			'fd' => array(
+				'mime_id' => array('type' => 'auto','nullable' => False),
+				'extension' => array('type' => 'varchar','precision' => '10','nullable' => False),
+				'mime' => array('type' => 'varchar','precision' => '50','nullable' => False),
+				'mime_magic' => array('type' => 'varchar','precision' => '255','nullable' => True),
+				'friendly' => array('type' => 'varchar','precision' => '50','nullable' => False),
+				'image' => array('type' => 'blob'),
+				'proper_id' => array('type' => 'varchar','precision' => '4')
+			),
+			'pk' => array('mime_id'),
+			'fk' => array(),
+			'ix' => array(),
+			'uc' => array()
+		),
+		'phpgw_vfs2_files' => array(
+			'fd' => array(
+				'file_id' => array('type' => 'auto','nullable' => False),
+				'mime_id' => array('type' => 'int','precision' => '4'),
+				'owner_id' => array('type' => 'int','precision' => '4','nullable' => False),
+				'createdby_id' => array('type' => 'int','precision' => '4'),
+				'modifiedby_id' => array('type' => 'int','precision' => '4'),
+				'created' => array('type' => 'timestamp','nullable' => False,'default' => '1970-01-01 00:00:00'),
+				'modified' => array('type' => 'timestamp'),
+				'size' => array('type' => 'int','precision' => '8'),
+				'deleteable' => array('type' => 'char','precision' => '1','default' => 'Y'),
+				'comment' => array('type' => 'varchar','precision' => '255'),
+				'app' => array('type' => 'varchar','precision' => '25'),
+				'directory' => array('type' => 'varchar','precision' => '255'),
+				'name' => array('type' => 'varchar','precision' => '64','nullable' => False),
+				'link_directory' => array('type' => 'varchar','precision' => '255'),
+				'link_name' => array('type' => 'varchar','precision' => '128'),
+				'version' => array('type' => 'varchar','precision' => '30','nullable' => False,'default' => '0.0.0.0'),
+				'content' => array('type' => 'longtext'),
+				'is_backup' => array('type' => 'varchar','precision' => '1','nullable' => False,'default' => 'N'),
+				'shared' => array('type' => 'varchar','precision' => '1','nullable' => False,'default' => 'N'),
+				'proper_id' => array('type' => 'varchar','precision' => '45')
+			),
+			'pk' => array('file_id'),
+			'fk' => array(),
+			'ix' => array(array('directory','name')),
+			'uc' => array()
+		),
+		'phpgw_vfs2_customfields' => array(
+			'fd' => array(
+				'customfield_id' => array('type' => 'auto','nullable' => False),
+				'customfield_name' => array('type' => 'varchar','precision' => '60','nullable' => False),
+				'customfield_description' => array('type' => 'varchar','precision' => '255','nullable' => True),
+				'customfield_type' => array('type' => 'varchar','precision' => '20','nullable' => False),
+				'customfield_precision' => array('type' => 'int','precision' => '4','nullable' => True),
+				'customfield_active' => array('type' => 'varchar','precision' => '1','nullable' => False,'default' => 'N')
+			),
+			'pk' => array('customfield_id'),
+			'fk' => array(),
+			'ix' => array(),
+			'uc' => array()
+		),
+		'phpgw_vfs2_quota' => array(
+			'fd' => array(
+				'account_id' => array('type' => 'int','precision' => '4','nullable' => False),
+				'quota' => array('type' => 'int','precision' => '4','nullable' => False)
+			),
+			'pk' => array('account_id'),
+			'fk' => array('account_id' => array('egw_accounts' => 'account_id')),
+			'ix' => array(),
+			'uc' => array()
+		),
+		'phpgw_vfs2_shares' => array(
+			'fd' => array(
+				'account_id' => array('type' => 'int','precision' => '4','nullable' => False),
+				'file_id' => array('type' => 'int','precision' => '4','nullable' => False),
+				'acl_rights' => array('type' => 'int','precision' => '4','nullable' => False)
+			),
+			'pk' => array('account_id','file_id'),
+			'fk' => array('account_id' => array('egw_accounts' => 'account_id'),'file_id' => array('phpgw_vfs2_files' => 'file_id')),
+			'ix' => array(),
+			'uc' => array()
+		),
+		'phpgw_vfs2_versioning' => array(
+			'fd' => array(
+				'version_id' => array('type' => 'auto','nullable' => False),
+				'file_id' => array('type' => 'int','precision' => '4','nullable' => False),
+				'operation' => array('type' => 'int','precision' => '4','nullable' => False),
+				'modifiedby_id' => array('type' => 'int','precision' => '4','nullable' => False),
+				'modified' => array('type' => 'timestamp','nullable' => False),
+				'version' => array('type' => 'varchar','precision' => '30','nullable' => False),
+				'comment' => array('type' => 'varchar','precision' => '255','nullable' => True),
+				'backup_file_id' => array('type' => 'int','precision' => '4','nullable' => True),
+				'backup_content' => array('type' => 'longtext','nullable' => True),
+				'src' => array('type' => 'varchar','precision' => '255','nullable' => True),
+				'dest' => array('type' => 'varchar','precision' => '255','nullable' => True)
+			),
+			'pk' => array('version_id'),
+			'fk' => array('file_id' => array('phpgw_vfs2_files' => 'file_id')),
+			'ix' => array(),
+			'uc' => array()
+		),
+		'phpgw_vfs2_customfields_data' => array(
+			'fd' => array(
+				'file_id' => array('type' => 'int','precision' => '4','nullable' => False),
+				'customfield_id' => array('type' => 'int','precision' => '4','nullable' => False),
+				'data' => array('type' => 'longtext','nullable' => True)
+			),
+			'pk' => array('file_id','customfield_id'),
+			'fk' => array('file_id' => array('phpgw_vfs2_files' => 'file_id'),'customfield_id' => array('phpgw_vfs2_customfields' => 'customfield_id')),
+			'ix' => array(),
+			'uc' => array()
+		),
+		'phpgw_vfs2_prefixes' => array(
+			'fd' => array(
+				'prefix_id' => array('type' => 'auto','nullable' => False),
+				'prefix' => array('type' => 'varchar','precision' => '8','nullable' => False),
+				'owner_id' => array('type' => 'int','precision' => '4','nullable' => False),
+				'prefix_description' => array('type' => 'varchar','precision' => '30','nullable' => True),
+				'prefix_type' => array('type' => 'varchar','precision' => '1','nullable' => False,'default' => 'p')
+			),
+			'pk' => array('prefix_id'),
+			'fk' => array(),
+			'ix' => array(),
+			'uc' => array()
+		),
+		'egw_contentmap' => array(
+			'fd' => array(
+				'map_id' => array('type' => 'varchar','precision' => '128','nullable' => False),
+				'map_guid' => array('type' => 'varchar','precision' => '100','nullable' => False),
+				'map_locuid' => array('type' => 'varchar','precision' => '100','nullable' => False),
+				'map_timestamp' => array('type' => 'timestamp','nullable' => False),
+				'map_expired' => array('type' => 'bool','nullable' => False)
+			),
+			'pk' => array('map_id','map_guid','map_locuid'),
+			'fk' => array(),
+			'ix' => array('map_expired',array('map_id','map_locuid')),
+			'uc' => array()
+		),
+		'egw_syncmldevinfo' => array(
+			'fd' => array(
+				'dev_id' => array('type' => 'varchar','precision' => '255','nullable' => False),
+				'dev_dtdversion' => array('type' => 'varchar','precision' => '10','nullable' => False),
+				'dev_numberofchanges' => array('type' => 'bool','nullable' => False),
+				'dev_largeobjs' => array('type' => 'bool','nullable' => False),
+				'dev_swversion' => array('type' => 'varchar','precision' => '100','nullable' => False),
+				'dev_oem' => array('type' => 'varchar','precision' => '100','nullable' => False),
+				'dev_model' => array('type' => 'varchar','precision' => '100','nullable' => False),
+				'dev_manufacturer' => array('type' => 'varchar','precision' => '100','nullable' => False),
+				'dev_devicetype' => array('type' => 'varchar','precision' => '100','nullable' => False),
+				'dev_deviceid' => array('type' => 'varchar','precision' => '100','nullable' => False),
+				'dev_datastore' => array('type' => 'text','nullable' => False)
+			),
+			'pk' => array('dev_id'),
+			'fk' => array(),
+			'ix' => array(),
+			'uc' => array()
+		),
+		'egw_syncmlsummary' => array(
+			'fd' => array(
+				'dev_id' => array('type' => 'varchar','precision' => '255','nullable' => False),
+				'sync_path' => array('type' => 'varchar','precision' => '100','nullable' => False),
+				'sync_serverts' => array('type' => 'varchar','precision' => '20','nullable' => False),
+				'sync_clientts' => array('type' => 'varchar','precision' => '20','nullable' => False)
+			),
+			'pk' => array(array('dev_id','sync_path')),
+			'fk' => array(),
+			'ix' => array(),
+			'uc' => array()
+		),
+		'egw_links' => array(
+			'fd' => array(
+				'link_id' => array('type' => 'auto','nullable' => False),
+				'link_app1' => array('type' => 'varchar','precision' => '25','nullable' => False),
+				'link_id1' => array('type' => 'varchar','precision' => '50','nullable' => False),
+				'link_app2' => array('type' => 'varchar','precision' => '25','nullable' => False),
+				'link_id2' => array('type' => 'varchar','precision' => '50','nullable' => False),
+				'link_remark' => array('type' => 'varchar','precision' => '100'),
+				'link_lastmod' => array('type' => 'int','precision' => '4','nullable' => False),
+				'link_owner' => array('type' => 'int','precision' => '4','nullable' => False)
+			),
+			'pk' => array('link_id'),
+			'fk' => array(),
+			'ix' => array(array('link_app1','link_id1','link_lastmod'),array('link_app2','link_id2','link_lastmod')),
+			'uc' => array()
 		)
 	);
-?>
