@@ -11,19 +11,19 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-	/* $Id: index.php,v 1.9 2004/01/10 02:18:08 shrykedude Exp $ */
+	/* $Id: index.php 20295 2006-02-15 12:31:25Z  $ */
 
-	$GLOBALS['phpgw_info'] = array();
-
-	$GLOBALS['phpgw_info']['flags'] = array(
-		'currentapp'              => 'polls',
-		'noheader'                => True,
-		'nonavbar'                => True,
-		'enable_nextmatchs_class' => True
+	$GLOBALS['egw_info'] = array(
+		'flags' => array(
+			'currentapp'              => 'polls',
+			'noheader'                => True,
+			'nonavbar'                => True,
+			'enable_nextmatchs_class' => True,
+		),
 	);
 	include('../header.inc.php');
 
 	ExecMethod('polls.ui.index');
 
-	$GLOBALS['phpgw']->common->phpgw_footer();
+	$GLOBALS['egw']->common->egw_footer();
 ?>
