@@ -1,7 +1,7 @@
 <?php
 	/**************************************************************************\
-	* phpGroupWare - Registration                                              *
-	* http://www.phpgroupware.org                                              *
+	* eGroupWare - Registration                                                *
+	* http://www.egroupware.org                                                *
 	* This application written by Joseph Engo <jengo@phpgroupware.org>         *
 	* Modified by Jason Wies (Zone) <zone@users.sourceforge.net>               *
 	* Modified by Loic Dachary <loic@gnu.org>                                  *
@@ -15,7 +15,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.uireg.inc.php,v 1.18 2004/04/21 18:26:27 mipmip Exp $ */
+	/* $Id: class.uireg.inc.php 20049 2005-11-29 12:08:25Z nelius_weiss $ */
 
 	class uireg
 	{
@@ -31,6 +31,7 @@
 			'lostpw1' => True,
 			'lostpw3' => True,
 			'lostpw4' => True,
+			'lostid1' => True,
 			'ready_to_activate' => True,
 			'email_sent_lostpw' => True,
 			'tos'     => True
@@ -38,16 +39,25 @@
 
 		function uireg()
 		{
-			$this->template = $GLOBALS['phpgw']->template;
-			$this->bo = createobject ('registration.boreg');
-			$this->bomanagefields = createobject ('registration.bomanagefields');
+			$this->template = $GLOBALS['egw']->template;
+			$this->bo =& CreateObject ('registration.boreg');
+			$this->bomanagefields =& CreateObject ('registration.bomanagefields');
 			$this->fields = $this->bomanagefields->get_field_list ();
 
 			$this->set_lang_code();
+
+			$var = Array (
+				'website_title' => $GLOBALS['egw_info']['server']['site_title'] .'[Registration]',
+				'img_icon' => substr($GLOBALS['egw_info']['server']['login_logo_file'],0,4) == 'http' ? 
+					$GLOBALS['egw_info']['server']['login_logo_file'] :
+					$GLOBALS['egw']->common->image('phpgwapi',$GLOBALS['egw_info']['server']['login_logo_file'] ? 
+						$GLOBALS['egw_info']['server']['login_logo_file'] : 'logo'),
+				'logo_url' => $GLOBALS['egw_info']['server']['login_logo_url']?$GLOBALS['egw_info']['server']['login_logo_url']:'http://www.eGroupWare.org',
+				'logo_title' => $GLOBALS['egw_info']['server']['login_logo_title']?$GLOBALS['egw_info']['server']['login_logo_title']:'www.eGroupWare.org',
+			) ;
+			$this->template->set_var($var) ;
 		}
 
-
-
 		function set_lang_code($code='')
 		{
 			if($code)
@@ -65,13 +75,13 @@
 
 			if ($this->lang_code)
 			{
-				$GLOBALS['phpgw_info']['user']['preferences']['common']['lang'] = $this->lang_code;
-				$GLOBALS['phpgw']->translation->init();	
+				$GLOBALS['egw_info']['user']['preferences']['common']['lang'] = $this->lang_code;
+				$GLOBALS['egw']->translation->init();	
 			}
 			else
 			{
-				$GLOBALS['phpgw_info']['user']['preferences']['common']['lang'] = $GLOBALS[default_lang];
-				$GLOBALS['phpgw']->translation->init();	
+				$GLOBALS['egw_info']['user']['preferences']['common']['lang'] = $GLOBALS[default_lang];
+				$GLOBALS['egw']->translation->init();	
 			}
 		}
 
@@ -86,16 +96,15 @@
 
 		function header($head_subj='')
 		{
+			$GLOBALS['egw']->common->egw_header();
 			$this->set_header_footer_blocks();
-			$this->template->set_var('charset',$GLOBALS['phpgw']->translation->charset());
-			$this->template->set_var('lang',$GLOBALS[phpgw_info][user][preferences][common][lang]);
 			if($head_subj)
 			{
 				$this->template->set_var('lang_header',$head_subj);
 			}
 			else
 			{
-				$this->template->set_var('lang_header',lang('eGroupWare - Account registration'));
+				$this->template->set_var('lang_header',$GLOBALS['egw_info']['server']['site_title'].' - '.lang('Account registration'));
 			}
 
 			$this->template->pfp('out','header');
@@ -137,7 +146,7 @@
 			if ($errors && $config['username_is'] == 'http')
 			{
 				$vars[message]=	lang('An error occured. Please contact our technical support and let them know.');
-				$this->simple_screen ('error_general.tpl', $GLOBALS['phpgw']->common->error_list ($errors),$vars);
+				$this->simple_screen ('error_general.tpl', $GLOBALS['egw']->common->error_list ($errors),$vars);
 			}
 
 			/* Note that check_select_username () may not return */
@@ -145,7 +154,7 @@
 			if (!$select_username || is_string ($select_username))
 			{
 				$vars[message]=	lang('An error occured. Please contact our technical support and let them know.');
-				$this->simple_screen ('error_general.tpl', $GLOBALS['phpgw']->common->error_list (array ($select_username)),$vars);
+				$this->simple_screen ('error_general.tpl', $GLOBALS['egw']->common->error_list (array ($select_username)),$vars);
 			}
 
 			$this->header();
@@ -156,11 +165,11 @@
 
 			if ($errors)
 			{
-				$this->template->set_var('errors',$GLOBALS['phpgw']->common->error_list($errors));
+				$this->template->set_var('errors',$GLOBALS['egw']->common->error_list($errors));
 			}
 
 			// temporary set all available langcodes
-			$langs = $GLOBALS['phpgw']->translation->get_installed_langs();
+			$langs = $GLOBALS['egw']->translation->get_installed_langs();
 			$comeback_code=$this->lang_code;
 			foreach ($langs as $key => $name)	// if we have a translation use it
 			{
@@ -185,7 +194,7 @@
 			$this->set_lang_code($comeback_code);
 
 			$this->template->set_var('title',lang('Choose Language')); 
-			$this->template->set_var('illustration',$GLOBALS['phpgw']->common->image('registration','screen0_language'));
+			$this->template->set_var('illustration',$GLOBALS['egw']->common->image('registration','screen0_language'));
 				
 			$this->template->set_var('lang_choose_language',$lang_choose_string);
 
@@ -198,7 +207,7 @@
 
 
 
-			$this->template->set_var('form_action',$GLOBALS['phpgw']->link('/registration/main.php','menuaction=registration.boreg.step1'));
+			$this->template->set_var('form_action',$GLOBALS['egw']->link('/registration/index.php','menuaction=registration.boreg.step1'));
 			$this->template->set_var('lang_username',lang('Username'));
 			$this->template->set_var('lang_submit',lang('Submit'));
 
@@ -230,11 +239,11 @@
 			$this->template->set_block('_personal_info','form');
 			$this->template->set_var('lang_code',$this->lang_code);
 			$this->template->set_var('lang_username',lang('Username'));
-			$this->template->set_var('value_username',$GLOBALS['phpgw']->session->appsession('loginid','registration'));
+			$this->template->set_var('value_username',$GLOBALS['egw']->session->appsession('loginid','registration'));
 
 			if ($errors)
 			{
-				$this->template->set_var('errors',$GLOBALS['phpgw']->common->error_list($errors));
+				$this->template->set_var('errors',$GLOBALS['egw']->common->error_list($errors));
 			}
 
 			if ($missing_fields)
@@ -263,7 +272,7 @@
 				}
 			}
 
-			$this->template->set_var('form_action',$GLOBALS['phpgw']->link('/registration/main.php','menuaction=registration.boreg.step2'));
+			$this->template->set_var('form_action',$GLOBALS['egw']->link('/registration/index.php','menuaction=registration.boreg.step2'));
 			$this->template->set_var('lang_password',lang('Password'));
 			$this->template->set_var('lang_reenter_password',lang('Re-enter password'));
 			$this->template->set_var('lang_submit',lang('Submit'));
@@ -294,7 +303,7 @@
 
 			if ($config['display_tos'])
 			{
-				$this->template->set_var('tos_link',$GLOBALS['phpgw']->link('/registration/main.php','menuaction=registration.uireg.tos'));
+				$this->template->set_var('tos_link',$GLOBALS['egw']->link('/registration/index.php','menuaction=registration.uireg.tos'));
 				$this->template->set_var('lang_tos_agree',lang('I have read the terms and conditions and agree by them.'));
 				if ($r_reg['tos_agree'])
 				{
@@ -323,10 +332,11 @@
 
 			if ($errors)
 			{
-				$this->template->set_var('errors',$GLOBALS['phpgw']->common->error_list($errors));
+				$this->template->set_var('errors',$GLOBALS['egw']->common->error_list($errors));
 			}
-
-			$this->template->set_var('form_action',$GLOBALS['phpgw']->link('/registration/main.php','menuaction=registration.boreg.lostpw1'));
+			
+			$this->template->set_var('lang_lost_password',lang('Lost Password')) ;
+			$this->template->set_var('form_action',$GLOBALS['egw']->link('/registration/index.php','menuaction=registration.boreg.lostpw1'));
 			$this->template->set_var('lang_explain',lang('After you enter your username, instructions to change your password will be sent to you by e-mail to the address you gave when you registered.'));
 			$this->template->set_var('lang_username',lang('Username'));
 			$this->template->set_var('lang_submit',lang('Submit'));
@@ -348,10 +358,10 @@
 
 			if ($errors)
 			{
-				$this->template->set_var('errors',$GLOBALS['phpgw']->common->error_list($errors));
+				$this->template->set_var('errors',$GLOBALS['egw']->common->error_list($errors));
 			}
 
-			$this->template->set_var('form_action',$GLOBALS['phpgw']->link('/registration/main.php','menuaction=registration.boreg.lostpw3'));
+			$this->template->set_var('form_action',$GLOBALS['egw']->link('/registration/index.php','menuaction=registration.boreg.lostpw3'));
 			$this->template->set_var('value_username', $lid);
 			$this->template->set_var('lang_changepassword',lang("Change password for user"));
 			$this->template->set_var('lang_enter_password',lang('Enter your new password'));
@@ -372,14 +382,35 @@
 				'screen' => 'lostpw_changed.tpl'
 			));
 
-			$message=lang('Your password was changed. You can go back to the <a href="%1">login</a> page.',$GLOBALS['phpgw_info']['server']['webserver_url']);
-
+			$message=lang('Your password was changed. You can go back to the <a href="%1">login</a> page.',$GLOBALS['egw']->link('/login.php'));
 			$this->template->set_var('message',$message);
 
 			$this->template->pfp('out','screen');
 			$this->footer();
 		}
 
+		function lostid1($errors = '',$r_reg = '')
+		{
+			$this->header();
+			$this->template->set_file(array(
+				'_lostid_select' => 'lostid_select.tpl'
+			));
+			$this->template->set_block('_lostid_select','form');
+
+			if ($errors)
+			{
+				$this->template->set_var('errors',$GLOBALS['egw']->common->error_list($errors));
+			}
+			$this->template->set_var('lang_lost_user_id',lang('Lost User Id')) ;
+			$this->template->set_var('form_action',$GLOBALS['egw']->link('/registration/index.php','menuaction=registration.boreg.lostid1'));
+			$this->template->set_var('lang_explain',lang('After you enter your email address, the user accounts associated with this email address will be mailed to that address.'));
+			$this->template->set_var('lang_email',lang('email address'));
+			$this->template->set_var('lang_submit',lang('Submit'));
+
+			$this->template->pfp('out','form');
+			$this->footer();
+		}
+		
 		function get_input_field ($field_info, $post_values)
 		{
 			$r_regs=$_POST['r_reg'];
@@ -465,7 +496,7 @@
 
 			if ($type == 'birthday' || $type == 'state' || $type == 'country')
 			{
-				$sbox = createobject ('phpgwapi.sbox');
+				$sbox =& CreateObject ('phpgwapi.sbox');
 			}
 
 			if ($type == 'state')
@@ -542,7 +573,7 @@
 			{
 
 				/* ($config['activate_account'] == 'immediately') */
-				$GLOBALS['phpgw']->redirect($GLOBALS['phpgw']->link('/registration/main.php','menuaction=registration.boreg.step4&lang_code='.$this->lang_code.'&reg_id=' . $this->bo->reg_id));
+				$GLOBALS['egw']->redirect($GLOBALS['egw']->link('/registration/index.php','menuaction=registration.boreg.step4&lang_code='.$this->lang_code.'&reg_id=' . $this->bo->reg_id));
 			}
 		}
 
@@ -551,15 +582,22 @@
 			$vars[message]=lang('We have sent a mail with instructions to change your password. You should follow the included link within two hours. If you do not, you will have to go to the lost password screen again.');
 			$this->simple_screen('confirm_email_sent_lostpw.tpl','',$vars);
 		}
+		
+		function email_sent_lostid($email)
+		{
+			$vars[message]=sprintf(lang("We have sent a mail to your email account: %s with your lost user ids."),$email);
+			$this->simple_screen('confirm_email_sent_lostpw.tpl','',$vars);
+		}
 
 		function welcome_screen()
 		{
 			$this->set_lang_code();
 			$this->header();
 
-			$login_url=$GLOBALS['phpgw_info']['server']['webserver_url'].'/login.php';
+			$login_url = $GLOBALS['egw']->link('/login.php');
 			
-			$message = lang('Your account is now active!  Click <a href="%1">here</a> to log into your account.',$login_url);
+			$message = lang('Your account is now active!  Click <a href="%s">here</a> to log into your account.') ;
+			$message = sprintf($message,$login_url) ;
 
 			$this->template->set_file(array(
 				'screen' => 'welcome_message.tpl'
