@@ -1,46 +1,45 @@
 <?php
-  /**************************************************************************\
-  * eGroupWare - Setup Check Installation                                    *
-  * http://www.eGroupWare.org                                                *
-  * --------------------------------------------                             *
-  *  This program is free software; you can redistribute it and/or modify it *
-  *  under the terms of the GNU General Public License as published by the   *
-  *  Free Software Foundation; either version 2 of the License, or (at your  *
-  *  option) any later version.                                              *
-  \**************************************************************************/
-
-  /* $Id: check_install.php,v 1.21.2.8 2005/02/21 08:04:51 ralfbecker Exp $ */
+	/**************************************************************************\
+	* eGroupWare - Setup Check Installation                                    *
+	* http://www.eGroupWare.org                                                *
+	* --------------------------------------------                             *
+	*  This program is free software; you can redistribute it and/or modify it *
+	*  under the terms of the GNU General Public License as published by the   *
+	*  Free Software Foundation; either version 2 of the License, or (at your  *
+	*  option) any later version.                                              *
+	\**************************************************************************/
+	
+	/* $Id: check_install.php 22249 2006-08-15 17:01:33Z ralfbecker $ */
 
 	$run_by_webserver = !!$_SERVER['PHP_SELF'];
 	$is_windows = strtoupper(substr(PHP_OS,0,3)) == 'WIN';
 
-
 	if ($run_by_webserver)
 	{
-		$phpgw_info = array();
-		$GLOBALS['phpgw_info']['flags'] = array(
-			'noheader' => True,
-			'nonavbar' => True,
-			'currentapp' => 'home',
-			'noapi' => True
-		);
+		$GLOBALS['egw_info'] = array(
+			'flags' => array(
+				'noheader' => True,
+				'nonavbar' => True,
+				'currentapp' => 'home',
+				'noapi' => True
+		));
 		$safe_er = error_reporting();
 		include ('./inc/functions.inc.php');
 		error_reporting($safe_er);
 
-		$GLOBALS['phpgw_info']['setup']['stage']['header'] = $GLOBALS['phpgw_setup']->detection->check_header();
-		if ($GLOBALS['phpgw_info']['setup']['stage']['header'] == '10')
+		$GLOBALS['egw_info']['setup']['stage']['header'] = $GLOBALS['egw_setup']->detection->check_header();
+		if ($GLOBALS['egw_info']['setup']['stage']['header'] == '10')
 		{
 			// Check header and authentication
-			if (!$GLOBALS['phpgw_setup']->auth('Config') && !$GLOBALS['phpgw_setup']->auth('Header'))
+			if (!$GLOBALS['egw_setup']->auth('Config') && !$GLOBALS['egw_setup']->auth('Header'))
 			{
 				Header('Location: index.php');
 				exit;
 			}
 		}
-		$passed_icon = '<img src="templates/default/images/completed.png" title="Passed" align="middle"> ';
-		$error_icon = '<img src="templates/default/images/incomplete.png" title="Error" align="middle"><span id="setup_error">';
-		$warning_icon = '<img src="templates/default/images/dep.png" title="Warning" align="middle"><span id="setup_warning"> ';
+		$passed_icon = '<img src="templates/default/images/completed.png" title="Passed" alt="Passed" align="middle" />';
+		$error_icon = '<img src="templates/default/images/incomplete.png" title="Error" alt="Error" align="middle" />';
+		$warning_icon = '<img src="templates/default/images/dep.png" title="Warning" alt="Warning" align="middle" />';
 	}
 	else
 	{
@@ -54,6 +53,12 @@
 		}
 	}
 	$checks = array(
+		'phpversion' => array(
+			'func' => 'php_version',
+			'value' => 4.3,
+			'verbose_value' => '4.3+',
+			'recommended' => '5.0',
+		),
 		'safe_mode' => array(
 			'func' => 'php_ini_check',
 			'value' => 0,
@@ -63,15 +68,6 @@
 				lang('*** You have to do the changes manualy in your php.ini (usualy in /etc on linux) in order to get eGW fully working !!!')."\n".
 				lang('*** Do NOT update your database via setup, as the update might be interrupted by the max_execution_time, which leaves your DB in an unrecoverable state (your data is lost) !!!')
 		),
-/* not longer needed, as it gets set now on runtime (works even with safe_mode)
-		'error_reporting' => array(
-			'func' => 'php_ini_check',
-			'value' => E_NOTICE,
-			'verbose_value' => 'E_NOTICE',
-			'check' => 'not set',
-			'safe_mode' => 'error_reporting = E_ALL & ~E_NOTICE'
-		),
-*/
 		'magic_quotes_runtime' => array(
 			'func' => 'php_ini_check',
 			'value' => 0,
@@ -98,44 +94,68 @@
 			'error' => lang('max_execution_time is set to less than 30 (seconds): eGroupWare sometimes needs a higher execution_time, expect occasional failures'),
 			'safe_mode' => 'max_execution_time = 30'
 		),
+		'file_uploads' => array(
+			'func' => 'php_ini_check',
+			'value' => 1,
+			'verbose_value' => 'On',
+			'error' => lang('File uploads are switched off: You can NOT use any of the filemanagers, nor can you attach files in several applications!'),
+		),
 		'include_path' => array(
 			'func' => 'php_ini_check',
 			'value' => '.',
 			'check' => 'contain',
 			'error' => lang('include_path need to contain "." - the current directory'),
-			'save_mode' => 'max_execution_time = 30'
 		),
 		'mysql' => array(
 			'func' => 'extension_check',
-			'warning' => "<div id='setup_info'>" . lang('The %1 extension is needed, if you plan to use a %2 database.','mysql','MySQL').'</div>'
+			'warning' => "<div class='setup_info'>" . lang('The %1 extension is needed, if you plan to use a %2 database.','mysql','MySQL').'</div>'
 		),
 		'pgsql' => array(
 			'func' => 'extension_check',
-			'warning' => '<div id="setup_info">' . lang('The %1 extension is needed, if you plan to use a %2 database.','pgsql','pgSQL').'</div>'
+			'warning' => '<div class="setup_info">' . lang('The %1 extension is needed, if you plan to use a %2 database.','pgsql','pgSQL').'</div>'
 		),
 		'mssql' => array(
 			'func' => 'extension_check',
-			'warning' => '<div id="setup_info">' . lang('The %1 extension is needed, if you plan to use a %2 database.','mssql','MsSQL') . '</div>',
+			'warning' => '<div class="setup_info">' . lang('The %1 extension is needed, if you plan to use a %2 database.','mssql','MsSQL') . '</div>',
 			'win_only' => True
 		),
+		'odbc' => array(
+			'func' => 'extension_check',
+			'warning' => '<div class="setup_info">' . lang('The %1 extension is needed, if you plan to use a %2 database.','odbc','MaxDB, MsSQL or Oracle') . '</div>',
+		),
+		'oci8' => array(
+			'func' => 'extension_check',
+			'warning' => '<div class="setup_info">' . lang('The %1 extension is needed, if you plan to use a %2 database.','oci','Oracle') . '</div>',
+		),
 		'mbstring' => array(
 			'func' => 'extension_check',
-			'warning' => '<div id="setup_info">' . lang('The mbstring extension is needed to fully support unicode (utf-8) or other multibyte-charsets.') . "</div>"
+			'warning' => '<div class="setup_info">' . lang('The mbstring extension is needed to fully support unicode (utf-8) or other multibyte-charsets.') . "</div>"
 		),
 		'mbstring.func_overload' => array(
 			'func' => 'php_ini_check',
 			'value' => 7,
-			'warning' => '<div id="setup_info">' . lang('The mbstring.func_overload = 7 is needed to fully support unicode (utf-8) or other multibyte-charsets.') . "</div>",
+			'warning' => '<div class="setup_info">' . lang('The mbstring.func_overload = 7 is needed to fully support unicode (utf-8) or other multibyte-charsets.') . "</div>",
 			'change' => extension_loaded('mbstring')  || function_exists('dl') && @dl(PHP_SHLIB_PREFIX.'mbstring.'.PHP_SHLIB_SUFFIX) ? 'mbstring.func_overload = 7' : '',
 		),
 		'imap' => array(
 			'func' => 'extension_check',
-			'warning' => '<div id="setup_info">' . lang('The imap extension is needed by the two email apps (even if you use email with pop3 as protocoll).') . '</div>'
+			'warning' => '<div class="setup_info">' . lang('The imap extension is needed by the two email apps (even if you use email with pop3 as protocoll).') . '</div>'
 		),
 		'session' => array(
 			'func' => 'extension_check',
-			'warning' => '<div id="setup_info">' . lang('The session extension is needed to use php4 session (db-sessions work without).') . "</div>"
+			'warning' => '<div class="setup_info">' . lang('The session extension is needed to use php sessions (db-sessions work without).') . "</div>"
+		),
+		'' => array(
+			'func' => 'pear_check',
+			'warning' => '<div class="setup_info">' . lang('PEAR is needed by SyncML or the iCal import+export of calendar.') . "</div>"
 		),	
+		'Log' => array(
+			'func' => 'pear_check',
+			'warning' => '<div class="setup_info">' . lang('PEAR::Log is needed by SyncML.').' '.lang('You can install it by running:').' pear install Log' . "</div>"
+		),
+		'gd' => array(
+			'func' => 'gd_check',
+		),
 		'.' => array(
 			'func' => 'permission_check',
 			'is_world_writable' => False,
@@ -144,22 +164,24 @@
 		'header.inc.php' => array(
 			'func' => 'permission_check',
 			'is_world_readable' => False,
-			'only_if_exists' => @$GLOBALS['phpgw_info']['setup']['stage']['header'] != 10
-		),
-		'phpgwapi/images' => array(
-			'func' => 'permission_check',
-			'is_writable' => True
+			'only_if_exists' => @$GLOBALS['egw_info']['setup']['stage']['header'] != 10
 		),
 		'fudforum' => array(
 			'func' => 'permission_check',
 			'is_writable' => True,
 			'only_if_exists' => True
 		),
-		'gd' => array(
-			'func' => 'gd_check'
-		)
 	);
-
+	if (extension_loaded('session'))
+	{
+		//ini_set('session.save_path','/hugo');
+		$checks[session_save_path()] = array(
+			'func' => 'permission_check',
+			'is_writable' => true,
+			'msg' => lang("Checking if php.ini setting session.save_path='%1' is writable by the webserver",session_save_path()),
+			'error' => lang('You will NOT be able to log into eGroupWare using PHP sessions: "session could not be verified" !!!'),
+		);
+	}
 	// some constants for pre php4.3
 	if (!defined('PHP_SHLIB_SUFFIX'))
 	{
@@ -169,6 +191,51 @@
 	{
 		define('PHP_SHLIB_PREFIX',PHP_SHLIB_SUFFIX == 'dll' ? 'php_' : '');
 	}
+	
+	function php_version($name,$args)
+	{
+		global $passed_icon, $error_icon;
+
+		$version_ok = (float) phpversion() >= $args['value'];
+
+		echo '<div>'.($version_ok ? $passed_icon : $error_icon).' <span'.($version_ok ? '' : ' class="setup_error"').'>'.
+			lang('Checking required PHP version %1 (recommended %2)',$args['verbose_value'],$args['recommended']).': '.
+			phpversion().' ==> '.($version_ok ? lang('True') : lang('False'))."</span></div>\n";
+	}
+
+	function pear_check($package,$args)
+	{
+		global $passed_icon, $warning_icon;
+		static $pear_available = null;
+		
+		if (is_null($pear_available))
+		{
+			$pear_available = @include('PEAR.php');
+
+			if (!class_exists('PEAR')) $pear_available = false;
+		
+			echo '<div>'.($pear_available ? $passed_icon : $warning_icon).' <span'.($pear_available ? '' : ' class="setup_warning"').'>'.
+				lang('Checking PEAR%1 is installed','').': '.($pear_available ? lang('True') : lang('False'))."</span></div>\n";
+		}
+		if ($pear_available && $package)
+		{
+			$available = @include($package.'.php');
+
+			if (!class_exists($package)) $available = false;
+			
+			echo '<div>'.($available ? $passed_icon : $warning_icon).' <span'.($available ? '' : ' class="setup_warning"').'>'.
+				lang('Checking PEAR%1 is installed','::'.$package).': '.($available ? lang('True') : lang('False'))."</span></div>\n";
+		}
+		$available = $pear_available && (!$package || $available);
+		
+		if (!$available)
+		{
+			echo $args['warning'];
+		}
+		echo "\n";
+
+		return $available;
+	}
 
 	function extension_check($name,$args)
 	{
@@ -179,17 +246,17 @@
 			return True;	// check only under windows
 		}
 		// we check for the existens of 'dl', as multithreaded webservers dont have it !!!
-		$availible = extension_loaded($name) || function_exists('dl') && @dl(PHP_SHLIB_PREFIX.$name.'.'.PHP_SHLIB_SUFFIX);
+		$available = extension_loaded($name) || function_exists('dl') && @dl(PHP_SHLIB_PREFIX.$name.'.'.PHP_SHLIB_SUFFIX);
 
-		echo ($availible ? $passed_icon : $warning_icon).' '.lang('Checking extension %1 is loaded or loadable',$name).': '.($availible ? lang('True') : lang('False'))."</span><br>\n";
+		echo '<div>'.($available ? $passed_icon : $warning_icon).' <span'.($available ? '' : ' class="setup_warning"').'>'.lang('Checking extension %1 is loaded or loadable',$name).': '.($available ? lang('True') : lang('False'))."</span></div>\n";
 
-		if (!$availible)
+		if (!$available)
 		{
 			echo $args['warning'];
 		}
 		echo "\n";
 
-		return $availible;
+		return $available;
 	}
 
 	function verbosePerms( $in_Perms )
@@ -252,12 +319,12 @@
 		global $passed_icon, $error_icon, $warning_icon,$is_windows;
 		//echo "<p>permision_check('$name',".print_r($args,True).",'$verbose')</p>\n";
 
-		if (substr($name,0,3) != '../')
+		// add a ../ for non-absolute pathes
+		$rel_name = $name;
+		if (substr($name,0,3) != '../' && $name{0} != '/' && $name{0} != '\\' && strstr($name,':') === false)
 		{
 			$name = '../'.$name;
 		}
-		$rel_name = substr($name,3);
-
 		if (!file_exists($name) && isset($args['only_if_exists']) && $args['only_if_exists'])
 		{
 			return True;
@@ -272,24 +339,50 @@
 		}
 
 		$checks = array();
-		if (isset($args['is_readable'])) $checks[] = (!$args['is_readable']?'not ':'').lang('readable by the webserver');
-		if (isset($args['is_writable'])) $checks[] = (!$args['is_writable']?'not ':'').lang('writable by the webserver');
-		if (isset($args['is_world_readable'])) $checks[] = (!$args['is_world_readable']?lang('not').' ':'').lang('world readable');
-		if (isset($args['is_world_writable'])) $checks[] = (!$args['is_world_writable']?lang('not').' ':'').lang('world writable');
+		if (isset($args['is_readable']))
+		{
+			$checks[] = lang('readable by the webserver');
+			$check_not = (!$args['is_readable']?lang('not'):'');
+		}
+		if (isset($args['is_writable']))
+		{
+			$checks[] = lang('writable by the webserver');
+			$check_not = (!$args['is_writable']?lang('not'):'');
+		}
+		if (isset($args['is_world_readable']))
+		{
+			$checks[] = lang('world readable');
+			$check_not = (!$args['is_world_readable']?lang('not'):'');
+		}
+		if (isset($args['is_world_writable']))
+		{
+			$checks[] = lang('world writable');
+			$check_not = (!$args['is_world_writable']?lang('not'):'');
+		}
 		$checks = implode(', ',$checks);
 
 		$icon = $passed_icon;
-		$msg = lang('Checking file-permissions of %1 for %2: %3',$rel_name,$checks,$perms)."<br>\n";
-
+		if (isset($args['msg']) && ($msg = $args['msg']))
+		{
+			$msg .= ': '.$perms."<br />\n";
+		}
+		else
+		{
+			$msg = lang('Checking file-permissions of %1 for %2 %3: %4',$rel_name,$check_not,$checks,$perms)."<br />\n";
+		}
+		if (isset($args['error']) && $args['error'])
+		{
+			$extra_error_msg = "<br />\n".$args['error'];
+		}
 		if (!file_exists($name))
 		{
-			echo $error_icon . $msg . lang('%1 does not exist !!!',$rel_name)."</span><br/>\n";
+			echo '<div>'. $error_icon . '<span class="setup_error">' . $msg . lang('%1 does not exist !!!',$rel_name).$extra_error_msg."</span></div>\n";
 			return False;
 		}
 		$warning = False;
 		if (!$GLOBALS['run_by_webserver'] && (@$args['is_readable'] || @$args['is_writable']))
 		{
-			echo $warning_icon.' '.$msg. lang('Check can only be performed, if called via a webserver, as the user-id/-name of the webserver is not known.')."</span><br/>\n";
+			echo $warning_icon.' '.$msg. lang('Check can only be performed, if called via a webserver, as the user-id/-name of the webserver is not known.')."\n";
 			unset($args['is_readable']);
 			unset($args['is_writable']);
 			$warning = True;
@@ -297,22 +390,22 @@
 		$Ok = True;
 		if (isset($args['is_writable']) && is_writable($name) != $args['is_writable'])
 		{
-			echo "$error_icon $msg ".lang('%1 is %2%3 !!!',$rel_name,$args['is_writable']?lang('not').' ':'',lang('writable by the webserver'))."</span><br/>\n";
+			echo '<div>'.$error_icon.' <span class="setup_error">'.$msg.' '.lang('%1 is %2%3 !!!',$rel_name,$args['is_writable']?lang('not').' ':'',lang('writable by the webserver')).$extra_error_msg."</span></div>\n";
 			$Ok = False;
 		}
 		if (isset($args['is_readable']) && is_readable($name) != $args['is_readable'])
 		{
-			echo "$error_icon $msg ". lang('%1 is %2%3 !!!',$rel_name,$args['is_readable']?lang('not').' ':'',lang('readable by the webserver'))."</span><br/>\n";
+			echo '<div>'.$error_icon.' <span class="setup_error">'.$msg.' '.lang('%1 is %2%3 !!!',$rel_name,$args['is_readable']?lang('not').' ':'',lang('readable by the webserver')).$extra_error_msg."</span></div>\n";
 			$Ok = False;
 		}
 		if (!$is_windows && isset($args['is_world_readable']) && !(fileperms($name) & 04) == $args['is_world_readable'])
 		{
-			echo "$error_icon $msg" . lang('%1 is %2%3 !!!',$rel_name,$args['is_world_readable']?lang('not').' ':'',lang('world readable'))."</span><br/>\n";
+			echo '<div>'.$error_icon.' <span class="setup_error">'.$msg.' '.lang('%1 is %2%3 !!!',$rel_name,$args['is_world_readable']?lang('not').' ':'',lang('world readable')).$extra_error_msg."</span></div>\n";
 			$Ok = False;
 		}
 		if (!$is_windows && isset($args['is_world_writable']) && !(fileperms($name) & 02) == $args['is_world_writable'])
 		{
-			echo "$error_icon $msg " . lang('%1 is %2%3 !!!',$rel_name,$args['is_world_writable']?lang('not').' ':'',lang('world writable'))."</span><br/>\n";
+			echo '<div>'.$error_icon.' <span class="setup_error">'.$msg.' '.lang('%1 is %2%3 !!!',$rel_name,$args['is_world_writable']?lang('not').' ':'',lang('world writable')).$extra_error_msg."</span></div>\n";
 			$Ok = False;
 		}
 		if ($Ok && !$warning && $verbose)
@@ -323,7 +416,7 @@
 		{
 			if ($verbose)
 			{
-				echo "<div id='setup_info'>" . lang('This might take a while, please wait ...')."</div>\n";
+				echo "<div class='setup_info'>" . lang('This might take a while, please wait ...')."</div>\n";
 				flush();
 			}
 			@set_time_limit(0);
@@ -387,30 +480,30 @@
 				$result = $ini_value == $args['value'];
 				break;
 		}
-		$msg = ' '.lang('Checking php.ini').": $name $check $verbose_value: <div id='setup_info'>ini_get('$name')='$ini_value'$ini_value_verbose</div>\n";
+		$msg = ' '.lang('Checking php.ini').": $name $check $verbose_value: <span class='setup_info'>ini_get('$name')='$ini_value'$ini_value_verbose</span>";
 
 		if ($result)
 		{
-			echo $passed_icon.$msg;
+			echo "<div>".$passed_icon.$msg."</div>\n";
 		}
 		if (!$result)
 		{
 			if (isset($args['warning']))
 			{
-				echo $warning_icon.$msg.$args['warning']."<br/></span>\n";
+				echo "<div>".$warning_icon.' <span class="setup_warning">'.$msg.'</span><div class="setup_info">'.$args['warning']."</div></div>\n";
 			}
 			if (isset($args['error']))
 			{
-				echo $error_icon.$msg.$args['error']."</br></span>\n";
+				echo "<div>".$error_icon.' <span class="setup_error">'.$msg.'</span><div class="setup_info">'.$args['error']."</div></div>\n";
 			}
 			if (isset($args['safe_mode']) && $safe_mode || @$args['change'])
 			{
 				if (!isset($args['warning']) && !isset($args['error']))
 				{
-					echo $error_icon.$msg."<br/></span>";
+					echo '<div>'.$error_icon.' <span class="setup_error">'.$msg.'</span></div>';
 				}
-				echo "<div id='setup_error'>\n";
-				echo '*** '.lang('Please make the following change in your php.ini').' ('.get_php_ini().'): '.(@$args['safe_mode']?$args['safe_mode']:$args['change'])."<br>\n";
+				echo "<div class='setup_error'>\n";
+				echo '*** '.lang('Please make the following change in your php.ini').' ('.get_php_ini().'): '.(@$args['safe_mode']?$args['safe_mode']:$args['change'])."<br />\n";
 				echo '*** '.lang('AND reload your webserver, so the above changes take effect !!!')."</div>\n";
 			}
 		}
@@ -430,21 +523,21 @@
 	function gd_check()
 	{
 		global $passed_icon, $warning_icon;
+
 		$available = (function_exists('imagecopyresampled')  || function_exists('imagecopyresized'));
 		
-		echo ($available ? $passed_icon : $warning_icon).' '.lang('Checking for GD support...').': '.($available ? lang('True') : lang('False'))."<br/></span>\n";
+		echo "<div>".($available ? $passed_icon : $warning_icon).' <span'.($available?'':' class="setup_warning"').'>'.lang('Checking for GD support...').': '.($available ? lang('True') : lang('False'))."</span></div>\n";
 		
 		if (!$available)
 		{
 			echo lang('Your PHP installation does not have appropriate GD support. You need gd library version 1.8 or newer to see Gantt charts in projects.')."\n";
-			return false;
 		}
-		return true;
+		return $available;
 	}
 	
 	if ($run_by_webserver)
 	{
-		$tpl_root = $GLOBALS['phpgw_setup']->html->setup_tpl_dir('setup');
+		$tpl_root = $GLOBALS['egw_setup']->html->setup_tpl_dir('setup');
 		$setup_tpl = CreateObject('setup.Template',$tpl_root);
 		$setup_tpl->set_file(array(
 			'T_head' => 'head.tpl',
@@ -454,21 +547,22 @@
 		if (@$_GET['intro']) {
 			if($ConfigLang = get_var('ConfigLang',array('POST','COOKIE')))
 			{
-				$GLOBALS['phpgw_setup']->set_cookie('ConfigLang',$ConfigLang,(int) (time()+(1200*9)),'/');
+				$GLOBALS['egw_setup']->set_cookie('ConfigLang',$ConfigLang,(int) (time()+(1200*9)),'/');
 			}
-			$GLOBALS['phpgw_setup']->html->show_header(lang('Welcome to the eGroupWare Installation'),False,'config');
+			$GLOBALS['egw_setup']->html->show_header(lang('Welcome to the eGroupWare Installation'),False,'config');
 			echo '<h1>'.lang('Welcome to the eGroupWare Installation')."</h1>\n";
 			if(!$ConfigLang)
 			{
 				echo '<p><form action="check_install.php?intro=1" method="Post">Please Select your language '.lang_select(True,'en')."</form></p>\n";
 			}
-			echo '<p>'.lang('The first step in installing eGroupWare is to ensure your environment has the necessary settings to correctly run the application.');
-			echo '<br /><br />'.lang('We will now run a series of tests, which may take a few minutes.  Click the link below to proceed.');
+			echo '<p>'.lang('The first step in installing eGroupWare is to ensure your environment has the necessary settings to correctly run the application.').'</p>';
+			echo '<p>'.lang('We will now run a series of tests, which may take a few minutes.  Click the link below to proceed.').'</p>';
 			echo '<h3><a href="check_install.php">'.lang('Run installation tests').'</a></h3>';
+			echo '<p><a href="manageheader.php">'.lang('Skip the installation tests (not recommended)')."</a></p>\n";
 			$setup_tpl->pparse('out','T_footer');
 			exit;
 		} else {
-			$GLOBALS['phpgw_setup']->html->show_header(lang('Checking the eGroupWare Installation'),False,'config',$ConfigDomain ? $ConfigDomain . '(' . @$phpgw_domain[$ConfigDomain]['db_type'] . ')' : '');
+			$GLOBALS['egw_setup']->html->show_header(lang('Checking the eGroupWare Installation'),False,'config',$ConfigDomain ? $ConfigDomain . '(' . @$GLOBALS['egw_domain'][$ConfigDomain]['db_type'] . ')' : '');
 			echo '<h1>'.lang('Checking the eGroupWare Installation')."</h1>\n";
 			# echo "<pre style=\"text-align: left;\">\n";;
 		}
@@ -490,7 +584,7 @@
 	{
 		# echo "</pre>\n";;
 
-		if ($GLOBALS['phpgw_info']['setup']['stage']['header'] != 10)
+		if ($GLOBALS['egw_info']['setup']['stage']['header'] != 10)
 		{
 			if (!$Ok)
 			{
@@ -510,7 +604,7 @@
 			{
 				echo lang('Please fix the above errors (%1) and warnings(%2)',$error_icon,$warning_icon).'. ';
 			}
-			echo '<br><a href="'.str_replace('check_install.php','',$_SERVER['HTTP_REFERER']).'">'.lang('Return to Setup')."</a></h3>\n";
+			echo '<br /><a href="'.str_replace('check_install.php','',$_SERVER['HTTP_REFERER']).'">'.lang('Return to Setup')."</a></h3>\n";
 		}
 		$setup_tpl->pparse('out','T_footer');
 		//echo "</body>\n</html>\n";
