@@ -9,19 +9,19 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: ldapimport.php,v 1.18.2.1 2005/05/07 20:57:10 wolffc Exp $ */
+  /* $Id: ldapimport.php 20295 2006-02-15 12:31:25Z  $ */
 
-	$phpgw_info = array();
-	$phpgw_info["flags"] = array(
-		'noheader'   => True,
-		'nonavbar'   => True,
-		'currentapp' => 'home',
-		'noapi'      => True
-	);
+	$GLOBALS['egw_info'] = array(
+		'flags' => array(
+			'noheader'   => True,
+			'nonavbar'   => True,
+			'currentapp' => 'home',
+			'noapi'      => True
+	));
 	include('./inc/functions.inc.php');
 
 	// Authorize the user to use setup app and load the database
-	if(!$GLOBALS['phpgw_setup']->auth('Config'))
+	if(!$GLOBALS['egw_setup']->auth('Config'))
 	{
 		Header('Location: index.php');
 		exit;
@@ -39,10 +39,10 @@
 	$phpgw->common = CreateObject('phpgwapi.common');
 
 	$common = $phpgw->common;
-	$GLOBALS['phpgw_setup']->loaddb();
-	$phpgw->db = $GLOBALS['phpgw_setup']->db;
+	$GLOBALS['egw_setup']->loaddb();
+	$phpgw->db = $GLOBALS['egw_setup']->db;
 
-	$tpl_root = $GLOBALS['phpgw_setup']->html->setup_tpl_dir('setup');
+	$tpl_root = $GLOBALS['egw_setup']->html->setup_tpl_dir('setup');
 	$setup_tpl = CreateObject('setup.Template',$tpl_root);
 	$setup_tpl->set_file(array(
 		'ldap'   => 'ldap.tpl',
@@ -51,23 +51,25 @@
 		'T_alert_msg' => 'msg_alert_msg.tpl'
 	));
 
-	$phpgw_info['server']['auth_type'] = 'ldap';
+	$GLOBALS['egw_info']['server']['auth_type'] = 'ldap';
 
 	$phpgw->applications = CreateObject('phpgwapi.applications');
 	$applications        = $phpgw->applications;
 
-	$GLOBALS['phpgw_setup']->db->query("SELECT config_name,config_value FROM phpgw_config WHERE config_name LIKE 'ldap%' OR config_name='account_repository'",__LINE__,__FILE__);
-	while($GLOBALS['phpgw_setup']->db->next_record())
+	$GLOBALS['egw_setup']->db->select($GLOBALS['egw_setup']->config_table,'config_name,config_value',array(
+		"config_name LIKE 'ldap%' OR config_name='account_repository'",
+	),__LINE__,__FILE__);
+	while($GLOBALS['egw_setup']->db->next_record())
 	{
-		$config[$GLOBALS['phpgw_setup']->db->f('config_name')] = $GLOBALS['phpgw_setup']->db->f('config_value');
+		$config[$GLOBALS['egw_setup']->db->f('config_name')] = $GLOBALS['egw_setup']->db->f('config_value');
 	}
-	$phpgw_info['server']['ldap_host']          = $config['ldap_host'];
-	$phpgw_info['server']['ldap_context']       = $config['ldap_context'];
-	$phpgw_info['server']['ldap_group_context'] = $config['ldap_group_context'];
-	$phpgw_info['server']['ldap_root_dn']       = $config['ldap_root_dn'];
-	$phpgw_info['server']['ldap_root_pw']       = $config['ldap_root_pw'];
-	$phpgw_info['server']['ldap_version3']      = $config['ldap_version3'] == "True" ? True : False;
-	$phpgw_info['server']['account_repository'] = $config['account_repository'];
+	$GLOBALS['egw_info']['server']['ldap_host']          = $config['ldap_host'];
+	$GLOBALS['egw_info']['server']['ldap_context']       = $config['ldap_context'];
+	$GLOBALS['egw_info']['server']['ldap_group_context'] = $config['ldap_group_context'];
+	$GLOBALS['egw_info']['server']['ldap_root_dn']       = $config['ldap_root_dn'];
+	$GLOBALS['egw_info']['server']['ldap_root_pw']       = $config['ldap_root_pw'];
+	$GLOBALS['egw_info']['server']['ldap_version3']      = $config['ldap_version3'] == "True" ? True : False;
+	$GLOBALS['egw_info']['server']['account_repository'] = $config['account_repository'];
 
 	$phpgw->accounts     = CreateObject('phpgwapi.accounts');
 	$acct                = $phpgw->accounts;
@@ -87,52 +89,51 @@
 		exit;
 	}
 
-	$sr = ldap_search($ldap,$config['ldap_context'],'(|(uid=*))',array('sn','givenname','uid','uidnumber'));
+	$sr = ldap_search($ldap,$config['ldap_context'],'(|(uid=*))',array('sn','givenname','uid','uidnumber','email','gidnumber'));
 	$info = ldap_get_entries($ldap, $sr);
-	$tmp = '';
-
+	$account_info = $group_info = array();
+	
 	for($i=0; $i<$info['count']; $i++)
 	{
-		if(!$phpgw_info['server']['global_denied_users'][$info[$i]['uid'][0]])
+		if(!$GLOBALS['egw_info']['server']['global_denied_users'][$info[$i]['uid'][0]])
 		{
-			$tmp = $info[$i]['uidnumber'][0];
-			$account_info[$tmp]['account_id']        = $info[$i]['uidnumber'][0];
-			$account_info[$tmp]['account_lid']       = $info[$i]['uid'][0];
-			$account_info[$tmp]['account_firstname'] = $info[$i]['givenname'][0];
-			$account_info[$tmp]['account_lastname']  = $info[$i]['sn'][0];
-			$account_info[$tmp]['account_passwd']    = $info[$i]['userpassword'][0];
+			$account_info[$info[$i]['uidnumber'][0]] = array(
+				'account_id'        => $info[$i]['uidnumber'][0],
+				'account_lid'       => $info[$i]['uid'][0],
+				'account_firstname' => $info[$i]['givenname'][0],
+				'account_lastname'  => $info[$i]['sn'][0],
+				'account_passwd'    => $info[$i]['userpassword'][0],
+				'account_email'     => $info[$i]['email'][0],
+				'account_primary_group' => -$info[$i]['gidnumber'][0],
+			);
 		}
 	}
 
-	if($phpgw_info['server']['ldap_group_context'])
+	if($GLOBALS['egw_info']['server']['ldap_group_context'])
 	{
 		$srg = ldap_search($ldap,$config['ldap_group_context'],'(|(cn=*))',array('gidnumber','cn','memberuid'));
 		$info = ldap_get_entries($ldap, $srg);
-		$tmp = '';
 
 		for($i=0; $i<$info['count']; $i++)
 		{
-			if(!$phpgw_info['server']['global_denied_groups'][$info[$i]['cn'][0]] &&
+			if(!$GLOBALS['egw_info']['server']['global_denied_groups'][$info[$i]['cn'][0]] &&
 				!$account_info[$i][$info[$i]['cn'][0]])
 			{
-				$tmp = $info[$i]['gidnumber'][0];
-				$group_info[$tmp]['account_id']        = $info[$i]['gidnumber'][0];
-				$group_info[$tmp]['account_lid']       = $info[$i]['cn'][0];
-				$group_info[$tmp]['members']           = $info[$i]['memberuid'];
-				$group_info[$tmp]['account_firstname'] = $info[$i]['cn'][0];
-				$group_info[$tmp]['account_lastname']  = 'Group';
+				$group_info[-$info[$i]['gidnumber'][0]] = array(
+					'account_id'        => -$info[$i]['gidnumber'][0],
+					'account_lid'       => $info[$i]['cn'][0],
+					'members'           => $info[$i]['memberuid'],
+					'account_firstname' => $info[$i]['cn'][0],
+					'account_lastname'  => 'Group'
+				);
 			}
 		}
 	}
-	else
-	{
-		$group_info = array();
-	}
 
-	$GLOBALS['phpgw_setup']->db->query("SELECT app_name FROM phpgw_applications WHERE app_enabled!='0' AND app_enabled!='3' ORDER BY app_name",__LINE__,__FILE__);
-	while($GLOBALS['phpgw_setup']->db->next_record())
+	$GLOBALS['egw_setup']->db->select($GLOBALS['egw_setup']->applications_table,'app_name','app_enabled != 0 AND app_enabled != 3',__LINE__,__FILE__);
+	while($GLOBALS['egw_setup']->db->next_record())
 	{
-		$apps[$GLOBALS['phpgw_setup']->db->f('app_name')] = lang($GLOBALS['phpgw_setup']->db->f('app_name'));
+		$apps[$GLOBALS['egw_setup']->db->f('app_name')] = lang($GLOBALS['egw_setup']->db->f('app_name'));
 	}
 
 	$cancel = get_var('cancel','POST');
@@ -152,32 +153,27 @@
 	{
 		if(!count($admins))
 		{
-			$error = '<br>You must select at least 1 admin';
+			$error = '<br />You must select at least 1 admin';
 		}
 
 		if(!count($s_apps))
 		{
-			$error .= '<br>You must select at least 1 application';
+			$error .= '<br />You must select at least 1 application';
 		}
 
 		if(!$error)
 		{
 			if($users)
 			{
-				while(list($key,$id) = each($users))
+				foreach($users as $id) 
 				{
-					$id_exist = 0;
 					$thisacctid    = $account_info[$id]['account_id'];
 					$thisacctlid   = $account_info[$id]['account_lid'];
-					$thisfirstname = $account_info[$id]['account_firstname'];
-					$thislastname  = $account_info[$id]['account_lastname'];
-					$thispasswd    = $account_info[$id]['account_passwd'];
 
 					// Do some checks before we try to import the data.
 					if(!empty($thisacctid) && !empty($thisacctlid))
 					{
-						$accounts = CreateObject('phpgwapi.accounts',(int)$thisacctid);
-						copyobj($GLOBALS['phpgw_setup']->db,$accounts->db);
+						$accounts =& CreateObject('phpgwapi.accounts',(int)$thisacctid);
 
 						// Check if the account is already there.
 						// If so, we won't try to create it again.
@@ -190,17 +186,11 @@
 						// If not, create it now.
 						if(!$id_exist)
 						{
-							$thisaccount_info = array(
+							$thisacctid = $accounts->create($account_info[$id]+array(
 								'account_type'      => 'u',
-								'account_lid'       => $thisacctlid,
-								'account_passwd'    => 'x',
-							/*	'account_passwd'    => $thispasswd, */
-								'account_firstname' => $thisfirstname,
-								'account_lastname'  => $thislastname,
 								'account_status'    => 'A',
-								'account_expires'   => -1
-							);
-							$thisacctid = $accounts->create($thisaccount_info);
+								'account_expires'   => -1,
+							));
 						}
 						if (!$thisacctid)	// if we have no account_id, we cant continue
 						{
@@ -211,7 +201,7 @@
 						//  these rights.  Instead, we make the user a member of the Default group
 						//  below.
 						$acl = CreateObject('phpgwapi.acl',(int)$thisacctid);
-						$acl->db = $GLOBALS['phpgw_setup']->db;
+						$acl->db = $GLOBALS['egw_setup']->db;
 						$acl->read_repository();
 
 						// Only give them admin if we asked for them to have it.
@@ -246,7 +236,7 @@
 
 			if($ldapgroups)
 			{
-				while(list($key,$groupid) = each($ldapgroups))
+				foreach($ldapgroups as $groupid)
 				{
 					$id_exist = 0;
 					$thisacctid    = $group_info[$groupid]['account_id'];
@@ -259,7 +249,6 @@
 					if(!empty($thisacctid) && !empty($thisacctlid))
 					{
 						$groups = CreateObject('phpgwapi.accounts',(int)$thisacctid);
-						copyobj($GLOBALS['phpgw_setup']->db,$groups->db);
 
 						// Check if the account is already there.
 						// If so, we won't try to create it again.
@@ -273,34 +262,33 @@
 						// If not, create it now.
 						if(!$id_exist)
 						{
-							$thisgroup_info = array(
+							$thisacctid = $groups->create(array(
 								'account_type'      => 'g',
 								'account_lid'       => $thisacctlid,
-								'account_passwd'    => $passwd,
+								'account_passwd'    => 'x',
 								'account_firstname' => $thisfirstname,
 								'account_lastname'  => $thislastname,
 								'account_status'    => 'A',
 								'account_expires'   => -1
-							);
-							$thisacctid = $groups->create($thisgroup_info);
+							));
 						}
 						if (!$thisacctid)	// if we have no account_id, we cant continue
 						{
 							continue;
 						}
 						// Now make them a member of this group in phpgw.
-						while(list($key,$members) = each($thismembers))
+						foreach($thismembers as $key =>$members)
 						{
 							if($key == 'count')
 							{
 								continue;
 							}
-							/* echo '<br>members: ' . $members; */
+							/* echo '<br />members: ' . $members; */
 							$tmpid = 0;
 							@reset($account_info);
 							while(list($x,$y) = each($account_info))
 							{
-								/* echo '<br>checking: '.$y['account_lid']; */
+								/* echo '<br />checking: '.$y['account_lid']; */
 								if($members == $y['account_lid'])
 								{
 									$tmpid = $acct->name2id($y['account_lid']);
@@ -314,7 +302,6 @@
 							if($tmpid)
 							{
 								$acl = CreateObject('phpgwapi.acl',$tmpid);
-								copyobj($GLOBALS['phpgw_setup']->db,$acl->db);
 								$acl->account_id = (int)$tmpid;
 								$acl->read_repository();
 
@@ -331,7 +318,7 @@
 									App access is added below.
 								*/
 								$pref = CreateObject('phpgwapi.preferences',$tmpid);
-								$pref->db = $GLOBALS['phpgw_setup']->db;
+								$pref->db = $GLOBALS['egw_setup']->db;
 								$pref->account_id = (int)$tmpid;
 								$pref->read_repository();
 								@reset($s_apps);
@@ -343,9 +330,8 @@
 							}
 						}
 						/* Now give this group some rights */
-						$phpgw_info['user']['account_id'] = $thisacctid;
+						$GLOBALS['egw_info']['user']['account_id'] = $thisacctid;
 						$acl = CreateObject('phpgwapi.acl');
-						copyobj($GLOBALS['phpgw_setup']->db,$acl->db);
 						$acl->account_id = (int)$thisacctid;
 						$acl->read_repository();
 						@reset($s_apps);
@@ -363,7 +349,6 @@
 			{
 				/* Create the 'Default' group */
 				$groups = CreateObject('phpgwapi.accounts',$defaultgroupid);
-				copyobj($GLOBALS['phpgw_setup']->db,$groups->db);
 
 				// Check if the group account is already there.
 				// If so, set our group_id to that account's id for use below.
@@ -387,12 +372,9 @@
 					'account_status'    => 'A',
 					'account_expires'   => -1
 				);
-				$acct->create($thisgroup_info);
-
-				$defaultgroupid = $acct->name2id('Default');
+				$defaultgroupid = $acct->create($thisgroup_info);
 
 				$acl = CreateObject('phpgwapi.acl',$defaultgroupid);
-				copyobj($GLOBALS['phpgw_setup']->db,$acl->db);
 				$acl->account_id = (int)$defaultgroupid;
 				$acl->read_repository();
 				@reset($s_apps);
@@ -407,18 +389,18 @@
 		$setup_complete = True;
 	}
 
-	$GLOBALS['phpgw_setup']->html->show_header(lang('LDAP Import'),False,'config',$GLOBALS['phpgw_setup']->ConfigDomain . '(' . $phpgw_domain[$GLOBALS['phpgw_setup']->ConfigDomain]['db_type'] . ')');
+	$GLOBALS['egw_setup']->html->show_header(lang('LDAP Import'),False,'config',$GLOBALS['egw_setup']->ConfigDomain . '(' . $GLOBALS['egw_domain'][$GLOBALS['egw_setup']->ConfigDomain]['db_type'] . ')');
 
 	if($error)
 	{
-		//echo '<br><center><b>Error:</b> '.$error.'</center>';
-		$GLOBALS['phpgw_setup']->html->show_alert_msg('Error',$error);
+		//echo '<br /><center><b>Error:</b> '.$error.'</center>';
+		$GLOBALS['egw_setup']->html->show_alert_msg('Error',$error);
 	}
 
 	if($setup_complete)
 	{
-		echo '<br><center>'.lang('Import has been completed!').' '.lang('Click <a href="index.php">here</a> to return to setup.').'</center>';
-		$GLOBALS['phpgw_setup']->html->show_footer();
+		echo '<br /><center>'.lang('Import has been completed!').' '.lang('Click <a href="index.php">here</a> to return to setup.').'</center>';
+		$GLOBALS['egw_setup']->html->show_footer();
 		exit;
 	}
 
@@ -467,7 +449,7 @@
 		}
 		else
 		{
-			$app_list .= '<option value="' . $appname . '" selected>' . $apptitle . '</option>';
+			$app_list .= '<option value="' . $appname . '" selected="selected">' . $apptitle . '</option>';
 		}
 	}
 
@@ -495,5 +477,5 @@
 	$setup_tpl->pfp('out','submit');
 	$setup_tpl->pfp('out','footer');
 
-	$GLOBALS['phpgw_setup']->html->show_footer();
+	$GLOBALS['egw_setup']->html->show_footer();
 ?>
