@@ -9,28 +9,28 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: schematoy.php,v 1.15.2.1 2005/09/03 18:19:49 milosch Exp $ */
+  /* $Id: schematoy.php 20295 2006-02-15 12:31:25Z  $ */
 
 	$GLOBALS['DEBUG'] = True;
 
-	$phpgw_info = array();
-	$GLOBALS['phpgw_info']['flags'] = array(
-		'noheader' => True,
-		'nonavbar' => True,
-		'currentapp' => 'home',
-		'noapi' => True
-	);
+	$GLOBALS['egw_info'] = array(
+		'flags' => array(
+			'noheader' => True,
+			'nonavbar' => True,
+			'currentapp' => 'home',
+			'noapi' => True
+	));
 	include ('./inc/functions.inc.php');
 
 	// Check header and authentication
-	if (!$GLOBALS['phpgw_setup']->auth('Config'))
+	if (!$GLOBALS['egw_setup']->auth('Config'))
 	{
 		Header('Location: index.php');
 		exit;
 	}
 	// Does not return unless user is authorized
 
-	$tpl_root = $GLOBALS['phpgw_setup']->html->setup_tpl_dir('setup');
+	$tpl_root = $GLOBALS['egw_setup']->html->setup_tpl_dir('setup');
 	$GLOBALS['setup_tpl'] = CreateObject('setup.Template',$tpl_root);
 	$GLOBALS['setup_tpl']->set_file(array(
 		'T_head' => 'head.tpl',
@@ -86,16 +86,16 @@
 		}
 	}
 
-	$GLOBALS['phpgw_setup']->loaddb();
-	$GLOBALS['phpgw_info']['setup']['stage']['db'] = $GLOBALS['phpgw_setup']->detection->check_db();
+	$GLOBALS['egw_setup']->loaddb();
+	$GLOBALS['egw_info']['setup']['stage']['db'] = $GLOBALS['egw_setup']->detection->check_db();
 
-	$GLOBALS['setup_info'] = $GLOBALS['phpgw_setup']->detection->get_versions();
+	$GLOBALS['setup_info'] = $GLOBALS['egw_setup']->detection->get_versions();
 	//var_dump($GLOBALS['setup_info']);exit;
-	$GLOBALS['setup_info'] = $GLOBALS['phpgw_setup']->detection->get_db_versions($GLOBALS['setup_info']);
+	$GLOBALS['setup_info'] = $GLOBALS['egw_setup']->detection->get_db_versions($GLOBALS['setup_info']);
 	//var_dump($GLOBALS['setup_info']);exit;
-	$GLOBALS['setup_info'] = $GLOBALS['phpgw_setup']->detection->compare_versions($GLOBALS['setup_info']);
+	$GLOBALS['setup_info'] = $GLOBALS['egw_setup']->detection->compare_versions($GLOBALS['setup_info']);
 	//var_dump($GLOBALS['setup_info']);exit;
-	$GLOBALS['setup_info'] = $GLOBALS['phpgw_setup']->detection->check_depends($GLOBALS['setup_info']);
+	$GLOBALS['setup_info'] = $GLOBALS['egw_setup']->detection->check_depends($GLOBALS['setup_info']);
 	//var_dump($GLOBALS['setup_info']);exit;
 	@ksort($GLOBALS['setup_info']);
 
@@ -105,7 +105,7 @@
 		exit;
 	}
 
-	$GLOBALS['phpgw_setup']->html->show_header(lang("Developers' Table Schema Toy"),False,'config',$GLOBALS['phpgw_setup']['ConfigDomain']);
+	$GLOBALS['egw_setup']->html->show_header(lang("Developers' Table Schema Toy"),False,'config',$GLOBALS['egw_setup']['ConfigDomain']);
 
 	if(get_var('submit',Array('POST')))
 	{
@@ -123,11 +123,11 @@
 			$terror[$appname]['version'] = $version[$appname];
 			$terror[$appname]['status'] = 'U';
 
-			$appdir  = PHPGW_SERVER_ROOT . SEP . $appname . SEP . 'setup' . SEP;
+			$appdir  = EGW_SERVER_ROOT . SEP . $appname . SEP . 'setup' . SEP;
 
 			// Drop newest tables
 			$terror[$appname]['tables'] = $GLOBALS['setup_info'][$appname]['tables'];
-			$GLOBALS['phpgw_setup']->process->droptables($terror,$GLOBALS['DEBUG']);
+			$GLOBALS['egw_setup']->process->droptables($terror,$GLOBALS['DEBUG']);
 			$terror[$appname]['tables'] = array();
 
 			// Reset tables field to baseline table names
@@ -137,36 +137,36 @@
 				while(list($table,$null) = @each($phpgw_baseline))
 				{
 					$terror[$appname]['tables'][] = $table;
-					echo '<br>Adding app table: ' . $table;
+					echo '<br />Adding app table: ' . $table;
 				}
 			}
 
 			if($version[$appname])
 			{
-				echo '<br>Processing ' . $terror[$appname]['name'] . ' to ' . $version[$appname];
+				echo '<br />Processing ' . $terror[$appname]['name'] . ' to ' . $version[$appname];
 
-				$terror = $GLOBALS['phpgw_setup']->process->droptables($terror,$GLOBALS['DEBUG']);
-				$GLOBALS['phpgw_setup']->deregister_app($terror[$appname]['name']);
+				$terror = $GLOBALS['egw_setup']->process->droptables($terror,$GLOBALS['DEBUG']);
+				$GLOBALS['egw_setup']->deregister_app($terror[$appname]['name']);
 
-				$terror = $GLOBALS['phpgw_setup']->process->baseline($terror,$GLOBALS['DEBUG']);
-				$terror = $GLOBALS['phpgw_setup']->process->test_data($terror,$GLOBALS['DEBUG']);
+				$terror = $GLOBALS['egw_setup']->process->baseline($terror,$GLOBALS['DEBUG']);
+				$terror = $GLOBALS['egw_setup']->process->test_data($terror,$GLOBALS['DEBUG']);
 
-				$terror = $GLOBALS['phpgw_setup']->process->upgrade($terror,$GLOBALS['DEBUG']);
+				$terror = $GLOBALS['egw_setup']->process->upgrade($terror,$GLOBALS['DEBUG']);
 				$terror[$appname]['version'] = $version[$appname];
 			}
 			else
 			{
-				echo '<br>Baseline-only completed for ' . $terror[$appname]['name'];
+				echo '<br />Baseline-only completed for ' . $terror[$appname]['name'];
 			}
-			echo '<br>' . $GLOBALS['setup_info'][$appname]['title'] . ' '
+			echo '<br />' . $GLOBALS['setup_info'][$appname]['title'] . ' '
 				. lang('tables installed, unless there are errors printed above') . '.';
 
 			$GLOBALS['setup_info'][$appname]['version'] = $terror[$appname]['version'];
-			$GLOBALS['phpgw_setup']->register_app($appname);
-			echo '<br>' . $terror[$appname]['title'] . ' ' . lang('registered') . '.';
+			$GLOBALS['egw_setup']->register_app($appname);
+			echo '<br />' . $terror[$appname]['title'] . ' ' . lang('registered') . '.';
 		}
 
-		echo '<br><a href="schematoy.php">' . lang('Go back') . '</a>';
+		echo '<br /><a href="schematoy.php">' . lang('Go back') . '</a>';
 		$GLOBALS['setup_tpl']->pparse('out','footer');
 		exit;
 	}
@@ -177,7 +177,7 @@
 		@reset($GLOBALS['setup_info'][$detail]);
 		$GLOBALS['setup_tpl']->set_var('description',lang('App details') . ':');
 		$GLOBALS['setup_tpl']->pparse('out','header');
-		
+
 		while (list($key,$val) = each($GLOBALS['setup_info'][$detail]))
 		{
 			if ($i) { $i = 0; }
@@ -203,13 +203,13 @@
 			$GLOBALS['setup_tpl']->pparse('out','detail');
 		}
 
-		echo '<br><a href="schematoy.php">' . lang('Go back') . '</a>';
+		echo '<br /><a href="schematoy.php">' . lang('Go back') . '</a>';
 		$GLOBALS['setup_tpl']->pparse('out','footer');
 		exit;
 	}
 	else
 	{
-		$GLOBALS['setup_tpl']->set_var('description',lang("Select an app, enter a target version, then submit to process to that version.<br>If you do not enter a version, only the baseline tables will be installed for the app.<br><blink>THIS WILL DROP ALL OF THE APPS' TABLES FIRST!</blink>"));
+		$GLOBALS['setup_tpl']->set_var('description',lang("Select an app, enter a target version, then submit to process to that version.<br />If you do not enter a version, only the baseline tables will be installed for the app.<br /><blink>THIS WILL DROP ALL OF THE APPS' TABLES FIRST!</blink>"));
 		$GLOBALS['setup_tpl']->pparse('out','header');
 
 		$GLOBALS['setup_tpl']->set_var('appdata',lang('Application Data'));
@@ -225,9 +225,9 @@
 		while (list ($key, $value) = each ($GLOBALS['setup_info']))
 		{
 			unset($test);
-			if (file_exists(PHPGW_SERVER_ROOT . '/' . $value['name'] . '/setup/tables_update.inc.php'))
+			if (file_exists(EGW_SERVER_ROOT . '/' . $value['name'] . '/setup/tables_update.inc.php'))
 			{
-				include(PHPGW_SERVER_ROOT . '/' . $value['name'] . '/setup/tables_update.inc.php');
+				include(EGW_SERVER_ROOT . '/' . $value['name'] . '/setup/tables_update.inc.php');
 			}
 
 			if (is_array($test))
@@ -258,7 +258,7 @@
 
 				$GLOBALS['setup_tpl']->set_var('instimg','completed.png');
 				$GLOBALS['setup_tpl']->set_var('instalt',lang('Completed'));
-				$GLOBALS['setup_tpl']->set_var('install','<input type="checkbox" name="install[' . $value['name'] . ']">');
+				$GLOBALS['setup_tpl']->set_var('install','<input type="checkbox" name="install[' . $value['name'] . ']" />');
 				$status = lang('OK') . ' - ' . $value['status'];
 
 				$GLOBALS['setup_tpl']->set_var('appinfo',$value['name'] . '-' . $status);
@@ -272,5 +272,5 @@
 	$GLOBALS['setup_tpl']->set_var('cancel',lang('Cancel'));
 	$GLOBALS['setup_tpl']->pparse('out','app_footer');
 	$GLOBALS['setup_tpl']->pparse('out','footer');
-	$GLOBALS['phpgw_setup']->html->show_footer();
+	$GLOBALS['egw_setup']->html->show_footer();
 ?>
