@@ -10,7 +10,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.Categories_SO.inc.php,v 1.22.2.4 2004/11/17 15:01:16 ralfbecker Exp $ */
+	/* $Id: class.Categories_SO.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	class Categories_SO
 	{
@@ -20,11 +20,11 @@
 		
 		function Categories_SO()
 		{
-			$this->cats = CreateObject('phpgwapi.categories',-1,'sitemgr');
-			$this->db = $GLOBALS['phpgw']->db;
+			$this->cats =& CreateObject('phpgwapi.categories',-1,'sitemgr');
+			$this->db = clone($GLOBALS['egw']->db);
 			$this->db->set_app('sitemgr');
-			$this->state_table = 'phpgw_sitemgr_categories_state';
-			$this->lang_table = 'phpgw_sitemgr_categories_lang';
+			$this->state_table = 'egw_sitemgr_categories_state';
+			$this->lang_table = 'egw_sitemgr_categories_lang';
 		}
 
 		function isactive($cat_id,$states=false)
@@ -37,8 +37,8 @@
 				'cat_id' => $cat_id,
 				'state'  => $states,
 			),__LINE__,__FILE__);
-
-			return $this->db->next_record();
+			
+			return $this->db->num_rows();
 		}
 
 		function getChildrenIDList($parent)
@@ -47,6 +47,8 @@
 			$order_by = 'cat_data';
 			switch($this->db->Type)
 			{
+				case 'sapdb': case 'maxdb':
+					break;  // cant cast text/LONG to int
 				case 'mysql':
 					// cast is mysql 4 only and has differnt types, eg. CAST(cat_data AS signed)
 					$order_by = "round($order_by)";
@@ -72,10 +74,10 @@
 		function addCategory($name, $description, $parent = False)
 		{
 			$cat_id = (int) $this->cats->add(array(
-				'name'		=> $name,
-				'descr'		=> $description,
-				'access'	=> 'public',
-				'parent'	=> $parent,
+				'name'    => $name,
+				'descr'   => $description,
+				'access'  => 'public',
+				'parent'  => $parent,
 				'old_parent' => $parent
 			));
 			$this->db->insert($this->state_table,array('cat_id'=>$cat_id),False, __LINE__,__FILE__);
@@ -97,17 +99,17 @@
 		{
 			$data = array
 			(
-				'name'		=> $cat_info->name,
-				'descr'		=> $cat_info->description,
-				'data'		=> sprintf('%04d',$cat_info->sort_order),
-				'access'	=> 'public',
-				'id'		=> (int) $cat_info->id,
-				'parent'	=> (int) $cat_info->parent,
+				'name'    => $cat_info->name,
+				'descr'   => $cat_info->description,
+				'data'    => sprintf('%04d',$cat_info->sort_order),
+				'access'  => 'public',
+				'id'    => (int) $cat_info->id,
+				'parent'  => (int) $cat_info->parent,
 				'old_parent' => (int) $cat_info->old_parent,
 			);
 			$this->cats->edit($data);
 
-			$this->db->update($this->state_table,array(
+			return $this->db->update($this->state_table,array(
 				'state' => $cat_info->state,
 				'index_page_id' => $cat_info->index_page_id,
 			),array('cat_id'=>$cat_info->id),__LINE__,__FILE__);
@@ -115,7 +117,7 @@
 
 		function saveCategoryLang($cat_id, $cat_name, $cat_description, $lang)
 		{
-			$this->db->insert($this->lang_table,array(
+			return $this->db->insert($this->lang_table,array(
 				'name'   => $cat_name,
 				'description' => $cat_description,
 			),array(
@@ -141,12 +143,12 @@
 
 			if (is_array($cat))
 			{
-				$cat_info				= CreateObject('sitemgr.Category_SO', True);
-				$cat_info->id			= $cat['id'];
-				$cat_info->sort_order	= (int) $cat['data'];
-				$cat_info->parent		= $cat['parent'];
-				$cat_info->depth		= $cat['level'];
-				$cat_info->root			= $cat['main'];
+				$cat_info       =& CreateObject('sitemgr.Category_SO', True);
+				$cat_info->id     = $cat['id'];
+				$cat_info->sort_order = (int) $cat['data'];
+				$cat_info->parent   = $cat['parent'];
+				$cat_info->depth    = $cat['level'];
+				$cat_info->root     = $cat['main'];
 
 				$this->db->select($this->state_table,array('state','index_page_id'),array('cat_id'=>$cat_id),__LINE__,__FILE__);
 				if ($this->db->next_record())
@@ -166,12 +168,12 @@
 						$cat_info->description = stripslashes($this->db->f('description'));
 					}
 				}
-				else	//if there is no lang argument we return the content in whatever languages turns up first
+				else  //if there is no lang argument we return the content in whatever languages turns up first
 				{
 					$this->db->select($this->lang_table,'*',array('cat_id' => $cat_id,),__LINE__,__FILE__);
 					if ($this->db->next_record())
 					{
-						$cat_info->name	= stripslashes($this->db->f('name'));
+						$cat_info->name = stripslashes($this->db->f('name'));
 						$cat_info->description = stripslashes($this->db->f('description'));
 						$cat_info->lang = $this->db->f('lang');
 					}
