@@ -11,11 +11,13 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.Content_SO.inc.php,v 1.18.2.2 2005/04/15 14:57:33 ralfbecker Exp $ */
+	/* $Id: class.Content_SO.inc.php 20295 2006-02-15 12:31:25Z  $ */
+
+	require_once(EGW_SERVER_ROOT . '/sitemgr/inc/class.Block_SO.inc.php');
 
 	class Content_SO
 	{
-		var $db;	/* @var $db db */
+		var $db;  /* @var $db db */
 		// Name of the differnt tables, initialised in the constructor
 		var $content_table,$content_lang_table,$blocks_table,$blocks_lang_table,$modules_table,$modules_lang_table;
 
@@ -24,12 +26,12 @@
 		 */
 		function Content_SO()
 		{
-			$this->db = $GLOBALS['phpgw']->db; 
+			$this->db = clone($GLOBALS['egw']->db); 
 			$this->db->set_app('sitemgr');
 			foreach(array('content','content_lang','blocks','blocks_lang','modules','modules_lang') as $name)
 			{
 				$var = $name.'_table';
-				$this->$var = 'phpgw_sitemgr_'.$name;	// only reference to the db-prefix
+				$this->$var = 'egw_sitemgr_'.$name; // only reference to the db-prefix
 			}
 		}
 
@@ -41,12 +43,12 @@
 		function addblock($block)
 		{
 			$this->db->insert($this->blocks_table,array(
-				'area'		=> $block->area,
-				'module_id'	=> $block->module_id,
-				'page_id'	=> $block->page_id,
-				'cat_id'	=> $block->cat_id,
+				'area'    => $block->area,
+				'module_id' => $block->module_id,
+				'page_id' => $block->page_id,
+				'cat_id'  => $block->cat_id,
 				'sort_order'=> 0,
-				'viewable'	=> 0,
+				'viewable'  => 0,
 			),False,__LINE__,__FILE__);
 
 			return $this->db->get_last_insert_id($this->blocks_table,'block_id');
@@ -63,10 +65,10 @@
 		function updatescope($blockid,$cat_id,$page_id)
 		{
 			$this->db->update($this->blocks_table,array(
-				'cat_id'	=> $cat_id,
-				'page_id'	=> $page_id,
+				'cat_id'  => $cat_id,
+				'page_id' => $page_id,
 			),array(
-				'block_id'	=> $blockid,
+				'block_id'  => $blockid,
 			),__LINE__,__FILE__);
 
 			return $this->db->affected_rows();
@@ -80,8 +82,8 @@
 		function createversion($blockid)
 		{
 			return $this->db->insert($this->content_table,array(
-				'block_id'	=> $blockid,
-				'state'		=>	SITEMGR_STATE_DRAFT,
+				'block_id'  => $blockid,
+				'state'   =>  SITEMGR_STATE_DRAFT,
 			),False,__LINE__,__FILE__);
 		}
 
@@ -93,9 +95,9 @@
 		function deleteversion($versionid)
 		{
 			if (!$this->db->delete($this->content_table,array('version_id'=>$versionid),__LINE__,__FILE__))
- 			{
- 				return False;
- 			}
+			{
+				return False;
+			}
 			return $this->db->delete($this->content_lang_table,array('version_id'=>$versionid),__LINE__,__FILE__);
 		}
 
@@ -118,11 +120,11 @@
 		 */
 		function removeblock($blockid)
 		{
- 			if (!$this->db->delete($this->blocks_table,array('block_id'=>$blockid),__LINE__,__FILE__))
- 			{
+			if (!$this->db->delete($this->blocks_table,array('block_id'=>$blockid),__LINE__,__FILE__))
+			{
 				return false;
 			}
- 			return $this->db->delete($this->blocks_lang_table,array('block_id'=>$blockid),__LINE__,__FILE__);
+			return $this->db->delete($this->blocks_lang_table,array('block_id'=>$blockid),__LINE__,__FILE__);
 		}
 
 		/**
@@ -131,24 +133,19 @@
 		 * @param int $page_id page-id or 0 for cat- or site-wide blocks
 		 * @return array of block-objects, with only block-id, module-id & -name and content-area set
 		 */
-		function getblocksforscope($cat_id,$page_id)
+		function &getblocksforscope($cat_id,$page_id)
 		{
-			$sql = $this->db->expression($this->blocks_table,"SELECT t1.block_id,t1.module_id,module_name,area FROM $this->blocks_table AS t1,$this->modules_table AS t2 WHERE t1.module_id = t2.module_id AND ",array(
-				'cat_id'	=> $cat_id,
-				'page_id'	=> $page_id,
+			$sql = $this->db->expression($this->blocks_table,"SELECT t1.block_id AS id,t1.module_id,module_name,area FROM $this->blocks_table AS t1,$this->modules_table AS t2 WHERE t1.module_id = t2.module_id AND ",array(
+				'cat_id'  => $cat_id,
+				'page_id' => $page_id,
 			),' ORDER BY sort_order');
 
 			$this->db->query($sql,__LINE__,__FILE__);
 
-			$block = CreateObject('sitemgr.Block_SO',True);
 			$result = array();
-			while ($this->db->next_record())
+			while (($row = $this->db->row(true)))
 			{
-				$block->id = $this->db->f('block_id');
-				$block->module_id = $this->db->f('module_id');
-				$block->module_name = $this->db->f('module_name');
-				$block->area = $this->db->f('area');
-				$result[$block->id] = $block;
+				$result[$row['id']] =& new Block_SO($row);
 			}
 			return $result;
 		}
@@ -164,7 +161,7 @@
 		function getallblocksforarea($area,$cat_list,$page_id,$lang)
 		{
 			$lang = $this->db->quote($lang);
-			$sql = "SELECT t1.block_id, area, cat_id, page_id, t1.module_id, module_name, sort_order, title, viewable".
+			$sql = "SELECT t1.block_id AS id, area, cat_id, page_id, t1.module_id, module_name, sort_order, title, viewable AS view".
 				" FROM $this->blocks_table AS t1".
 				" LEFT JOIN $this->modules_table AS t2 ON t1.module_id=t2.module_id".
 				" LEFT JOIN $this->blocks_lang_table AS t3 ON (t1.block_id=t3.block_id AND t3.lang=$lang) ".
@@ -173,10 +170,10 @@
 					'('
 				));
 				
-			$cat_list[] = CURRENT_SITE_ID;	// always included
+			$cat_list[] = CURRENT_SITE_ID;  // always included
 			$sql .= $this->db->expression($this->block_table,array(
-				'page_id'	=> 0,
-				'cat_id'	=> $cat_list,
+				'page_id' => 0,
+				'cat_id'  => $cat_list,
 			));
 			if ($page_id)
 			{
@@ -186,20 +183,10 @@
 
 			$this->db->query($sql,__LINE__,__FILE__);
 
-			$block = CreateObject('sitemgr.Block_SO',True);
 			$result = array();
-			while ($this->db->next_record())
+			while (($row = $this->db->row(true)))
 			{
-				$block->id = $this->db->f('block_id');
-				$block->area = $this->db->f('area');
-				$block->cat_id = $this->db->f('cat_id');
-				$block->page_id = $this->db->f('page_id');
-				$block->module_id = $this->db->f('module_id');
-				$block->module_name = $this->db->f('module_name');
-				$block->sort_order = $this->db->f('sort_order');
-				$block->title = stripslashes($this->db->f('title'));
-				$block->view = $this->db->f('viewable');
-				$result[$block->id] = $block;
+				$result[$row['id']] =& new Block_SO($row);
 			}
 			return $result;
 		}
@@ -243,9 +230,9 @@
 			$result = array();
 			while ($this->db->next_record())
 			{
- 				$version['arguments'] = array_merge(
- 					unserialize($this->db->f('arguments')),
- 					unserialize($this->db->f('arguments_lang'))
+				$version['arguments'] = array_merge(
+					(array) unserialize($this->db->f('arguments')),
+					(array) unserialize($this->db->f('arguments_lang'))
 				);
 				$version['state'] = $this->db->f('state');
 				$version['id'] = $this->db->f('version_id');
@@ -261,10 +248,10 @@
 		 * @param int/array $states state-id's
 		 * @return array of block-objects, without content
 		 */
-		function getallblocks($cat_list,$states)
+		function &getallblocks($cat_list,$states)
 		{
 			$cat_list[] = CURRENT_SITE_ID;
-			$sql = "SELECT COUNT(state) AS cnt,t1.block_id,area,cat_id,page_id,viewable,state FROM $this->blocks_table AS t1,$this->content_table as t2 WHERE ".
+			$sql = "SELECT COUNT(state) AS cnt,t1.block_id AS id,area,cat_id,page_id,viewable AS view,state FROM $this->blocks_table AS t1,$this->content_table as t2 WHERE ".
 				$this->db->expression($this->content,array(
 					't1.block_id=t2.block_id',
 					'cat_id' => $cat_list,
@@ -273,22 +260,13 @@
 
 			$this->db->query($sql,__LINE__,__FILE__);
 
-			$block = CreateObject('sitemgr.Block_SO',True);
 			$result = array();
-			while ($this->db->next_record())
+			while (($row = $this->db->row(true)))
 			{
-				$id = $this->db->f('block_id');
-				$block->id = $id;
-				$block->area = $this->db->f('area');
-				$block->cat_id = $this->db->f('cat_id');
-				$block->page_id = $this->db->f('page_id');
-				$block->view = $this->db->f('viewable');
-				$block->state = $this->db->f('state');
 				//in cnt we retrieve the numbers of versions that are commitable for a block,
 				//i.e. if there are more than one, it should normally be a prepublished version 
 				//that will replace a preunpublished version
-				$block->cnt =  $this->db->f('cnt');
-				$result[$id] = $block;
+				$result[$row['id']] =& new Block_SO($row);
 			}
 			return $result;
 		}
@@ -302,7 +280,7 @@
 		 * @param boolean $isuser viewer is regular eGW user, not anonymous
 		 * @return array of block-objects, with the latest version-id, but not the content
 		 */
-		function getvisibleblockdefsforarea($area,$cat_list,$page_id,$isadmin,$isuser)
+		function &getvisibleblockdefsforarea($area,$cat_list,$page_id,$isadmin,$isuser)
 		{
 			$viewable[] = SITEMGR_VIEWABLE_EVERBODY;
 			$viewable[] = $isuser ? SITEMGR_VIEWABLE_USER : SITEMGR_VIEWABLE_ANONYMOUS;
@@ -313,9 +291,9 @@
 			{
 				$viewable[] = SITEMGR_VIEWABLE_ANONYMOUS;
 			}
-			$cat_list[] = CURRENT_SITE_ID;	// always included
+			$cat_list[] = CURRENT_SITE_ID;  // always included
 
-			$sql = "SELECT t1.block_id,area,cat_id,page_id,t1.module_id,module_name,state,version_id,sort_order,viewable " . 
+			$sql = "SELECT t1.block_id AS id,area,cat_id,page_id,t1.module_id,module_name,state,version_id AS version,sort_order,viewable AS view " . 
 				"FROM $this->blocks_table AS t1,$this->modules_table AS t2,$this->content_table AS t3 " . 
 				"WHERE t1.module_id = t2.module_id AND t1.block_id=t3.block_id AND ".
 				$this->db->expression($this->blocks_table,array(
@@ -339,22 +317,10 @@
 			
 			$this->db->query($sql,__LINE__,__FILE__);
 
-			$block = CreateObject('sitemgr.Block_SO',True);
 			$result = array();
-			while ($this->db->next_record())
+			while (($row = $this->db->row(true)))
 			{
-				$id = $this->db->f('block_id');
-				$block->id = $id;
-				$block->area = $this->db->f('area');
-				$block->cat_id = $this->db->f('cat_id');
-				$block->page_id = $this->db->f('page_id');
-				$block->module_id = $this->db->f('module_id');
-				$block->module_name = $this->db->f('module_name');
-				$block->view = $this->db->f('viewable');
-				$block->state = $this->db->f('state');
-				$block->version = $this->db->f('version_id');
-				$block->sort_order = $this->db->f('sort_order');
-				$result[$id] = $block;
+				$result[$row['id']] =& new Block_SO($row);
 			}
 			return $result;
 		}
@@ -382,7 +348,7 @@
 		 * Retrives the availible languages for a blocks content-version
 		 * @param int $version_id version-id
 		 * @return array of 2-char language id's
-		 */		 
+		 */    
 		function getlangarrayforversion($version_id)
 		{
 			$this->db->select($this->content_lang_table,'lang',array(
@@ -429,29 +395,20 @@
 		 * @param string $lang 2-char language id
 		 * @return object/boolean block-object or false if not found
 		 */
-		function getblock($block_id,$lang)
+		function &getblock($block_id,$lang)
 		{
 			$lang = $this->db->quote($lang);
-			$sql = "SELECT area,cat_id,page_id,area,t1.module_id,module_name,sort_order,title,viewable".
+			$sql = "SELECT t1.block_id AS id,area,cat_id,page_id,area,t1.module_id,module_name,sort_order,title,viewable AS view".
 				" FROM $this->blocks_table AS t1".
 				" LEFT JOIN $this->modules_table as t2 ON t1.module_id=t2.module_id".
 				" LEFT JOIN $this->blocks_lang_table AS t3 ON (t1.block_id=t3.block_id AND t3.lang=$lang)".
 				" WHERE t1.block_id=".(int)$block_id;
 			
 			$this->db->query($sql,__LINE__,__FILE__);
-			if ($this->db->next_record())
+
+			if (($row = $this->db->row(true)))
 			{
-				$block = CreateObject('sitemgr.Block_SO',True);
-				$block->id = $block_id;
-				$block->cat_id = $this->db->f('cat_id');
-				$block->page_id = $this->db->f('page_id');
-				$block->area = $this->db->f('area');
-				$block->module_id = $this->db->f('module_id');
- 				$block->module_name = $this->db->f('module_name');
- 				$block->sort_order = $this->db->f('sort_order');
- 				$block->title = stripslashes($this->db->f('title'));
- 				$block->view = $this->db->f('viewable');
-				return $block;
+				return new Block_SO($row);
 			}
 			return false;
 		}
@@ -461,22 +418,17 @@
 		 * @param int $block_id block-id
 		 * @return object/boolean limited(!) block-object or false if not found
 		 */
-		function getblockdef($block_id)
+		function &getblockdef($block_id)
 		{
-			$sql = "SELECT cat_id,page_id,area,t1.module_id,module_name".
+			$sql = "SELECT t1.block_id AS id,cat_id,page_id,area,t1.module_id,module_name".
 				" FROM $this->blocks_table AS t1,$this->modules_table AS t2".
 				" WHERE t1.module_id=t2.module_id AND t1.block_id=".(int)$block_id;
+
 			$this->db->query($sql,__LINE__,__FILE__);
-			if ($this->db->next_record())
+
+			if (($row = $this->db->row(true)))
 			{
-				$block = CreateObject('sitemgr.Block_SO',True);
-				$block->id = $block_id;
-				$block->cat_id = $this->db->f('cat_id');
-				$block->page_id = $this->db->f('page_id');
-				$block->area = $this->db->f('area');
-				$block->module_id = $this->db->f('module_id');
- 				$block->module_name = $this->db->f('module_name');
-				return $block;
+				return new Block_SO($row);
 			}
 			return false;
 		}
@@ -496,6 +448,15 @@
 			return $this->db->next_record() ? $this->db->f('title') : false;
 		}
 
+		function getblockstate($block_id)
+		{
+			$cols = array('block_id' => $block_id);
+
+			$this->db->select($this->content_table,'state',$cols,__LINE__,__FILE__);
+				
+			return $this->db->next_record() ? $this->db->f('title') : false;
+		}
+
 		/**
 		 * Save block-data: sort-order and by whom viewable 
 		 * @param object $block block-object
@@ -504,8 +465,8 @@
 		function saveblockdata($block)
 		{
 			return $this->db->update($this->blocks_table,array(
-					'sort_order'	=> $block->sort_order,
-					'viewable'		=> $block->view,
+					'sort_order'  => $block->sort_order,
+					'viewable'    => $block->view,
 				),array('block_id' => $block->id),__LINE__,__FILE__);
 		}
 
@@ -521,8 +482,8 @@
 			return $this->db->insert($this->blocks_lang_table,array(
 					'title' => $title
 				),array(
-					'block_id'	=> $block_id,
-					'lang'		=> $lang,
+					'block_id'  => $block_id,
+					'lang'    => $lang,
 				),__LINE__,__FILE__);
 		}
 
@@ -549,7 +510,7 @@
 		}
 
 		/**
-		 * Save block-data: the language independent state of a version of block-content
+		 * Save block-state
 		 * @param int $block_id block-id
 		 * @param int $version_id version-id
 		 * @param int $state state 
@@ -560,8 +521,8 @@
 			return $this->db->update($this->content_table,array(
 					'state' => $state
 				),array(
-					'version_id'	=> $version_id,
-					'block_id'		=> $block_id,
+					'version_id'  => $version_id,
+					'block_id'    => $block_id,
 				),__LINE__,__FILE__);
 		}
 
@@ -582,8 +543,8 @@
 			return $this->db->insert($this->content_lang_table,array(
 					'arguments_lang' => serialize($data)
 				),array(
-					'version_id'	=> $version_id,
-					'lang'			=> $lang,
+					'version_id'  => $version_id,
+					'lang'      => $lang,
 				),__LINE__,__FILE__);
 		}
 
@@ -643,4 +604,4 @@
 					'block_id' => $block_id,
 				), __LINE__,__FILE__);
 		}
-	}
+}
\ No newline at end of file
