@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.module_filecontents.inc.php,v 1.6.2.1 2005/02/27 08:20:35 ralfbecker Exp $ */
+	/* $Id: class.module_filecontents.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 class module_filecontents extends Module 
 {
@@ -77,7 +77,7 @@ class module_filecontents extends Module
 			}
 			if (preg_match('/<meta http-equiv="content-type" content="text\/html; ?charset=([^"]+)"/i',$one_line,$parts))
 			{
-				$ret = $GLOBALS['phpgw']->translation->convert($ret,$parts[1]);
+				$ret = $GLOBALS['egw']->translation->convert($ret,$parts[1]);
 			}
 		}
 		return $ret;
@@ -87,7 +87,7 @@ class module_filecontents extends Module
 	//
 	function in_docroot($path)
 	{
-		$docroots = array(PHPGW_SERVER_ROOT,$_SERVER['DOCUMENT_ROOT']);
+		$docroots = array(EGW_SERVER_ROOT,$_SERVER['DOCUMENT_ROOT']);
 		$path = realpath($path);
 
 		foreach ($docroots as $docroot)
