@@ -10,7 +10,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.mos_ui.inc.php,v 1.8.2.1 2005/03/13 23:32:48 ralfbecker Exp $ */
+	/* $Id: class.mos_ui.inc.php 20295 2006-02-15 12:31:25Z  $ */
 
 	function mosCountModules($contentarea)
 	{
@@ -47,6 +47,14 @@
 	{
 		echo $url;
 	}
+	
+	function mosShowHead()
+	{
+		global $objui,$mosConfig_sitename;
+		echo "\t\t<title>$mosConfig_sitename</title>\n";
+		$objui->t->loadfile(realpath(dirname(__FILE__).'/../mos-compat/metadata.tpl'));
+		echo $objui->t->parse();
+	}
 
 	// this is just to make some templates work, it does nothing actually atm.
 	class mos_database
@@ -69,7 +77,7 @@
 		{
 			$themesel = $GLOBALS['sitemgr_info']['themesel'];
 			$this->templateroot = $GLOBALS['sitemgr_info']['site_dir'] . SEP . 'templates' . SEP . $themesel;
-			$this->t = new Template3($this->templateroot);
+			$this->t =& new Template3($this->templateroot);
 			$this->t->transformer_root = $this->mos_compat_dir = realpath(dirname(__FILE__).'/../mos-compat');
 		}
 
@@ -105,25 +113,27 @@
 		function generatePage()
 		{
 			global $database;
-			$database = new mos_database;
+			$database =& new mos_database;
 
 			// add a content-type header to overwrite an existing default charset in apache (AddDefaultCharset directiv)
-			header('Content-type: text/html; charset='.$GLOBALS['phpgw']->translation->charset());
+			header('Content-type: text/html; charset='.$GLOBALS['egw']->translation->charset());
 
 			// define global $mosConfig vars
-			global $mosConfig_sitename,$mosConfig_live_site,$modConfig_offset,$cur_template;
+			global $mosConfig_sitename,$mosConfig_live_site,$mosConfig_absolute_path,$mosConfig_offset,$cur_template;
 			$mosConfig_sitename = $this->t->get_meta('sitename').': '.$this->t->get_meta('title');
 			$mosConfig_live_site = substr($GLOBALS['sitemgr_info']['site_url'],0,-1);
-			$mosConfig_offset = (int) $GLOBALS['phpgw_info']['user']['preferences']['common']['tz_offset'];
+			$mosConfig_offset = (int) $GLOBALS['egw_info']['user']['preferences']['common']['tz_offset'];
+			$mosConfig_absolute_path = $GLOBALS['sitemgr_info']['site_dir'];
 			$cur_template = $GLOBALS['sitemgr_info']['themesel'];
 			define('_DATE_FORMAT_LC',str_replace(array('d','m','M','Y'),array('%d','%m','%b','%Y'),
-				$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']).
-				($GLOBALS['phpgw_info']['user']['preferences']['common']['timeformat']=='12'?' %I:%M %p' : ' %H:%M'));
-			define('_DATE_FORMAT',$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'].
-				($GLOBALS['phpgw_info']['user']['preferences']['common']['timeformat']=='12'?' h:i a' : ' H:i'));
+				$GLOBALS['egw_info']['user']['preferences']['common']['dateformat']).
+				($GLOBALS['egw_info']['user']['preferences']['common']['timeformat']=='12'?' %I:%M %p' : ' %H:%M'));
+			define('_DATE_FORMAT',$GLOBALS['egw_info']['user']['preferences']['common']['dateformat'].
+				($GLOBALS['egw_info']['user']['preferences']['common']['timeformat']=='12'?' h:i a' : ' H:i'));
 			define('_SEARCH_BOX',lang('Search').' ...');
-			define( '_ISO','charset='.$GLOBALS['phpgw']->translation->charset());
+			define( '_ISO','charset='.$GLOBALS['egw']->translation->charset());
 			define( '_VALID_MOS',True );
+			define( '_VALID_MYCSSMENU',True );
 			ini_set('include_path',$this->mos_compat_dir.(strtoupper(substr(PHP_OS, 0, 3)) == 'WIN' ? ';' : ':').ini_get('include_path'));
 
 			ob_start();		// else some modules like the redirect wont work
