@@ -10,8 +10,11 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: footer.php,v 1.1 2004/02/22 01:46:25 ralfbecker Exp $ */
+	/* $Id: footer.php 20295 2006-02-15 12:31:25Z  $ */
 
 	// This file echos the contentarea 'footer'
 	global $objui;
 	echo $objui->t->process_blocks('footer');
+	
+	// this is necessary to get wz_tooltips
+	echo $GLOBALS['phpgw_info']['flags']['need_footer'];
