@@ -10,32 +10,54 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: xmlrpc.php,v 1.19.2.2 2005/09/10 10:33:25 ralfbecker Exp $ */
-	/* $Source: /cvsroot/egroupware/egroupware/xmlrpc.php,v $ */
+	/* $Id: xmlrpc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Source$ */
+	/*list($usec, $sec) = explode(" ", microtime());
+	$GLOBALS['concisus']['script_start'] = ((float)$usec + (float)$sec);*/
 
-	$GLOBALS['phpgw_info'] = array();
-	$GLOBALS['phpgw_info']['flags'] = array(
+	$GLOBALS['egw_info'] = array();
+	$GLOBALS['egw_info']['flags'] = array(
 		'currentapp'            => 'login',
 		'noheader'              => True,
 		'disable_Template_class' => True
 	);
 	include('header.inc.php');
 
+	//viniciuscb: a secure way to know if we're in a xmlrpc call...
+	$GLOBALS['egw_info']['server']['xmlrpc'] = true;
+
 	$server = CreateObject('phpgwapi.xmlrpc_server');
+
 	/* uncomment here if you want to show all of the testing functions for compatibility */
-	//include(PHPGW_API_INC . '/xmlrpc.interop.php');
-	
-	if (!$GLOBALS['phpgw_info']['server']['xmlrpc_enabled'])
+	//include(EGW_API_INC . '/xmlrpc.interop.php');
+
+	if (!$GLOBALS['egw_info']['server']['xmlrpc_enabled'])
 	{
 		$server->xmlrpc_error(9999,'xmlrpc service is not enabled in the eGroupWare system configuration');
 		exit;
 	}
 
-	/* Note: this command only available under Apache */
+	/* Note: this command only available natively in Apache (Netscape/iPlanet/SunONE in php >= 4.3.3) */
+	if(!function_exists('getallheaders'))
+	{
+		function getallheaders()
+		{
+			settype($headers,'array');
+			foreach($_SERVER as $h => $v)
+			{
+				if(ereg('HTTP_(.+)',$h,$hp))
+				{
+					$headers[$hp[1]] = $v;
+				}
+			}
+			return $headers;
+		}
+	}
 	$headers = getallheaders();
+
 	//print_r($headers);
 	$isodate = $headers['isoDate'] ? $headers['isoDate'] : $headers['isodate'];
-	$isodate = ($isodate == 'simple' || strstr($_SERVER['HTTP_USER_AGENT'],"vbXMLRPC")) ? True : False;
+	$isodate = ($isodate == 'simple') ? True : False;
 	$server->setSimpleDate($isodate);
 	$auth_header = $headers['Authorization'] ? $headers['Authorization'] : $headers['authorization'];
 
@@ -49,7 +71,17 @@
 		$sessionid = get_var('sessionid',array('COOKIE','GET'));
 		$kp3 = get_var('kp3',array('COOKIE','GET'));
 	}
-	$server->authed = $GLOBALS['phpgw']->session->verify($sessionid,$kp3);
+	$server->authed = $GLOBALS['egw']->session->verify($sessionid,$kp3);
+
+	if (!$server->authed and isset($_SERVER['PHP_AUTH_USER']) and isset($_SERVER['PHP_AUTH_PW']))
+	{
+		$authed = $GLOBALS['egw']->session->create($login.'@'.$domain, $_SERVER['PHP_AUTH_PW'], 'text');
+
+		if ($authed)
+		{
+			$server->authed = true;
+		}
+	}
 
 	$server->service($_SERVER['HTTP_RAW_POST_DATA']);
 ?>
